<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Illuminate\Support\Facades\Log;

use App\Models\LoadAppointment;
use App\Models\LoadAppointmentLog;

use DB;
use Carbon\Carbon;

class AppointmentReminderCron extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature    = 'appointmentreminder:cron';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description  = 'Send Appointment Reminder 10 min cron';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        Log::info('Cron Start : Appointment reminder ( '.Carbon::now()->format('Y-m-d H:i:s').' )');

        $currentDateTime            = Carbon::now(); // 2023-06-15 14:36:00
        $startDateTime              = Carbon::now()->addHours(4); // 2023-06-15 18:36:00
        $endDateTime                = Carbon::now()->addHours(4)->addMinutes(10); // 2023-06-15 18:46:00

        $loadAppointments           = LoadAppointment::query()
            ->where('reminder_type', '4 Hours')
            ->where('reminder_status', 1)
            ->where('status', '!=', 1)
            ->whereBetween(DB::raw("CONCAT(request_date, ' ', request_time)"), [$startDateTime, $endDateTime])
            ->whereDoesntHave('logs', function ($query) {
                $query->whereIn('review_user_type', ['Broker', 'Broker Contact']);
                // $query->orWhere('review_status', 1);
            })
            ->get();
        if($loadAppointments->isNotEmpty()){
            foreach ($loadAppointments as $key => $loadAppointment) {
                Log::info('4 Hours Appointment '.$loadAppointment->id.' : Started at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                appointmentRequestSend($loadAppointment);
                Log::info('4 Hours Appointment '.$loadAppointment->id.' : Ended at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
            }
        }

        $currentDateTime            = Carbon::now(); // 2023-06-15 09:26:24
        $startDateTime              = Carbon::now()->addDay(); // 2023-06-16 09:26:24
        $endDateTime                = Carbon::now()->addDay()->addMinutes(10); // 2023-06-16 09:36:24

        $loadAppointments           = LoadAppointment::query()
            ->where('reminder_type', '24 Hours')
            ->where('reminder_status', 1)
            ->where('status', '!=', 1)
            ->whereBetween(DB::raw("CONCAT(request_date, ' ', request_time)"), [$startDateTime, $endDateTime])
            ->whereDoesntHave('logs', function ($query) {
                $query->whereIn('review_user_type', ['Broker', 'Broker Contact']);
                // $query->orWhere('review_status', 1);
            })
            ->get();
        if($loadAppointments->isNotEmpty()){
            foreach ($loadAppointments as $key => $loadAppointment) {
                Log::info('24 Hours Appointment '.$loadAppointment->id.' : Started at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                appointmentRequestSend($loadAppointment);
                Log::info('24 Hours Appointment '.$loadAppointment->id.' : Ended at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
            }
        }

        for ($i = 1; $i <= 24; $i++) {
            // Your logic here
            // Use $i as the current iteration value
            $currentDateTime        = Carbon::now(); // 2023-06-15 14:36:00
            $startDateTime          = Carbon::now()->addHours($i); // 2023-06-15 18:36:00
            $endDateTime            = Carbon::now()->addHours($i)->addMinutes(10); // 2023-06-15 18:46:00

            $loadAppointments       = LoadAppointment::query()
                ->where('reminder_type', 'Custom')
                ->where('reminder_repeat_every', 0)
                ->where('reminder_custom_hours', $i)
                ->where('reminder_status', 1)
                ->where('status', '!=', 1)
                ->whereBetween(DB::raw("CONCAT(request_date, ' ', request_time)"), [$startDateTime, $endDateTime])
                ->whereDoesntHave('logs', function ($query) {
                    $query->whereIn('review_user_type', ['Broker', 'Broker Contact']);
                    // $query->orWhere('review_status', 1);
                })
                ->get();
            if($loadAppointments->isNotEmpty()){
                foreach ($loadAppointments as $key => $loadAppointment) {
                    Log::info('Custom Appointment '.$loadAppointment->id.' : Started at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                    appointmentRequestSend($loadAppointment);
                    Log::info('Custom Appointment '.$loadAppointment->id.' : Ended at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                }
            }

            $currentDateTime        = Carbon::now(); // 2023-06-15 11:38:52
            $startDateTime          = Carbon::now()->subHours($i); // 2023-06-15 10:38:52
            $endDateTime            = Carbon::now()->subHours($i)->addMinutes(10); // 2023-06-15 10:48:52

            $loadAppointments       = LoadAppointment::query()
                ->where('reminder_type', 'Custom')
                ->where('reminder_repeat_every', 1)
                ->where('reminder_custom_hours', $i)
                ->where(function ($query) use ($startDateTime, $endDateTime) {
                    $query->whereBetween('reminder_repeat_date_time', [$startDateTime, $endDateTime])
                        ->orWhereNull('reminder_repeat_date_time');
                })
                ->where('reminder_status', 1)
                ->where('status', '!=', 1)
                ->whereDoesntHave('logs', function ($query) {
                    $query->whereIn('review_user_type', ['Broker', 'Broker Contact']);
                    // $query->orWhere('review_status', 1);
                })
                ->get();
            if($loadAppointments->isNotEmpty()){
                foreach ($loadAppointments as $key => $loadAppointment) {
                    Log::info('Repeat Every Appointment '.$loadAppointment->id.' : Started at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                    if(appointmentRequestSend($loadAppointment)){
                        $loadAppointment->reminder_repeat_date_time = $currentDateTime;
                        $loadAppointment->save();
                    }
                    Log::info('Repeat Every Appointment '.$loadAppointment->id.' : Ended at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                }
            }
        }

        Log::info('Cron End : Appointment reminder ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
    }
}
