<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Illuminate\Support\Facades\Log;

use App\Models\Gallery;

use DB;
use Carbon\Carbon;

class DocumentRequestReminderCron extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature    = 'documentRequestReminder:cron';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description  = 'Document Request Reminder Cron';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        Log::info('Cron Start : Document Request Reminder ( '.Carbon::now()->format('Y-m-d H:i:s').' )');

        /* Document Request 4 Hours Reminder - START */
        $currentDateTime        = Carbon::now(); // 2023-07-14 05:00:00
        $startDateTime          = Carbon::now()->subHours(4); // 2023-07-14 01:00:00
        $endDateTime            = Carbon::now()->subHours(4)->addMinutes(10); //2023-07-14 01:10:00

        $galleryDocuments       = Gallery::query()
            ->where('source', 'drivers')
            ->whereNull('uploaded_date')
            ->whereNotNull('reminder_on')
            ->where('reminder_type', '4 Hours')
            ->where('reminder_repeat', 0)
            ->whereBetween('created_at', [$startDateTime, $endDateTime])
            ->get();

        if($galleryDocuments->isNotEmpty()){
            foreach ($galleryDocuments as $galleryDocument) {
                Log::info('4 Hours Document Request Reminder '.$galleryDocument->id.' : Started at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                documentRequestReminder($galleryDocument);
                Log::info('4 Hours Document Request Reminder '.$galleryDocument->id.' : Ended at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
            }
        }

        $currentDateTime        = Carbon::now(); // 2023-07-14 05:00:00
        $startDateTime          = Carbon::now()->subHours(4); // 2023-07-14 01:00:00
        $endDateTime            = Carbon::now()->subHours(4)->addMinutes(10); // 2023-07-14 01:10:00

        $galleryDocuments       = Gallery::query()
            ->where('source', 'drivers')
            ->whereNull('uploaded_date')
            ->whereNotNull('reminder_on')
            ->where('reminder_type', '4 Hours')
            ->where('reminder_repeat', 1)
            ->where(function ($query) use ($startDateTime, $endDateTime) {
                $query->whereBetween('reminder_repeat_date_time', [$startDateTime, $endDateTime]);
            })
            ->get();

        if($galleryDocuments->isNotEmpty()){
            foreach ($galleryDocuments as $galleryDocument) {
                Log::info('Repeat 4 Hours Document Request Reminder '.$galleryDocument->id.' : Started at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                if(documentRequestReminder($galleryDocument)){
                    $galleryDocument->reminder_repeat_date_time = $currentDateTime;
                    $galleryDocument->save();
                }
                Log::info('Repeat 4 Hours Document Request Reminder '.$galleryDocument->id.' : Ended at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
            }
        }
        /* Document Request 4 Hours Reminder - END */

        /* Document Request 24 Hours Reminder - START */
        $currentDateTime        = Carbon::now(); // 2023-07-14 05:30:00
        $startDateTime          = Carbon::now()->subDay(); // 2023-07-13 05:30:00
        $endDateTime            = Carbon::now()->subDay()->addMinutes(10); // 2023-07-13 05:40:00

        $galleryDocuments       = Gallery::query()
            ->where('source', 'drivers')
            ->whereNull('uploaded_date')
            ->whereNotNull('reminder_on')
            ->where('reminder_type', '24 Hours')
            ->where('reminder_repeat', 0)
            ->whereBetween('created_at', [$startDateTime, $endDateTime])
            ->get();

        if($galleryDocuments->isNotEmpty()){
            foreach ($galleryDocuments as $galleryDocument) {
                Log::info('24 Hours Document Request Reminder '.$galleryDocument->id.' : Started at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                documentRequestReminder($galleryDocument);
                Log::info('24 Hours Document Request Reminder '.$galleryDocument->id.' : Ended at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
            }
        }

        $currentDateTime        = Carbon::now(); // 2023-07-13 11:53:45
        $startDateTime          = Carbon::now()->subDay(); // 2023-07-12 11:53:45
        $endDateTime            = Carbon::now()->subDay()->addMinutes(10); // 2023-07-12 12:03:45

        $galleryDocuments       = Gallery::query()
            ->where('source', 'drivers')
            ->whereNull('uploaded_date')
            ->whereNotNull('reminder_on')
            ->where('reminder_type', '24 Hours')
            ->where('reminder_repeat', 1)
            ->where(function ($query) use ($startDateTime, $endDateTime) {
                $query->whereBetween('reminder_repeat_date_time', [$startDateTime, $endDateTime]);
            })
            ->get();

        if($galleryDocuments->isNotEmpty()){
            foreach ($galleryDocuments as $galleryDocument) {
                Log::info('Repeat 24 Hours Document Request Reminder '.$galleryDocument->id.' : Started at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                if(documentRequestReminder($galleryDocument)){
                    $galleryDocument->reminder_repeat_date_time = $currentDateTime;
                    $galleryDocument->save();
                }
                Log::info('Repeat 24 Hours Document Request Reminder '.$galleryDocument->id.' : Ended at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
            }
        }
        /* Document Request 24 Hours Reminder - END */

        /* Document Request Custom Hours Reminder - START */
        for ($i = 1; $i <= 24; $i++) { // Use $i as the Custom Hours
            $currentDateTime    = Carbon::now();
            $startDateTime      = Carbon::now()->subHours($i);
            $endDateTime        = Carbon::now()->subHours($i)->addMinutes(10);

            $galleryDocuments   = Gallery::query()
                ->where('source', 'drivers')
                ->whereNull('uploaded_date')
                ->whereNotNull('reminder_on')
                ->where('reminder_type', 'Custom')
                ->where('reminder_custom_hours', $i)
                ->where('reminder_repeat', 0)
                ->whereBetween('created_at', [$startDateTime, $endDateTime])
                ->get();

            if($galleryDocuments->isNotEmpty()){
                foreach ($galleryDocuments as $galleryDocument) {
                    Log::info($i.' Hours Document Request Reminder '.$galleryDocument->id.' : Started at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                    documentRequestReminder($galleryDocument);
                    Log::info($i.' Hours Document Request Reminder '.$galleryDocument->id.' : Ended at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                }
            }

            $currentDateTime    = Carbon::now();
            $startDateTime      = Carbon::now()->subHours($i);
            $endDateTime        = Carbon::now()->subHours($i)->addMinutes(10);

            $galleryDocuments   = Gallery::query()
                ->where('source', 'drivers')
                ->whereNull('uploaded_date')
                ->whereNotNull('reminder_on')
                ->where('reminder_custom_hours', $i)
                ->where('reminder_repeat', 1)
                ->where(function ($query) use ($startDateTime, $endDateTime) {
                    $query->whereBetween('reminder_repeat_date_time', [$startDateTime, $endDateTime]);
                })
                ->get();

            if($galleryDocuments->isNotEmpty()){
                foreach ($galleryDocuments as $galleryDocument) {
                    Log::info('Repeat '.$i.' Hours Document Request Reminder '.$galleryDocument->id.' : Started at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                    if(documentRequestReminder($galleryDocument)){
                        $galleryDocument->reminder_repeat_date_time = $currentDateTime;
                        $galleryDocument->save();
                    }
                    Log::info('Repeat '.$i.' Hours Document Request Reminder '.$galleryDocument->id.' : Ended at ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                }
            }
        }
        /* Document Request Custom Hours Reminder - END */

        Log::info('Cron End : Document Request Reminder ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
    }
}
