<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Mail;

use App\Models\LoadStop;
use App\Models\LoadDetail;

use App\Mail\DropHook\TrailerRetrievalReminder;

use Carbon\Carbon;

class DropHookRetrievalReminder extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature    = 'drophookretrievalreminder:cron';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description  = 'Drop & Hook Retrieval Reminder';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        Log::info('Cron Start : Drop & Hook retrieval reminder ( '.Carbon::now()->format('Y-m-d H:i:s').' )');

        $currentDateTime                                    = Carbon::now()->format('Y-m-d H:i'); // Carbon::parse('2023-11-28 07:24:00')->format('Y-m-d H:i');

        $load_details                                       = LoadDetail::query();
        $load_details->whereHas('driver', function ($query) {
            $query->whereNull('drivers.deleted_at');
        });
        $load_details->where( function($query) {
            $query->whereIn('load_details.load_type', [0, 6]) // 0 = OCCUPIED, 6 = TONU
                ->where(function($q) {
                    $q->whereNull('load_details.is_on_hold')->orWhereIn('load_details.is_on_hold', [0, 1]);
                })
                ->where('load_details.is_disable', 0);
        });
        $load_details->where(function($query) use ($currentDateTime) {
            $query->where(function($q) use ($currentDateTime) {
                $q->whereIn('load_details.shipper_drop_trailer_schedule', [1, 2]) // 0=Live, 1=Drop Trailer, 2=Drop & Hook
                    ->where('load_details.shipper_drop_trailer_reminder_status', 1)
                    ->whereRaw("DATE_FORMAT(load_details.shipper_drop_trailer_reminder_date_time, '%Y-%m-%d %H:%i') = ?", [$currentDateTime]);
            })->orWhere(function ($q) use ($currentDateTime) {
                $q->whereIn('load_details.delivery_drop_trailer_schedule', [1, 2]) // 0=Live, 1=Drop Trailer, 2=Drop & Hook
                    ->where('load_details.delivery_drop_trailer_reminder_status', 1)
                    ->whereRaw("DATE_FORMAT(load_details.delivery_drop_trailer_reminder_date_time, '%Y-%m-%d %H:%i') = ?", [$currentDateTime]);
            });
        });
        $load_details                                       = $load_details->get();
        if($load_details->isNotEmpty()){
            foreach ($load_details as $key => $load_detail) {
                if($currentDateTime == Carbon::parse($load_detail->shipper_drop_trailer_reminder_date_time)->format('Y-m-d H:i')){
                    // Dates are equal
                    if(isset($load_detail->shipper_drop_trailer_reminder_on)){
                        $reminder_on                        = explode(',', $load_detail->shipper_drop_trailer_reminder_on);
                        // Remove empty strings and null values from the array
                        $reminder_on                        = array_filter($reminder_on, function ($value) {
                            return $value !== "" && $value !== null;
                        });
                        if(!empty($reminder_on)){
                            $addresses                      = [];
                            if(isset($load_detail->shipper_address_one) && $load_detail->shipper_address_one!==''){
                                $addresses[]                = $load_detail->shipper_address_one;
                            }
                            if(isset($load_detail->shipper_address_two) && $load_detail->shipper_address_two!==''){
                                $addresses[]                = $load_detail->shipper_address_two;
                            }
                            if(isset($load_detail->shipper_city) && $load_detail->shipper_city!==''){
                                $addresses[]                = $load_detail->shipper_city;
                            }
                            if(isset($load_detail->shipper_state) && $load_detail->shipper_state!==''){
                                $addresses[]                = $load_detail->shipper_state;
                            }
                            if(isset($load_detail->shipper_zip) && $load_detail->shipper_zip!==''){
                                $addresses[]                = $load_detail->shipper_zip;
                            }
                            $addresses                      = implode(', ', $addresses);

                            $trailer_id                     = $load_detail->shipper_drop_trailer_id;
                            if((isset($load_detail->shipper_drop_trailer_match) && $load_detail->shipper_drop_trailer_match == 0) && (isset($load_detail->shipper_verified_drop_trailer_id) && $load_detail->shipper_verified_drop_trailer_id != '')){
                                $trailer_id                 = $load_detail->shipper_verified_drop_trailer_id;
                            }

                            $details                        = [];
                            $details['name']                = $load_detail->driver->full_name;
                            $details['id']                  = $load_detail->id;
                            $details['load_number']         = $load_detail->load_type == 0 || $load_detail->load_type == 6 ? $load_detail->load_number : getLoadTypeList()[$load_detail->load_type];
                            $details['addresses']           = $addresses;
                            $details['date']                = isset($load_detail->shipper_timezone_abbr) ? convertTimeToUSERzone(['str' => $load_detail->shipper_drop_trailer_reminder_date_time, 'toFormat' => getTimeLayout(), 'fromFormat' => 'Y-m-d H:i:s', 'abbr' => $load_detail->shipper_timezone_abbr]) : dateTimeFormatter($load_detail->shipper_drop_trailer_reminder_date_time, getTimeLayout(), 'Y-m-d H:i:s');
                            $details['trailer_id']          = $trailer_id;

                            $details['link']                = route('driver.admin.mytrips.index', ['active-tab' => 'nav-current-dispatch']); // 'http://127.0.0.1:8001/driver-admin/mytrips?active-tab=nav-current-dispatch';

                            foreach ($reminder_on as $key => $source) {
                                if($source == '1' && isset($load_detail->driver->email)){
                                    Log::info('Pickup Send Email : '.$load_detail->driver->email.' ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                                    Log::info(implode(', ', $details));

                                    try {
                                        Mail::to($load_detail->driver->email)->send(new TrailerRetrievalReminder($details));
                                    } catch (\Swift_TransportException $e) {
                                        // Handle transport exception (e.g., connection failure)

                                        // Log the error message
                                        Log::error('Email sending failed: ' . $e->getMessage());

                                        // Optionally, you can re-throw the exception if desired
                                        // throw $e;
                                    } catch (\Exception $e) {
                                        // Handle any other exception

                                        // Log the error message
                                        Log::error('An error occurred while sending the email: ' . $e->getMessage());

                                        // Optionally, you can re-throw the exception if desired
                                        // throw $e;
                                    }
                                }else if($source == '2' && isset($load_detail->driver->cell_phone)){
                                    Log::info('Pickup Send SMS : '.$load_detail->driver->cell_phone.' ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                                    Log::info(implode(', ', $details));

                                    // Twilio's credentials are fetched from company table
                                    $getCompanyTwilioData   = getCompanyTwilioData($load_detail->driver->company_id);
                                    if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
                                        $messageBody        = "Drop Trailer reminder notification: ".$details['name']."you have a trailer pickup reminder set for ".$details['date']." for load number: ".$details['load_number']." at: ".$details['addresses']." You are going to be picking up trailer: ".$details['trailer_id']." Please confirm you pick up the correct trailer\n".$details['link'];
                                        sendSMS($load_detail->driver->cell_phone, $messageBody, $getCompanyTwilioData);
                                    }
                                }
                            }
                        }
                    }
                }
                if($currentDateTime == Carbon::parse($load_detail->delivery_drop_trailer_reminder_date_time)->format('Y-m-d H:i')){
                    // Dates are equal
                    if(isset($load_detail->delivery_drop_trailer_reminder_on)){
                        $reminder_on                        = explode(',', $load_detail->delivery_drop_trailer_reminder_on);
                        // Remove empty strings and null values from the array
                        $reminder_on                        = array_filter($reminder_on, function ($value) {
                            return $value !== "" && $value !== null;
                        });
                        if(!empty($reminder_on)){
                            $addresses                      = [];
                            if(isset($load_detail->delivery_address_one) && $load_detail->delivery_address_one!==''){
                                $addresses[]                = $load_detail->delivery_address_one;
                            }
                            if(isset($load_detail->delivery_address_two) && $load_detail->delivery_address_two!==''){
                                $addresses[]                = $load_detail->delivery_address_two;
                            }
                            if(isset($load_detail->delivery_city) && $load_detail->delivery_city!==''){
                                $addresses[]                = $load_detail->delivery_city;
                            }
                            if(isset($load_detail->delivery_state) && $load_detail->delivery_state!==''){
                                $addresses[]                = $load_detail->delivery_state;
                            }
                            if(isset($load_detail->delivery_zip) && $load_detail->delivery_zip!==''){
                                $addresses[]                = $load_detail->delivery_zip;
                            }
                            $addresses                      = implode(', ', $addresses);

                            $trailer_id                     = $load_detail->delivery_drop_trailer_id;
                            if((isset($load_detail->delivery_drop_trailer_match) && $load_detail->delivery_drop_trailer_match == 0) && (isset($load_detail->delivery_verified_drop_trailer_id) && $load_detail->delivery_verified_drop_trailer_id != '')){
                                $trailer_id                 = $load_detail->delivery_verified_drop_trailer_id;
                            }

                            $details                        = [];
                            $details['name']                = $load_detail->driver->full_name;
                            $details['id']                  = $load_detail->id;
                            $details['load_number']         = $load_detail->load_type == 0 || $load_detail->load_type == 6 ? $load_detail->load_number : getLoadTypeList()[$load_detail->load_type];
                            $details['addresses']           = $addresses;
                            $details['date']                = isset($load_detail->delivery_timezone_abbr) ? convertTimeToUSERzone(['str' => $load_detail->delivery_drop_trailer_reminder_date_time, 'toFormat' => getTimeLayout(), 'fromFormat' => 'Y-m-d H:i:s', 'abbr' => $load_detail->delivery_timezone_abbr]) : dateTimeFormatter($load_detail->delivery_drop_trailer_reminder_date_time, getTimeLayout(), 'Y-m-d H:i:s');
                            $details['trailer_id']          = $trailer_id;
                            $details['link']                = route('driver.admin.mytrips.index', ['active-tab' => 'nav-current-dispatch']);

                            foreach ($reminder_on as $key => $source) {
                                if($source == '1' && isset($load_detail->driver->email)){
                                    Log::info('Delivery Send Email : '.$load_detail->driver->email.' ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                                    Log::info(implode(', ', $details));

                                    try {
                                        Mail::to($load_detail->driver->email)->send(new TrailerRetrievalReminder($details));
                                    } catch (\Swift_TransportException $e) {
                                        // Handle transport exception (e.g., connection failure)

                                        // Log the error message
                                        Log::error('Email sending failed: ' . $e->getMessage());

                                        // Optionally, you can re-throw the exception if desired
                                        // throw $e;
                                    } catch (\Exception $e) {
                                        // Handle any other exception

                                        // Log the error message
                                        Log::error('An error occurred while sending the email: ' . $e->getMessage());

                                        // Optionally, you can re-throw the exception if desired
                                        // throw $e;
                                    }
                                }else if($source == '2' && isset($load_detail->driver->cell_phone)){
                                    Log::info('Delivery Send SMS : '.$load_detail->driver->cell_phone.' ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                                    Log::info(implode(', ', $details));

                                    // Twilio's credentials are fetched from company table
                                    $getCompanyTwilioData   = getCompanyTwilioData($load_detail->driver->company_id);
                                    if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
                                        $messageBody        = "Drop Trailer reminder notification: ".$details['name']."you have a trailer pickup reminder set for ".$details['date']." for load number: ".$details['load_number']." at: ".$details['addresses']." You are going to be picking up trailer: ".$details['trailer_id']." Please confirm you pick up the correct trailer\n".$details['link'];
                                        sendSMS($load_detail->driver->cell_phone, $messageBody, $getCompanyTwilioData);
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }

        $load_stops                                         = LoadStop::query();
        $load_stops->whereHas('loads.load_detail.driver', function ($query) {
            $query->whereNull('drivers.deleted_at');
        });
        $load_stops->whereHas('loads.load_detail', function ($query) {
            $query->where( function($query) {
                $query->whereIn('load_details.load_type', [0, 6]) // 0 = OCCUPIED, 6 = TONU
                    ->where(function($q) {
                        $q->whereNull('load_details.is_on_hold')->orWhereIn('load_details.is_on_hold', [0, 1]);
                    })
                    ->where('load_details.is_disable', 0);
            });
        });
        $load_stops->where(function($query) use ($currentDateTime) {
            $query->where(function($q) use ($currentDateTime) {
                $q->whereIn('load_stops.drop_trailer_schedule', [1, 2]) // 0=Live, 1=Drop Trailer, 2=Drop & Hook
                    ->where('load_stops.drop_trailer_reminder_status', 1)
                    ->whereRaw("DATE_FORMAT(load_stops.drop_trailer_reminder_date_time, '%Y-%m-%d %H:%i') = ?", [$currentDateTime]);
            });
        });
        $load_stops                                         = $load_stops->get();
        if($load_stops->isNotEmpty()){
            foreach ($load_stops as $key => $load_stop) {
                if($currentDateTime == Carbon::parse($load_stop->drop_trailer_reminder_date_time)->format('Y-m-d H:i')){
                    // Dates are equal
                    if(isset($load_stop->drop_trailer_reminder_on)){
                        $reminder_on                        = explode(',', $load_stop->drop_trailer_reminder_on);
                        // Remove empty strings and null values from the array
                        $reminder_on                        = array_filter($reminder_on, function ($value) {
                            return $value !== "" && $value !== null;
                        });
                        if(!empty($reminder_on)){
                            $addresses                      = [];
                            if(isset($load_stop->address_one) && $load_stop->address_one!==''){
                                $addresses[]                = $load_stop->address_one;
                            }
                            if(isset($load_stop->address_two) && $load_stop->address_two!==''){
                                $addresses[]                = $load_stop->address_two;
                            }
                            if(isset($load_stop->city) && $load_stop->city!==''){
                                $addresses[]                = $load_stop->city;
                            }
                            if(isset($load_stop->state) && $load_stop->state!==''){
                                $addresses[]                = $load_stop->state;
                            }
                            if(isset($load_stop->zip) && $load_stop->zip!==''){
                                $addresses[]                = $load_stop->zip;
                            }
                            $addresses                      = implode(', ', $addresses);

                            $trailer_id                     = $load_stop->drop_trailer_id;
                            if((isset($load_stop->drop_trailer_match) && $load_stop->drop_trailer_match == 0) && (isset($load_stop->verified_drop_trailer_id) && $load_stop->verified_drop_trailer_id != '')){
                                $trailer_id                 = $load_stop->verified_drop_trailer_id;
                            }

                            $details                        = [];
                            $details['name']                = $load_stop->loads->load_detail->driver->full_name;
                            $details['id']                  = $load_stop->loads->load_detail->id;
                            $details['load_number']         = $load_stop->loads->load_detail->load_type == 0 || $load_stop->loads->load_detail->load_type == 6 ? $load_stop->loads->load_detail->load_number : getLoadTypeList()[$load_stop->loads->load_detail->load_type];
                            $details['addresses']           = $addresses;
                            $details['date']                = isset($load_stop->timezone_abbr) ? convertTimeToUSERzone(['str' => $load_stop->drop_trailer_reminder_date_time, 'toFormat' => getTimeLayout(), 'fromFormat' => 'Y-m-d H:i:s', 'abbr' => $load_stop->timezone_abbr]) : dateTimeFormatter($load_stop->drop_trailer_reminder_date_time, getTimeLayout(), 'Y-m-d H:i:s');
                            $details['trailer_id']          = $trailer_id;
                            $details['link']                = route('driver.admin.mytrips.index', ['active-tab' => 'nav-current-dispatch']);

                            foreach ($reminder_on as $key => $source) {
                                if($source == '1' && isset($load_stop->loads->load_detail->driver->email)){
                                    Log::info((($load_stop->customer_type == 1) ? 'Pickup' :'Delivery').' Send Email : '.$load_stop->loads->load_detail->driver->email.' ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                                    Log::info(implode(', ', $details));

                                    try {
                                        Mail::to($load_stop->loads->load_detail->driver->email)->send(new TrailerRetrievalReminder($details));
                                    } catch (\Swift_TransportException $e) {
                                        // Handle transport exception (e.g., connection failure)

                                        // Log the error message
                                        Log::error('Email sending failed: ' . $e->getMessage());

                                        // Optionally, you can re-throw the exception if desired
                                        // throw $e;
                                    } catch (\Exception $e) {
                                        // Handle any other exception

                                        // Log the error message
                                        Log::error('An error occurred while sending the email: ' . $e->getMessage());

                                        // Optionally, you can re-throw the exception if desired
                                        // throw $e;
                                    }
                                }else if($source == '2' && isset($load_stop->loads->load_detail->driver->cell_phone)){
                                    Log::info((($load_stop->customer_type == 1) ? 'Pickup' :'Delivery').' Send SMS : '.$load_stop->loads->load_detail->driver->cell_phone.' ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
                                    Log::info(implode(', ', $details));

                                    // Twilio's credentials are fetched from company table
                                    $getCompanyTwilioData   = getCompanyTwilioData($load_stop->loads->load_detail->driver->company_id);
                                    if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
                                        $messageBody        = "Drop Trailer reminder notification: ".$details['name']."you have a trailer pickup reminder set for ".$details['date']." for load number: ".$details['load_number']." at: ".$details['addresses']." You are going to be picking up trailer: ".$details['trailer_id']." Please confirm you pick up the correct trailer\n".$details['link'];
                                        sendSMS($load_stop->loads->load_detail->driver->cell_phone, $messageBody, $getCompanyTwilioData);
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }

        Log::info('Cron End : Drop & Hook retrieval reminder ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
    }
}
