<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Illuminate\Support\Facades\Log;

use App\Models\Truck;
use App\Models\IntegrationSetting;

use App\Models\LoadStop;
use App\Models\LoadDetail;

use GuzzleHttp\Client;
use GuzzleHttp\Exception\ClientException;
use GuzzleHttp\Exception\ServerException;

use Carbon\Carbon;

class RealTimeTruckLocationUpdate extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature    = 'trucklocation:update';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description  = 'Real time truck location update 15min';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        Log::info('Cron Start : Real time truck location update ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
        $query      = Truck::query();
        $query->where(function ($q) {
            $q->whereNotNull('samsara_id')->whereNotNull('vin_number');
        });
        // $query->skip(15)->take(10);
        $results    = $query->get();
        if($results->isNotEmpty()){
            foreach( $results as $key => $truck ) {
                $getAPIKey                          = IntegrationSetting::where('company_id', $truck->company_id)->where('carrier_id', $truck->carrier_id)->where('app_center_id', config('settings.app_id.samsara'))->where('sync_vehicles', '1')->first();
                if(!is_null($getAPIKey)){
                    try {
                        $url                        = 'https://api.samsara.com/fleet/vehicles/locations?vehicleIds='.$truck->samsara_id;
                        $client                     = new Client();
                        $response                   = $client->request('GET', $url, [
                            'headers'               => [
                                'Accept'            => 'application/json',
                                'Authorization'     => 'Bearer '.$getAPIKey->api_key,
                            ],
                        ]);
                        // Check if response status code is OK (200)
                        if ($response->getStatusCode() == 200) {
                            $body                   = json_decode($response->getBody());
                            // Do something with the response body
                            if(isset($body)){
                                $data               = isset($body->data[0])?$body->data[0]:null;
                                if(isset($data)){
                                    if(isset($data->location)){
                                        try {
                                            $location                   = $data->location;

                                            $array                      = [
                                                'Coords'                => $location->longitude.','.$location->latitude,
                                                'matchNamedRoadsOnly'   => 'true',
                                                'maxCleanupMiles'       => '20',
                                                'region'                => 'NA',
                                                'dataset'               => 'Current',
                                                'vehicle'               => 'Truck',
                                                'timestamp'             => Carbon::now(),
                                                'includeTrimblePlaceIds'=> 'true'
                                            ];
                                            $param                      = array();
                                            foreach($array as $k => $v){
                                                $param[]                = $k . '=' . urlencode($v);
                                            }
                                            $param                      = implode('&', $param);

                                            $trimble_url                = 'https://pcmiler.alk.com/apis/rest/v1.0/Service.svc/locations/reverse?'.$param;
                                            $trimble_response           = $client->request('GET', $trimble_url, [
                                                'headers'               => [
                                                    'Accept'            => 'application/json',
                                                    'Content-Type'      => 'application/json',
                                                    'Authorization'     => $truck->getCompany->trimble_api_key, //'83FF948F08EB3C4BB97E3AED42BEF772',
                                                ],
                                            ]);
                                            // Check if response status code is OK (200)
                                            if ($trimble_response->getStatusCode() == 200) {
                                                $trimble_body           = json_decode($trimble_response->getBody());
                                                // Do something with the response body
                                                if(isset($trimble_body->Address)){
                                                    $truck->last_location_name          = null; // $location->reverseGeo->formattedLocation;
                                                    $truck->last_location_address       = $trimble_body->Address->StreetAddress;
                                                    $truck->last_location_address_2     = null;
                                                    $truck->last_location_city          = $trimble_body->Address->City;
                                                    $truck->last_location_state         = $trimble_body->Address->State;
                                                    $truck->last_location_zip           = $trimble_body->Address->Zip;
                                                }
                                                if(isset($trimble_body->Coords)){
                                                    $truck->last_location_latitude      = $trimble_body->Coords->Lat;
                                                    $truck->last_location_longitude     = $trimble_body->Coords->Lon;
                                                }
                                                $last_location_timezone                 = null;
                                                $last_location_timezone_offset          = null;
                                                if(isset($trimble_body->TimeZone)){
                                                    $last_location_timezone             = timezone_name_from_abbr($trimble_body->TimeZone);
                                                    $last_location_timezone_offset      = Carbon::createFromTimestamp(time(), $last_location_timezone)->getOffsetString();
                                                    $truck->last_location_timezone_abbr = $trimble_body->TimeZone;
                                                }
                                                $truck->last_location_timezone          = $last_location_timezone;
                                                $truck->last_location_timezone_offset   = $last_location_timezone_offset;
                                                $truck->last_location_address_verified  = 1;
                                                $truck->last_location_notes             = null;
                                                $truck->last_location_load_status       = '0';
                                                $truck->updated_at                      = Carbon::now();
                                                if($truck->save()){
                                                    Log::info('Truck vin number ('.$truck->vin_number.') : success');
                                                }
                                            }
                                        } catch (ClientException $e) {
                                            // Handle client-side errors (e.g. 4xx status codes)
                                            $response                   = $e->getResponse();
                                            if ($response) {
                                                $statusCode             = $response->getStatusCode();
                                                $body                   = $response->getBody()->getContents();
                                                Log::error('Truck vin number ('.$truck->vin_number.') : Trimble response '.$body);
                                            } else {
                                                $errorMessage           = $e->getMessage();
                                                Log::error('Truck vin number ('.$truck->vin_number.') : Trimble response '.$errorMessage);
                                            }
                                        } catch (ServerException $e) {
                                            // Handle server-side errors (e.g. 5xx status codes)
                                            $response                   = $e->getResponse();
                                            if ($response) {
                                                $statusCode             = $response->getStatusCode();
                                                $body                   = $response->getBody()->getContents();
                                                Log::error('Truck vin number ('.$truck->vin_number.') : Trimble response '.$body);
                                            } else {
                                                $errorMessage           = $e->getMessage();
                                                Log::error('Truck vin number ('.$truck->vin_number.') : Trimble response '.$errorMessage);
                                            }
                                        } catch (\Exception $e) {
                                            // Handle other exceptions
                                            $errorMessage               = $e->getMessage();
                                            Log::error('Truck vin number ('.$truck->vin_number.') : Trimble response '.$errorMessage);
                                        }
                                    }else{
                                        Log::error('Truck vin number ('.$truck->vin_number.') : Samsara response location not set.');
                                    }
                                }else{
                                    Log::error('Truck vin number ('.$truck->vin_number.') : Samsara response data not set.');
                                }
                            }else{
                                Log::error('Truck vin number ('.$truck->vin_number.') : Samsara response body not set.');
                            }
                        }
                    } catch (ClientException $e) {
                        // Handle client-side errors (e.g. 4xx status codes)
                        $response               = $e->getResponse();
                        if ($response) {
                            $statusCode         = $response->getStatusCode();
                            $body               = $response->getBody()->getContents();
                            Log::error('Truck vin number ('.$truck->vin_number.') : Samsara response '.$body);
                        } else {
                            $errorMessage       = $e->getMessage();
                            Log::error('Truck vin number ('.$truck->vin_number.') : Samsara response '.$errorMessage);
                        }
                    } catch (ServerException $e) {
                        // Handle server-side errors (e.g. 5xx status codes)
                        $response               = $e->getResponse();
                        if ($response) {
                            $statusCode         = $response->getStatusCode();
                            $body               = $response->getBody()->getContents();
                            Log::error('Truck vin number ('.$truck->vin_number.') : Samsara response '.$body);
                        } else {
                            $errorMessage       = $e->getMessage();
                            Log::error('Truck vin number ('.$truck->vin_number.') : Samsara response '.$errorMessage);
                        }
                    } catch (\Exception $e) {
                        // Handle other exceptions
                        $errorMessage           = $e->getMessage();
                        Log::error('Truck vin number ('.$truck->vin_number.') : Samsara response '.$errorMessage);
                    }
                }
            }
        }

        $query      = Truck::query();
        $query->where(function ($q) {
            $q->whereNull('samsara_id')->whereNotNull('vin_number')->whereNotNull('unit');
        });
        $results    = $query->get();
        if($results->isNotEmpty()){
            foreach( $results as $key => $truck ) {
                $load_detail = LoadDetail::select(
                    'id','load_id','load_number','truck_number',
                    'occupied_pickup_day',
                    'shipping_time_range','shipper_date_time','shipper_date_time_end','actual_shipper_date',
                    'shipper_location','shipper_address_one','shipper_address_two','shipper_state','shipper_city','shipper_zip','shipper_note','shipper_latitude','shipper_longitude','shipper_timezone','shipper_timezone_offset','shipper_timezone_abbr','shipper_address_verified',
                    'shipper_is_arrived','shipper_arrived_at',
                    'shipper_is_leaves','shipper_leaves_at',
                    'delivery_time_range','delivery_date_time','delivery_date_time_end','actual_delivery_date',
                    'delivery_location','delivery_address_one','delivery_address_two','delivery_state','delivery_city','delivery_zip','delivery_note','delivery_latitude','delivery_longitude','delivery_timezone','delivery_timezone_offset','delivery_timezone_abbr','delivery_address_verified',
                    'delivery_is_arrived','delivery_arrived_at','delivery_is_leaves','delivery_leaves_at'
                );
                $load_detail->where(function($query) use ($truck){
                    $query->where('truck_number',$truck->unit)
                        ->where('shipper_is_arrived', 1);
                });
                $load_detail->orderBy('actual_shipper_date', 'DESC')
                    ->orderBy('actual_delivery_date', 'DESC');
                $load_detail        = $load_detail->first();
                if(!is_null($load_detail)){
                    if($load_detail->delivery_is_arrived==1){
                        $truck->last_location_name                  = $load_detail->delivery_location;
                        $truck->last_location_address               = $load_detail->delivery_address_one;
                        $truck->last_location_address_2             = $load_detail->delivery_address_two;
                        $truck->last_location_city                  = $load_detail->delivery_city;
                        $truck->last_location_state                 = $load_detail->delivery_state;
                        $truck->last_location_zip                   = $load_detail->delivery_zip;

                        $truck->last_location_latitude              = $load_detail->delivery_latitude;
                        $truck->last_location_longitude             = $load_detail->delivery_longitude;

                        $truck->last_location_timezone              = $load_detail->delivery_timezone;
                        $truck->last_location_timezone_offset       = $load_detail->delivery_timezone_offset;
                        $truck->last_location_timezone_abbr         = $load_detail->delivery_timezone_abbr;
                        $truck->last_location_address_verified      = $load_detail->delivery_address_verified;

                        $truck->last_location_notes                 = $load_detail->delivery_note;

                        $truck->last_location_load_status           = '0';
                        $truck->updated_at                          = Carbon::now();
                        if($truck->save()){
                            Log::info('Truck vin number ('.$truck->vin_number.') : success');
                        }
                    }else{
                        $load_stop  = LoadStop::where('load_id', $load_detail->load_id)->where('is_arrived', 1)->orderBy('date_time', 'DESC')->first();
                        if(!is_null($load_stop)){
                            $truck->last_location_name              = $load_stop->location;
                            $truck->last_location_address           = $load_stop->address_one;
                            $truck->last_location_address_2         = $load_stop->address_two;
                            $truck->last_location_city              = $load_stop->city;
                            $truck->last_location_state             = $load_stop->state;
                            $truck->last_location_zip               = $load_stop->zip;

                            $truck->last_location_latitude          = $load_stop->latitude;
                            $truck->last_location_longitude         = $load_stop->longitude;

                            $truck->last_location_timezone          = $load_stop->timezone;
                            $truck->last_location_timezone_offset   = $load_stop->timezone_offset;
                            $truck->last_location_timezone_abbr     = $load_stop->timezone_abbr;
                            $truck->last_location_address_verified  = $load_stop->address_verified;

                            $truck->last_location_notes             = $load_stop->stop_note;

                            $truck->last_location_load_status       = '0';
                            $truck->updated_at                      = Carbon::now();
                            if($truck->save()){
                                Log::info('Truck vin number ('.$truck->vin_number.') : success');
                            }
                        }else{
                            $truck->last_location_name              = $load_detail->shipper_location;
                            $truck->last_location_address           = $load_detail->shipper_address_one;
                            $truck->last_location_address_2         = $load_detail->shipper_address_two;
                            $truck->last_location_city              = $load_detail->shipper_city;
                            $truck->last_location_state             = $load_detail->shipper_state;
                            $truck->last_location_zip               = $load_detail->shipper_zip;

                            $truck->last_location_latitude          = $load_detail->shipper_latitude;
                            $truck->last_location_longitude         = $load_detail->shipper_longitude;

                            $truck->last_location_timezone          = $load_detail->shipper_timezone;
                            $truck->last_location_timezone_offset   = $load_detail->shipper_timezone_offset;
                            $truck->last_location_timezone_abbr     = $load_detail->shipper_timezone_abbr;
                            $truck->last_location_address_verified  = $load_detail->shipper_address_verified;

                            $truck->last_location_notes             = $load_detail->shipper_note;

                            $truck->last_location_load_status       = '0';
                            $truck->updated_at                      = Carbon::now();
                            if($truck->save()){
                                Log::info('Truck vin number ('.$truck->vin_number.') : success');
                            }
                        }
                    }
                }
            }
        }
        Log::info('Cron End : Real time truck location update ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
    }
}
