<?php

namespace App\Console\Commands;

use App\Models\IntegrationSetting;
use App\Models\Truck;
use Carbon\Carbon;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\Log;

class SyncTruckOdometer extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'syncTruckOdometer:cron';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Command description';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        Log::info('Cron start : Sync Truck Odometer ( '.Carbon::now()->format('Y-m-d H:i:s').' )');

        $trucks = Truck::whereNotNull('samsara_id')->get();

        foreach ($trucks as $truck){
            $carrierId = (isset($truck->carrier_id)) ? $truck->carrier_id : '';

            if($carrierId != ''){
                $getAPIKey = IntegrationSetting::where('company_id', $truck->company_id)->where('carrier_id', $carrierId)->where('app_center_id', config('settings.app_id.samsara'))->where('sync_vehicles', '1')->first();

                if(isset($getAPIKey->api_key) && !empty($getAPIKey->api_key)){
                    try {
                        $url                    = 'https://api.samsara.com/fleet/vehicles/stats?vehicleIds='.$truck->samsara_id.'&types=obdOdometerMeters';
                        $client                 = new \GuzzleHttp\Client(['verify' => false]);
                        $response               = $client->request('GET', $url, [
                            'headers'           => [
                                'Accept'        => 'application/json',
                                'Authorization' => 'Bearer '.$getAPIKey->api_key,
                            ],
                        ]);
                        // Check if response status code is OK (200)
                        if ($response->getStatusCode() == 200) {
                            $body = json_decode($response->getBody());
                            // Do something with the response body
                            if(isset($body)){
                                $data = isset($body->data[0]) ? $body->data[0] :null;
                                if(isset($data)){
                                    if(isset($data->obdOdometerMeters->value) && $data->obdOdometerMeters->value != ""){
                                        $truck->current_odometer = number_format(round($data->obdOdometerMeters->value * 0.000621371)) ?? null;
                                        $truck->save();
                                    }
                                }
                            }
                        }
                    } catch (\GuzzleHttp\Exception\ClientException $e) {
                        // Handle client-side errors (e.g. 4xx status codes)
                        $response               = $e->getResponse();
                        if ($response) {
                            $statusCode         = $response->getStatusCode();
                            $body               = $response->getBody()->getContents();
                            Log::error('Truck vin number ('.$truck->vin_number ?? '-'.') : client exception '.$body);
                        } else {
                            $errorMessage       = $e->getMessage();
                            Log::error('Truck vin number ('.$truck->vin_number ?? '-'.') : client exception '.$errorMessage);
                        }
                    } catch (\GuzzleHttp\Exception\ServerException $e) {
                        // Handle server-side errors (e.g. 5xx status codes)
                        $response               = $e->getResponse();
                        if ($response) {
                            $statusCode         = $response->getStatusCode();
                            $body               = $response->getBody()->getContents();
                            Log::error('Truck vin number ('.$truck->vin_number ?? '-'.') : server exception '.$body);
                        } else {
                            $errorMessage       = $e->getMessage();
                            Log::error('Truck vin number ('.$truck->vin_number ?? '-'.') : server exception '.$errorMessage);
                        }
                    } catch (\Exception $e) {
                        // Handle other exceptions
                        $errorMessage           = $e->getMessage();
                        Log::error('Truck vin number ('.$truck->vin_number ?? '-'.') : other exception '.$errorMessage);
                    }
                }
            }
        }

        Log::info('Cron end : Sync Truck Odometer ( '.Carbon::now()->format('Y-m-d H:i:s').' )');
    }
}
