<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Admin\AdminController;
use Illuminate\Http\Request;

use App\Models\MasterMaintenanceAppointmentType;

use Validator;
use DataTables;

class AppointmentTypeController extends AdminController{

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(){
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request){
        if ($request->ajax()) {
            $data = MasterMaintenanceAppointmentType::get();
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function($row){
                    $btn = '<a href="#" class="edit-btn mr-4" data-id="'.$row->id.'" data-toggle="modal" data-target="#editModal"><img src="'.asset('theme/img/edit-icon.png').'" alt=""></a>';
                    $btn = $btn.' <a href="javascript:" class="destroy" data-action="'.route('admin.appointment-types.destroy',$row->id).'" data-id="'.$row->id.'"><img src="'.asset('theme/img/delete-icon.png').'" alt=""></a>';
                    return $btn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.appointmentTypes.index');

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(){
        return Redirect::back();
        //return view('admin.eventType.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request){
        $input      = $request->all();

        $validator  = Validator::make($input,[
            "name"  => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        MasterMaintenanceAppointmentType::create($input);

        notification('success', $this->crudMessage('create', 'AppointmentType'));
        return response()->json(['success' => "Appointment Type created successfully"]);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(EventType $appointment_type){
        return redirect()->route('admin.appointment-type.index');
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(MasterMaintenanceAppointmentType $appointment_type){
        return view('admin.eventType.edit', compact('appointment_type'));
    }

    public function editFormView(Request $request){
        $appointmentType = MasterMaintenanceAppointmentType::find($request->id);

        $view = view('admin.appointmentTypes.editFormView', compact('appointmentType'))->render();

        return response()->json(['view' => $view, 'data' => $appointmentType]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, MasterMaintenanceAppointmentType $appointment_type){
        $input      = $request->all();

        $validator  = Validator::make($input,[
            "name"  => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $appointment_type->update($input);

        notification('success', $this->crudMessage('update', 'AppointmentType'));

        return response()->json(['success' => "Appointment Type updated successfully"]);
    }

    public function destroy(MasterMaintenanceAppointmentType $appointment_type){
        $appointment_type->delete();

        notification('success', $this->crudMessage('delete', 'AppointmentType'));

        return redirect()->route('admin.appointment-types.index');
    }

}
