<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Admin\AdminController;
use Illuminate\Http\Request;

use App\Http\Requests\Admin\CompanyAccidentViolationCodeStoreRequest;
use App\Http\Requests\Admin\CompanyAccidentViolationCodeUpdateRequest;

use App\Models\CompanyAccidentViolationCode;

use DataTables;

class CompanyAccidentViolationCodeController extends AdminController{

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(){
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request){
        if ($request->ajax()) {
            $data = CompanyAccidentViolationCode::get();
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function($row){
                    $btn = ' <a href="'.route('admin.company-accident-violation-code.edit', $row->id).'"><img src="'.asset('theme/img/edit-icon.png').'" class="mr-4" alt=""></a>';
                    $btn = $btn.' <a href="javascript:" class="destroy" data-action="'.route('admin.company-accident-violation-code.destroy',$row->id).'" data-id="'.$row->id.'"><img src="'.asset('theme/img/delete-icon.png').'" alt=""></a>';
                    return $btn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.companyAccidentViolationCode.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(){
        return view('admin.companyAccidentViolationCode.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(CompanyAccidentViolationCodeStoreRequest $request){
        $input                              = $request->except(['_token']);
        $company_accident_violation_code    = CompanyAccidentViolationCode::create($input);

        /*
        $get_company = \App\Models\Company::get();
        foreach($get_company as $company){
            $input['company_id'] = $company->id;
            \App\Models\ManageCompanyType::create($input);
        }
        */

        notification('success', $this->crudMessage('create', ''));

        return redirect()->route('admin.company-accident-violation-code.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(){
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(CompanyAccidentViolationCode $companyAccidentViolationCode){
        return view('admin.companyAccidentViolationCode.edit', compact('companyAccidentViolationCode'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(CompanyAccidentViolationCodeUpdateRequest $request, CompanyAccidentViolationCode $companyAccidentViolationCode){
        $input = $request->except(['_token']);
        $companyAccidentViolationCode->update($input);

        notification('success', $this->crudMessage('update', ''));

        return redirect()->route('admin.company-accident-violation-code.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request){
        $data = CompanyAccidentViolationCode::find($request->id);
        $data->delete();

        notification('success', $this->crudMessage('delete', ''));

        return redirect()->route('admin.company-accident-violation-code.index');
    }

}
