<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Admin\AdminController;

use App\Models\CompanyDeductionType;
use App\Models\CompanyEmailTemplate;
use App\Models\CompanyInsuranceType;
use App\Models\CompanyOnboarding;
use App\Models\CompanyPmServiceType;
use App\Models\CompanyPmType;
use App\Models\CompanyPmWarrantyProvider;
use App\Models\CompanySafetyCompliance;
use App\Models\CompanyTruckType;
use App\Models\CompanyWorkOrder;
use App\Models\DeductionType;
use App\Models\EmailTemplate;
use App\Models\InsuranceType;
use App\Models\Onboarding;
use App\Models\PmServiceType;
use App\Models\PmType;
use App\Models\PmWarrantyProvider;
use App\Models\SafetyCompliance;
use App\Models\TruckType;
use App\Models\WorkOrder;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

use App\Models\Company;

use App\Models\CompanyInspectionLevel;
use App\Models\DriverInspectionLevel;

use App\Models\CompanyDisciplinaryAction;
use App\Models\DriverDisciplinaryAction;

use App\Models\CompanyHosViolationCode;
use App\Models\DriverHosViolationCode;

use App\Models\CompanyCitationsViolationCode;
use App\Models\DriverCitationsViolationCode;

use App\Models\CompanyAccidentViolationCode;
use App\Models\DriverAccidentViolationCode;

use App\Models\ManageType;
use App\Models\ManageCompanyType;

use App\Models\Holiday;
use App\Models\CompanyHoliday;

use App\Models\MasterMaintenanceAppointmentType;
use App\Models\MasterMaintenanceTicketType;

use App\Models\MaintenanceTicketType;
use App\Models\MaintenanceAppointmentType;

use App\Models\AdminTrailerType;
use App\Models\TrailerType;

use App\Models\Accessorial;
use App\Models\CompanyAccessorial;

use App\Models\Commodity;
use App\Models\CompanyCommodity;

use App\Models\Term;
use App\Models\CompanyTerm;

use App\Models\LoadDocument;
use App\Models\CompanyLoadDocument;

use App\Models\LoadRequirementsItem;
use App\Models\CompanyLoadRequirementsItem;

use App\Models\CompanyAdmin;
use App\Models\CompanySmsPurchaseLog;

use App\Http\Requests\Admin\CompanyStoreRequest;
use App\Http\Requests\Admin\CompanyUpdateRequest;
use App\Mail\Admin\WelcomeMailToCompanyAdmin;

use DB;
use Mail;
use Hash;
use Session;
use DataTables;
use Carbon\Carbon;

class CompanyController extends AdminController{

    /**
     * Create a new controller instance.
     *
     * @return void
     */

    public $timeZoneId;
    public $offset;

    public function __construct(){
        parent::__construct();

        $this->middleware(function ($request, $next) {
            $this->timeZoneId   = getTimeZoneId();
            $this->offset       = getTimeZoneOffset();

            return $next($request);
        });
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request){
        if ($request->ajax()) {
            $offset     = $this->offset;
            $search     = $request->search['value'] ?? '';
            $data       = Company::query()
                ->select(
                    '*',
                    DB::raw('CONVERT_TZ(companies.created_at,"+00:00","'.$offset.'") as created_at')
                );
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('drivers', function($row){
                    return $row->drivers->count();
                })
                ->addColumn('monthly_revenue', function($row){
                    return "$12,541.36";
                })
                ->addColumn('signup_date', function($row){
                    if(auth()->guard('admin')->user()->time_format=='12'){
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->orderColumn('signup_date', function ($query, $order) {
                    $query->orderBy('created_at', $order);
                })
                ->filterColumn('signup_date', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(companies.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(companies.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->addColumn('action', function($row){
                    $btn = '<a href="'.route('admin.companies.show', $row->id).'"><img src="'.asset('theme/img/big-eye.png').'" alt=""></a>';
                    $btn = $btn.' <a href="'.route('admin.companies.edit', $row->id).'"><img src="'.asset('theme/img/big-pen.png').'" alt=""></a>';
                    $btn = $btn.' <a href="'.route('admin.login.to.company', $row->id).'"><img src="'.asset('theme/img/icon-2.png').'" alt=""></a>';
                    return $btn;
                })
                ->rawColumns(['action','drivers','monthly_revenue','signup_date'])
                ->make(true);
        }
        return view('admin.company.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.company.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(CompanyStoreRequest $request)
    {
        /*
        $request->validate([
            'trimble_api_key' => 'nullable|unique:companies'
        ]);
        */

        $input                              = $request->except(['_token','company_id']);
        // Added at 18-04-2023
        $input['shortname']                 = strtolower( $input['shortname'] );
        $checkName                          = Company::where('shortname', $request->shortname)->first();
        if( $checkName ) {
            notification('error', 'Short name already exists');
            return redirect()->route('admin.companies.create');
        }
        $input['unique_id']                 = $request->company_id;

        if($request->address_verified==1){
            $timezone                       = null;
            $timezone_offset                = null;
            if(isset($input['timezone_abbr'])){
                $timezone                   = timezone_name_from_abbr($input['timezone_abbr']);
                $timezone_offset            = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['timezone']              = $timezone;
            $input['timezone_offset']       = $timezone_offset;
        }

        $company                            = Company::create($input);

        $plogData = [];
        $plogData['company_id'] = $company->id;
        $plogData['sms_limit'] = $request->sms_limit;
        $plogData['created_name'] = auth()->guard('admin')->user()->full_name;
        CompanySmsPurchaseLog::create($plogData);

        $CompanyInspectionLevel             = CompanyInspectionLevel::get();
        foreach($CompanyInspectionLevel as $InspectionLevel){
            $type_val                       = [];
            $type_val['company_id']         = $company->id;
            $type_val['name']               = $InspectionLevel->name;
            DriverInspectionLevel::create($type_val);
        }

        $CompanyDisciplinaryAction          = CompanyDisciplinaryAction::get();
        foreach($CompanyDisciplinaryAction as $DisciplinaryAction){
            $type_val                       = [];
            $type_val['company_id']         = $company->id;
            $type_val['name']               = $DisciplinaryAction->name;
            DriverDisciplinaryAction::create($type_val);
        }

        $get_hos_code                       = CompanyHosViolationCode::get();
        foreach($get_hos_code as $hoscode){
            $type_val                       = [];
            $type_val['company_id']         = $company->id;
            $type_val['code']               = $hoscode->code;
            $type_val['description']        = $hoscode->description;
            DriverHosViolationCode::create($type_val);
        }

        $get_citations_code                 = CompanyCitationsViolationCode::get();
        foreach($get_citations_code as $citationscode){
            $type_val                       = [];
            $type_val['company_id']         = $company->id;
            $type_val['code']               = $citationscode->code;
            $type_val['description']        = $citationscode->description;
            DriverCitationsViolationCode::create($type_val);
        }

        $get_accident_code                  = CompanyAccidentViolationCode::get();
        foreach($get_accident_code as $accidentcode){
            $type_val                       = [];
            $type_val['company_id']         = $company->id;
            $type_val['code']               = $accidentcode->code;
            $type_val['description']        = $accidentcode->description;
            DriverAccidentViolationCode::create($type_val);
        }

        $get_manag_type                     = ManageType::get();
        foreach($get_manag_type as $type){
            $type_val                       = [];
            $type_val['company_id']         = $company->id;
            $type_val['category_id']        = $type->category_id;
            $type_val['name']               = $type->name;
            ManageCompanyType::create($type_val);
        }

        $getHoliday                         = Holiday::get();
        foreach($getHoliday as $holy){
            $type_val                       = [];
            $type_val['company_id']         = $company->id;
            $type_val['name']               = $holy->name;
            $type_val['from_date']          = $holy->from_date;
            $type_val['to_date']            = $holy->to_date;
            CompanyHoliday::create($type_val);
        }

        // master ticket type to maintenance ticket type of company admin
        $getMasterTicketType                = MasterMaintenanceTicketType::get();
        if(!empty($getMasterTicketType)){
            foreach($getMasterTicketType as $type){
                $type_val                   = [];
                $type_val['company_id']     = $company->id;
                $type_val['name']           = $type->name;
                MaintenanceTicketType::create($type_val);
            }
        }

        // master appointment type to maintenance appointment type of company admin
        $getMasterAppointmentType           = MasterMaintenanceAppointmentType::get();
        if(!empty($getMasterAppointmentType)){
            foreach($getMasterAppointmentType as $app_type){
                $type_val                   = [];
                $type_val['company_id']     = $company->id;
                $type_val['name']           = $app_type->name;
                MaintenanceAppointmentType::create($type_val);
            }
        }

        $admin_trailer_types                = AdminTrailerType::get();
        foreach($admin_trailer_types as $trailer_types) {
            TrailerType::create(['company_id' => $company->id, 'name' => $trailer_types->name, 'is_temp_required' => $trailer_types->is_temp_required]);
        }

        // Accessorial
        $accessorials                       = Accessorial::get();
        foreach($accessorials as $accessorial) {
            CompanyAccessorial::create(['company_id' => $company->id, 'name' => $accessorial->name, 'default_amount' => $accessorial->default_amount, 'gl_code' => $accessorial->gl_code]);
        }

        // Commodity
        $commodities                        = Commodity::get();
        foreach($commodities as $commodity) {
            CompanyCommodity::create(['company_id' => $company->id, 'name' => $commodity->name]);
        }

        // Terms
        $terms                              = Term::get();
        foreach($terms as $term) {
            CompanyTerm::create(['company_id' => $company->id, 'name' => $term->name]);
        }

        // Load Document
        $LoadDocuments                      = LoadDocument::get();
        foreach($LoadDocuments as $LoadDocument) {
            CompanyLoadDocument::create(['company_id' => $company->id, 'name' => $LoadDocument->name, 'include_w_billing' => $LoadDocument->include_w_billing]);
        }

        // Load Requirements Items
        $loadRequirementsItems              = LoadRequirementsItem::get();
        foreach($loadRequirementsItems as $loadRequirementsItem) {
            CompanyLoadRequirementsItem::create(['company_id' => $company->id, 'name' => $loadRequirementsItem->name]);
        }

        // Truck Types
        $truck_types = TruckType::get();
        foreach($truck_types as $truck_type) {
            CompanyTruckType::create(['company_id' => $company->id, 'name' => $truck_type->name]);
        }

        // Work Orders Documents
        $workOrders = WorkOrder::get();
        foreach($workOrders as $workOrder) {
            CompanyWorkOrder::create(['company_id' => $company->id, 'name' => $workOrder->name]);
        }

        // Safety And Compliance Documents
        $safetyAndCompliances= SafetyCompliance::get();
        foreach($safetyAndCompliances as $safetyAndCompliance) {
            CompanySafetyCompliance::create(['company_id' => $company->id, 'name' => $safetyAndCompliance->name]);
        }

        // Onboarding Documents
        $companyOnboardings = Onboarding::get();
        foreach($companyOnboardings as $companyOnboarding) {
            CompanyOnboarding::create(['company_id' => $company->id, 'name' => $companyOnboarding->name]);
        }

        // Deduction Type
        $deduction_types = DeductionType::get();
        foreach($deduction_types as $deduction_type) {
            CompanyDeductionType::create(['company_id' => $company->id, 'name' => $deduction_type->name]);
        }

        // Insurance Types
        $insurance_types = InsuranceType::get();
        foreach($insurance_types as $insurance_type) {
            CompanyInsuranceType::create(['company_id' => $company->id, 'name' => $insurance_type->name]);
        }

        // Insurance Types
        $pm_types = PmType::get();
        foreach($pm_types as $pm_type) {
            CompanyPmType::create(['company_id' => $company->id, 'name' => $pm_type->name]);
        }

        // PM Service Types
        $pm_service_types = PmServiceType::get();
        foreach($pm_service_types as $pm_service_type) {
            CompanyPmServiceType::create(['company_id' => $company->id, 'name' => $pm_service_type->name]);
        }

        // PM Warranty Providers
        $pm_warranty_providers = PmWarrantyProvider::get();
        foreach($pm_warranty_providers as $pm_warranty_provider) {
            CompanyPmWarrantyProvider::create(['company_id' => $company->id, 'name' => $pm_warranty_provider->name]);
        }

        // Email Template
        $emailTemplates = EmailTemplate::get(['title', 'subject', 'content', 'tags', 'description'])->toArray();
        foreach ($emailTemplates as $emailTemplate){
            $emailTemplate = array_merge(array('company_id' => $company->id), $emailTemplate);
            CompanyEmailTemplate::create($emailTemplate);
        }

        $password                           = Str::random(8);
        $input['company_id']                = $company->id;
        $input['password']                  = Hash::make($password);
        $input['type']                      = 0;
        $input['weekly_strat_day']          = auth()->guard('admin')->user()->weekly_strat_day;
        $companyAdmin = CompanyAdmin::create($input);

        

        // $mailData                        = [];
        // $mailData['name']                = $input['name'];
        // $mailData['email']               = $input['email'];
        // $mailData['password']            = $password;
        // Mail::to($input['email'])->send(new WelcomeMailToCompanyAdmin($mailData));

        notification('success', $this->crudMessage('create', 'Company'));
        return redirect()->route('admin.companies.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Company $company)
    {
        $companyAdmin = $company->company_admin;
        return view('admin.company.show', compact('company', 'companyAdmin'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Company $company)
    {
        $purchaseLog = CompanySmsPurchaseLog::where('company_id', $company->id)->get();
        $companyAdmin = $company->company_admin;
        return view('admin.company.edit', compact('company', 'companyAdmin','purchaseLog'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(CompanyUpdateRequest $request, Company $company)
    {
        /*
        $request->validate([
            'trimble_api_key' => 'nullable|unique:companies,trimble_api_key,'.$company->id
        ]);
        */

        $input                          = $request->except(['_token','company_id']);
        // Added at 18-04-2023
        $input['shortname']             = strtolower( $input['shortname'] );
        $checkName                      = Company::where('id', '!=', $company->id)->where('shortname', $request->shortname)->first();
        if( $checkName ) {
            notification('error', 'Short name already exists');
            return redirect()->route('admin.companies.edit', $company->id);
        }
        $input['unique_id']             = $request->company_id;



        if($request->address_verified==1){
            $timezone                   = null;
            $timezone_offset            = null;
            if(isset($input['timezone_abbr'])){
                $timezone               = timezone_name_from_abbr($input['timezone_abbr']);
                $timezone_offset        = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['timezone']          = $timezone;
            $input['timezone_offset']   = $timezone_offset;
        }else{
            $input['latitude']          = null;
            $input['longitude']         = null;
            $input['timezone']          = null;
            $input['timezone_offset']   = null;
            $input['timezone_abbr']     = null;
        }

        $tot_sms = $company->sms_limit + $request->sms_last_added;
        $input['sms_limit'] = $tot_sms;
        $input['sms_last_added'] = $tot_sms;

        $company->update($input);

        if($company->wasChanged()){
            if(isset($company->getChanges()['sms_last_added'])){
                $plogData = [];
                $plogData['company_id'] = $company->id;
                $plogData['sms_limit'] = $request->sms_last_added;
                $plogData['created_name'] = auth()->guard('admin')->user()->full_name;
                CompanySmsPurchaseLog::create($plogData);
            }
        }
        

        $company->company_admin->update($input);

        notification('success', $this->crudMessage('update', 'Company'));

        return redirect()->route('admin.companies.index');
    }

    /**
     * Login to company admin.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function login($id)
    {
        // $previous_user_id = auth()->guard('admin')->user()->id;
        $last_login_user = ['id'=>auth()->guard('admin')->user()->id,
                            'name'=> auth()->guard('admin')->user()->first_name.' '.auth()->guard('admin')->user()->last_name,
                            'user_type' => 'admin',
                            'last_user_guard_type' => ''
                        ];
        $last_login_user=json_encode($last_login_user);
        $companyAdmin = CompanyAdmin::where('company_id', $id)->first();

        auth()->guard('company-admin')->loginUsingId($companyAdmin->id);

        Session::put('impersonate_user', $companyAdmin);
        Session::put('last_user',$last_login_user);
        Session::put('companyAdmin-2fa', $id);
        // Session::put('previous_user_id', $previous_user_id);
        // Session::put('previous_user_type', 'super');

        // return redirect()->route('company.admin.home');
        return redirect()->route('company.admin.home')->withCookie(cookie()->forever('last_user',$last_login_user));
    }
}
