<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Admin\AdminController;
use Illuminate\Http\Request;

use App\Http\Requests\Admin\CompanyInspectionLevelStoreRequest;
use App\Http\Requests\Admin\CompanyInspectionLevelUpdateRequest;

use App\Models\CompanyInspectionLevel;

use DataTables;

class CompanyInspectionLevelController extends AdminController{

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(){
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request){
        if ($request->ajax()) {
            $data = CompanyInspectionLevel::get();
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function($row){
                    $btn = ' <a href="'.route('admin.company-inspection-level.edit', $row->id).'"><img src="'.asset('theme/img/edit-icon.png').'" class="mr-4" alt=""></a>';
                    $btn = $btn.' <a href="javascript:" class="destroy" data-action="'.route('admin.company-inspection-level.destroy',$row->id).'" data-id="'.$row->id.'"><img src="'.asset('theme/img/delete-icon.png').'" alt=""></a>';
                    return $btn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.companyInspectionLevel.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(){
        return view('admin.companyInspectionLevel.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(CompanyInspectionLevelStoreRequest $request){
        $input = $request->except(['_token']);
        CompanyInspectionLevel::create($input);

        notification('success', $this->crudMessage('create', ''));

        return redirect()->route('admin.company-inspection-level.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(){
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(CompanyInspectionLevel $companyInspectionLevel){
        return view('admin.companyInspectionLevel.edit', compact('companyInspectionLevel'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(CompanyInspectionLevelUpdateRequest $request, CompanyInspectionLevel $companyInspectionLevel){
        $input = $request->except(['_token']);
        $companyInspectionLevel->update($input);

        notification('success', $this->crudMessage('update', ''));

        return redirect()->route('admin.company-inspection-level.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request){
        $data = CompanyInspectionLevel::find($request->id);
        $data->delete();

        notification('success', $this->crudMessage('delete', ''));

        return redirect()->route('admin.company-inspection-level.index');
    }

}
