<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Admin\AdminController;
use App\Models\Company;
use App\Models\CompanyEquipmentTitle;
use App\Models\EquipmentTitle;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Yajra\DataTables\Facades\DataTables;

class EquipmentTitleController extends AdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(){
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $data = EquipmentTitle::get();
            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function($row){
                    $btn = '<a href="#" class="edit-btn mr-4" data-id="'.$row->id.'" data-toggle="modal" data-target="#editModal"><img src="'.asset('theme/img/edit-icon.png').'" alt=""></a>';

                    $btn = $btn.' <a href="javascript:" class="destroy" data-action="'.route('admin.equipment-titles.destroy', $row->id).'" data-id="'.$row->id.'"><img src="'.asset('theme/img/delete-icon.png').'" alt=""></a>';
                    return $btn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.equipmentTitles.index');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $input      = $request->all();
        $validator  = Validator::make($input,[
            "name"  => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $data = EquipmentTitle::create($input);

        $getCompnay = Company::get();
        foreach ($getCompnay as $compnay){
            CompanyEquipmentTitle::create(['company_id' => $compnay->id, 'name' => $data->name]);
        }

        notification('success', $this->crudMessage('create', 'EquipmentTitle'));
        return response()->json(['success' => "Equipment Title created successfully"]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(EquipmentTitle $equipmentTitle)
    {
        return view('admin.equipmentTitles.edit', compact('equipmentTitle'));
    }

    public function editFormView(Request $request)
    {
        $equipmentTitle = EquipmentTitle::find($request->id);

        $view = view('admin.equipmentTitles.editFormView', compact('equipmentTitle'))->render();

        return response()->json(['view' => $view, 'data' => $equipmentTitle]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, EquipmentTitle $equipmentTitle)
    {
        $input = $request->all();

        $validator  = Validator::make($input,[
            "name"  => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }
        $equipmentTitle->update($input);

        notification('success', $this->crudMessage('update', 'EquipmentTitle'));

        return response()->json(['success' => "Equipment Title updated successfully"]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(EquipmentTitle $equipmentTitle)
    {
        CompanyEquipmentTitle::where('name', $equipmentTitle->name)->where('company_id', 0)->delete();
        $equipmentTitle->delete();

        notification('success', $this->crudMessage('delete', 'EquipmentTitle'));

        return redirect()->route('admin.equipment-titles.index');
    }
}
