<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Admin\AdminController;
use Illuminate\Http\Request;

use App\Http\Requests\Admin\AppCenterStoreRequest;
use App\Http\Requests\Admin\AppCenterUpdateRequest;

use App\Models\AppCenter;
use App\Models\Company;
use App\Models\TruckStatusLog;
use App\Models\DriverStatusLog;
use App\Models\TrailerStatusLog;
use App\Models\CompanyAdminStatusLog;
use App\Models\LoadLog;
use App\Models\SMSLog;
use App\Models\CompanySmsPurchaseLog;

use File;
use DataTables;
use Carbon\Carbon;
use Carbon\CarbonPeriod;
use Illuminate\Support\Facades\DB;

class InvoiceController extends AdminController{

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public $timeZone;

    public function __construct(){
        parent::__construct();

        $this->middleware(function ($request, $next) {
            $this->timeZone     = getTimeZone();

            return $next($request);
        });
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request){

        $companys = Company::get();
        return view('admin.invoice.index', compact('companys'));

    }

    public function invoiceReport(Request $request){

        if($request->get_data == 'current'){
            $now                = Carbon::createFromDate($request->cyear,$request->cmonth,'01',$this->timeZone);
        }elseif($request->get_data == 'next'){
            $now                = Carbon::createFromDate($request->cyear,$request->cmonth,'01',$this->timeZone)->addMonth();
        }elseif($request->get_data == 'previous'){
            $now                = Carbon::createFromDate($request->cyear,$request->cmonth,'01',$this->timeZone)->subMonth();
        }else{
            $now                = Carbon::now()->timezone($this->timeZone);
        }

        $month                  = $now->format('m');
        $month_name             = $now->format('F');
        $year                   = $now->format('Y');
        $startDate              = $now->startOfMonth()->format('Y-m-d');
        $endDate                = $now->endOfMonth()->format('Y-m-d');

        $truckStatusLogCount = TruckStatusLog::where('status_id','!=',2)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '>=', $startDate)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '<=', $endDate)
                            ->groupBy('truck_id');
        if(isset($request->company_id) && !empty($request->company_id)){
            $truckStatusLogCount = $truckStatusLogCount->where('company_id', $request->company_id);    
        }
        $truckStatusLogCount = $truckStatusLogCount->get()->count();

        // Driver status log
        $driverStatusLogCount = DriverStatusLog::where('status_id','!=',2)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '>=', $startDate)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '<=', $endDate)
                            ->groupBy('driver_id');
        if(isset($request->company_id) && !empty($request->company_id)){
            $driverStatusLogCount = $driverStatusLogCount->where('company_id', $request->company_id);    
        }
        $driverStatusLogCount = $driverStatusLogCount->get()->count();

        // Trailer status log
        $trailerStatusLogCount = TrailerStatusLog::where('status_id','!=',1)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '>=', $startDate)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '<=', $endDate)
                            ->groupBy('trailer_id');
        if(isset($request->company_id) && !empty($request->company_id)){
            $trailerStatusLogCount = $trailerStatusLogCount->where('company_id', $request->company_id);    
        }
        $trailerStatusLogCount = $trailerStatusLogCount->get()->count();

        // Dispatcher status log
        $dispatcherStatusLogCount = CompanyAdminStatusLog::where('status_id','!=',2)->where('type', '2')
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '>=', $startDate)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '<=', $endDate)
                            ->groupBy('company_admin_id');
        if(isset($request->company_id) && !empty($request->company_id)){
            $dispatcherStatusLogCount = $dispatcherStatusLogCount->where('company_id', $request->company_id);    
        }
        $dispatcherStatusLogCount = $dispatcherStatusLogCount->get()->count();

        // Manager status log
        $managerStatusLogCount = CompanyAdminStatusLog::where('status_id','!=',2)->where('type', '1')
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '>=', $startDate)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '<=', $endDate)
                            ->groupBy('company_admin_id');
        if(isset($request->company_id) && !empty($request->company_id)){
            $managerStatusLogCount = $managerStatusLogCount->where('company_id', $request->company_id);    
        }
        $managerStatusLogCount = $managerStatusLogCount->get()->count();


        // Load status log
        $loadLogCount = LoadLog::where('load_status', 3)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '>=', $startDate)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '<=', $endDate)
                            ->groupBy('load_id');
        if(isset($request->company_id) && !empty($request->company_id)){
            $loadLogCount = $loadLogCount->where('company_id', $request->company_id);    
        }
        $loadLogCount = $loadLogCount->get()->count();

        // SMS Log log
        $smsLogCount = SMSLog::where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '>=', $startDate)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '<=', $endDate);
        if(isset($request->company_id) && !empty($request->company_id)){
            $smsLogCount = $smsLogCount->where('company_id', $request->company_id);    
        }
        $smsLogCount = $smsLogCount->get()->count();

        // SMS Log log
        $smsPurchaseLogCount = CompanySmsPurchaseLog::where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '>=', $startDate)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '<=', $endDate);
        if(isset($request->company_id) && !empty($request->company_id)){
            $smsPurchaseLogCount = $smsPurchaseLogCount->where('company_id', $request->company_id);    
        }
        $smsPurchaseLogCount = $smsPurchaseLogCount->sum('sms_limit');


        //dd($truckStatusLogCount, $request->company_id, $startDate, $endDate);
        
        $view                       = view('admin.invoice.ajax.report', compact('year','month','month_name','startDate','endDate','truckStatusLogCount', 'driverStatusLogCount','trailerStatusLogCount', 'dispatcherStatusLogCount', 'managerStatusLogCount','loadLogCount','smsLogCount','smsPurchaseLogCount'))->render();
        return response()->json(['view' => $view]);
    }

    public function invoiceReportDataView    (Request $request){

        $now                = Carbon::createFromDate($request->cyear,$request->cmonth,'01',$this->timeZone);
        $month                  = $now->format('m');
        $month_name             = $now->format('F');
        $year                   = $now->format('Y');
        $startDate              = $now->startOfMonth()->format('Y-m-d');
        $endDate                = $now->endOfMonth()->format('Y-m-d');
        $type = $request->type;

        $lableName = 'Active Details';
        // Truck log show
        if($type == 'truck_status_logs'){
        
            $statusLog = TruckStatusLog::where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '>=', $startDate)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '<=', $endDate);

            if(isset($request->company_id) && !empty($request->company_id)){
                $statusLog = $statusLog->where('company_id', $request->company_id);    
            }

            $statusLog = $statusLog->orderBy('created_at', 'ASC')->get();
        }

        // Driver log show
        if($type == 'driver_status_logs'){
           
            $statusLog = DriverStatusLog::where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '>=', $startDate)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '<=', $endDate);

            if(isset($request->company_id) && !empty($request->company_id)){
                $statusLog = $statusLog->where('company_id', $request->company_id);    
            }

            $statusLog = $statusLog->orderBy('created_at', 'ASC')->get();
        }

        // Driver log show
        if($type == 'trailer_status_logs'){
           
            $statusLog = TrailerStatusLog::where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '>=', $startDate)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '<=', $endDate);

            if(isset($request->company_id) && !empty($request->company_id)){
                $statusLog = $statusLog->where('company_id', $request->company_id);    
            }

            $statusLog = $statusLog->orderBy('created_at', 'ASC')->get();
        }

        // Dispatcher log show
        if($type == 'dispatcher_status_logs'){
           
            $statusLog = CompanyAdminStatusLog::where('type', '2')->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '>=', $startDate)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '<=', $endDate);

            if(isset($request->company_id) && !empty($request->company_id)){
                $statusLog = $statusLog->where('company_id', $request->company_id);    
            }

            $statusLog = $statusLog->orderBy('created_at', 'ASC')->get();
        }

        // Manager log show
        if($type == 'manager_status_logs'){
            $statusLog = CompanyAdminStatusLog::where('type', '1')->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '>=', $startDate)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '<=', $endDate);
            if(isset($request->company_id) && !empty($request->company_id)){
                $statusLog = $statusLog->where('company_id', $request->company_id);    
            }
            $statusLog = $statusLog->orderBy('created_at', 'ASC')->get();
        }

        // Load Log log show
        if($type == 'load_logs'){
            $statusLog = LoadLog::where('load_status', '3')->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '>=', $startDate)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '<=', $endDate);
            if(isset($request->company_id) && !empty($request->company_id)){
                $statusLog = $statusLog->where('company_id', $request->company_id);    
            }
            $statusLog = $statusLog->orderBy('created_at', 'ASC')->get();
        }

        // Load Log log show
        $purchaseLog = '';
        if($type == 'sms_logs'){
            $purchaseLog = CompanySmsPurchaseLog::get();
            $statusLog = SMSLog::where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '>=', $startDate)
                            ->where(DB::raw('DATE_FORMAT(created_at, "%Y-%m-%d")'), '<=', $endDate);
            if(isset($request->company_id) && !empty($request->company_id)){
                $statusLog = $statusLog->where('company_id', $request->company_id);    
                $purchaseLog = CompanySmsPurchaseLog::where('company_id', $company->id)->get();
            }
            $statusLog = $statusLog->orderBy('created_at', 'ASC')->get();

            
        }

        
        
        $view                       = view('admin.invoice.ajax.logdata', compact('lableName','year','month_name','statusLog','type','purchaseLog'))->render();
        return response()->json(['view' => $view]);
        
    }
    

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        notification('error', 'Access permission denied.');
        return redirect()->route('admin.app-center.index');
        //return view('admin.appCenter.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(AppCenterStoreRequest $request)
    {
        notification('error', 'Access permission denied.');
        return redirect()->route('admin.app-center.index');
        /*
        $input = $request->all();
        if($request->profile_picture_hidden){
            $input['logo'] = $request->profile_picture_hidden;
        }
        if($request->status == 1){
            $input['status'] = '1';
        }else{
            $input['status'] = '0';
        }

        AppCenter::create($input);
        notification('success', $this->crudMessage('create', 'AppCenter'));
        return redirect()->route('admin.app-center.index');
        */
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(AppCenter $app_center){
       return redirect()->route('admin.app-center.index');
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(AppCenter $app_center){
        return view('admin.appCenter.edit', compact('app_center'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(AppCenterUpdateRequest $request, AppCenter $app_center){
        $input                  = $request->all();

        if($request->profile_picture_hidden){
            $input['logo']      = $request->profile_picture_hidden;
        }

        if($request->status == 1){
            $input['status']    = '1';
        }else{
            $input['status']    = '0';
        }

        $app_center->update($input);
        notification('success', $this->crudMessage('update', 'app_center'));
        return redirect()->route('admin.app-center.index');
    }

    public function destroy(AppCenter $app_center){
        notification('error', 'Access permission denied.');
        return redirect()->route('admin.app-center.index');
        /*
        $app_center->delete();

        notification('success', $this->crudMessage('delete', 'app_center'));

        return redirect()->route('admin.app-center.index');
        */
    }


    public function cropPicture(Request $request){
        $path           = "storage/companyAdmin/app_logo/";
        if(File::ensureDirectoryExists($path)){
            File::makeDirectory($path);
        }
        $data           = $request->image;
        $image_array_1  = explode(";", $data);
        $image_array_2  = explode(",", $image_array_1[1]);
        $data           = base64_decode($image_array_2[1]);
        $fileName       = "logo_".time().".". 'png';
        $imageName      = $path.$fileName;
        file_put_contents($imageName, $data);
        echo $fileName;
   }

}
