<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Admin\AdminController;
use Illuminate\Http\Request;

use App\Http\Requests\Admin\ManageTypeStoreRequest;
use App\Http\Requests\Admin\ManageTypeUpdateRequest;

use App\Models\Company;

use App\Models\ManageType;
use App\Models\ManageCompanyType;

use DataTables;

class ManageTypeController extends AdminController{

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(){
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request){
        if ($request->ajax()) {
            $data = ManageType::leftJoin('manage_type_categories as mc', function($join) {
                    $join->on('manage_types.category_id', '=', 'mc.id');
                })
                ->select('manage_types.*','mc.name as category_name')
                ->get();

                return Datatables::of($data)
                    ->addIndexColumn()
                    ->addColumn('action', function($row){
                        //$btn = ' <a href="'.route('admin.manage-type.edit', $row->id).'"><img src="'.asset('theme/img/edit-icon.png').'" class="mr-4" alt=""></a>';
                        $btn = ' <a href="javascript:" class="destroy" data-action="'.route('admin.manage-type.destroy',$row->id).'" data-id="'.$row->id.'"><img src="'.asset('theme/img/delete-icon.png').'" alt=""></a>';
                        return $btn;
                    })
                    ->rawColumns(['action'])
                    ->make(true);
        }
        return view('admin.manageType.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(){
        return view('admin.manageType.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(ManageTypeStoreRequest $request){
        $input          = $request->except(['_token']);
        $manage_type    = ManageType::create($input);
        $get_company    = Company::get();
        foreach($get_company as $company){
            $input['company_id'] = $company->id;
            ManageCompanyType::create($input);
        }

        notification('success', $this->crudMessage('create', ''));

        return redirect()->route('admin.manage-type.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(){

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(ManageType $manageType){
        return view('admin.manageType.edit', compact('manageType'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(ManageTypeUpdateRequest $request, ManageType $manageType){
        $input = $request->except(['_token']);
        $manageType->update($input);

        notification('success', $this->crudMessage('update', ''));

        return redirect()->route('admin.manage-type.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request){
        $data = ManageType::find($request->id);
        $data->delete();

        notification('success', $this->crudMessage('delete', ''));

        return redirect()->route('admin.manage-type.index');
    }

}
