<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Admin\AdminController;
use App\Models\Company;
use App\Models\CompanyPmServiceType;
use App\Models\PmServiceType;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Yajra\DataTables\Facades\DataTables;

class PmServiceTypeController extends AdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(){
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $data = PmServiceType::get();
            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function($row){
                    $btn = '<a href="#" class="edit-btn mr-4" data-id="'.$row->id.'" data-toggle="modal" data-target="#editModal"><img src="'.asset('theme/img/edit-icon.png').'" alt=""></a>';

                    $btn = $btn.' <a href="javascript:" class="destroy" data-action="'.route('admin.pm-service-types.destroy', $row->id).'" data-id="'.$row->id.'"><img src="'.asset('theme/img/delete-icon.png').'" alt=""></a>';
                    return $btn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.pmServiceTypes.index');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $input      = $request->all();
        $validator  = Validator::make($input,[
            "name"  => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $data = PmServiceType::create($input);

        $getCompnay = Company::get();
        foreach ($getCompnay as $compnay){
            CompanyPmServiceType::create(['company_id' => $compnay->id, 'name' => $data->name]);
        }

        notification('success', $this->crudMessage('create', 'PmServiceType'));
        return response()->json(['success' => "PM Service Type created successfully"]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(PmServiceType $pmServiceType)
    {
        return view('admin.pmServiceTypes.edit', compact('pmServiceType'));
    }

    public function editFormView(Request $request)
    {
        $pmServiceType = PmServiceType::find($request->id);

        $view = view('admin.pmServiceTypes.editFormView', compact('pmServiceType'))->render();

        return response()->json(['view' => $view, 'data' => $pmServiceType]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, PmServiceType $pmServiceType)
    {
        $input = $request->all();

        $validator  = Validator::make($input,[
            "name"  => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }
        $pmServiceType->update($input);

        notification('success', $this->crudMessage('update', 'PmServiceType'));

        return response()->json(['success' => "PM Service Type updated successfully"]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(PmServiceType $pmServiceType)
    {
        CompanyPmServiceType::where('name', $pmServiceType->name)->where('company_id', 0)->delete();
        $pmServiceType->delete();

        notification('success', $this->crudMessage('delete', 'PmServiceType'));

        return redirect()->route('admin.pm-service-types.index');
    }
}
