<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Admin\AdminController;
use App\Models\AdminTrailerType;
use App\Models\TrailerType;
use App\Models\Company;


use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Yajra\DataTables\DataTables;

class TrailerTypeController extends AdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(){
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $data = AdminTrailerType::get();
            return DataTables::of($data)
                ->addIndexColumn()
                
                ->addColumn('is_temp_required', function($row){
                    return ($row->is_temp_required == 0) ? 'No' : 'Yes';
                })
                ->addColumn('action', function($row){
                    $btn = '<a href="#" class="edit-btn mr-4" data-id="'.$row->id.'" data-toggle="modal" data-target="#editModal"><img src="'.asset('theme/img/edit-icon.png').'" alt=""></a>';

                    $btn = $btn.' <a href="javascript:" class="destroy" data-action="'.route('admin.trailer-types.destroy', $row->id).'" data-id="'.$row->id.'"><img src="'.asset('theme/img/delete-icon.png').'" alt=""></a>';
                    return $btn;
                })
                ->rawColumns(['action','is_temp_required'])
                ->make(true);
        }
        return view('admin.trailerTypes.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return Redirect::back();
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $input      = $request->all();
        $validator  = Validator::make($input,[
            "name"  => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $data = AdminTrailerType::create($input);

        $getCompnay = Company::get();
        foreach ($getCompnay as $compnay){
            TrailerType::create(['company_id' => $compnay->id, 'name' => $data->name, 'is_temp_required' => $data->is_temp_required]);    
        }
        
        
        notification('success', $this->crudMessage('create', 'TrailerType'));
        return response()->json(['success' => "Trailer Type created successfully"]);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(AdminTrailerType $trailerType)
    {
        return redirect()->route('admin.trailer-types.index');
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(AdminTrailerType $trailerType)
    {
        return view('admin.trailerTypes.edit', compact('trailerType'));
    }

    public function editFormView(Request $request)
    {
        $trailerType = AdminTrailerType::find($request->id);

        $view = view('admin.trailerTypes.editFormView', compact('trailerType'))->render();

        return response()->json(['view' => $view, 'data' => $trailerType]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, AdminTrailerType $trailerType)
    {
        $input = $request->all();

        $validator  = Validator::make($input,[
            "name"  => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }
        $trailerType->update($input);

        notification('success', $this->crudMessage('update', 'TrailerType'));

        return response()->json(['success' => "Trailer Type updated successfully"]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(AdminTrailerType $trailerType)
    {
        TrailerType::where('name', $trailerType->name)->where('company_id', 0)->delete();
        $trailerType->delete();

        notification('success', $this->crudMessage('delete', 'TrailerType'));

        return redirect()->route('admin.trailer-types.index');
    }
}
