<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Admin\AdminController;
use App\Models\Company;
use App\Models\CompanyWorkOrder;
use App\Models\WorkOrder;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Yajra\DataTables\Facades\DataTables;

class WorkOrderController extends AdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(){
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $data = WorkOrder::get();
            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function($row){
                    $btn = '<a href="#" class="edit-btn mr-4" data-id="'.$row->id.'" data-toggle="modal" data-target="#editModal"><img src="'.asset('theme/img/edit-icon.png').'" alt=""></a>';

                    $btn = $btn.' <a href="javascript:" class="destroy" data-action="'.route('admin.work-order-documents.destroy', $row->id).'" data-id="'.$row->id.'"><img src="'.asset('theme/img/delete-icon.png').'" alt=""></a>';
                    return $btn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.workOrders.index');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $input      = $request->all();
        $validator  = Validator::make($input,[
            "name"  => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $data = WorkOrder::create($input);

        $getCompnay = Company::get();
        foreach ($getCompnay as $compnay){
            CompanyWorkOrder::create(['company_id' => $compnay->id, 'name' => $data->name]);
        }

        notification('success', $this->crudMessage('create', 'WorkOrderDocument'));
        return response()->json(['success' => "Work Order Document created successfully"]);
    }

    public function editFormView(Request $request)
    {
        $workOrderDocument = WorkOrder::find($request->id);

        $view = view('admin.workOrders.editFormView', compact('workOrderDocument'))->render();

        return response()->json(['view' => $view, 'data' => $workOrderDocument]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, WorkOrder $workOrderDocument)
    {
        $input = $request->all();

        $validator  = Validator::make($input,[
            "name"  => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }
        $workOrderDocument->update($input);

        notification('success', $this->crudMessage('update', 'WorkOrderDocument'));

        return response()->json(['success' => "Work Order Document updated successfully"]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(WorkOrder $workOrderDocument)
    {
        CompanyWorkOrder::where('name', $workOrderDocument->name)->where('company_id', 0)->delete();
        $workOrderDocument->delete();

        notification('success', $this->crudMessage('delete', 'WorkOrderDocument'));

        return redirect()->route('admin.work-order-documents.index');
    }
}
