<?php

namespace App\Http\Controllers\Auth\Admin;

use App\Http\Controllers\Controller;
use App\Models\TwoFactorSetting;
use Illuminate\Http\Request;
use App\Providers\RouteServiceProvider;
use Illuminate\Foundation\Auth\AuthenticatesUsers;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Session;

class LoginController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Login Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles authenticating users for the application and
    | redirecting them to your home screen. The controller uses a trait
    | to conveniently provide its functionality to your applications.
    |
    */

    use AuthenticatesUsers;

    /**
     * Where to redirect users after login.
     *
     * @var string
     */
    protected $redirectTo = '/admin/home';

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest')->except('logout');
    }

    /**
     * Display the form of super admin login.
     *
     * @return \Illuminate\Http\Response
    */
    public function showLoginForm()
    {
        if (Auth::guard('admin')->check()) {
            return redirect()->route('admin.home');
        } else {
            return view('auth.adminLogin');
        }
    }

    /**
     * Login to super admin.
     *
     * @return \Illuminate\Http\Response
    */
    public function login(Request $request)
    {
        $this->validate($request,[
            'email' => 'required|email',
            'password' => 'required',
        ]);

        if (Auth::guard('admin')->attempt(['email' => $request->email, 'password' => $request->password])) {
            /* If Enable 2-Factor Authentication - START */
            $twoFactorSettings = TwoFactorSetting::IsAdmin()->first();

            if(!is_null($twoFactorSettings) && $twoFactorSettings->enable_two_factor == '1'){
                auth()->guard('admin')->user()->generateTwoFactorCode();
                return redirect()->route('admin.two-factor-authentication.index');
            }
            /* If Enable 2-Factor Authentication - END */

            return redirect()->route('admin.home');
        } else {
            return redirect()->back()->with('error' , 'Email or password are wrong.');
        }

        return redirect()->back();
    }

    /**
     * Logout from super admin.
     *
     *
     * @return \Illuminate\Http\Response
    */
    public function logout()
    {
        Auth::guard('admin')->logout();

        // Session::flush();
        Session::forget('admin-2fa');

        return redirect()->route('admin.login');
    }
}
