<?php

namespace App\Http\Controllers\Auth\Admin;

use App\Http\Controllers\Controller;
use App\Providers\RouteServiceProvider;
use Illuminate\Foundation\Auth\ResetsPasswords;
use Illuminate\Http\Request;
use App\Models\PasswordReset;
use App\Models\Admin;
use Hash;
use Validator;
use Illuminate\Support\Arr;

class ResetPasswordController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Password Reset Controller
    |--------------------------------------------------------------------------
    |
    | This controller is responsible for handling password reset requests
    | and uses a simple trait to include this behavior. You're free to
    | explore this trait and override any methods you wish to tweak.
    |
    */

    use ResetsPasswords;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->passwordReset = new PasswordReset;
    }

    /**
     * Where to redirect users after resetting their password.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    /** 
     * Display the form of reset password.
     *
     * @return \Illuminate\Http\Response
    */
    public function showResetForm($token)
    {
        $data = $this->passwordReset->getPasswordResetWithToken($token);

        if (!is_null($data)){
            return view('auth.passwords.admin.reset', compact('data'));
        }else{
            return redirect()->route('admin.password.request')->with('forget_password_error_message',"Something Went To Wrong.");
        }
    }

    /** 
     * Reset new password.
     *
     * @return \Illuminate\Http\Response
    */
    public function reset(Request $request)
    {
        $input = $request->all();

        $passwordReset = $this->passwordReset->getPasswordResetWithToken($input['token']);

        $validator = Validator::make($input, [
            'email' =>  ['required',function($attribute, $value, $fail) use($passwordReset){
                            if ($value != $passwordReset->email) {
                                $fail('The email is invalid.');
                            }
                        }],
            'password'=>'required|same:confirm_password',
            'confirm_password'=>'required'
        ]);        

        if ($validator->passes()) {

            $input['password'] = Hash::make($input['password']);
            $input = Arr::except($input,array('confirm_password'));

            Admin::where('email',$passwordReset->email)->update(['password' => $input['password']]);

            $this->passwordReset->deleteUsingEmail($passwordReset->email);

            return redirect()->route('admin.login.view')->with('success','Your password has been reset successfully! You can login now.');
        }

        return redirect()->back()->withErrors($validator)->withInput(); 
    }
}
