<?php

namespace App\Http\Controllers\Auth\DriverAdmin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use App\Providers\RouteServiceProvider;

use Illuminate\Support\Arr;
use Illuminate\Foundation\Auth\ResetsPasswords;

use App\Models\Driver;
use App\Models\PasswordReset;

use Hash;
use Validator;

class ResetPasswordController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Password Reset Controller
    |--------------------------------------------------------------------------
    |
    | This controller is responsible for handling password reset requests
    | and uses a simple trait to include this behavior. You're free to
    | explore this trait and override any methods you wish to tweak.
    |
    */

    use ResetsPasswords;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->passwordReset = new PasswordReset;
    }

    /**
     * Where to redirect users after resetting their password.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    /** 
     * Display the form of reset password.
     *
     * @return \Illuminate\Http\Response
    */
    public function showResetForm($token)
    {
        $data = $this->passwordReset->getPasswordResetWithToken($token);
        if (!is_null($data)){
            return view('auth.passwords.driverAdmin.reset', compact('data'));
        }else{
            return redirect()->route('driver.admin.password.request')->with('forget_password_error_message',"Something Went To Wrong.");
        }
    }

    /** 
     * Reset new password.
     *
     * @return \Illuminate\Http\Response
    */
    public function reset(Request $request)
    {
        $input          = $request->all();
        $passwordReset  = $this->passwordReset->getPasswordResetWithToken($input['token']);
        $validator      = Validator::make($input, [
            'email'             =>  ['
                required',function($attribute, $value, $fail) use($passwordReset){
                    if ($value != $passwordReset->email) {
                        $fail('The email is invalid.');
                    }
                }],
            'password'          => 'required|same:confirm_password',
            'confirm_password'  => 'required'
        ]);        

        if ($validator->passes()) {
            $input['password']  = Hash::make($input['password']);
            $input              = Arr::except($input,array('confirm_password'));

            Driver::where('email',$passwordReset->email)->update(['password' => $input['password']]);

            $this->passwordReset->deleteUsingEmail($passwordReset->email);

            return redirect()->route('driver.admin.login.view')->with('success','Your password has been reset successfully! You can login now.');
        }
        return redirect()->back()->withErrors($validator)->withInput(); 
    }
}
