<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;

use Illuminate\Http\Request;
use Illuminate\Support\Str;

use App\Models\Driver;
use App\Models\CompanyAdmin;

use App\Models\Announcement;
use App\Http\Requests\CompanyAdmin\AnnouncementStoreRequest;
use App\Http\Requests\CompanyAdmin\AnnouncementUpdateRequest;

use DB;
use DataTables;
use Carbon\Carbon;

class AnnouncementController extends CompanyAdminController{

    /**
     * Create a new controller instance.
     *
     * @return void
     */

    public $timeZone;
    public $timeZoneId;
    public $offset;

    public function __construct(){
        parent::__construct();

        $this->middleware(function ($request, $next) {
            $this->timeZone     = getTimeZone();
            $this->timeZoneId   = getTimeZoneId();
            $this->offset       = getTimeZoneOffset();

            return $next($request);
        });
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request){
        if ($request->ajax()) {
            $offset     = $this->offset;
            $search     = $request->search['value'] ?? '';
            if(auth()->guard('company-admin')->user()->type==0 || auth()->guard('company-admin')->user()->type==1){
                $data   = Announcement::query()
                    ->select(
                        '*',
                        DB::raw('CONVERT_TZ(announcements.created_at,"+00:00","'.$offset.'") as created_at')
                    )
                    ->where('module','Company')
                    ->where('company_id',auth()->guard('company-admin')->user()->company_id);
            }elseif (auth()->guard('company-admin')->user()->type==2) {
                $data   = Announcement::query()
                    ->select(
                        '*',
                        DB::raw('CONVERT_TZ(announcements.created_at,"+00:00","'.$offset.'") as created_at')
                    )
                    ->where('module','Company')
                    ->where(function($query) {
                        $query->where(function($q) {
                            $q->whereRaw('FIND_IN_SET(2,show_up)')
                                ->whereRaw('FIND_IN_SET("'.auth()->guard('company-admin')->user()->company_id.'",company_id)');
                        });
                    });
            }else{
                $data   = Announcement::query()
                    ->select(
                        '*',
                        DB::raw('CONVERT_TZ(announcements.created_at,"+00:00","'.$offset.'") as created_at')
                    )
                    ->where('module','Company');
            }
            return Datatables::of($data)
                    ->addIndexColumn()
                    ->editColumn('description', function ($data) {
                        return Str::limit(strip_tags($data->description), 50);
                    })
                    ->editColumn('created_at', function($data){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($data->created_at) ? Carbon::parse($data->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($data->created_at) ? Carbon::parse($data->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->addColumn('action', function($data){
                        $action = '<a href="'.route('company.admin.announcement.show',base64Encode($data->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-eye" aria-hidden="true"></i></a>';

                        if(auth()->guard('company-admin')->user()->type == '0'){
                            $action .= '<a href="'.route('company.admin.announcement.edit',base64Encode($data->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-pencil" aria-hidden="true"></i></a>';
                            $action .= '<a href="javascript:void(0);" class="btn btn-sm btn-outline-black-trash destroy" data-action="'.route('company.admin.announcement.destroy',$data->id).'" data-id="'.$data->id.'"><i class="fa fa-trash" aria-hidden="true"></i></a>';
                        }

                        return $action;
                    })
                    ->filterColumn('created_at', function ($query, $keyword) use ($search, $offset) {
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(announcements.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                        }else{
                            $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(announcements.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                        }
                    })
                    ->rawColumns(['action'])
                    ->make(true);
        }
        return view('companyAdmin.announcements.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(){
        return view('companyAdmin.announcements.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(AnnouncementStoreRequest $request){
        $input                          = $request->all();

        $showArry                       = [];
        if (isset($input['show_manager'])){
            $showArry[]                 = $input['show_manager'];
        }
        if (isset($input['show_dispatcher'])){
            $showArry[]                 = $input['show_dispatcher'];
        }
        if (isset($input['show_driver'])){
            $showArry[]                 = $input['show_driver'];
        }
        $show                           = null;
        if(!empty($showArry)){
            $show                       = implode(',', $showArry);
        }

        $notifyArry                     = [];
        $notifyUsers                    = [];
        if (isset($input['notify_manager'])){
            $notifyArry[]               = $input['notify_manager'];
            $notifyUsers['manager']     = CompanyAdmin::company()->manager()->get();
        }
        if (isset($input['notify_dispatcher'])){
            $notifyArry[]               = $input['notify_dispatcher'];
            $notifyUsers['dispatcher']  = CompanyAdmin::company()->dispatcher()->get();
        }
        if (isset($input['notify_driver'])){
            $notifyArry[]               = $input['notify_driver'];
            $notifyUsers['driver']      = Driver::isCompany()->get();
        }
        $notify                         = null;
        if(!empty($notifyArry)){
            $notify                     = implode(',', $notifyArry);
        }

        $announcement                   = Announcement::create([
            'name'                      => $input['name'],
            'description'               => $input['description'],
            'company_id'                => auth()->guard('company-admin')->user()->company_id,
            'show_up'                   => $show,
            'notify'                    => $notify,
            'module'                    => 'Company',
            'created_at'                => Carbon::now(),
            'created_by'                => auth()->guard('company-admin')->user()->id
        ]);

        if($announcement){
            if (!empty($notifyUsers)) {
                // Twilio's credentials are fetched from company table
                $getCompanyTwilioData   = getCompanyTwilioData();
                $message = 'There is new announcement so please login and check.';
                
                foreach ($notifyUsers as $key => $value) {
                    if($key=='manager'){
                        $users              = $notifyUsers[$key];
                        if($users->isNotEmpty()){
                            foreach ($users as $key => $user) {
                                createNotification(
                                    10, // source
                                    $announcement->name, // name
                                    $user->id, // user_id
                                    $user->type, // user_type
                                    1, // type
                                    $announcement->id, // action_id
                                    $announcement->description, // description
                                    'Notification', // module
                                    [], // properties
                                    $user->company_id // company_id
                                );
                                $checkNotify = isUnreadDelay($user->id, $user->type, 9);
                                if(isset($checkNotify)){
                                    if(isset($checkNotify->email) && $checkNotify->email==1 && isset($user->email)) {
                                        $details                    = [];
                                        $details['company_id']      = $user->company_id;
                                        $details['email']           = $user->email;
                                        $details['name']            = $user->full_name;
                                        $details['announcement']    = $announcement;
                                        //dispatch(new App\Jobs\AnnouncementEmailJob($details));
                                        //\Mail::to($user->email)->send(new \App\Mail\AnnouncementEmail($details));
                                        sendEmail($user->email, new \App\Mail\AnnouncementEmail($details));
                                    }
                                    if (isset($checkNotify->sms) && $checkNotify->sms==1 && isset($user->cell_phone)) {
                                        if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
                                            sendSMS($user->cell_phone, $message, $getCompanyTwilioData, array('company_id' => $user->company_id, 'user_id' => $user->id));
                                        }
                                    }
                                }
                            }
                        }
                    }elseif ($key=='dispatcher') {
                        $users              = $notifyUsers[$key];
                        if($users->isNotEmpty()){
                            foreach ($users as $key => $user) {
                                createNotification(
                                    10, // source
                                    $announcement->name, // name
                                    $user->id, // user_id
                                    $user->type, // user_type
                                    1, // type
                                    $announcement->id, // action_id
                                    $announcement->description, // description
                                    'Notification', // module
                                    [], // properties
                                    $user->company_id // company_id
                                );
                                $checkNotify = isUnreadDelay($user->id, $user->type, 9);
                                if(isset($checkNotify)){
                                    if(isset($checkNotify->email) && $checkNotify->email==1 && isset($user->email)) {
                                        $details                    = [];
                                        $details['company_id']      = $user->company_id;
                                        $details['email']           = $user->email;
                                        $details['name']            = $user->full_name;
                                        $details['announcement']    = $announcement;
                                        //dispatch(new App\Jobs\AnnouncementEmailJob($details));
                                        //\Mail::to($user->email)->send(new \App\Mail\AnnouncementEmail($details));
                                        sendEmail($user->email, new \App\Mail\AnnouncementEmail($details));
                                    }
                                    if (isset($checkNotify->sms) && $checkNotify->sms==1 && isset($user->cell_phone)) {
                                        if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
                                            sendSMS($user->cell_phone, $message, $getCompanyTwilioData, array('company_id' => $user->company_id, 'user_id' => $user->id));
                                        }
                                    }
                                }
                            }
                        }
                    }elseif ($key=='driver') {
                        $users              = $notifyUsers[$key];
                        if($users->isNotEmpty()){
                            foreach ($users as $key => $user) {
                                createNotification(
                                    10, // source
                                    $announcement->name, // name
                                    $user->id, // user_id
                                    3, // user_type
                                    1, // type
                                    $announcement->id, // action_id
                                    $announcement->description, // description
                                    'Notification', // module
                                    [], // properties
                                    $user->company_id // company_id
                                );
                                $checkNotify = isUnreadDelay($user->id, 3, 9);
                                if(isset($checkNotify)){
                                    if(isset($checkNotify->email) && $checkNotify->email==1 && isset($user->email)) {
                                        $details                    = [];
                                        $details['company_id']      = $user->company_id;
                                        $details['email']           = $user->email;
                                        $details['name']            = $user->full_name;
                                        $details['announcement']    = $announcement;
                                        //dispatch(new App\Jobs\AnnouncementEmailJob($details));
                                        //\Mail::to($user->email)->send(new \App\Mail\AnnouncementEmail($details));
                                        sendEmail($user->email, new \App\Mail\AnnouncementEmail($details));
                                    }
                                    if (isset($checkNotify->sms) && $checkNotify->sms==1 && isset($user->cell_phone)) {
                                        if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
                                            sendSMS($user->cell_phone, $message, $getCompanyTwilioData, array('company_id' => $user->company_id, 'user_id' => $user->id));
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }

        notification('success', $this->crudMessage('create', 'Announcement'));

        return redirect()->route('company.admin.announcement.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id){
        $announcement=Announcement::find(base64Decode($id));
        $getTimeZone    = $this->timeZone;
        $getTimeZoneId  = $this->timeZoneId;
        return view('companyAdmin.announcements.show', compact('announcement', 'getTimeZone', 'getTimeZoneId'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id){
        $announcement=Announcement::find(base64Decode($id));
        return view('companyAdmin.announcements.edit', compact('announcement'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(AnnouncementUpdateRequest $request, Announcement $announcement){
        $input                          = $request->all();

        $showArry                       = [];
        if (isset($input['show_manager'])){
            $showArry[]                 = $input['show_manager'];
        }
        if (isset($input['show_dispatcher'])){
            $showArry[]                 = $input['show_dispatcher'];
        }
        if (isset($input['show_driver'])){
            $showArry[]                 = $input['show_driver'];
        }
        $show                           = null;
        if(!empty($showArry)){
            $show                       = implode(',', $showArry);
        }

        $notifyArry                     = [];
        $notifyUsers                    = [];
        if (isset($input['notify_manager'])){
            $notifyArry[]               = $input['notify_manager'];
            $notifyUsers['manager']     = CompanyAdmin::company()->manager()->get();
        }
        if (isset($input['notify_dispatcher'])){
            $notifyArry[]               = $input['notify_dispatcher'];
            $notifyUsers['dispatcher']  = CompanyAdmin::company()->dispatcher()->get();
        }
        if (isset($input['notify_driver'])){
            $notifyArry[]               = $input['notify_driver'];
            $notifyUsers['driver']      = Driver::isCompany()->get();
        }
        $notify                         = null;
        if(!empty($notifyArry)){
            $notify                     = implode(',', $notifyArry);
        }

        $announcement->name             = $input['name'];
        $announcement->description      = $input['description'];
        $announcement->company_id       = auth()->guard('company-admin')->user()->company_id;
        $announcement->show_up          = $show;
        $announcement->notify           = $notify;
        $announcement->module           = 'Company';
        $announcement->updated_at       = Carbon::now();
        $announcement->updated_by       = auth()->guard('company-admin')->user()->id;
        if($announcement->save()){
            if (!empty($notifyUsers)) {
                // Twilio's credentials are fetched from company table
                $getCompanyTwilioData   = getCompanyTwilioData();
                $message = 'There is new announcement so please login and check.';
                foreach ($notifyUsers as $key => $value) {
                    if($key=='manager'){
                        $users              = $notifyUsers[$key];
                        if($users->isNotEmpty()){
                            foreach ($users as $key => $user) {
                                createNotification(
                                    10, // source
                                    $announcement->name, // name
                                    $user->id, // user_id
                                    $user->type, // user_type
                                    1, // type
                                    $announcement->id, // action_id
                                    $announcement->description, // description
                                    'Notification', // module
                                    [], // properties
                                    $user->company_id // company_id
                                );
                                $checkNotify = isUnreadDelay($user->id, $user->type, 9);
                                if(isset($checkNotify)){
                                    if(isset($checkNotify->email) && $checkNotify->email==1 && isset($user->email)) {
                                        $details                    = [];
                                        $details['company_id']      = $user->company_id;
                                        $details['email']           = $user->email;
                                        $details['name']            = $user->full_name;
                                        $details['announcement']    = $announcement;
                                        //dispatch(new App\Jobs\AnnouncementEmailJob($details));
                                        //\Mail::to($user->email)->send(new \App\Mail\AnnouncementEmail($details));
                                        sendEmail($user->email, new \App\Mail\AnnouncementEmail($details));
                                    }
                                    if (isset($checkNotify->sms) && $checkNotify->sms==1 && isset($user->cell_phone)) {
                                        if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
                                            sendSMS($user->cell_phone, $message, $getCompanyTwilioData, array('company_id' => $user->company_id, 'user_id' => $user->id));
                                        }
                                    }
                                }
                            }
                        }
                    }elseif ($key=='dispatcher') {
                        $users              = $notifyUsers[$key];
                        if($users->isNotEmpty()){
                            foreach ($users as $key => $user) {
                                createNotification(
                                    10, // source
                                    $announcement->name, // name
                                    $user->id, // user_id
                                    $user->type, // user_type
                                    1, // type
                                    $announcement->id, // action_id
                                    $announcement->description, // description
                                    'Notification', // module
                                    [], // properties
                                    $user->company_id // company_id
                                );
                                $checkNotify = isUnreadDelay($user->id, $user->type, 9);
                                if(isset($checkNotify)){
                                    if(isset($checkNotify->email) && $checkNotify->email==1 && isset($user->email)) {
                                        $details                    = [];
                                        $details['company_id']      = $user->company_id;
                                        $details['email']           = $user->email;
                                        $details['name']            = $user->full_name;
                                        $details['announcement']    = $announcement;
                                        //dispatch(new App\Jobs\AnnouncementEmailJob($details));
                                        //\Mail::to($user->email)->send(new \App\Mail\AnnouncementEmail($details));
                                        sendEmail($user->email, new \App\Mail\AnnouncementEmail($details));
                                    }
                                    if (isset($checkNotify->sms) && $checkNotify->sms==1 && isset($user->cell_phone)) {
                                        if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){

                                            sendSMS($user->cell_phone, $message, $getCompanyTwilioData, array('company_id' => $user->company_id, 'user_id' => $user->id));
                                        }
                                    }

                                }
                            }
                        }
                    }elseif ($key=='driver') {
                        $users              = $notifyUsers[$key];
                        if($users->isNotEmpty()){
                            foreach ($users as $key => $user) {
                                createNotification(
                                    10, // source
                                    $announcement->name, // name
                                    $user->id, // user_id
                                    3, // user_type
                                    1, // type
                                    $announcement->id, // action_id
                                    $announcement->description, // description
                                    'Notification', // module
                                    [], // properties
                                    $user->company_id // company_id
                                );
                                $checkNotify = isUnreadDelay($user->id, 3, 9);
                                if(isset($checkNotify)){
                                    if(isset($checkNotify->email) && $checkNotify->email==1 && isset($user->email)) {
                                        $details                    = [];
                                        $details['company_id']      = $user->company_id;
                                        $details['email']           = $user->email;
                                        $details['name']            = $user->full_name;
                                        $details['announcement']    = $announcement;
                                        //dispatch(new App\Jobs\AnnouncementEmailJob($details));
                                        //\Mail::to($user->email)->send(new \App\Mail\AnnouncementEmail($details));
                                        sendEmail($user->email, new \App\Mail\AnnouncementEmail($details));
                                    }
                                    if (isset($checkNotify->sms) && $checkNotify->sms==1 && isset($user->cell_phone)) {
                                        if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
                                            sendSMS($user->cell_phone, $message, $getCompanyTwilioData, array('company_id' => $user->company_id, 'user_id' => $user->id));
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }

        notification('success', $this->crudMessage('update', 'Announcement'));

        return redirect()->route('company.admin.announcement.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Announcement $announcement){
        $announcement->delete();
        notification('success', $this->crudMessage('delete', 'Announcement'));
        return redirect()->route('company.admin.announcement.index');
    }
}
