<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use App\Models\ShortUrl;
use App\Models\LoadAppointment;
use App\Models\LoadAppointmentLog;

use App\Traits\AuditLoagTrait;

use DB;
use Validator;
use Carbon\Carbon;

class AppointmentRequestController extends Controller
{

    use AuditLoagTrait;

	public function redirect($code){
        $shortUrl = ShortUrl::where('short_code', $code)->first();
        if ($shortUrl) {
            return redirect($shortUrl->long_url);
        }
        return abort(404); // Handle case when the identifier is not found
    }

    public function view($encryptedId, $encryptedText, $encryptedSource){
        $id                                     = decryptData($encryptedId);

        $text                                   = decryptData($encryptedText);
        $text_array                             = explode('|', $text);
        if(count($text_array) !== 3){
            return abort(404); // Handle case when the identifier is not found
        }

        $source                                 = decryptData($encryptedSource);

        $appointment                            = LoadAppointment::findOrFail($id);

        $appointment_contacts                   = [];
        if($source == '2'){
            if(isset($appointment->broker->phone)){
                $appointment_contacts[]         = [
                    'table'                     => 'brokers',
                    'field_name'                => 'phone',
                    'id'                        => $appointment->broker->id,
                    'name'                      => $appointment->broker->name,
                    'source'                    => $appointment->broker->phone,
                    'type'                      => 0 // brokers
                ];
            }
            if(isset($appointment->broker->billing_phone)){
                $appointment_contacts[]         = [
                    'table'                     => 'brokers',
                    'field_name'                => 'billing_phone',
                    'id'                        => $appointment->broker->id,
                    'name'                      => $appointment->broker->name,
                    'source'                    => $appointment->broker->billing_phone,
                    'type'                      => 0 // brokers
                ];
            }
            if(isset($appointment->broker->broker_contact) && $appointment->broker->broker_contact->isNotEmpty()){
                foreach ($appointment->broker->broker_contact as $key => $cdata) {
                    if(isset($cdata->cell_number)){
                        $appointment_contacts[] = [
                            'table'             => 'broker_contacts',
                            'field_name'        => 'cell_number',
                            'id'                => $cdata->id,
                            'name'              => $cdata->name,
                            'source'            => $cdata->cell_number,
                            'type'              => 1
                        ];
                    }
                }
            }
            if(isset($appointment->customer->phone)){
                $appointment_contacts[]         = [
                    'table'                     => 'customers',
                    'field_name'                => 'phone',
                    'id'                        => $appointment->customer->id,
                    'name'                      => $appointment->customer->name,
                    'source'                    => $appointment->customer->phone,
                    'type'                      => 2 // customers
                ];
            }
        }else{
            if(isset($appointment->broker->email)){
                $appointment_contacts[]         = [
                    'table'                     => 'brokers',
                    'field_name'                => 'email',
                    'id'                        => $appointment->broker->id,
                    'name'                      => $appointment->broker->name,
                    'source'                     => $appointment->broker->email,
                    'type'                      => 0 // brokers
                ];
            }
            if(isset($appointment->broker->billing_email)){
                $appointment_contacts[]         = [
                    'table'                     => 'brokers',
                    'field_name'                => 'billing_email',
                    'id'                        => $appointment->broker->id,
                    'name'                      => $appointment->broker->name,
                    'source'                    => $appointment->broker->billing_email,
                    'type'                      => 0 // brokers
                ];
            }
            if(isset($appointment->broker->broker_contact) && $appointment->broker->broker_contact->isNotEmpty()){
                foreach ($appointment->broker->broker_contact as $key => $cdata) {
                    if(isset($cdata->email)){
                        $appointment_contacts[] = [
                            'table'             => 'broker_contacts',
                            'field_name'        => 'email',
                            'id'                => $cdata->id,
                            'name'              => $cdata->name,
                            'source'            => $cdata->email,
                            'type'              => 1
                        ];
                    }
                }
            }
            if(isset($appointment->customer->email)){
                $appointment_contacts[]         = [
                    'table'                     => 'customers',
                    'field_name'                => 'email',
                    'id'                        => $appointment->customer->id,
                    'name'                      => $appointment->customer->name,
                    'source'                    => $appointment->customer->email,
                    'type'                      => 2 // customers
                ];
            }
        }

        $appointment_contact                    = [];

        $filteredItems                          = array_filter($appointment_contacts, function ($var) use ($text_array) {
            // $text_array[0] = table, $text_array[1] = field_name, $text_array[2] = email, phone
            return $var['table'] === $text_array[0] && $var['field_name'] === $text_array[1] && $var['source'] === $text_array[2];
        });
        // Get the first matching key
        $matchingKeys                           = array_keys($filteredItems);
        $firstMatchingKey                       = reset($matchingKeys);
        if($firstMatchingKey!==false){
            $appointment_contact                = $appointment_contacts[$firstMatchingKey] ?? [];
        }
        if(empty($appointment_contact)){
            return abort(404); // Handle case when the identifier is not found
        }

        $reply_from                             = $appointment_contact['source'] ?? '';

        $getGeoTimeZone                         = getGeoTimeZone();
        return view('companyAdmin.appointment.broker.view', compact('appointment','appointment_contact','source','reply_from','getGeoTimeZone'));
    }

    public function save(Request $request){
        $response['success']                                    = false;
        $response['message']                                    = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $validator = Validator::make($request->all(), [
                    'review_status' => 'required',
                ]);
                if ($validator->fails()) {
                    $response['errors']                         = $validator->errors()->all();
                    $response['success']                        = false;
                    $response['message']                        = "Oops! Something went wrong..";
                } else {
                    $item                                       = LoadAppointment::where('id', $request->id)->first();
                    if(!is_null($item)){
                        $oldData                                = $item->toArray();
                        // 0=Pending,1=Confirm,2=Reject,3=Amended
                        $latestLog                              = $item->logs()->latest()->first();
                        if($request->review_status == '3'){ // Amended
                            $item->confirmation_numbers         = !empty($request->req_confirmation_number) ? implode(', ', $request->req_confirmation_number) : null;
                        }elseif($request->review_status == '1'){ // Confirm
                            $item->confirm_date                 = $latestLog->date;
                            $item->confirm_time                 = $latestLog->time;
                        }
                        $item->status                           = $request->review_status;
                        $item->status_at                        = Carbon::now()->format('Y-m-d H:i:s');
                        $item->updated_at                       = Carbon::now()->format('Y-m-d H:i:s');
                        if($item->save()){
                            if($item->wasChanged()){
                                $this->setLoadAudit($item->load_detail->load_id, 'update', 'Load appointment updated', $item->getChanges(), $oldData);
                            }

                            $newRecord                          = $latestLog->replicate();
                            if($request->review_status == '3'){ // Amended
                                $newRecord->date                = date('Y-m-d', strtotime($request->req_date));
                                $newRecord->time                = date('H:i:s', strtotime($request->req_time));
                            }
                            $newRecord->note                    = $request->req_note;
                            $newRecord->source                  = $request->source;
                            $newRecord->reply_from              = $request->reply_from;
                            $newRecord->reply_at                = Carbon::now()->format('Y-m-d H:i:s');
                            $newRecord->ip_address              = $request->ip();
                            $newRecord->review_user_type        = $request->review_user_type;
                            $newRecord->review_by               = $request->review_by;
                            $newRecord->review_status           = $request->review_status;
                            $newRecord->review_at               = Carbon::now()->format('Y-m-d H:i:s');
                            $newRecord->created_at              = Carbon::now()->format('Y-m-d H:i:s');
                            $newRecord->updated_at              = Carbon::now()->format('Y-m-d H:i:s');
                            if($newRecord->save()){
                                $response['success']            = true;
                                $response['message']            = "Appointment review request submitted successfully.";
                            }else{
                                $response['success']            = false;
                                $response['message']            = "Oops! Something went wrong..";
                            }
                        }
                    }else{
                        $response['success']                    = false;
                        $response['message']                    = "Detention record not found.";
                    }
                }
            }catch (\Exception $e) {
                $response['success']                            = false;
                $response['message']                            = $e->getMessage();
            }
        }
        return response()->json($response);
    }
}
