<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;

use App\Http\Requests\CompanyAdmin\BrokerStoreRequest;
use App\Http\Requests\CompanyAdmin\BrokerUpdateRequest;

use App\Models\Broker;
use App\Models\BrokerOffice;
use App\Models\BrokerContact;
use App\Models\BrokerAccessorial;

use App\Models\Bookmark;
use App\Models\FileUpload;
use App\Models\CompanyAccessorial;
use App\Models\CompanyLoadDocument;

use File;
use DataTables;
use Carbon\Carbon;
use App\Helpers\Common;

class BrokerController extends CompanyAdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(){
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request){
        $getCompanyAdmin            = auth()->guard('company-admin')->user();
        $getField                   = '';
        $isCheck                    = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','brokers')->first();
        if(!empty($isCheck->id)){
            //$getField               = unserialize($isCheck->config);
            $getField               = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_brokers_first'));
        }else{
            $getField               = config('settings.table_brokers_first');
        }
        if ($request->ajax()) {
            $data                   = Broker::isCompany();

            // General filter code - start
            foreach( $getField as $key => $value ) {
                $conditionReq       = 'search_string_condition_'.$key;
                $sortReq            = 'search_string_sort_'.$key;

                if( isset( request()->$conditionReq ) ) {
                    $typeReq        = 'search_string_type_'.$key;
                    $type           = request()->$typeReq;

                    if( $type == 'string' ) {
                        Common::getStringFilterResult( $data, $key );
                    }

                    if( $type == 'date' ) {
                        Common::getDateFilterResult( $data, $key );
                    }
                }

                if( isset( request()->$sortReq ) ) {
                    $nameReq        = 'search_string_name_'.$key;
                    $sortReq        = 'search_string_sort_'.$key;
                    $typeReq        = 'search_string_type_'.$key;
                    $tableNameReq   = 'search_table_name_'.$key;
                    $colAliasReq    = 'search_string_col_alias_'.$key;

                    $origData       = request()->$nameReq;
                    $condition_sort = request()->$sortReq;
                    $type           = request()->$typeReq;
                    $tableName      = isset( request()->$tableNameReq ) ? request()->$tableNameReq : '';
                    $colAlias       = isset( request()->$colAliasReq ) ? request()->$colAliasReq : '';

                    if( $type == 'string' ) {
                        if( isset( $condition_sort ) ) {
                            if( $colAlias != '' ) {
                                $data->orderBy( $tableName.'.'.$colAlias, $condition_sort );
                            } else {
                                if( $tableName != '' ) {
                                    $data->orderBy( $tableName.'.'.$origData, $condition_sort );
                                } else {
                                    $data->orderBy( $origData, $condition_sort );
                                }
                            }
                        }
                    }
                }
            }
            $data->select('*');
            /// end

            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function($row){
                    $action = '<a href="'.route('company.admin.brokers.show', base64Encode($row->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-eye" aria-hidden="true"></i></a>';
                    $action .= '<a href="'.route('company.admin.brokers.edit', base64Encode($row->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-pencil" aria-hidden="true"></i></a>';
                    $action .= '<a href="javascript:void(0);" class="btn btn-sm btn-outline-black-trash destroy" data-action="'.route('company.admin.trucks.destroy',$row->id).'" data-id="'.$row->id.'"><i class="fa fa-trash" aria-hidden="true"></i></a>';

                    return $action;
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        $tableName = 'settings.table_brokers';
        return view('companyAdmin.broker.index', compact('getField','tableName'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(){
        $broker                                 = new Broker;
        $load_documents                         = getCompanyLoadDocument();
        $shipper_files                          = [];
        $fixed_shipper_files                    = [];
        $consignee_files                        = [];
        $fixed_consignee_files                  = [];
        foreach ($load_documents as $key => $value) {
            $arry                               = $value->toArray();
            if($value->for_whom == 'shipper'){
                if($value->fixed == 'no'){
                    $shipper_files[]            = $arry;
                }else{
                    $fixed_shipper_files[]      = $arry;
                }
            }else if($value->for_whom == 'consignee'){
                if($value->fixed == 'no'){
                    $consignee_files[]          = $arry;
                }else{
                    $fixed_consignee_files[]    = $arry;
                }
            }else {
                if($value->fixed == 'no'){
                    $shipper_files[]            = $arry;
                    $consignee_files[]          = $arry;
                }else{
                    $fixed_shipper_files[]      = $arry;
                    $fixed_consignee_files[]    = $arry;
                }
            }
        }
        return view('companyAdmin.broker.createNew', compact('shipper_files', 'fixed_shipper_files', 'consignee_files', 'fixed_consignee_files'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(BrokerStoreRequest $request){
        // dd('Store Broker', $request->all());

        $input                                                          = $request->all();

        if($request->address_verified==1){
            $timezone                                                   = null;
            $timezone_offset                                            = null;
            if(isset($input['timezone_abbr'])){
                $timezone                                               = timezone_name_from_abbr($input['timezone_abbr']);
                $timezone_offset                                        = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['timezone']                                          = $timezone;
            $input['timezone_offset']                                   = $timezone_offset;
        }
        if($request->billing_address_verified==1){
            $billing_timezone                                           = null;
            $billing_timezone_offset                                    = null;
            if(isset($input['billing_timezone_abbr'])){
                $billing_timezone                                       = timezone_name_from_abbr($input['billing_timezone_abbr']);
                $billing_timezone_offset                                = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['billing_timezone']                                  = $billing_timezone;
            $input['billing_timezone_offset']                           = $billing_timezone_offset;
        }

        $input['company_id']                                            = auth()->guard('company-admin')->user()->company_id;
        if (isset($input['logo'])) {
            $input['logo']                                              = FileUpload::upload('companyAdmin/brokers', $input['logo']);
        }

        $shipper_files_array                                            = [];
        $shipper_i                                                      = 0;
        if(isset($request->shipper_files) && !empty($request->shipper_files)){
            foreach($request->shipper_files['name_id'] as $key => $sefdata){
                $shipper_files_array[$shipper_i]['name_id']             = isset($request->shipper_files['name_id'][$key]) ? $request->shipper_files['name_id'][$key] : '';
                $shipper_files_array[$shipper_i]['name']                = isset($request->shipper_files['name'][$key]) ? $request->shipper_files['name'][$key] : '';
                $shipper_files_array[$shipper_i]['is_required']         = isset($request->shipper_files['is_required'][$key]) ? $request->shipper_files['is_required'][$key] : 'off';
                $shipper_files_array[$shipper_i]['type']                = isset($request->shipper_files['type'][$key]) ? $request->shipper_files['type'][$key] : '';
                $shipper_files_array[$shipper_i]['fixed']               = isset($request->shipper_files['fixed'][$key]) ? $request->shipper_files['fixed'][$key] : '';
                $shipper_files_array[$shipper_i]['include_w_billing']   = isset($request->shipper_files['include_w_billing'][$key]) && $request->shipper_files['include_w_billing'][$key]=='yes' ? 'yes' : 'no';
                $shipper_i++;
            }
        }

        $consignee_files_array                                          = [];
        $consignee_i                                                    = 0;
        if(isset($request->consignee_files) && !empty($request->consignee_files)){
            foreach($request->consignee_files['name_id'] as $key => $sefdata){
                $consignee_files_array[$consignee_i]['name_id']         = isset($request->consignee_files['name_id'][$key]) ? $request->consignee_files['name_id'][$key] : '';
                $consignee_files_array[$consignee_i]['name']            = isset($request->consignee_files['name'][$key]) ? $request->consignee_files['name'][$key] : '';
                $consignee_files_array[$consignee_i]['is_required']     = isset($request->consignee_files['is_required'][$key]) ? $request->consignee_files['is_required'][$key] : 'off';
                $consignee_files_array[$consignee_i]['type']            = isset($request->consignee_files['type'][$key]) ? $request->consignee_files['type'][$key] : '';
                $consignee_files_array[$consignee_i]['fixed']           = isset($request->consignee_files['fixed'][$key]) ? $request->consignee_files['fixed'][$key] : '';
                $consignee_files_array[$consignee_i]['include_w_billing']= isset($request->consignee_files['include_w_billing'][$key]) && $request->consignee_files['include_w_billing'][$key]=='yes' ? 'yes' : 'no';
                $consignee_i++;
            }
        }

        $input['shipper_files']                                         = !empty($shipper_files_array) ? serialize($shipper_files_array) : null;
        $input['consignee_files']                                       = !empty($consignee_files_array) ? serialize($consignee_files_array) : null;
        if($input['account_number']!=""){
            $input['account_number']                                    = base64_encode($input['account_number']);
        }
        $broker                                                         = Broker::create($input);

        $offices                                                        = $request->offices ?? [];
        // $offices                                                     = array_filter($offices, function($var) {
        //     return isset($var['name']) && $var['name'] !== null;
        // });
        if(!empty($offices)){
            foreach ($offices as $key => $office) {
                $broker_offices                                         = [];
                $broker_offices['broker_id']                            = $broker->id;
                $broker_offices['name']                                 = $office['name'];
                $broker_offices['address_one']                          = $office['address'];
                $broker_offices['state']                                = $office['state'];
                $broker_offices['city']                                 = $office['city'];
                $broker_offices['zip']                                  = $office['zip'];
                if($office['address_verified']==1){
                    $timezone                                           = null;
                    $timezone_offset                                    = null;
                    if(isset($office['timezone_abbr'])){
                        $timezone                                       = timezone_name_from_abbr($office['timezone_abbr']);
                        $timezone_offset                                = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
                    }
                    $broker_offices['latitude']                         = $office['latitude'];
                    $broker_offices['longitude']                        = $office['longitude'];
                    $broker_offices['timezone']                         = $timezone;
                    $broker_offices['timezone_offset']                  = $timezone_offset;
                    $broker_offices['timezone_abbr']                    = $office['timezone_abbr'];
                }
                $broker_offices['address_verified']                     = $office['address_verified'];
                BrokerOffice::create($broker_offices);
            }
        }

        $additional_contacts                                            = $request->additional_contacts ?? [];
        if(!empty($additional_contacts)){
            foreach ($additional_contacts as $key => $contact) {
                $cat                                                    = [];
                $cat['source']                                          = 'broker';
                $cat['action_id']                                       = $broker->id;
                $cat['department']                                      = $contact['department'];

                $name                                                   = null;
                if(!is_null($contact['first_name'])){
                    $name                                               = $contact['first_name'];
                }
                if(!is_null($contact['last_name'])){
                    if(!is_null($name)){
                        $name                                           .= ' '.$contact['last_name'];
                    }else{
                        $name                                           = $contact['last_name'];
                    }
                }
                $cat['name']                                            = $name;
                $cat['first_name']                                      = $contact['first_name'];
                $cat['last_name']                                       = $contact['last_name'];

                $cat['phone_number']                                    = $contact['phone_number'];
                $cat['cell_number']                                     = $contact['cell_number'];
                $cat['ext']                                             = $contact['ext'];
                $cat['email']                                           = $contact['email'];

                $preferred_connections                                  = null;
                if(isset($contact['preferred_connections']) && !empty($contact['preferred_connections'])){
                    $preferred_connections                              = implode(',', $contact['preferred_connections']);
                }
                $cat['preferred_connections']                           = $preferred_connections;

                $primary_contact                                        = isset($contact['primary_contact'])?$contact['primary_contact']:0;
                $cat['primary_contact']                                 = $primary_contact;
                if($primary_contact==1){
                    $primary_contact_id                                 = null;
                    if(isset($contact['dispatcher_id']) && !empty($contact['dispatcher_id'])){
                        $primary_contact_id                             = implode(',', $contact['dispatcher_id']);
                    }
                    $cat['primary_contact_id']                          = $primary_contact_id;
                }else{
                    $cat['primary_contact_id']                          = null;
                }
                BrokerContact::create($cat);
            }
        }

        notification('success', $this->crudMessage('create', 'Broker'));
        return redirect()->route('company.admin.brokers.index');
    }

    /**
     * Display the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id){
        $id     = base64Decode($id);
        $broker = Broker::findOrFail($id);
        return view('companyAdmin.broker.show', compact('broker'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id){
        $id                                     = base64Decode($id);
        $broker                                 = Broker::findOrFail($id);
        if($broker->account_number!=""){
            $broker->account_number             = base64_decode($broker->account_number);
        }

        $accessorialList                        = CompanyAccessorial::isCompany()->get(['id', 'name', 'default_amount', 'gl_code']);
        $accessorialDropDown                    = "";
        if($accessorialList->count() > 0){
            $accessorialDropDown                .= '<option value="">Select accessorial</option>';
            foreach ($accessorialList as $accessorial){
                $accessorialDropDown            .= '<option value="'.$accessorial->id.'" data-default-amount="'.$accessorial->default_amount.'">'.$accessorial->name.'</option>';
            }
        }else{
            $accessorialDropDown                .= '<option value="" data-default-amount="">Select accessorial</option>';
        }

        $broker_shipper_files                   = [];
        if(isset($broker->shipper_files) && is_serialized($broker->shipper_files) && !empty(unserialize($broker->shipper_files))){
            $broker_shipper_files               = unserialize($broker->shipper_files);
            $broker_shipper_files               = array_filter($broker_shipper_files, function($var) {
                return isset($var['name_id']) && $var['name_id'] !== null;
            });
        }

        $broker_consignee_files                 = [];
        if(isset($broker->consignee_files) && is_serialized($broker->consignee_files) && !empty(unserialize($broker->consignee_files))){
            $broker_consignee_files             = unserialize($broker->consignee_files);
            $broker_consignee_files             = array_filter($broker_consignee_files, function($var) {
                return isset($var['name_id']) && $var['name_id'] !== null;
            });
        }

        $load_documents                         = getCompanyLoadDocument();
        $shipper_files                          = [];
        $fixed_shipper_files                    = [];
        $consignee_files                        = [];
        $fixed_consignee_files                  = [];
        foreach ($load_documents as $key => $value) {
            $arry                               = $value->toArray();
            if($value->for_whom == 'shipper'){
                if($value->fixed == 'no'){
                    $shipper_files[]            = $arry;
                }else{
                    $fixed_shipper_files[]      = $arry;
                }
            }else if($value->for_whom == 'consignee'){
                if($value->fixed == 'no'){
                    $consignee_files[]          = $arry;
                }else{
                    $fixed_consignee_files[]    = $arry;
                }
            }else {
                if($value->fixed == 'no'){
                    $shipper_files[]            = $arry;
                    $consignee_files[]          = $arry;
                }else{
                    $fixed_shipper_files[]      = $arry;
                    $fixed_consignee_files[]    = $arry;
                }
            }
        }

        return view('companyAdmin.broker.edit', compact(
                'broker',
                'accessorialDropDown',
                'broker_shipper_files',
                'broker_consignee_files',
                'shipper_files',
                'fixed_shipper_files',
                'consignee_files',
                'fixed_consignee_files'
            )
        );
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(BrokerUpdateRequest $request, Broker $broker){
        // dd('Update Broker', $request->all());

        $input                                                              = $request->all();

        if($request->address_verified==1){
            $timezone                                                       = null;
            $timezone_offset                                                = null;
            if(isset($input['timezone_abbr'])){
                $timezone                                                   = timezone_name_from_abbr($input['timezone_abbr']);
                $timezone_offset                                            = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['timezone']                                              = $timezone;
            $input['timezone_offset']                                       = $timezone_offset;
        }else{
            $input['latitude']                                              = null;
            $input['longitude']                                             = null;
            $input['timezone']                                              = null;
            $input['timezone_offset']                                       = null;
            $input['timezone_abbr']                                         = null;
        }
        if($request->billing_address_verified==1){
            $billing_timezone                                               = null;
            $billing_timezone_offset                                        = null;
            if(isset($input['billing_timezone_abbr'])){
                $billing_timezone                                           = timezone_name_from_abbr($input['billing_timezone_abbr']);
                $billing_timezone_offset                                    = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['billing_timezone']                                      = $billing_timezone;
            $input['billing_timezone_offset']                               = $billing_timezone_offset;
        }else{
            $input['billing_latitude']                                      = null;
            $input['billing_longitude']                                     = null;
            $input['billing_timezone']                                      = null;
            $input['billing_timezone_offset']                               = null;
            $input['billing_timezone_abbr']                                 = null;
        }

        if (isset($input['logo'])) {
            $input['logo']                                                  = FileUpload::upload('companyAdmin/brokers', $input['logo']);
        }else{
            if(!empty($input['remove_image'])){
                $input['logo']                                              = null;
            }
        }

        $shipper_files_array                                                = [];
        $shipper_i                                                          = 0;
        if(isset($request->shipper_files) && !empty($request->shipper_files)){
            foreach($request->shipper_files['name_id'] as $key => $sefdata){
                $shipper_files_array[$shipper_i]['name_id']                 = isset($request->shipper_files['name_id'][$key]) ? $request->shipper_files['name_id'][$key] : '';
                $shipper_files_array[$shipper_i]['name']                    = isset($request->shipper_files['name'][$key]) ? $request->shipper_files['name'][$key] : '';
                $shipper_files_array[$shipper_i]['is_required']             = isset($request->shipper_files['is_required'][$key]) ? $request->shipper_files['is_required'][$key] : 'off';
                $shipper_files_array[$shipper_i]['type']                    = isset($request->shipper_files['type'][$key]) ? $request->shipper_files['type'][$key] : '';
                $shipper_files_array[$shipper_i]['fixed']                   = isset($request->shipper_files['fixed'][$key]) ? $request->shipper_files['fixed'][$key] : '';
                $shipper_files_array[$shipper_i]['include_w_billing']       = isset($request->shipper_files['include_w_billing'][$key]) && $request->shipper_files['include_w_billing'][$key]=='yes' ? 'yes' : 'no';
                $shipper_i++;
            }
        }

        $consignee_files_array                                              = [];
        $consignee_i                                                        = 0;
        if(isset($request->consignee_files) && !empty($request->consignee_files)){
            foreach($request->consignee_files['name_id'] as $key => $sefdata){
                $consignee_files_array[$consignee_i]['name_id']             = isset($request->consignee_files['name_id'][$key]) ? $request->consignee_files['name_id'][$key] : '';
                $consignee_files_array[$consignee_i]['name']                = isset($request->consignee_files['name'][$key]) ? $request->consignee_files['name'][$key] : '';
                $consignee_files_array[$consignee_i]['is_required']         = isset($request->consignee_files['is_required'][$key]) ? $request->consignee_files['is_required'][$key] : 'off';
                $consignee_files_array[$consignee_i]['type']                = isset($request->consignee_files['type'][$key]) ? $request->consignee_files['type'][$key] : '';
                $consignee_files_array[$consignee_i]['fixed']               = isset($request->consignee_files['fixed'][$key]) ? $request->consignee_files['fixed'][$key] : '';
                $consignee_files_array[$consignee_i]['include_w_billing']   = isset($request->consignee_files['include_w_billing'][$key]) && $request->consignee_files['include_w_billing'][$key]=='yes' ? 'yes' : 'no';
                $consignee_i++;
            }
        }

        $input['shipper_files']                                             = !empty($shipper_files_array) ? serialize($shipper_files_array) : null;
        $input['consignee_files']                                           = !empty($consignee_files_array) ? serialize($consignee_files_array) : null;
        if($input['account_number']!=""){
            $input['account_number']                                        = base64_encode($input['account_number']);
        }
        $broker->update($input);

        // office
        $offices                                                            = $request->offices ?? [];
        // $offices                                                         = array_filter($offices, function($var) {
        //     return isset($var['name']) && $var['name'] !== null;
        // });

        $offices_old_id                                                     = array_column($offices, 'old_id');
        $offices_remove_query                                               = BrokerOffice::where('broker_id', $broker->id);
        if(!empty($offices_old_id)){
            $offices_remove_query->whereNotIn('id', $offices_old_id);
        }
        $offices_remove_query_result                                        = $offices_remove_query->get();

        if(!empty($offices)){
            foreach ($offices as $key => $office) {
                if(isset($office['old_id']) && $office['old_id']!=''){
                    $item                                                   = BrokerOffice::where('id', '=', $office['old_id'])->first();
                    if($item){
                        $item->name                                         = $office['name'];
                        $item->address_one                                  = $office['address'];
                        $item->state                                        = $office['state'];
                        $item->city                                         = $office['city'];
                        $item->zip                                          = $office['zip'];
                        if($office['address_verified']==1){
                            $timezone                                       = null;
                            $timezone_offset                                = null;
                            if(isset($office['timezone_abbr'])){
                                $timezone                                   = timezone_name_from_abbr($office['timezone_abbr']);
                                $timezone_offset                            = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
                            }
                            $item->latitude                                 = $office['latitude'];
                            $item->longitude                                = $office['longitude'];
                            $item->timezone                                 = $timezone;
                            $item->timezone_offset                          = $timezone_offset;
                            $item->timezone_abbr                            = $office['timezone_abbr'];
                        }else{
                            $item->latitude                                 = null;
                            $item->longitude                                = null;
                            $item->timezone                                 = null;
                            $item->timezone_offset                          = null;
                            $item->timezone_abbr                            = null;
                        }
                        $item->address_verified                             = $office['address_verified'];
                        $item->save();
                    }
                }else{
                    $item                                                   = new BrokerOffice();
                    $item->broker_id                                        = $broker->id;
                    $item->name                                             = $office['name'];
                    $item->address_one                                      = $office['address'];
                    $item->state                                            = $office['state'];
                    $item->city                                             = $office['city'];
                    $item->zip                                              = $office['zip'];
                    if($office['address_verified']==1){
                        $timezone                                           = null;
                        $timezone_offset                                    = null;
                        if(isset($office['timezone_abbr'])){
                            $timezone                                       = timezone_name_from_abbr($office['timezone_abbr']);
                            $timezone_offset                                = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
                        }
                        $item->latitude                                     = $office['latitude'];
                        $item->longitude                                    = $office['longitude'];
                        $item->timezone                                     = $timezone;
                        $item->timezone_offset                              = $timezone_offset;
                        $item->timezone_abbr                                = $office['timezone_abbr'];
                    }
                    $item->address_verified                                 = $office['address_verified'];
                    $item->save();
                }
            }
        }

        if($offices_remove_query_result->count() > 0){
            foreach ($offices_remove_query_result as $remove) {
                $remove->delete();
            }
        }

        // additional_contacts
        $additional_contacts                                                = $request->additional_contacts ?? [];

        $contacts_old_id                                                    = array_column($additional_contacts, 'old_id');
        $contacts_remove_query                                              = BrokerContact::where('action_id', $broker->id)->where('source', 'broker');
        if(!empty($contacts_old_id)){
            $contacts_remove_query->whereNotIn('id', $contacts_old_id);
        }
        $contacts_remove_query_result                                       = $contacts_remove_query->get();

        if(!empty($additional_contacts)){
            foreach ($additional_contacts as $key => $contact) {
                if(isset($contact['old_id']) && $contact['old_id']!=''){
                    $item                                                   = BrokerContact::where('id', '=', $contact['old_id'])->first();
                    if($item){
                        $item->office_id                                    = $contact['office_id'];
                        $item->department                                   = $contact['department'];

                        $name                                               = null;
                        if(!is_null($contact['first_name'])){
                            $name                                           = $contact['first_name'];
                        }
                        if(!is_null($contact['last_name'])){
                            if(!is_null($name)){
                                $name                  .= ' '.$contact['last_name'];
                            }else{
                                $name                                       = $contact['last_name'];
                            }
                        }

                        $item->name                                         = $name;
                        $item->first_name                                   = $contact['first_name'];
                        $item->last_name                                    = $contact['last_name'];

                        $item->phone_number                                 = $contact['phone_number'];
                        $item->cell_number                                  = $contact['cell_number'];
                        $item->ext                                          = $contact['ext'];
                        $item->email                                        = $contact['email'];

                        $preferred_connections                              = null;
                        if(isset($contact['preferred_connections']) && !empty($contact['preferred_connections'])){
                            $preferred_connections                          = implode(',', $contact['preferred_connections']);
                        }
                        $item->preferred_connections                        = $preferred_connections;

                        $primary_contact                                    = isset($contact['primary_contact'])?$contact['primary_contact']:0;
                        $item->primary_contact                              = $primary_contact;
                        if($primary_contact==1){
                            $primary_contact_id                             = null;
                            if(isset($contact['dispatcher_id']) && !empty($contact['dispatcher_id'])){
                                $primary_contact_id                         = implode(',', $contact['dispatcher_id']);
                            }
                            $item->primary_contact_id                       = $primary_contact_id;
                        }else{
                            $item->primary_contact_id                       = null;
                        }
                        $item->save();
                    }
                }else{
                    $cat                                                    = [];
                    $cat['source']                                          = 'broker';
                    $cat['action_id']                                       = $broker->id;
                    $cat['office_id']                                       = $contact['office_id'];
                    $cat['department']                                      = $contact['department'];

                    $name                                                   = null;
                    if(!is_null($contact['first_name'])){
                        $name                                               = $contact['first_name'];
                    }
                    if(!is_null($contact['last_name'])){
                        if(!is_null($name)){
                            $name                      .= ' '.$contact['last_name'];
                        }else{
                            $name                                           = $contact['last_name'];
                        }
                    }
                    $cat['name']                                            = $name;
                    $cat['first_name']                                      = $contact['first_name'];
                    $cat['last_name']                                       = $contact['last_name'];

                    $cat['phone_number']                                    = $contact['phone_number'];
                    $cat['cell_number']                                     = $contact['cell_number'];
                    $cat['ext']                                             = $contact['ext'];
                    $cat['email']                                           = $contact['email'];

                    $preferred_connections                                  = null;
                    if(isset($contact['preferred_connections']) && !empty($contact['preferred_connections'])){
                        $preferred_connections                              = implode(',', $contact['preferred_connections']);
                    }
                    $cat['preferred_connections']                           = $preferred_connections;

                    $primary_contact                                        = isset($contact['primary_contact'])?$contact['primary_contact']:0;
                    $cat['primary_contact']                                 = $primary_contact;
                    if($primary_contact==1){
                        $primary_contact_id                                 = null;
                        if(isset($contact['dispatcher_id']) && !empty($contact['dispatcher_id'])){
                            $primary_contact_id                             = implode(',', $contact['dispatcher_id']);
                        }
                        $cat['primary_contact_id']                          = $primary_contact_id;
                    }else{
                        $cat['primary_contact_id']                          = null;
                    }
                    BrokerContact::create($cat);
                }
            }
        }

        if($contacts_remove_query_result->count() > 0){
            foreach ($contacts_remove_query_result as $remove) {
                $remove->delete();
            }
        }
        //
        notification('success', $this->crudMessage('update', 'Broker'));
        return redirect()->route('company.admin.brokers.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Broker $broker){
        $broker->delete();
        notification('success', $this->crudMessage('delete', 'Broker'));
        return redirect()->route('company.admin.brokers.index');
    }

    public function addContact(Request $request){
        $input                          = $request->all();

        $cat                            = [];
        $cat['source']                  = 'broker';
        $cat['action_id']               = $input['action_id'];
        $cat['department']              = $input['department'];

        $name                           = null;
        if(!is_null($input['first_name'])){
            $name                       = $input['first_name'];
        }
        if(!is_null($input['last_name'])){
            if(!is_null($name)){
                $name                  .= ' '.$input['last_name'];
            }else{
                $name                   = $input['last_name'];
            }
        }
        $cat['name']                    = $name;
        $cat['first_name']              = $input['first_name'];
        $cat['last_name']               = $input['last_name'];

        $cat['phone_number']            = $input['phone_number'];
        $cat['cell_number']             = $input['cell_number'];
        $cat['ext']                     = $input['ext'];
        $cat['email']                   = $input['email'];

        $preferred_connections          = null;
        if(isset($input['preferred_connections']) && !empty($input['preferred_connections'])){
            $preferred_connections      = implode(',', $input['preferred_connections']);
        }
        $cat['preferred_connections']   = $preferred_connections;

        $primary_contact                = isset($input['primary_contact'])?$input['primary_contact']:0;
        $cat['primary_contact']         = $primary_contact;
        if($primary_contact==1){
            $primary_contact_id         = null;
            if(isset($input['dispatcher_id']) && !empty($input['dispatcher_id'])){
                $primary_contact_id     = implode(',', $input['dispatcher_id']);
            }
            $cat['primary_contact_id']  = $primary_contact_id;
        }else{
            $cat['primary_contact_id']  = null;
        }
        if(isset($input['include_address']) && $input['include_address'] == 1){
            $cat['include_department_address']  = 1;
        }
        if(isset($input['invite']) && $input['invite'] == 1){
            $cat['is_invite']           = 1;
        }
        $cat['created_by']              = auth()->guard('company-admin')->user()->id;
        $getBroker                      = BrokerContact::create($cat);
        return response()->json(['success' => true, 'id' => $getBroker->name]);
    }

    public function accessorialSave(Request $request){
        $response['success']                            = false;
        $response['message']                            = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                if($request->has('id') && !is_null($request->id)){
                    $item = BrokerAccessorial::where('id', $request->id)
                        ->update([
                            'company_accessorial_id'    => $request->company_accessorial_id,
                            'rate'                      => $request->rate,
                            'note'                      => $request->note
                        ]);
                    if($item){
                        $response['success']            = true;
                        $response['message']            = "Save successfully";
                    }else{
                        $response['success']            = false;
                        $response['message']            = "Oops! Something went wrong..";
                    }
                }else{
                    $item = BrokerAccessorial::create([
                        'broker_id'                     => $request->broker_id,
                        'company_accessorial_id'        => $request->company_accessorial_id,
                        'rate'                          => $request->rate,
                        'note'                          => $request->note
                    ]);
                    if($item){
                        $response['success']            = true;
                        $response['message']            = "Save successfully";
                    }else{
                        $response['success']            = false;
                        $response['message']            = "Oops! Something went wrong..";
                    }
                }
            }catch (\Exception $e) {
                $response['success']                    = false;
                $response['message']                    = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function accessorialDestroy(Request $request){
        $response['success']                            = false;
        $response['message']                            = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $item                                   = BrokerAccessorial::where('id',$request->id)->first();
                if($item){
                    $item->delete();
                    $response['success']                = true;
                    $response['message']                = "Deleted successfully";
                }else{
                    $response['success']                = false;
                    $response['message']                = "Record not found";
                }
            }catch (\Exception $e) {
                $response['success']                    = false;
                $response['message']                    = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function accessorialView(Request $request){
        $response['success']                            = false;
        $response['message']                            = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $item                                   = Broker::where('id',$request->id)->first();
                if(!is_null($item)){
                    $response['html']                   = view('companyAdmin.broker.ajax.accessorial', compact('item'))->render();
                    $response['success']                = true;
                    $response['message']                = "Retrieved successfully";
                }
            }catch (\Exception $e) {
                $response['success']                    = false;
                $response['message']                    = $e->getMessage();
            }
        }
        return response()->json($response);
    }
}
