<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use App\Models\ComplianceWidget;
use App\Models\Driver;
use App\Models\Trailer;
use App\Models\Truck;
use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Http\Request;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Str;

class ComplianceController extends CompanyAdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */

    public $company_admin;
    public $timeZone;
    public $defaultRange;
    public $listingDefaultRange;

    public function __construct()
    {
        parent::__construct();

        $this->middleware(function ($request, $next) {
            $this->company_admin        = auth()->guard('company-admin')->user();
            $this->timeZone             = getTimeZone();
            $this->defaultRange         = 'cy';
            $this->listingDefaultRange  = 'cy';

            return $next($request);
        });
    }

    /* ***************** Custom functions - START ***************** */
    public function getRangeTypes()
    {
        return [
            'pd' => 'Past Due',
            'cw' => 'Current Week',
            'nw' => 'Next Week',
            'nm' => 'Next Month',
            'n7d' => 'Next 7 days',
            'n14d' => 'Next 14 days',
            'n30d' => 'Next 30 days',
            'cm' => 'Current Month',
            'cq' => 'Current Quarter',
            'cy' => 'Current Year'
        ];
    }

    public function getIcons()
    {
        return [
            'pd' => 'theme/images/calendar-Due-date.svg',
            'cw' => 'theme/images/calendar-time.svg',
            'nw' => 'theme/images/calendar-time.svg',
            'nm' => 'theme/images/calendar-time.svg',
            'n7d' => 'theme/images/calendar-time.svg',
            'n14d' => 'theme/images/calendar-time.svg',
            'n30d' => 'theme/images/calendar-time.svg',
            'cm' => 'theme/images/calendar-time.svg',
            'cq' => 'theme/images/calendar-time.svg',
            'cy' => ''
        ];
    }

    public function isDraggable(Request $request)
    {
        $isDraggable = $request->isDraggable;

        ComplianceWidget::IsCompanyAdmin()->whereIn('tab', ['counter', 'list'])->update(['isDraggable' => $isDraggable]);

        return response()->json(['success' => true, 'message' => 'Updated successfully']);
    }

    public function getRangeDate($range, $format = "Y-m-d")
    {
        $startDate = null; $endDate = null;

        /*
        if($range == 'pd') { //Past Due
            $startDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->format($format);
        }elseif($range == 'cw') { //Current Week
            $startDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->startOfWeek()->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->endOfWeek()->format($format);
        }elseif($range == 'nw') { //Next Week
            $startDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->addDays(7)->startOfWeek()->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->addDays(7)->endOfWeek()->format($format);
        }elseif($range == 'nm') { //Next Month
            $startDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->addMonth()->startOfMonth()->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->addMonth()->endOfMonth()->format($format);
        }elseif($range == 'n7d') { //Next 7 days
            $startDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->addDays(7)->format($format);
        }elseif($range == 'n14d') { //Next 14 days
            $startDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->addDays(14)->format($format);
        }elseif($range == 'n30d') { //Next 30 days
            $startDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->addDays(30)->format($format);
        } elseif($range == 'cm') { //Current Month
            $startDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->startOfMonth()->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->endOfMonth()->format($format);
        }elseif($range == 'cq') { //Current Quarter
            $startDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->startOfQuarter()->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->endOfQuarter()->format($format);
        }else{ // Current Year
            $startDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->startOfYear()->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->subYear(1)->endOfYear()->format($format);
        }
        */

        if($range == 'pd') { //Past Due
            $startDate = Carbon::now()->timezone($this->timeZone)->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->format($format);
        }elseif($range == 'cw') { //Current Week
            $startDate = Carbon::now()->timezone($this->timeZone)->startOfWeek()->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->endOfWeek()->format($format);
        }elseif($range == 'nw') { //Next Week
            $startDate = Carbon::now()->timezone($this->timeZone)->addDays(7)->startOfWeek()->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->addDays(7)->endOfWeek()->format($format);
        }elseif($range == 'nm') { //Next Month
            $startDate = Carbon::now()->timezone($this->timeZone)->addMonth()->startOfMonth()->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->addMonth()->endOfMonth()->format($format);
        }elseif($range == 'n7d') { //Next 7 days
            $startDate = Carbon::now()->timezone($this->timeZone)->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->addDays(7)->format($format);
        }elseif($range == 'n14d') { //Next 14 days
            $startDate = Carbon::now()->timezone($this->timeZone)->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->addDays(14)->format($format);
        }elseif($range == 'n30d') { //Next 30 days
            $startDate = Carbon::now()->timezone($this->timeZone)->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->addDays(30)->format($format);
        } elseif($range == 'cm') { //Current Month
            $startDate = Carbon::now()->timezone($this->timeZone)->startOfMonth()->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->endOfMonth()->format($format);
        }elseif($range == 'cq') { //Current Quarter
            $startDate = Carbon::now()->timezone($this->timeZone)->startOfQuarter()->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->endOfQuarter()->format($format);
        }else{ // Current Year
            $startDate = Carbon::now()->timezone($this->timeZone)->startOfYear()->format($format);
            $endDate = Carbon::now()->timezone($this->timeZone)->endOfYear()->format($format);
        }

        return [
            'startDate' => $startDate,
            'endDate' => $endDate,
        ];
    }

    public function getRangeWiseRecordCount()
    {
        $countArray = array();
        $rangeArr = array_keys($this->getRangeTypes());

        foreach ($rangeArr as $range){
            $arrayData = array(
                $this->getNewDriverPipeline(['is_count' => true, 'range' => $range]),
                $this->getDrugAndAlcoholTesting(['is_count' => true, 'range' => $range]),
                $this->getMVRExp(['is_count' => true, 'range' => $range]),
                $this->getDriverLicenseExp(['is_count' => true, 'range' => $range]),
                $this->getMedicalCertExp(['is_count' => true, 'range' => $range]),
                $this->getNyhutRenewal(['is_count' => true, 'range' => $range]),
                $this->getTruckServices(['is_count' => true, 'range' => $range]),
                $this->getTrailerServices(['is_count' => true, 'range' => $range]),
                $this->getBirthdays(['is_count' => true, 'range' => $range]),
                $this->getWorkingAnniversary(['is_count' => true, 'range' => $range]),
                $this->get2290HeavyHighwayUse(['is_count' => true, 'range' => $range]),
            );

            $countArray[$range] = array_sum($arrayData);
        }

        return $countArray;
    }

    public function listTypes()
    {
        /*
         * Note:
         * If you want to add new listing follow below steps:
         * 1. Make new function for listing data e.g. getDrugAndAlcoholTesting($param = []);
         * 2. then new created function add under the getRangeWiseRecordCount() inside the $arrayData for counter
         * 3. then add new List name as key & as array element add new created function name & list of column name in below array
         */

        return [
            'New Driver Pipeline' => array(
                'functionName' => 'getNewDriverPipeline',
                'columns' => array('full_name' => 'Driver Name', 'stage' => 'Stage', 'start_date' => 'Proj. Start Date')
            ),
            'Drug & Alcohol Testing' => array(
                'functionName' => 'getDrugAndAlcoholTesting',
                'columns' => array('full_name' => 'Driver Name', 'drug_alcohol' => 'Due Date')
            ),
            'MVR Expiration' => array(
                'functionName' => 'getMVRExp',
                'columns' => array('full_name' => 'Driver Name', 'mvr_date' => 'Due Date')
            ),
            'Driver License Exp' => array(
                'functionName' => 'getDriverLicenseExp',
                'columns' => array('full_name' => 'Driver Name', 'license_exp' => 'Expiration Date')
            ),
            'Medical Certification Expiration' => array(
                'functionName' => 'getMedicalCertExp',
                'columns' => array('full_name' => 'Driver Name', 'medical_cert' => 'Expiration Date')
            ),
            'NYHUT Renewal' => array(
                'functionName' => 'getNyhutRenewal',
                'columns' => array('unit' => 'Unit No', 'nyhut_date' => 'Due Date')
            ),
            'Truck Services' => array(
                'functionName' => 'getTruckServices',
                'columns' => array('unit' => 'Unit No', 'type' => 'Type', 'truck_service_date' => 'Due Date')
            ),
            'Trailer Services' => array(
                'functionName' => 'getTrailerServices',
                'columns' => array('trailer_id' => 'Unit No', 'type' => 'Type', 'trailer_service_date' => 'Due Date')
            ),
            'Birthdays' => array(
                'functionName' => 'getBirthdays',
                'columns' => array('full_name' => 'Driver Name', 'birthday' => 'Birthdays')
            ),
            'Working Anniversary Date' => array(
                'functionName' => 'getWorkingAnniversary',
                'columns' => array('full_name' => 'Driver Name', 'anniversary' => 'Anniversary')
            ),
            '2290 Heavy Highway Use' => array(
                'functionName' => 'get2290HeavyHighwayUse',
                'columns' => array('unit' => 'Unit No', '2290_due_date' => 'Due Date')
            ),
        ];
    }

    public function getListdataArray($param = [])
    {
        $dataArray = [];
        $listTypes = $this->listTypes();

        $getComplianceLists = ComplianceWidget::IsCompanyAdmin()->where('tab', 'list')->get()->toArray();

        if(count($getComplianceLists) > 0){
            $lastDisplayNo = null; $isDraggable = null; $filters = null;
            foreach ($getComplianceLists as $complianceLists){
                if(isset($listTypes[$complianceLists['widget_name']])){
                    $functionName = $listTypes[$complianceLists['widget_name']]['functionName'];
                    $columnsName = $listTypes[$complianceLists['widget_name']]['columns'];
                    $filters = (!is_null($complianceLists['filters'])) ? unserialize($complianceLists['filters']) : null;
                    $getDBRecords = $this->$functionName(['range' => $complianceLists['range'], 'filter' => $filters]);

                    $dataArray[] = [
                        'id' => $complianceLists['id'],
                        'widget_name' => $complianceLists['widget_name'],
                        'displayNo' => $complianceLists['display_no'],
                        'range' => $complianceLists['range'],
                        'isActive' => $complianceLists['isActive'],
                        'isDraggable' => $complianceLists['isDraggable'],
                        'filters' => $filters,
                        'dataCount' => $getDBRecords['count'],
                        'columns' => $columnsName,
                        'data' => $getDBRecords['data'],
                        'isDefault' => 0,
                    ];

                    $lastDisplayNo = $complianceLists['display_no'] + 1;
                    $isDraggable = $complianceLists['isDraggable'];
                }
            }

            $defaultListing = array_keys($listTypes);
            $dbExistListing = array_column($getComplianceLists, 'widget_name');
            $newAddedList = array_values(array_diff($defaultListing, $dbExistListing));

            if(!empty($newAddedList)){
                $i = $lastDisplayNo;
                foreach ($newAddedList as $type){
                    $functionName = $listTypes[$type]['functionName'];
                    $columnsName = $listTypes[$type]['columns'];
                    $getDBRecords = $this->$functionName(['range' => $this->listingDefaultRange, 'filter' => $filters]);

                    $dataArray[] = [
                        'id' => null,
                        'widget_name' => $type,
                        'displayNo' => $i++,
                        'range' => $this->listingDefaultRange,
                        'isActive' => '1',
                        'isDraggable' => $isDraggable,
                        'filters' => $filters,
                        'dataCount' => $getDBRecords['count'],
                        'columns' => $columnsName,
                        'data' => $getDBRecords['data'],
                    ];
                }
            }
        }else{
            $i = 1;
            foreach ($listTypes as $type => $data){
                $functionName = $data['functionName'];
                $columnsName = $data['columns'];
                $getDBRecords = $this->$functionName(['range' => $this->listingDefaultRange, 'filter' => null]);

                $dataArray[] = [
                    'id' => Str::slug($type),
                    'widget_name' => $type,
                    'displayNo' => $i++,
                    'range' => $this->listingDefaultRange,
                    'isActive' => '1',
                    'isDraggable' => '0',
                    'filters' => null,
                    'dataCount' => $getDBRecords['count'],
                    'columns' => $columnsName,
                    'data' => $getDBRecords['data'],
                    'isDefault' => 1,
                ];
            }
        }

        $dataCol = array_column($dataArray, 'displayNo');
        array_multisort($dataCol, SORT_ASC, $dataArray);

        return $dataArray;
    }
    /* ***************** Custom functions - END ***************** */

    public function index(Request $request)
    {
        $iconArr = $this->getIcons();
        $rangeArr = $this->getRangeTypes();
        $rangeRecordCount = $this->getRangeWiseRecordCount();

        //Counter Widgets
        $getComplianceWidgets = ComplianceWidget::IsCompanyAdmin()->where('tab', 'counter')->orderBy('display_no', 'ASC')->get()->toArray();

        $defaultWidgets = []; $complianceWidgets = array();

        if(!empty($getComplianceWidgets)){
            $i = 1;
            foreach ($getComplianceWidgets as $widget){
                $complianceWidgets[$widget['display_no']] = array(
                    'display_no' => $widget['display_no'],
                    'range' => $widget['range'],
                    'isActive' => $widget['isActive'],
                    'count' => $rangeRecordCount[$widget['range']],
                    'widget_name' => $rangeArr[$widget['range']],
                    'icon' => $iconArr[$widget['range']],
                );
            }
        }else{
            $i = 1;
            foreach ($rangeArr as $sortName => $longName){
                $defaultWidgets[$i] = array(
                    'display_no' => $i,
                    'range' => $sortName,
                    'isActive' => ($i <= 5) ? '1' : '0',
                    'count' => $rangeRecordCount[$sortName],
                    'widget_name' => $longName,
                    'icon' => $iconArr[$sortName],
                );

                $i++;
            }
        }

        //List Widgets
        $complianceList = $this->getListdataArray();
        $isDefault = array_unique(array_column($complianceList, 'isDefault'))[0];
        $isDraggable = array_unique(array_column($complianceList, 'isDraggable'))[0];
        $filters = (!empty(array_filter(array_column($complianceList, 'filters')))) ? array_filter(array_column($complianceList, 'filters'))[0] : [];
        $listViews = view('companyAdmin.compliance.ajax_list_update',compact('rangeArr', 'complianceList'))->render();
        $listDisplayOption = view('companyAdmin.compliance.ajax_display_option_update', compact('rangeArr', 'complianceList'))->render();
        if($listViews == ""){
            $listViews = '<div class="col-12 text-center"><h3 class="font-weight-bold mt-5">No active list found</h3></div>';
        }

        return view('companyAdmin.compliance.index', compact('defaultWidgets', 'complianceWidgets', 'rangeArr', 'listViews', 'listDisplayOption', 'complianceList', 'isDraggable', 'isDefault', 'filters'));
    }

    public function widgetData(Request $request)
    {
        if ($request->ajax()) {
            try {
                $user = $this->company_admin;

                $iconArr = $this->getIcons();
                $rangeArr = $this->getRangeTypes();
                $rangeRecordCount = $this->getRangeWiseRecordCount();

                $dataArray = json_decode($request->dataArr, true);

                foreach (array_keys($rangeArr) as $range){
                    $getComplianceWidgets = ComplianceWidget::IsCompanyAdmin()->where('tab', 'counter')->where('range', $range)->first();

                    if(!is_null($getComplianceWidgets)){
                        $getComplianceWidgets->widget_name = $dataArray[$getComplianceWidgets->range]['itemName'];
                        $getComplianceWidgets->display_no = $dataArray[$getComplianceWidgets->range]['displayNo'];
                        $getComplianceWidgets->isActive = $dataArray[$getComplianceWidgets->range]['isActive'];
                        $getComplianceWidgets->updated_at = Carbon::now()->timezone($this->timeZone);
                        $getComplianceWidgets->save();
                    }else{
                        $insertArray = [];
                        $insertArray['company_id'] = $user->company_id;
                        $insertArray['company_admins_id'] = $user->id;
                        $insertArray['widget_name'] = $dataArray[$range]['itemName'];
                        $insertArray['display_no'] = $dataArray[$range]['displayNo'];
                        $insertArray['range'] = $range;
                        $insertArray['isActive'] = ($dataArray[$range]['isActive'] == '1') ? '1' : '0';
                        $insertArray['tab'] = 'counter';
                        $insertArray['guard_name'] = 'company-admin';
                        $insertArray['created_at'] = Carbon::now()->timezone($this->timeZone);

                        ComplianceWidget::create($insertArray);
                    }
                }

                $activeComplianceWidgets = ComplianceWidget::IsCompanyAdmin()->where('tab', 'counter')->where('isActive', '1')->orderBy('display_no', 'ASC')->get()->toArray();

                $updatedContent = '';
                foreach($activeComplianceWidgets as $widgets){
                    $updatedContent .= '<div class="grid-item">';
                    $updatedContent .= '<div class="card-box">';
                    $updatedContent .= '<div class="row align-items-xl-center">';
                    $updatedContent .= '<div class="col-xl-8 col-7">';
                    $updatedContent .= '<h2>'.(($rangeRecordCount[$widgets["range"]] < 10) ? sprintf("%02d", $rangeRecordCount[$widgets["range"]]) : $rangeRecordCount[$widgets["range"]]).'</h2>';
                    $updatedContent .= '<h5>'.$rangeArr[$widgets["range"]].'</h5>';
                    $updatedContent .= '</div>';
                    $updatedContent .= '<div class="col-xl-4 col-5 pl-0">';
                    $updatedContent .= '<img src="'.asset($iconArr[$widgets["range"]]).'" class="img-fluid" alt="">';
                    $updatedContent .= '</div>';
                    $updatedContent .= '</div>';
                    $updatedContent .= '</div>';
                    $updatedContent .= '</div>';
                }

                if(!empty($updatedContent)){
                    $response['widgetData'] = $updatedContent;
                    $response['success']  = true;
                    $response['message']  = "Widget updated successfully.";
                }else{
                    $response['success'] = false;
                    $response['message'] = "Widget record not found.";
                }
            } catch (\Exception $e) {
                $response['success'] = false;
                $response['message'] = $e->getMessage();
            }
            return response()->json($response);
        }else{
            return abort(404);
        }
    }

    public function listData(Request $request)
    {
        if ($request->ajax()) {
            try {
                $user = $this->company_admin;
                $rangeArr = $this->getRangeTypes();
                $dataArray = json_decode($request->dataArray, true);
                $dataFilterArray = array_filter(json_decode($request->filterArr, true));

                $getComplianceLists = ComplianceWidget::IsCompanyAdmin()->where('tab', 'list')->count();
                if($getComplianceLists > 0){
                    foreach ($dataArray as $data){
                        if($data['id'] != ""){
                            $getList = ComplianceWidget::IsCompanyAdmin()->where('tab', 'list')->where('id', $data['id'])->first();
                            $getList->widget_name = $data['listName'];
                            $getList->display_no = $data['displayNo'];
                            $getList->range = $data['range'];
                            $getList->isActive = $data['isActive'];
                            $getList->isDraggable = $data['isDraggable'];
                            $getList->filters = (!empty($dataFilterArray)) ? serialize($dataFilterArray) : null;
                            $getList->updated_at = Carbon::now()->timezone($this->timeZone);
                            $getList->save();
                        }else{
                            $insertArray = [];
                            $insertArray['company_id'] = $user->company_id;
                            $insertArray['company_admins_id'] = $user->id;
                            $insertArray['widget_name'] = $data['listName'];
                            $insertArray['display_no'] = $data['displayNo'];
                            $insertArray['range'] = $data['range'];
                            $insertArray['isActive'] = $data['isActive'];
                            $insertArray['isDraggable'] = $data['isDraggable'];
                            $insertArray['filters'] = (!empty($dataFilterArray)) ? serialize($dataFilterArray) : null;
                            $insertArray['tab'] = 'list';
                            $insertArray['guard_name'] = 'company-admin';
                            $insertArray['created_at'] = Carbon::now()->timezone($this->timeZone);

                            ComplianceWidget::create($insertArray);
                        }
                    }
                }else{
                    foreach ($dataArray as $data){
                        $insertArray = [];
                        $insertArray['company_id'] = $user->company_id;
                        $insertArray['company_admins_id'] = $user->id;
                        $insertArray['widget_name'] = $data['listName'];
                        $insertArray['display_no'] = $data['displayNo'];
                        $insertArray['range'] = $data['range'];
                        $insertArray['isActive'] = $data['isActive'];
                        $insertArray['isDraggable'] = $data['isDraggable'];
                        $insertArray['filters'] = (!empty($dataFilterArray)) ? serialize($dataFilterArray) : null;
                        $insertArray['tab'] = 'list';
                        $insertArray['guard_name'] = 'company-admin';
                        $insertArray['created_at'] = Carbon::now()->timezone($this->timeZone);

                        ComplianceWidget::create($insertArray);
                    }
                }

                $complianceList = $this->getListdataArray();

                if(isset($request->isViewAllPage) && $request->isViewAllPage == 'true'){
                    $displayListNo = $request->displayListNo;
                    $updatedListContent = view('companyAdmin.compliance.ajax_view_all_list', compact('rangeArr', 'complianceList', 'displayListNo'))->render();
                }else{
                    $updatedListContent = view('companyAdmin.compliance.ajax_list_update', compact('rangeArr', 'complianceList'))->render();
                    $updatedDOPContent = view('companyAdmin.compliance.ajax_display_option_update', compact('rangeArr', 'complianceList'))->render();
                }

                if($updatedListContent == ""){
                    $updatedListContent = '<div class="col-12 text-center"><h3 class="font-weight-bold mt-5">No active list found</h3></div>';
                }

                if(!empty($updatedListContent)){
                    $response['listData'] = $updatedListContent;
                    if(isset($updatedDOPContent)){
                        $response['displayOptionData'] = $updatedDOPContent;
                    }
                    $response['success']  = true;
                    $response['message']  = "List updated successfully.";
                }else{
                    if(isset($updatedDOPContent)){
                        $response['displayOptionData'] = $updatedDOPContent;
                    }
                    $response['success'] = false;
                    $response['message'] = "List record not found.";
                }
            } catch (\Exception $e) {
                $response['success'] = false;
                $response['message'] = $e->getMessage();
            }
            return response()->json($response);
        }else{
            return abort(404);
        }
    }

    public function listOption(Request $request)
    {
        if ($request->ajax()) {
            try {
                $rangeArr = $this->getRangeTypes();
                $dataArray = json_decode($request->dataArray, true);

                foreach ($dataArray as $data){
                    $getList = ComplianceWidget::IsCompanyAdmin()->where('tab', 'list')->where('id', $data['id'])->first();
                    $getList->display_no = $data['displayNo'];
                    $getList->updated_at = Carbon::now()->timezone($this->timeZone);
                    $getList->save();
                }

                $complianceList = $this->getListdataArray();
                $updatedDOPContent = view('companyAdmin.compliance.ajax_display_option_update', compact('rangeArr', 'complianceList'))->render();

                if(!empty($updatedDOPContent)){
                    $response['displayOptionData'] = $updatedDOPContent;
                    $response['success']  = true;
                    $response['message']  = "List updated successfully.";
                }else{
                    $response['success'] = false;
                    $response['message'] = "Something went wrong!";
                }
            } catch (\Exception $e) {
                $response['success'] = false;
                $response['message'] = $e->getMessage();
            }
            return response()->json($response);
        }else{
            return abort(404);
        }
    }

    public function getNewDriverPipeline($param = [])
    {
        $range = (isset($param['range'])) ? $param['range'] : $this->defaultRange;
        $filter = (isset($param['filter'])) ? $param['filter'] : [];

        $rangeDate = $this->getRangeDate($range);

        $newDriverPipeline = Driver::select('drivers.id', 'drivers.first_name', 'drivers.last_name', 'drivers.start_date', 'driver_onboardings.detail')
                                ->join('driver_informations','driver_informations.driver_id','=','drivers.id')
                                ->leftjoin('driver_onboardings','driver_onboardings.driver_id','=','drivers.id')
                                ->whereNotNull('drivers.start_date')
                                ->where('drivers.company_id', $this->company_admin->company_id)
                                ->where(function ($query) use ($filter){
                                    if(!empty($filter)){
                                        if(isset($filter['carrierFilter'])){
                                            $query->whereIn('driver_informations.carrier_id', $filter['carrierFilter']);
                                        }
                                        if(isset($filter['terminalFilter'])){
                                            $query->whereIn('driver_informations.terminal_id', $filter['terminalFilter']);
                                        }
                                        if(isset($filter['teamFilter'])){
                                            $query->whereIn('drivers.team_id', $filter['teamFilter']);
                                        }
                                        if(isset($filter['dispatcherFilter'])){
                                            $query->whereIn('drivers.manager_id', $filter['dispatcherFilter']);
                                        }
                                        if(isset($filter['equipmentFilter'])){
                                            $query->whereIn('driver_informations.trailer_type', $filter['equipmentFilter']);
                                        }
                                    }
                                })
                                ->where(function ($query) use($range, $rangeDate) {
                                    if($range == 'pd'){
                                        $query->where('drivers.start_date', '<' , $rangeDate['startDate']);
                                    }elsE{
                                        $query->where('drivers.start_date', '>=' , $rangeDate['startDate']);
                                        $query->where('drivers.start_date', '<=' , $rangeDate['endDate']);
                                    }
                                })
                                ->orderBy('start_date');

        if(isset($param['is_count'])){
            return $newDriverPipeline->count();
        }else{
            $newDriverPipeline = $newDriverPipeline->get();

            foreach ($newDriverPipeline as $key => $newDriver){
                $newDriverPipeline[$key]->stage = null;
                if(!is_null($newDriver->detail)){
                    $detailJson = json_decode($newDriver->detail, 'true');
                    $collection = collect($detailJson);
                    $filtered_collection = $collection->filter(function ($item) {
                        return $item['yes_no'] == 1 && $item['is_complete'] == 1;
                    })->last();
                    if(!is_null($filtered_collection)){
                        $newDriverPipeline[$key]->stage = $filtered_collection['stage_no'];
                    }
                }
            }

            return array(
                'count' => $newDriverPipeline->count(),
                'data' => $newDriverPipeline->toArray()
            );
        }
    }

    public function getDrugAndAlcoholTesting($param = [])
    {
        $range = (isset($param['range'])) ? $param['range'] : $this->defaultRange;
        $filter = (isset($param['filter'])) ? $param['filter'] : [];

        $rangeDate = $this->getRangeDate($range);

        $drugAndAlcoholTesting = Driver::select('drivers.first_name', 'drivers.last_name', 'drivers.drug_alcohol')
                                    ->join('driver_informations','driver_informations.driver_id','=','drivers.id')
                                    ->where('drivers.company_id', $this->company_admin->company_id)
                                    ->where(function ($query) use ($filter){
                                        if(!empty($filter)){
                                            if(isset($filter['carrierFilter'])){
                                                $query->whereIn('driver_informations.carrier_id', $filter['carrierFilter']);
                                            }
                                            if(isset($filter['terminalFilter'])){
                                                $query->whereIn('driver_informations.terminal_id', $filter['terminalFilter']);
                                            }
                                            if(isset($filter['teamFilter'])){
                                                $query->whereIn('drivers.team_id', $filter['teamFilter']);
                                            }
                                            if(isset($filter['dispatcherFilter'])){
                                                $query->whereIn('drivers.manager_id', $filter['dispatcherFilter']);
                                            }
                                            if(isset($filter['equipmentFilter'])){
                                                $query->whereIn('driver_informations.trailer_type', $filter['equipmentFilter']);
                                            }
                                        }
                                    })
                                    ->whereNotNull('drivers.drug_alcohol')
                                    ->where(function ($query) use($range, $rangeDate) {
                                        if($range == 'pd'){
                                            $query->where('drivers.drug_alcohol', '<' , $rangeDate['startDate']);
                                        }elsE{
                                            $query->where('drivers.drug_alcohol', '>=', $rangeDate['startDate']);
                                            $query->where('drivers.drug_alcohol', '<=', $rangeDate['endDate']);
                                        }
                                    })
                                    ->orderBy('drug_alcohol');

        if(isset($param['is_count'])){
            return $drugAndAlcoholTesting->count();
        }else{
            return array(
                'count' => $drugAndAlcoholTesting->count(),
                'data' => $drugAndAlcoholTesting->get()->toArray()
            );
        }
    }

    public function getMVRExp($param = [])
    {
        $range = (isset($param['range'])) ? $param['range'] : $this->defaultRange;
        $filter = (isset($param['filter'])) ? $param['filter'] : [];

        $rangeDate = $this->getRangeDate($range);

        $mvrExp = Driver::select('drivers.first_name', 'drivers.last_name', 'drivers.mvr_date')
                    ->join('driver_informations','driver_informations.driver_id','=','drivers.id')
                    ->where('drivers.company_id', $this->company_admin->company_id)
                    ->where(function ($query) use ($filter){
                        if(!empty($filter)){
                            if(isset($filter['carrierFilter'])){
                                $query->whereIn('driver_informations.carrier_id', $filter['carrierFilter']);
                            }
                            if(isset($filter['terminalFilter'])){
                                $query->whereIn('driver_informations.terminal_id', $filter['terminalFilter']);
                            }
                            if(isset($filter['teamFilter'])){
                                $query->whereIn('drivers.team_id', $filter['teamFilter']);
                            }
                            if(isset($filter['dispatcherFilter'])){
                                $query->whereIn('drivers.manager_id', $filter['dispatcherFilter']);
                            }
                            if(isset($filter['equipmentFilter'])){
                                $query->whereIn('driver_informations.trailer_type', $filter['equipmentFilter']);
                            }
                        }
                    })
                    ->whereNotNull('drivers.mvr_date')
                    ->where(function ($query) use($range, $rangeDate) {
                        if($range == 'pd'){
                            $query->where('drivers.mvr_date', '<' , $rangeDate['startDate']);
                        }elsE{
                            $query->where('drivers.mvr_date', '>=', $rangeDate['startDate']);
                            $query->where('drivers.mvr_date', '<=', $rangeDate['endDate']);
                        }
                    })
                    ->orderBy('mvr_date');

        if(isset($param['is_count'])){
            return $mvrExp->count();
        }else{
            return array(
                'count' => $mvrExp->count(),
                'data' => $mvrExp->get()->toArray()
            );
        }
    }

    public function getScheduledOrientation($param = [])
    {
        // Scheduled Orientation
    }

    public function getDriverLicenseExp($param = [])
    {
        $range = (isset($param['range'])) ? $param['range'] : $this->defaultRange;
        $filter = (isset($param['filter'])) ? $param['filter'] : [];

        $rangeDate = $this->getRangeDate($range);

        $driverLicenseExp = Driver::select('drivers.first_name', 'drivers.last_name', 'drivers.license_exp')
                            ->join('driver_informations','driver_informations.driver_id','=','drivers.id')
                            ->where('company_id', $this->company_admin->company_id)
                            ->where(function ($query) use ($filter){
                                if(!empty($filter)){
                                    if(isset($filter['carrierFilter'])){
                                        $query->whereIn('driver_informations.carrier_id', $filter['carrierFilter']);
                                    }
                                    if(isset($filter['terminalFilter'])){
                                        $query->whereIn('driver_informations.terminal_id', $filter['terminalFilter']);
                                    }
                                    if(isset($filter['teamFilter'])){
                                        $query->whereIn('drivers.team_id', $filter['teamFilter']);
                                    }
                                    if(isset($filter['dispatcherFilter'])){
                                        $query->whereIn('drivers.manager_id', $filter['dispatcherFilter']);
                                    }
                                    if(isset($filter['equipmentFilter'])){
                                        $query->whereIn('driver_informations.trailer_type', $filter['equipmentFilter']);
                                    }
                                }
                            })
                            ->whereNotNull('drivers.license_exp')
                            ->where(function ($query) use($range, $rangeDate) {
                                if($range == 'pd'){
                                    $query->where('drivers.license_exp', '<' , $rangeDate['startDate']);
                                }elsE{
                                    $query->where('drivers.license_exp', '>=', $rangeDate['startDate']);
                                    $query->where('drivers.license_exp', '<=', $rangeDate['endDate']);
                                }
                            })
                            ->orderBy('license_exp');

        if(isset($param['is_count'])){
            return $driverLicenseExp->count();
        }else{
            return array(
                'count' => $driverLicenseExp->count(),
                'data' => $driverLicenseExp->get()->toArray()
            );
        }
    }

    public function getMedicalCertExp($param = [])
    {
        $range = (isset($param['range'])) ? $param['range'] : $this->defaultRange;
        $filter = (isset($param['filter'])) ? $param['filter'] : [];

        $rangeDate = $this->getRangeDate($range);

        $medicalCertExp = Driver::select('drivers.first_name', 'drivers.last_name', 'drivers.medical_cert')
                            ->join('driver_informations','driver_informations.driver_id','=','drivers.id')
                            ->where('company_id', $this->company_admin->company_id)
                            ->where(function ($query) use ($filter){
                                if(!empty($filter)){
                                    if(isset($filter['carrierFilter'])){
                                        $query->whereIn('driver_informations.carrier_id', $filter['carrierFilter']);
                                    }
                                    if(isset($filter['terminalFilter'])){
                                        $query->whereIn('driver_informations.terminal_id', $filter['terminalFilter']);
                                    }
                                    if(isset($filter['teamFilter'])){
                                        $query->whereIn('drivers.team_id', $filter['teamFilter']);
                                    }
                                    if(isset($filter['dispatcherFilter'])){
                                        $query->whereIn('drivers.manager_id', $filter['dispatcherFilter']);
                                    }
                                    if(isset($filter['equipmentFilter'])){
                                        $query->whereIn('driver_informations.trailer_type', $filter['equipmentFilter']);
                                    }
                                }
                            })
                            ->whereNotNull('drivers.medical_cert')
                            ->where(function ($query) use($range, $rangeDate) {
                                if($range == 'pd'){
                                    $query->where('drivers.medical_cert', '<' , $rangeDate['startDate']);
                                }elsE{
                                    $query->where('drivers.medical_cert', '>=', $rangeDate['startDate']);
                                    $query->where('drivers.medical_cert', '<=', $rangeDate['endDate']);
                                }
                            })
                            ->orderBy('medical_cert');

        if(isset($param['is_count'])){
            return $medicalCertExp->count();
        }else{
            return array(
                'count' => $medicalCertExp->count(),
                'data' => $medicalCertExp->get()->toArray()
            );
        }
    }

    public function getDotViolationReviews($param = [])
    {
        // DOT Violation Reviews
    }

    public function getHosViolation($param = [])
    {
        // HOS Violation
    }

    public function getFaiInspection($param = [])
    {
        // FAI Inspection
    }

    public function getIrpRegistrationRenewal($param = [])
    {
        // IRP Registration Renewal
    }

    public function getIftaRenewal($param = [])
    {
        // IFTA Renewal
    }

    public function getNyhutRenewal($param = [])
    {
        $range = (isset($param['range'])) ? $param['range'] : $this->defaultRange;
        $filter = (isset($param['filter'])) ? $param['filter'] : [];

        $rangeDate = $this->getRangeDate($range);

        $nyhutRenewal = Truck::select('trucks.unit', 'trucks.nyhut_date')
                            ->where('trucks.company_id', $this->company_admin->company_id)
                            ->where(function ($query) use ($filter){
                                if(!empty($filter)){
                                    if(isset($filter['carrierFilter'])){
                                        $query->whereIn('trucks.carrier_id', $filter['carrierFilter']);
                                    }
                                    if(isset($filter['terminalFilter'])){
                                        $query->whereIn('trucks.terminal_id', $filter['terminalFilter']);
                                    }
                                    /*if(isset($filter['teamFilter'])){
                                        $query->whereIn('team_id', $filter['teamFilter']);
                                    }
                                    if(isset($filter['dispatcherFilter'])){
                                        $query->whereIn('manager_id', $filter['dispatcherFilter']);
                                    }
                                    if(isset($filter['equipmentFilter'])){
                                        $query->whereIn('trailer_type', $filter['equipmentFilter']);
                                    }*/
                                }
                            })
                            ->whereNotNull('trucks.nyhut_date')
                            ->where(function ($query) use($range, $rangeDate) {
                                if($range == 'pd'){
                                    $query->where('trucks.nyhut_date', '<' , $rangeDate['startDate']);
                                }elsE{
                                    $query->where('trucks.nyhut_date', '>=', $rangeDate['startDate']);
                                    $query->where('trucks.nyhut_date', '<=', $rangeDate['endDate']);
                                }
                            })
                            ->orderBy('nyhut_date');

        if(isset($param['is_count'])){
            return $nyhutRenewal->count();
        }else{
            return array(
                'count' => $nyhutRenewal->count(),
                'data' => $nyhutRenewal->get()->toArray()
            );
        }
    }

    public function getTruckServices($param = [])
    {
        $range = (isset($param['range'])) ? $param['range'] : $this->defaultRange;
        $filter = (isset($param['filter'])) ? $param['filter'] : [];

        $rangeDate = $this->getRangeDate($range);

        $truckServices = Truck::select('trucks.unit', 'trucks.truck_service_date')
                            ->where('trucks.company_id', $this->company_admin->company_id)
                            ->where(function ($query) use ($filter){
                                if(!empty($filter)){
                                    if(isset($filter['carrierFilter'])){
                                        $query->whereIn('trucks.carrier_id', $filter['carrierFilter']);
                                    }
                                    if(isset($filter['terminalFilter'])){
                                        $query->whereIn('trucks.terminal_id', $filter['terminalFilter']);
                                    }
                                    /*if(isset($filter['teamFilter'])){
                                        $query->whereIn('team_id', $filter['teamFilter']);
                                    }
                                    if(isset($filter['dispatcherFilter'])){
                                        $query->whereIn('manager_id', $filter['dispatcherFilter']);
                                    }
                                    if(isset($filter['equipmentFilter'])){
                                        $query->whereIn('trailer_type', $filter['equipmentFilter']);
                                    }*/
                                }
                            })
                            ->whereNotNull('trucks.truck_service_date')
                            ->where(function ($query) use($range, $rangeDate) {
                                if($range == 'pd'){
                                    $query->where('trucks.truck_service_date', '<' , $rangeDate['startDate']);
                                }elsE{
                                    $query->where('trucks.truck_service_date', '>=', $rangeDate['startDate']);
                                    $query->where('trucks.truck_service_date', '<=', $rangeDate['endDate']);
                                }
                            })
                            ->orderBy('truck_service_date');

        if(isset($param['is_count'])){
            return $truckServices->count();
        }else{
            return array(
                'count' => $truckServices->count(),
                'data' => $truckServices->get()->toArray()
            );
        }
    }

    public function getTrailerServices($param = [])
    {
        $range = (isset($param['range'])) ? $param['range'] : $this->defaultRange;
        $filter = (isset($param['filter'])) ? $param['filter'] : [];

        $rangeDate = $this->getRangeDate($range);

        $trailerServices = Trailer::select('trailers.trailer_id', 'trailers.trailer_service_date')
                                ->where('trailers.company_id', $this->company_admin->company_id)
                                ->whereNotNull('trailers.trailer_service_date')
                                ->where(function ($query) use($range, $rangeDate) {
                                    if($range == 'pd'){
                                        $query->where('trailers.trailer_service_date', '<' , $rangeDate['startDate']);
                                    }elsE{
                                        $query->where('trailers.trailer_service_date', '>=', $rangeDate['startDate']);
                                        $query->where('trailers.trailer_service_date', '<=', $rangeDate['endDate']);
                                    }
                                })
                                ->orderBy('trailer_service_date');

        if(isset($param['is_count'])){
            return $trailerServices->count();
        }else{
            return array(
                'count' => $trailerServices->count(),
                'data' => $trailerServices->get()->toArray()
            );
        }
    }

    public function getEquipmentRecovery($param = [])
    {
        // Equipment Recovery
    }

    public function getDormantEquipment($param = [])
    {
        // Dormant Equipment
    }

    public function getTimeOffRequest($param = [])
    {
        // Time Off Request
    }

    public function getBirthdays($param = [])
    {
        $range = (isset($param['range'])) ? $param['range'] : $this->defaultRange;
        $filter = (isset($param['filter'])) ? $param['filter'] : [];

        $rangeDate = $this->getRangeDate($range, 'm-d');

        $birthdays = Driver::select('drivers.first_name', 'drivers.last_name', DB::raw('CONCAT(DATE_FORMAT(NOW(), "%Y"),"-",DATE_FORMAT(drivers.birthday, "%m-%d")) as birthday'))
                        ->join('driver_informations','driver_informations.driver_id','=','drivers.id')
                        ->where('drivers.company_id', $this->company_admin->company_id)
                        ->where(function ($query) use ($filter){
                            if(!empty($filter)){
                                if(isset($filter['carrierFilter'])){
                                    $query->whereIn('driver_informations.carrier_id', $filter['carrierFilter']);
                                }
                                if(isset($filter['terminalFilter'])){
                                    $query->whereIn('driver_informations.terminal_id', $filter['terminalFilter']);
                                }
                                if(isset($filter['teamFilter'])){
                                    $query->whereIn('drivers.team_id', $filter['teamFilter']);
                                }
                                if(isset($filter['dispatcherFilter'])){
                                    $query->whereIn('drivers.manager_id', $filter['dispatcherFilter']);
                                }
                                if(isset($filter['equipmentFilter'])){
                                    $query->whereIn('driver_informations.trailer_type', $filter['equipmentFilter']);
                                }
                            }
                        })
                        ->whereNotNull('drivers.birthday')
                        ->where(function ($query) use($range, $rangeDate) {
                            if($range == 'pd'){
                                $query->where(DB::raw('DATE_FORMAT(drivers.birthday, "%m-%d")'), '<' , $rangeDate['startDate']);
                            }elsE{
                                $query->where(DB::raw('DATE_FORMAT(drivers.birthday, "%m-%d")'), '>=', $rangeDate['startDate']);
                                $query->where(DB::raw('DATE_FORMAT(drivers.birthday, "%m-%d")'), '<=', $rangeDate['endDate']);
                            }
                        })
                        ->orderBy('birthday');

        if(isset($param['is_count'])){
            return $birthdays->count();
        }else{
            return array(
                'count' => $birthdays->count(),
                'data' => $birthdays->get()->toArray()
            );
        }
    }

    public function getWorkingAnniversary($param = [])
    {
        $range = (isset($param['range'])) ? $param['range'] : $this->defaultRange;
        $filter = (isset($param['filter'])) ? $param['filter'] : [];

        $rangeDate = $this->getRangeDate($range, 'm-d');

        $workingAnniversary = Driver::select('drivers.first_name', 'drivers.last_name', DB::raw('CONCAT(DATE_FORMAT(NOW(), "%Y"),"-",DATE_FORMAT(drivers.anniversary, "%m-%d")) as anniversary'))
                                ->join('driver_informations','driver_informations.driver_id','=','drivers.id')
                                ->where('drivers.company_id', $this->company_admin->company_id)
                                ->where(function ($query) use ($filter){
                                    if(!empty($filter)){
                                        if(isset($filter['carrierFilter'])){
                                            $query->whereIn('driver_informations.carrier_id', $filter['carrierFilter']);
                                        }
                                        if(isset($filter['terminalFilter'])){
                                            $query->whereIn('driver_informations.terminal_id', $filter['terminalFilter']);
                                        }
                                        if(isset($filter['teamFilter'])){
                                            $query->whereIn('drivers.team_id', $filter['teamFilter']);
                                        }
                                        if(isset($filter['dispatcherFilter'])){
                                            $query->whereIn('drivers.manager_id', $filter['dispatcherFilter']);
                                        }
                                        if(isset($filter['equipmentFilter'])){
                                            $query->whereIn('driver_informations.trailer_type', $filter['equipmentFilter']);
                                        }
                                    }
                                })
                                ->whereNotNull('drivers.anniversary')
                                ->where(function ($query) use($range, $rangeDate) {
                                    if($range == 'pd'){
                                        $query->where(DB::raw('DATE_FORMAT(drivers.anniversary, "%m-%d")'), '<' , $rangeDate['startDate']);
                                    }elsE{
                                        $query->where(DB::raw('DATE_FORMAT(drivers.anniversary, "%m-%d")'), '>=', $rangeDate['startDate']);
                                        $query->where(DB::raw('DATE_FORMAT(drivers.anniversary, "%m-%d")'), '<=', $rangeDate['endDate']);
                                    }
                                })
                                ->orderBy('anniversary');

        if(isset($param['is_count'])){
            return $workingAnniversary->count();
        }else{
            return array(
                'count' => $workingAnniversary->count(),
                'data' => $workingAnniversary->get()->toArray()
            );
        }
    }

    public function get2290HeavyHighwayUse($param = [])
    {
        $range = (isset($param['range'])) ? $param['range'] : $this->defaultRange;
        $filter = (isset($param['filter'])) ? $param['filter'] : [];

        $rangeDate = $this->getRangeDate($range);

        $heavyHighwayUsed = Truck::select('trucks.unit', 'trucks.2290_due_date')
            ->where('trucks.company_id', $this->company_admin->company_id)
            ->where(function ($query) use ($filter){
                if(!empty($filter)){
                    if(isset($filter['carrierFilter'])){
                        $query->whereIn('trucks.carrier_id', $filter['carrierFilter']);
                    }
                    if(isset($filter['terminalFilter'])){
                        $query->whereIn('trucks.terminal_id', $filter['terminalFilter']);
                    }
                    /*if(isset($filter['teamFilter'])){
                        $query->whereIn('team_id', $filter['teamFilter']);
                    }
                    if(isset($filter['dispatcherFilter'])){
                        $query->whereIn('manager_id', $filter['dispatcherFilter']);
                    }
                    if(isset($filter['equipmentFilter'])){
                        $query->whereIn('trailer_type', $filter['equipmentFilter']);
                    }*/
                }
            })
            ->whereNotNull('trucks.2290_due_date')
            ->where(function ($query) use($range, $rangeDate) {
                if($range == 'pd'){
                    $query->where('trucks.2290_due_date', '<' , $rangeDate['startDate']);
                }elsE{
                    $query->where('trucks.2290_due_date', '>=', $rangeDate['startDate']);
                    $query->where('trucks.2290_due_date', '<=', $rangeDate['endDate']);
                }
            })
            ->orderBy('2290_due_date');

        if(isset($param['is_count'])){
            return $heavyHighwayUsed->count();
        }else{
            return array(
                'count' => $heavyHighwayUsed->count(),
                'data' => $heavyHighwayUsed->get()->toArray()
            );
        }
    }

    public function getAccidentReviews($param = [])
    {
        // Accident Reviews
    }

    public function getIncidentReviews($param = [])
    {
        // Incident Reviews
    }

    public function getClaimReviews($param = [])
    {
        // Claim Reviews
    }

    public function getInjuryReviews($param = [])
    {
        // Injury Reviews
    }

    public function complianceReport(Request $request)
    {
        $rangeArr = $this->getRangeTypes();
        $complianceList = $this->getListdataArray();
        $filters = (!empty(array_filter(array_column($complianceList, 'filters')))) ? array_filter(array_column($complianceList, 'filters'))[0] : [];
        $createdDate = Carbon::now()->timezone($this->timeZone)->format("m/d/Y");
        $displayListNo = (isset($request->index)) ? $request->index : null;

        $listViews = view('companyAdmin.compliance.ajax_view_all_list', compact('rangeArr', 'complianceList', 'displayListNo'))->render();
        if($listViews == ""){
            $listViews = '<div class="col-12 text-center"><h3 class="font-weight-bold mt-5">No active list found</h3></div>';
        }

        return view('companyAdmin.compliance.report', compact('rangeArr', 'listViews', 'complianceList', 'filters', 'createdDate', 'displayListNo'));
    }

    public function complianceReportGeneratePDF(Request $request)
    {
        $rangeArr = $this->getRangeTypes();
        $complianceList = $this->getListdataArray();
        $createdDate = Carbon::now()->timezone($this->timeZone)->format("m/d/Y");
        $displayListNo = (isset($request->index)) ? $request->index : null;

        $data = [
            'createdDate' => $createdDate,
            'rangeArr' => $rangeArr,
            'complianceList' => $complianceList,
            'displayListNo' => $displayListNo
        ];

        //return view('companyAdmin.compliance.report-pdf', $data); // View Pdf HTMl page

        $pdf = Pdf::loadView('companyAdmin.compliance.report-pdf', $data)->setPaper('a4', 'portrait')->setOptions(['default_font' => 'sans-serif', 'dpi' => 130]);

        //return $pdf->stream("dashboard-report.pdf", array("Attachment" => false)); // View Pdf in browser

        return $pdf->download('dashboard-report.pdf'); // Download Pdf
    }
}
