<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

use App\Http\Requests\CompanyAdmin\DriverCitationsViolationCodeStoreRequest;
use App\Http\Requests\CompanyAdmin\DriverCitationsViolationCodeUpdateRequest;

use App\Models\Company;
use App\Models\Bookmark;
use App\Models\CompanyAdmin;
use App\Models\DriverCitationsViolationCode;
use Mail;
use Hash;
use DataTables;
use Carbon\Carbon;
use App\Helpers\Common;

class DriverCitationsViolationCodeController extends CompanyAdminController{

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(){
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request){
        $getCompanyAdmin    = auth()->guard('company-admin')->user();
        $getField           = '';
        $isCheck            = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','driver_citations_violation_codes')->first();
        if(!empty($isCheck->id)){
            //$getField       = unserialize($isCheck->config);
            $getField       = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_driver_citations_violation_codes_first'));
        }else{
            $getField       = config('settings.table_driver_citations_violation_codes_first');
        }
        if ($request->ajax()) {
            $data = DriverCitationsViolationCode::IsCompany();
                // General filter code - start
                foreach( $getField as $key => $value ) {
                    $conditionReq = 'search_string_condition_'.$key;
                    $sortReq = 'search_string_sort_'.$key;

                    if( isset( request()->$conditionReq ) ) {
                        $typeReq = 'search_string_type_'.$key;
                        $type = request()->$typeReq;

                        if( $type == 'string' ) {
                            Common::getStringFilterResult( $data, $key );
                        }

                        if( $type == 'date' ) {
                            Common::getDateFilterResult( $data, $key );
                        }
                    }

                    if( isset( request()->$sortReq ) ) {
                        $nameReq = 'search_string_name_'.$key;
                        $sortReq = 'search_string_sort_'.$key;
                        $typeReq = 'search_string_type_'.$key;
                        $tableNameReq = 'search_table_name_'.$key;
                        $colAliasReq = 'search_string_col_alias_'.$key;

                        $origData = request()->$nameReq;
                        $condition_sort = request()->$sortReq;
                        $type = request()->$typeReq;
                        $tableName = isset( request()->$tableNameReq ) ? request()->$tableNameReq : '';
                        $colAlias = isset( request()->$colAliasReq ) ? request()->$colAliasReq : '';

                        if( $type == 'string' ) {
                            if( isset( $condition_sort ) ) {
                                if( $colAlias != '' ) {
                                    $data->orderBy( $tableName.'.'.$colAlias, $condition_sort );
                                } else {
                                    if( $tableName != '' ) {
                                        $data->orderBy( $tableName.'.'.$origData, $condition_sort );
                                    } else {
                                        $data->orderBy( $origData, $condition_sort );
                                    }
                                }
                            }
                        }
                    }
                }
                $data->get();
                // General filter code - end

            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function($row){
                    $action = '<a href="'.route('company.admin.driver-citations-violation-code.edit', base64Encode($row->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-pencil" aria-hidden="true"></i></a>';
                    $action .= '<a href="javascript:void(0);" class="btn btn-sm btn-outline-black-trash destroy" data-action="'.route('company.admin.driver-citations-violation-code.destroy',$row->id).'" data-id="'.$row->id.'"><i class="fa fa-trash" aria-hidden="true"></i></a>';

                    return $action;
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        $tableName = 'settings.table_driver_citations_violation_codes';
        return view('companyAdmin.driverCitationsViolationCode.index', compact('getField','tableName'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(){
        return view('companyAdmin.driverCitationsViolationCode.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(DriverCitationsViolationCodeStoreRequest $request){
        $input                  = $request->except(['_token']);
        $input['company_id']    = auth()->guard('company-admin')->user()->company_id;
        DriverCitationsViolationCode::create($input);

        notification('success', $this->crudMessage('create', ''));

        return redirect()->route('company.admin.driver-citations-violation-code.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(){
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id){
        $manageCompanyType = DriverCitationsViolationCode::findOrFail(base64Decode($id));

        return view('companyAdmin.driverCitationsViolationCode.edit', compact('manageCompanyType'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(DriverCitationsViolationCodeUpdateRequest $request,$id){
        $input                  = $request->except(['_token','_method']);
        $input['company_id']    = auth()->guard('company-admin')->user()->company_id;
        $manageCompanyType      = DriverCitationsViolationCode::findOrFail($id);
        $manageCompanyType->update($input);

        notification('success', $this->crudMessage('update', ''));

        return redirect()->route('company.admin.driver-citations-violation-code.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request){
        $data                   = DriverCitationsViolationCode::find($request->id);
        $data->delete();

        notification('success', $this->crudMessage('delete', ''));

        return redirect()->route('company.admin.driver-citations-violation-code.index');
    }

}
