<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;
use App\Models\Driver;
use App\Models\DriverHosViolation;
use App\Models\DriverHosViolationsData;
use App\Models\DriverNonViolation;
use App\Models\DriverNonViolationsData;
use App\Models\FileUpload;
use App\Models\Gallery;

use DataTables;
use Validator;
use Carbon\Carbon;

class DriverHosViolationController extends CompanyAdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request, $id)
    {
        if ($request->ajax()) {
            $data = DriverHosViolation::select('*');
            return Datatables::of($data)
                    ->addIndexColumn()
                    ->filterColumn("date", function ($query, $keyword) {
                        $query->whereRaw(
                            "DATE_FORMAT(date,'%m/%d/%Y') LIKE ?",
                            ["%$keyword%"]
                        );
                    })
                    ->addColumn('action', function($row){
                        $btn = '<a href="#" data-id="'.$row->id.'" data-toggle="modal" data-target="#showHOSViolationsModal" class="show-hos-violations-btn mr-4"><img src="'.asset('theme/img/eye.png').'" alt=""></a>';
                        $btn = $btn.' <a href="#" data-id="'.$row->id.'" data-toggle="modal" data-target="#editHOSViolationsModal" class="edit-hos-violations-btn mr-4"><img src="'.asset('theme/img/edit-icon.png').'" alt=""></a>';
                        $btn = $btn.' <a href="javascript:" class="destroy" data-action="'.route('company.admin.hos.violation.destroy',$row->id).'" data-id="'.$row->id.'"><img src="'.asset('theme/img/delete-icon.png').'" alt=""></a>';
                        return $btn;
                    })
                    ->rawColumns(['action'])
                    ->make(true);
        }

        return view('companyAdmin.driver.hosViolation',compact('id'));
    }

    /**
     * Render the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function createFormView(Request $request)
    {
        $driverId = $request->driver_id;

        $driver = Driver::findOrFail($driverId);
        $view = view('companyAdmin.driver.view.hosViolationCreateFormView', compact('driverId','driver'))->render();

        return response()->json(['view' => $view]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $input = $request->all();
        //dd($input);


        $validator = Validator::make($input,[
            "title" => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $input['hazmat_inspection'] = $input['hazmat_inspection'] ?? 0;
        $input['certified_returned'] = $input['certified_returned'] ?? 0;
        $input['dataq'] = $input['dataq'] ?? 0;
        $input['dot_crash'] = $input['dot_crash'] ?? 0;
        $input['towed'] = $input['towed'] ?? 0;
        $input['injury'] = $input['injury'] ?? 0;

        if(!empty($input['date'])){
            $input['event_calendar_date'] =  Carbon::createFromFormat('m/d/Y',$input['date'])->addDays(15)->format('Y-m-d');
        }

        $getDriverHosViolation = DriverHosViolation::create($input);

        if(!is_null($input['dummy_id']) && isset($input['dummy_id'])){
            $dummyloadid = $input['dummy_id'];
            Gallery::where('action_id', $dummyloadid)->update(['action_id' => $getDriverHosViolation->id]);
        }

        $vosData              = count($request->unit_type);
        if($vosData > 0){
            for ($x = 0; $x < $vosData; $x++){
                if(!is_null($request->unit_type[$x])){
                    $vosData_array     = [];
                    $vosData_array['company_id'] = auth()->guard('company-admin')->user()->company_id;
                    $vosData_array['driver_hos_violation_id'] = $getDriverHosViolation->id;
                    $vosData_array['unit_type']       = $request->unit_type[$x];
                    $vosData_array['unit_id']       = 0;
                    $vosData_array['make']       = $request->make[$x] ?? null;
                    $vosData_array['year']       = $request->year[$x] ?? null;
                    $vosData_array['vin']       = $request->vin[$x] ?? null;
                    $vosData_array['oos']       = $request->oos[$x] ?? null;
                    $vosData_array['violation_code']       = $request->violation_code[$x];
                    $vosData_array['description']       = $request->description[$x];
                    DriverHosViolationsData::create($vosData_array);
                }
            }

            if($vosData == count(array_filter($request->oos))){
                $driver = Driver::find($request->driver_id);
                $driver->status = '1';
                $driver->save();
            }
        }

        notification('success', $this->crudMessage('create', 'HOS Violation'));

        return response()->json(['success' => "HOS Violation created successfully"]);
    }

    /**
     * Render the form for showing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function showView(Request $request)
    {
        $driverHosViolation = DriverHosViolation::find($request->id);

        $view = view('companyAdmin.driver.view.hosViolationShowView', compact('driverHosViolation'))->render();

        return response()->json(['view' => $view]);
    }

    /**
     * Render the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function editFormView(Request $request)
    {
        $driverHosViolation = DriverHosViolation::find($request->id);

        $view = view('companyAdmin.driver.view.hosViolationEditFormView', compact('driverHosViolation'))->render();

        return response()->json(['view' => $view]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $input = $request->all();

        // dd($input);

        $validator = Validator::make($input,[
            "title" => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $input['hazmat_inspection'] = $input['hazmat_inspection'] ?? 0;
        $input['certified_returned'] = $input['certified_returned'] ?? 0;
        $input['dataq'] = $input['dataq'] ?? 0;
        $input['dot_crash'] = $input['dot_crash'] ?? 0;
        $input['towed'] = $input['towed'] ?? 0;
        $input['injury'] = $input['injury'] ?? 0;

        if(!empty($input['date'])){
            $input['event_calendar_date'] =  Carbon::createFromFormat('m/d/Y',$input['date'])->addDays(15)->format('Y-m-d');
        }


        DriverHosViolation::find($request->id)->update($input);


        DriverHosViolationsData::where('driver_hos_violation_id',$request->id)->delete();
        $vosData              = count($request->unit_type);
        if($vosData > 0){
            for ($x = 0; $x < $vosData; $x++){
                if(!is_null($request->unit_type[$x])){
                    $vosData_array     = [];
                    $vosData_array['company_id']           = auth()->guard('company-admin')->user()->company_id;
                    $vosData_array['driver_hos_violation_id'] = $request->id;
                    $vosData_array['unit_type']       = $request->unit_type[$x];
                    $vosData_array['unit_id']       = 0;
                    $vosData_array['make']       = $request->make[$x];
                    $vosData_array['year']       = $request->year[$x];
                    $vosData_array['vin']       = $request->vin[$x];
                    $vosData_array['oos']       = ($request->oos[$x] == '1') ? $request->oos[$x] : '0';
                    $vosData_array['violation_code']       = $request->violation_code[$x];
                    $vosData_array['description']       = $request->description[$x];
                    DriverHosViolationsData::create($vosData_array);
                }
            }

            if($vosData == count(array_filter($request->oos))){
                $driver = Driver::find($request->driver_id);
                $driver->status = '1';
                $driver->save();
            }
        }

        notification('success', $this->crudMessage('update', 'HOS Violation'));

        return response()->json(['success' => "HOS Violation updated successfully"]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        DriverHosViolation::find($id)->delete();

        notification('success', $this->crudMessage('delete', 'HOS Violation'));

        return redirect()->back();
    }

    public function indexNonViolation(Request $request,$id){
        if ($request->ajax()) {
            $data = DriverNonViolation::select('*');
            return Datatables::of($data)
                    ->addIndexColumn()
                    ->filterColumn("date", function ($query, $keyword) {
                        $query->whereRaw(
                            "DATE_FORMAT(date,'%m/%d/%Y') LIKE ?",
                            ["%$keyword%"]
                        );
                    })
                    ->addColumn('action', function($row){
                        $btn = '<a href="#" data-id="'.$row->id.'" data-toggle="modal" data-target="#showNONViolationsModal" class="show-non-violations-btn mr-4"><img src="'.asset('theme/img/eye.png').'" alt=""></a>';
                        $btn = $btn.' <a href="#" data-id="'.$row->id.'" data-toggle="modal" data-target="#editNONViolationsModal" class="edit-non-violations-btn mr-4"><img src="'.asset('theme/img/edit-icon.png').'" alt=""></a>';
                        $btn = $btn.' <a href="javascript:" class="destroy" data-action="'.route('company.admin.non.violation.destroy',$row->id).'" data-id="'.$row->id.'"><img src="'.asset('theme/img/delete-icon.png').'" alt=""></a>';
                        return $btn;
                    })
                    ->rawColumns(['action'])
                    ->make(true);
        }

        return view('companyAdmin.driver.nonViolation',compact('id'));
    }

    // create non violation form view
    public function createNonVioloationFormView(Request $request){
        $driverId = $request->driver_id;

        $driver = Driver::findOrFail($driverId);
        $view = view('companyAdmin.driver.view.nonViolationCreateFormView', compact('driverId','driver'))->render();

        return response()->json(['view' => $view]);
    }

    public function nonViolationStore(Request $request){
        $input = $request->all();

        $validator = Validator::make($input,[
            "title" => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $input['hazmat_inspection'] = $input['hazmat_inspection'] ?? 0;
        $input['certified_returned'] = $input['certified_returned'] ?? 0;
        $input['dataq'] = $input['dataq'] ?? 0;
        $input['dot_crash'] = $input['dot_crash'] ?? 0;
        $input['towed'] = $input['towed'] ?? 0;
        $input['injury'] = $input['injury'] ?? 0;

        if(!empty($input['date'])){
            $input['event_calendar_date'] =  Carbon::createFromFormat('m/d/Y',$input['date'])->addDays(15)->format('Y-m-d');
        }


        $getDriverNonViolation = DriverNonViolation::create($input);

        if(!is_null($input['dummy_id']) && isset($input['dummy_id'])){
            $dummyloadid = $input['dummy_id'];
            Gallery::where('action_id', $dummyloadid)->update(['action_id' => $getDriverNonViolation->id]);
        }

        $vosData              = count($request->unit_type);
        if($vosData > 0){
            for ($x = 0; $x < $vosData; $x++){
                if(!is_null($request->unit_type[$x])){
                    $vosData_array     = [];
                    $vosData_array['company_id']           = auth()->guard('company-admin')->user()->company_id;
                    $vosData_array['driver_non_violation_id'] = $getDriverNonViolation->id;
                    $vosData_array['unit_type']       = $request->unit_type[$x];
                    $vosData_array['unit_id']       = 0;
                    $vosData_array['make']       = $request->make[$x] ?? null;
                    $vosData_array['year']       = $request->year[$x] ?? null;
                    $vosData_array['vin']       = $request->vin[$x] ?? null;
                    $vosData_array['oos']       = $request->oos[$x] ?? null;
                    $vosData_array['violation_code']       = $request->violation_code[$x];
                    $vosData_array['description']       = $request->description[$x];
                    DriverNonViolationsData::create($vosData_array);
                }
            }
        }

        notification('success', $this->crudMessage('create', 'NON Violation'));

        return response()->json(['success' => "NON Violation created successfully"]);
    }

    public function showNonViolationView(Request $request)
    {
        $driverNonViolation = DriverNonViolation::find($request->id);

        $view = view('companyAdmin.driver.view.nonViolationShowView', compact('driverNonViolation'))->render();

        return response()->json(['view' => $view]);
    }

    public function destroyNonViolation($id){
        $driverNonViolation = DriverNonViolation::find($id)->delete();

        notification('success', $this->crudMessage('delete', 'Non Violation'));

        return redirect()->back();

    }

    public function editNonViolationFormView(Request $request)
    {
        $driverNonViolation = DriverNonViolation::find($request->id);

        $view = view('companyAdmin.driver.view.nonViolationEditFormView', compact('driverNonViolation'))->render();

        return response()->json(['view' => $view]);
    }

    public function updateNonViolation(Request $request,$id)
    {
        $input = $request->all();

        // dd($input);

        $validator = Validator::make($input,[
            "title" => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $input['hazmat_inspection'] = $input['hazmat_inspection'] ?? 0;
        $input['certified_returned'] = $input['certified_returned'] ?? 0;
        $input['dataq'] = $input['dataq'] ?? 0;
        $input['dot_crash'] = $input['dot_crash'] ?? 0;
        $input['towed'] = $input['towed'] ?? 0;
        $input['injury'] = $input['injury'] ?? 0;

        if(!empty($input['date'])){
            $input['event_calendar_date'] =  Carbon::createFromFormat('m/d/Y',$input['date'])->addDays(15)->format('Y-m-d');
        }


        DriverNonViolation::find($request->id)->update($input);


        DriverNonViolationsData::where('driver_non_violation_id',$request->id)->delete();
        $vosData              = count($request->unit_type);
        if($vosData > 0){
            for ($x = 0; $x < $vosData; $x++){
                if(!is_null($request->unit_type[$x])){
                    $vosData_array     = [];
                    $vosData_array['company_id']           = auth()->guard('company-admin')->user()->company_id;
                    $vosData_array['driver_non_violation_id'] = $request->id;
                    $vosData_array['unit_type']       = $request->unit_type[$x];
                    $vosData_array['unit_id']       = 0;
                    $vosData_array['make']       = $request->make[$x] ?? null;
                    $vosData_array['year']       = $request->year[$x] ?? null;
                    $vosData_array['vin']       = $request->vin[$x] ?? null;
                    $vosData_array['oos']       = $request->oos[$x] ?? null;
                    $vosData_array['violation_code']       = $request->violation_code[$x] ?? null;
                    $vosData_array['description']       = $request->description[$x] ?? null;
                    DriverNonViolationsData::create($vosData_array);
                }
            }
        }

        notification('success', $this->crudMessage('update', 'Non Violation'));

        return response()->json(['success' => "Non Violation updated successfully"]);
    }
}
