<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use App\Models\DriverOnboarding;
use Illuminate\Http\Request;
use App\Models\Driver;
use App\Models\DriverOnboardingHistory;
use App\Models\FileUpload;
use Illuminate\Support\Arr;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Yajra\DataTables\Facades\DataTables;

class DriverOnboardingController extends CompanyAdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {

        $input = $request->all();
        $input['detail'] = array_filter($input['detail'], function ($v) {
            return array_filter($v);
        });
        foreach ($input['detail'] as $key => $value) {
            // stage
            if (isset($value['yes_no'])) {
                $value['yes_no'] = 1;
                $value['is_complete'] = 1;
                $value['completed_on'] = Carbon::now()->format('Y-m-d');
                $value['completed_by'] = auth()->guard('company-admin')->user()->id;
            } else {
                $value['yes_no'] = 0;
                $value['is_complete'] = 0;
            }
            if (isset($value['file'])) {
                $value['file'] = FileUpload::upload('companyAdmin/driver', $value['file']);
            }
            if (isset($value['date'])) {
                $value['date'] = Carbon::parse($value['date'])->format('Y-m-d');
            }

            $input['detail'][$key] = $value;

            // sub stage
            $svalue = [];

            foreach ($value as $skey => $svalue) {

                if (is_array($svalue)) {

                    if (isset($svalue['yes_no'])) {
                        $svalue['yes_no'] = 1;
                        $svalue['is_complete'] = 1;
                        $svalue['completed_on'] = Carbon::now()->format('Y-m-d');
                        $svalue['completed_by'] = auth()->guard('company-admin')->user()->id;
                    } else {
                        $svalue['yes_no'] = 0;
                        $svalue['is_complete'] = 0;
                    }

                    if (isset($svalue['file'])) {
                        $svalue['file'] = FileUpload::upload('companyAdmin/driver', $svalue['file']);
                    }
                    if (isset($svalue['date'])) {
                        $svalue['date'] = Carbon::parse($svalue['date'])->format('Y-m-d');
                    }

                    $input['detail'][$key][$skey] = $svalue;

                }
            }
        }

        $input['detail'] = json_encode($input['detail']);


        $exist = DriverOnboarding::where("driver_id", $input['driver_id'])->first();
        if (is_null($exist)) {
            $exist = DriverOnboarding::create($input);
        } else {
            $exist->update($input);
        }

        if (!empty($request->start_date)) {
            $driver_array = [];
            $driver_array['start_date'] = $request->start_date;
            $driver = Driver::where("id", $exist->driver_id)->first();
            $driver->update($driver_array);
        }

        $input['driver_onboarding_id'] = $exist->id;

        DriverOnboardingHistory::create($input);

        return response()->json(['success' => 'Data Added Successfully']);

    }

    /**
     * Fetch view for file.
     *
     * @return \Illuminate\Http\Response
     */
    public function fileView(Request $request)
    {
        $driverOnboarding = DriverOnboarding::where('driver_id', $request->driver_id)->first();

        $check_is_sub = explode('&&&&', $request->stage_name);

        $stageName = $check_is_sub[0];

        if (count($check_is_sub) > 1) {
            $stageDetail = $driverOnboarding->detail_json[$check_is_sub[0]][$check_is_sub[1]];
        } else {
            $stageDetail = $driverOnboarding->detail_json[$request->stage_name];
        }

        $view = view('companyAdmin.driver.view.onboardingFileView', compact('stageDetail', 'driverOnboarding', 'stageName'))->render();

        return response()->json(['view' => $view]);
    }

    /**
     * Remove the file from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function fileDelete(Request $request)
    {
        $driverOnboarding = DriverOnboarding::find($request->onboarding_id);

        $array = [];
        foreach ($driverOnboarding->detail_json as $key => $value) {
            if ($key == $request->stage_name) {
                if (isset($value['file'])) {
                    $value['file'] = null;
                }
            }

            $array[$key] = $value;
        }

        $driverOnboarding->update(['detail' => json_encode($array)]);

        return response()->json(['success' => 'File deleted successfully']);
    }


    public function Onboarding()
    {
        $companyId = auth()->guard('company-admin')->user()->company_id;

        $driverOnboardings = DriverOnboarding::leftjoin('drivers', 'drivers.id', '=', 'driver_onboardings.driver_id')
            ->whereIn('driver_onboardings.status', [0, 1])
            ->where('drivers.company_id', '=', $companyId)
            ->whereNotNull('driver_onboardings.application_date')
            ->whereNull('drivers.deleted_at')
            ->paginate(10);

        $hireds = DriverOnboarding::leftjoin('drivers', 'drivers.id', '=', 'driver_onboardings.driver_id')
            ->where('driver_onboardings.status', '=', 2)
            ->whereNotNull('driver_onboardings.application_date')
            ->where('drivers.company_id', '=', $companyId)
            ->paginate(10);

        $rejecteds = DriverOnboarding::leftjoin('drivers', 'drivers.id', '=', 'driver_onboardings.driver_id')
            ->where('driver_onboardings.status', '=', 3)
            ->whereNotNull('driver_onboardings.application_date')
            ->where('drivers.company_id', '=', $companyId)
            ->paginate(10);

        $terminateds = DriverOnboarding::join('drivers', 'drivers.id', '=', 'driver_onboardings.driver_id')
            ->whereNotNull('drivers.deleted_at')
            ->whereNotNull('driver_onboardings.application_date')
            ->where('drivers.company_id', '=', $companyId)
            ->paginate(10);
        $onboardingCount = DriverOnboarding::leftjoin('drivers', 'drivers.id', '=', 'driver_onboardings.driver_id')
            ->whereIn('driver_onboardings.status', [0, 1])
            ->whereNotNull('driver_onboardings.application_date')
            ->where('drivers.company_id', '=', $companyId)
            ->whereNull('drivers.deleted_at')->count();

        $hired = DriverOnboarding::leftjoin('drivers', 'drivers.id', '=', 'driver_onboardings.driver_id')
            ->where('driver_onboardings.status', '=', 2)
            ->whereNotNull('driver_onboardings.application_date')
            ->where('drivers.company_id', '=', $companyId)->count();
        $rejected = DriverOnboarding::leftjoin('drivers', 'drivers.id', '=', 'driver_onboardings.driver_id')
            ->where('driver_onboardings.status', '=', 3)
            ->whereNotNull('driver_onboardings.application_date')
            ->where('drivers.company_id', '=', $companyId)->count();

        $terminatedCount = DriverOnboarding::join('drivers', 'drivers.id', '=', 'driver_onboardings.driver_id')
            ->whereNotNull('drivers.deleted_at')
            ->whereNotNull('driver_onboardings.application_date')
            ->where('drivers.company_id', '=', $companyId)->count();


        return view('companyAdmin.driver.view.driver-onboarding', compact('driverOnboardings', 'onboardingCount', 'hired', 'rejected', 'hireds', 'rejecteds', 'terminateds', 'terminatedCount'));

    }

    public function onBoardings(Request $request)
    {
        if ($request->ajax() && $request) {

            $companyId = auth()->guard('company-admin')->user()->company_id;
            $data = DriverOnboarding::leftjoin('drivers', 'drivers.id', '=', 'driver_onboardings.driver_id')
                ->whereIn('driver_onboardings.status', [0, 1])
                ->where('drivers.company_id', '=', $companyId)
                ->get();

            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('name', function ($row) {
                    return $row->last_name . ', ' . $row->first_name;
                })
                ->addColumn('status', function ($row) {
                    if ($row->status == 0) {
                        return 'Pending';
                    } elseif ($row->status == 1){
                        return  'Onboarding';
                    }elseif($row->status == 2){
                        return 'Hired';
                    }elseif($row->status == 3){
                        return 'Rejected';
                    }

                })
                ->addColumn('Onboarding', function ($row) {
                    return $row->days_to_onboard??"n/a";
                })
                ->addColumn('action', function ($row) {

                    $btn = '<a href="' . route('company.admin.drivers.show', base64Encode($row->id)) . '" class="mr-4"><i class="fa fa-eye" style="color: #BFC0C2"></i></a>';
                    return $btn;
                })
                ->rawColumns(['action', 'status','Onboarding'])
                ->make(true);

        }
    }

    public function driverOnboardingHired(Request $request)
    {
        if ($request->ajax() && $request) {
            $companyId = auth()->guard('company-admin')->user()->company_id;
            $data = DriverOnboarding::leftjoin('drivers', 'drivers.id', '=', 'driver_onboardings.driver_id')
                ->where('status', '=', 2)
                ->where('drivers.company_id', '=', $companyId)
                ->get();

            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('name', function ($row) {
                    return $row->last_name . ', ' . $row->first_name;
                })
                ->addColumn('status', function ($row) {
                    if ($row->status == 0) {
                        return 'Pending';
                    } elseif ($row->status == 1){
                        return  'Onboarding';
                    }elseif($row->status == 2){
                        return 'Hired';
                    }elseif($row->status == 3){
                        return 'Rejected';
                    }

                })
                ->addColumn('Onboarding', function ($row) {
                    return $row->days_to_onboard??"n/a";
                })
                ->addColumn('action', function ($row) {

                    $btn = '<a href="' . route('company.admin.drivers.show', base64Encode($row->id)) . '" class="mr-4"><i class="fa fa-eye" style="color: #BFC0C2"></i></a>';
                    return $btn;
                })
                ->rawColumns(['action', 'status','Onboarding'])
                ->make(true);

        }
    }
    public function onBoardingsHtml(Request $request)
    {
        $companyId = auth()->guard('company-admin')->user()->company_id;
        $driverOnboardings = DriverOnboarding::leftjoin('drivers', 'drivers.id', '=', 'driver_onboardings.driver_id')
            ->whereIn('driver_onboardings.status', [0, 1])
            ->where('drivers.company_id', '=', $companyId)
            ->where('drivers.id', '=', $request->id)
            ->get();
        $view = view('companyAdmin.driver.view.currentOnBording',compact('driverOnboardings'))->render();
        return response()->json(['status'=>1,'html'=>$view,'massage'=>'']);

    }
    public function driverHiredHtml(Request $request)
    {
        $companyId = auth()->guard('company-admin')->user()->company_id;
        $hireds = DriverOnboarding::leftjoin('drivers', 'drivers.id', '=', 'driver_onboardings.driver_id')
            ->where('status', '=', 2)
            ->where('drivers.company_id', '=', $companyId)
            ->where('drivers.id', '=', $request->id)
            ->get();
        $view = view('companyAdmin.driver.view.hired',compact('hireds'))->render();
        return response()->json(['status'=>1,'html'=>$view,'massage'=>'']);

    }
    public function driverOnboardingTerminated(Request $request)
    {
        if ($request->ajax() && $request) {
            $companyId = auth()->guard('company-admin')->user()->company_id;
            $data = DriverOnboarding::leftjoin('drivers', 'drivers.id', '=', 'driver_onboardings.driver_id')
                ->where('drivers.deleted_at', '!=', 'null')
                ->where('drivers.company_id', '=', $companyId)
                ->get();

            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('name', function ($row) {
                    return $row->last_name . ', ' . $row->first_name;
                })
                ->addColumn('status', function ($row) {
                    if ($row->status == 0) {
                        return 'Pending';
                    } elseif ($row->status == 1){
                        return  'Onboarding';
                    }elseif($row->status == 2){
                        return 'Hired';
                    }elseif($row->status == 3){
                        return 'Rejected';
                    }

                })->addColumn('daysEmp', function ($row) {
                    if (isset($row->start_date) && isset($row->termination_date)) {
                        $start_date = $row->start_date;
                        $terminated_date = $row->termination_date;
                        $to = \Carbon\Carbon::parse($start_date);
                        $end = \Carbon\Carbon::parse($terminated_date);
                        //
                        $diff_in_days = $to->diffInDays($end);
                        return $diff_in_days . " Days";
                    }

                })
                ->addColumn('Onboarding', function ($row) {
                    return $row->days_to_onboard??"n/a";
                })
                ->addColumn('action', function ($row) {

                    $btn = '<a href="' . route('company.admin.drivers.show', base64Encode($row->id)) . '" class="mr-4"><i class="fa fa-eye" style="color: #BFC0C2"></i></a>';
                    return $btn;
                })
                ->rawColumns(['action', 'status','Onboarding','daysEmp'])
                ->make(true);

        }
    }

    public function driverTerminatedHtml(Request $request){
        $companyId = auth()->guard('company-admin')->user()->company_id;
        $terminateds = DriverOnboarding::leftjoin('drivers', 'drivers.id', '=', 'driver_onboardings.driver_id')
            ->where('drivers.deleted_at', '!=', 'null')
            ->where('drivers.company_id', '=', $companyId)
            ->where('drivers.id', '=', $request->id)
            ->get();
        $view = view('companyAdmin.driver.view.terminateTable',compact('terminateds'))->render();
        return response()->json(['status'=>1,'html'=>$view,'massage'=>'']);

    }
    public function driverRejectedHtml(Request $request){
        $companyId = auth()->guard('company-admin')->user()->company_id;
        $rejecteds = DriverOnboarding::leftjoin('drivers', 'drivers.id', '=', 'driver_onboardings.driver_id')
            ->where('status', '=', 3)
            ->where('drivers.company_id', '=', $companyId)
            ->where('drivers.id', '=', $request->id)
            ->get();
        $view = view('companyAdmin.driver.view.rejectedTable',compact('rejecteds'))->render();
        return response()->json(['status'=>1,'html'=>$view,'massage'=>'']);

    }

    public function driverOnboardingRejected(Request $request){
        if ($request->ajax() && $request) {

            $companyId = auth()->guard('company-admin')->user()->company_id;
            $data = DriverOnboarding::leftjoin('drivers', 'drivers.id', '=', 'driver_onboardings.driver_id')
                ->where('status', '=', 3)
                ->where('drivers.company_id', '=', $companyId)
                ->get();

            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('name', function ($row) {
                    return $row->last_name . ', ' . $row->first_name;
                })
                ->addColumn('status', function ($row) {
                    if ($row->status == 0) {
                        return 'Pending';
                    } elseif ($row->status == 1){
                        return  'Onboarding';
                    }elseif($row->status == 2){
                        return 'Hired';
                    }elseif($row->status == 3){
                        return 'Rejected';
                    }

                })
                ->addColumn('Onboarding', function ($row) {
                    return $row->days_to_onboard??"n/a";
                })
                ->addColumn('action', function ($row) {

                    $btn = '<a href="' . route('company.admin.drivers.show', base64Encode($row->id)) . '" class="mr-4"><i class="fa fa-eye" style="color: #BFC0C2"></i></a>';
                    return $btn;
                })
                ->rawColumns(['action', 'status','Onboarding'])
                ->make(true);

        }

    }
}
