<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use App\Models\Bookmark;
use App\Models\Broker;
use App\Models\Carrier;
use App\Models\DefaultFuelSurcharge;
use App\Models\Driver;
use App\Models\FuelSurchargeRegion;
use App\Models\FuelSurchargeTemplate;
use App\Models\LoadDetail;
use App\Models\ReportDriver;
use Carbon\Carbon;
use Carbon\CarbonPeriod;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Str;

class FuelSurchargesController extends CompanyAdminController
{
    public function parentChildTree(array $elements, $parentId = 0)
    {
        $branch = array();

        foreach ($elements as $element) {
            if ($element['parent'] == $parentId) {
                $children = $this->parentChildTree($elements, $element['id']);
                if ($children) {
                    $element['children'] = $children;
                }
                $branch[] = $element;
            }
        }

        return $branch;
    }

    public function index(Request $request)
    {


        $input = $request->all();

        $fuelSurchargeTemplate = null;
        if(isset($request->customer) && isset($request->company_id)){
            if(in_array($request->customer, ['fsg', 'fsd']) && $request->company_id != ''){
                if($request->company_id == auth()->guard('company-admin')->user()->company_id){
                    $customer = strtoupper($request->customer);
                    $companyId = strtoupper($request->company_id);

                    $fuelSurchargeTemplate = FuelSurchargeTemplate::where('company_id', $companyId)->where('customer', $customer)->first();
                }else{
                    return abort(404);
                }
            }else {
                return abort(404);
            }
        }

        $regions = FuelSurchargeRegion::get(['id', 'name as text', 'code', 'parent'])->toArray();
        $regionOptions = $this->parentChildTree($regions);

        $regionEPMRHtml = ''; $regionEPD2DHtml = '';
        $regionEPMRHtml .= '<option value="">Select Region</option>';
        $regionEPD2DHtml .= '<option value="">Select Region</option>';
        foreach($regionOptions as $key => $values){
            if($key == 0){
                foreach($values['children'] as $childs){
                    $regionEPMRHtml .= '<optgroup class="select2-result-selectable" label="'.$childs['text'].'">';
                    foreach($childs['children'] as $child){
                        if($child['code'] != ""){
                            $regionEPMRHtml .= '<option value="'.$child['text'].' ('.$child['code'].')">'.$child['text'].' ('.$child['code'].')</option>';
                        }else{
                            $regionEPMRHtml .= '<option value="'.$child['text'].'">'.$child['text'].'</option>';
                        }
                    }
                    $regionEPMRHtml .= '</optgroup>';
                }
            }else{
                foreach($values['children'] as $childs){
                    $regionEPD2DHtml .= '<optgroup class="select2-result-selectable" label="'.$childs['text'].'">';
                    foreach($childs['children'] as $child){
                        if($child['code'] != ""){
                            $regionEPD2DHtml .= '<option value="'.$child['text'].' ('.$child['code'].')">'.$child['text'].' ('.$child['code'].')</option>';
                        }else{
                            $regionEPD2DHtml .= '<option value="'.$child['text'].'">'.$child['text'].'</option>';
                        }
                    }
                    $regionEPD2DHtml .= '</optgroup>';
                }
            }
        }

        $brokersList = Broker::IsCompany()->get(['id', DB::raw("concat_ws(' - ', mc_number, name) as name" )])->pluck('name', 'id')->toArray();

        return view('companyAdmin.fuelSurcharges.index', compact(['regionEPMRHtml', 'regionEPD2DHtml', 'brokersList', 'regionOptions', 'fuelSurchargeTemplate']));
    }

    public function saveTemplate(Request $request)
    {
        $input = $request->all();
        $companyId = auth()->guard('company-admin')->user()->company_id;

        $isExists = FuelSurchargeTemplate::IsCompany()->where('customer', $input['customer'])->count();

        if($isExists > 0){
            $saveTemplate = FuelSurchargeTemplate::IsCompany()->where('customer', $input['customer'])->first();
            $saveTemplate->fuel_type = $request->fuelType;
            $saveTemplate->region = $request->region;
            $saveTemplate->rate_type = $request->rateType;
            $saveTemplate->start_price = $request->startPrice;
            $saveTemplate->ending_price = $request->endingPrice;
            $saveTemplate->price_change = $request->priceChange;
            $saveTemplate->base_percentage = $request->basePercentage;
            $saveTemplate->percentage_change = $request->percentageChange;
            $saveTemplate->per_mile_start = $request->perMileStart;
            $saveTemplate->per_mile_change = $request->perMileChange;
            $saveTemplate->customer_file_name = $request->customerFileName;
            $saveTemplate->save();
        }else{
            $saveTemplate = new FuelSurchargeTemplate();
            $saveTemplate->company_id = $companyId;
            $saveTemplate->fuel_type = $request->fuelType;
            $saveTemplate->region = $request->region;
            $saveTemplate->rate_type = $request->rateType;
            $saveTemplate->start_price = $request->startPrice;
            $saveTemplate->ending_price = $request->endingPrice;
            $saveTemplate->price_change = $request->priceChange;
            $saveTemplate->base_percentage = $request->basePercentage;
            $saveTemplate->percentage_change = $request->percentageChange;
            $saveTemplate->per_mile_start = $request->perMileStart;
            $saveTemplate->per_mile_change = $request->perMileChange;
            $saveTemplate->customer = $request->customer;
            $saveTemplate->customer_file_name = $request->customerFileName;
            $saveTemplate->save();
        }

        if($saveTemplate){
            $div_html = '';
            if(in_array($saveTemplate->customer, ['FSD', 'FSG'])){
                $currentDate = Carbon::now()->format('m/d/Y');
                $dataValue = saveDefaultFuelSurcharges($saveTemplate);
                if($dataValue != ''){
                    if($saveTemplate->fuel_type == "EPMR"){
                        $div_html .= '<p class="mb-0 text-white">Fuel Surcharge Gas</p>';
                        $div_html .= '<a class="nav-link p-0" href="'.route('company.admin.fuel-surcharges.index', ['customer' => 'fsg', 'company_id' => $companyId]).'">';
                        $div_html .= '<h6 class="text-white">'.$dataValue.'</h6>';
                        $div_html .= '<span class="nav-text mt-0">Last Updated: '.$currentDate.'</span>';
                        $div_html .= '</a>';
                    }else if($saveTemplate->fuel_type  == "EPD2D"){
                        $div_html .= '<p class="mb-0 text-white">Fuel Surcharge Diesel</p>';
                        $div_html .= '<a class="nav-link p-0" href="'.route('company.admin.fuel-surcharges.index', ['customer' => 'fsd', 'company_id' => $companyId]).'">';
                        $div_html .= '<h6 class="text-white">'.$dataValue.'</h6>';
                        $div_html .= '<span class="nav-text mt-0">Last Updated: '.$currentDate.'</span>';
                        $div_html .= '</a>';
                    }
                }
            }
            return response()->json(['success' => true, 'message' => 'Template saved successfully', 'div_html' => $div_html]);
        }else{
            return response()->json(['success' => false, 'message' => 'Error on save template.']);
        }
    }

    public function historicalFuelData()
    {
        $regions = FuelSurchargeRegion::get(['id', 'name as text', 'code', 'parent'])->toArray();
        $regionOptions = $this->parentChildTree($regions);

        $regionEPMRHtml = ''; $regionEPD2DHtml = '';
        $dieselOptions = []; $dieselOptionsCode = [];
        $gasolineOptions = []; $gasolineOptionsCode = [];

        $regionEPMRHtml .= '<option value="">Select Region</option>';
        $regionEPD2DHtml .= '<option value="">Select Region</option>';
        foreach($regionOptions as $key => $values){
            if($key == 0){
                $gasolineOptions[] = 'Release Date';
                $gasolineOptions[] = 'U.S.';
                foreach($values['children'] as $childs){
                    $regionEPMRHtml .= '<optgroup class="select2-result-selectable" label="'.$childs['text'].'">';
                    foreach($childs['children'] as $child){
                        if($child['text'] != 'U.S. Average') {
                            if ($child['code'] != "") {
                                $gasolineOptions[] = $child['text'];
                                $gasolineOptionsCode[$child['text']] = $child['code'];

                                $regionEPMRHtml .= '<option value="' . strtoupper($child['code']) . '">' . $child['text'] . ' (' . $child['code'] . ')</option>';
                            } else {
                                $gasolineOptions[] = $child['text'];

                                $regionEPMRHtml .= '<option value="' . strtoupper($child['text']) . '">' . $child['text'] . '</option>';
                            }
                        }
                    }
                    $regionEPMRHtml .= '</optgroup>';
                }
            }else{
                $dieselOptions[] = 'Release Date';
                $dieselOptions[] = 'U.S.';
                foreach($values['children'] as $childs){
                    $regionEPD2DHtml .= '<optgroup class="select2-result-selectable" label="'.$childs['text'].'">';
                    foreach($childs['children'] as $child){
                        if($child['text'] != 'U.S. Average'){
                            if($child['code'] != ""){
                                $dieselOptions[] = $child['text'];
                                $dieselOptionsCode[$child['text']] = $child['code'];

                                $regionEPD2DHtml .= '<option value="'.strtoupper($child['code']).'">'.$child['text'].' ('.$child['code'].')</option>';
                            }else{
                                $dieselOptions[] = $child['text'];

                                $regionEPD2DHtml .= '<option value="'.strtoupper($child['text']).'">'.$child['text'].'</option>';
                            }
                        }
                    }
                    $regionEPD2DHtml .= '</optgroup>';
                }
            }
        }

        $carrierList = Carrier::IsCompany()->pluck('name', 'id')->toArray();
        $brokersList = Broker::IsCompany()->get(['id', DB::raw("concat_ws(' - ', name, CONCAT(city, ', ', state)) as name" )])->pluck('name', 'id')->toArray();

        $dieselColumns = []; $gasolineColumns = [];
        $getCompanyAdmin = auth()->guard('company-admin')->user();

        $isCheckDiesel = Bookmark::where('company_id', getUserCompnayId())->where('user_id', $getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id', 'dieselPricing')->first();
        if(!empty($isCheckDiesel->id)){
            $dieselColumns = unserialize($isCheckDiesel->config);
        }else{
            foreach ($dieselOptions as $option){
                $dieselColumns[$option] = 1;
            }
        }

        $isCheckGasoline = Bookmark::where('company_id', getUserCompnayId())->where('user_id', $getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id', 'gasolinePricing')->first();
        if(!empty($isCheckGasoline->id)){
            $gasolineColumns = unserialize($isCheckGasoline->config);
        }else{
            foreach ($gasolineOptions as $option){
                $gasolineColumns[$option] = 1;
            }
        }

        $dieselFilterClear = count(array_filter($dieselColumns, function($var) { return $var == 0; }));
        $gasolineFilterClear = count(array_filter($gasolineColumns, function($var) { return $var == 0; }));

        return view('companyAdmin.fuelSurcharges.fuel-research', compact(['regionEPMRHtml', 'regionEPD2DHtml', 'regionOptions', 'carrierList', 'brokersList', 'dieselOptions', 'gasolineOptions', 'dieselColumns', 'gasolineColumns', 'dieselOptionsCode', 'gasolineOptionsCode', 'dieselFilterClear', 'gasolineFilterClear']));
    }

    public function carrierRatePerMile(Request $request)
    {
        $carrierId = $request->carrierId;
        $startDate = Carbon::parse($request->startDate);
        $endDate = Carbon::parse($request->endDate);
        $comparisonMiles = $request->comparisonMiles;

        $months = $endDate->diffInMonths($startDate);
        $weeks = $endDate->diffInWeeks($startDate);
        $data = []; $yearDates = []; $monthDates = []; $weekDates = [];

        if($months >= 20){
            $period = CarbonPeriod::create($startDate, $endDate);
            foreach ($period as $date) {
                $yearDates[] = $date->format('Y');
            }
            $dateRanges = collect(array_values(array_unique($yearDates)))->map(function ($value){
                return [
                  'startDate' => $value.'-01-01',
                  'endDate' => $value.'-12-31',
                ];
            })->toArray();
        }else{
            if($weeks >= 20){
                $period = CarbonPeriod::create($startDate, $endDate);
                foreach ($period as $date) {
                    $monthDates[] = $date->format('Y-m');
                }
                $dateRanges = collect(array_values(array_unique($monthDates)))->map(function ($value){
                    $days = Carbon::parse($value)->daysInMonth;
                    return [
                        'startDate' => $value.'-01',
                        'endDate' => $value.'-'.$days,
                    ];
                })->toArray();
            }else{
                $startDate = Carbon::parse($startDate)->modify('this monday');;
                $endDate = Carbon::parse($endDate);
                for ($date = $startDate; $date->lte($endDate); $date->addWeek()) {
                    $weekDates[] = $date->format('Y-m-d');
                }
                $dateRanges = collect(array_values(array_unique($weekDates)))->map(function ($date){
                    return [
                        'startDate' => Carbon::parse($date)->format('Y-m-d'),
                        'endDate' => Carbon::parse($date)->addWeek()->subDay(1)->format('Y-m-d'),
                    ];
                })->toArray();
            }
        }

        $carrierDrivers = Driver::isCompany()->join('driver_informations', 'driver_informations.driver_id', '=', 'drivers.id')
                            ->whereNull('drivers.deleted_at')->where('driver_informations.carrier_id', $carrierId)->pluck('drivers.id')->toArray();

        foreach ($dateRanges as $dates){
            $reportDriver = ReportDriver::whereIn('driver_id', $carrierDrivers)->where('date', '>=' ,$dates['startDate'])->where('date', '<=' ,$dates['endDate']);
            $actual_revenue = $reportDriver->sum('actual_revenue');

            if($comparisonMiles == "Loaded"){
                $actual_mileage = $reportDriver->sum('actual_mileage');
                if($actual_mileage > 0){
                    $data[] = round($actual_revenue / $actual_mileage, 3);
                }else{
                    $data[] = 0.000;
                }
            }else{
                $actual_total_mileage = $reportDriver->sum('actual_total_mileage');
                if($actual_total_mileage > 0){
                    $data[] = round($actual_revenue / $actual_total_mileage, 3);
                }else{
                    $data[] = 0.000;
                }
            }
        }

        return response()->json(['CarrierData' => $data]);
    }

    public function customerRatePerMile(Request $request)
    {
        $customerId = $request->customerId;
        $startDate = Carbon::parse($request->startDate);
        $endDate = Carbon::parse($request->endDate);
        $comparisonMiles = $request->comparisonMiles;

        $months = $endDate->diffInMonths($startDate);
        $weeks = $endDate->diffInWeeks($startDate);
        $data = []; $yearDates = []; $monthDates = []; $weekDates = [];

        if($months >= 20){
            $period = CarbonPeriod::create($startDate, $endDate);
            foreach ($period as $date) {
                $yearDates[] = $date->format('Y');
            }
            $dateRanges = collect(array_values(array_unique($yearDates)))->map(function ($value){
                return [
                    'startDate' => $value.'-01-01',
                    'endDate' => $value.'-12-31',
                ];
            })->toArray();
        }else{
            if($weeks >= 20){
                $period = CarbonPeriod::create($startDate, $endDate);
                foreach ($period as $date) {
                    $monthDates[] = $date->format('Y-m');
                }
                $dateRanges = collect(array_values(array_unique($monthDates)))->map(function ($value){
                    $days = Carbon::parse($value)->daysInMonth;
                    return [
                        'startDate' => $value.'-01',
                        'endDate' => $value.'-'.$days,
                    ];
                })->toArray();
            }else{
                $startDate = Carbon::parse($startDate)->modify('this monday');;
                $endDate = Carbon::parse($endDate);
                for ($date = $startDate; $date->lte($endDate); $date->addWeek()) {
                    $weekDates[] = $date->format('Y-m-d');
                }
                $dateRanges = collect(array_values(array_unique($weekDates)))->map(function ($date){
                    return [
                        'startDate' => Carbon::parse($date)->format('Y-m-d'),
                        'endDate' => Carbon::parse($date)->addWeek()->subDay(1)->format('Y-m-d'),
                    ];
                })->toArray();
            }
        }

        $customerDrivers = Driver::isCompany()->join('load_details', 'load_details.driver_id', '=', 'drivers.id')
                            ->whereNull('drivers.deleted_at')->where('load_details.brokerage_firm', $customerId)->groupBy('drivers.id')->pluck('drivers.id')->toArray();

        foreach ($dateRanges as $dates){
            $reportDriver = ReportDriver::whereIn('driver_id', $customerDrivers)->where('date', '>=' ,$dates['startDate'])->where('date', '<=' ,$dates['endDate']);
            $actual_revenue = $reportDriver->sum('actual_revenue');

            if($comparisonMiles == "Loaded"){
                $actual_mileage = $reportDriver->sum('actual_mileage');
                if($actual_mileage > 0){
                    $data[] = round($actual_revenue / $actual_mileage, 3);
                }else{
                    $data[] = 0.000;
                }
            }else{
                $actual_total_mileage = $reportDriver->sum('actual_total_mileage');
                if($actual_total_mileage > 0){
                    $data[] = round($actual_revenue / $actual_total_mileage, 3);
                }else{
                    $data[] = 0.000;
                }
            }
        }

        return response()->json(['CustomerData' => $data]);
    }
}
