<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;

use App\Http\Requests\CompanyAdmin\GalleryStoreRequest;
use App\Http\Requests\CompanyAdmin\GalleryUpdateRequest;

use App\Models\Gallery;
use App\Models\Bookmark;
use App\Models\FileUpload;
use App\Models\Driver;
use App\Models\CompanyAdmin;
use App\Helpers\Common;

use File;
use DataTables;
use Carbon\Carbon;
use Carbon\CarbonPeriod;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Str;

class GalleryController extends CompanyAdminController{

    /**
     * Create a new controller instance.
     *
     * @return void
     */

    public $timeZoneId;

    public function __construct(){
        parent::__construct();

        $this->middleware(function ($request, $next) {
            $this->timeZoneId   = getTimeZoneId();

            return $next($request);
        });
    }

    public function index(Request $request){
        $getCompanyAdmin    = auth()->guard('company-admin')->user();
        $getField           = '';
        $isCheck            = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','request_documents')->first();
        if(!empty($isCheck->id)){
            //$getField       = unserialize($isCheck->config);
            $getField       = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_request_documents_first'));
        }else{
            $getField       = config('settings.table_request_documents_first');
        }
        if ($request->ajax()) {
            $data           = Gallery::isCompany()
                ->where('source','!=','load_accessorial_temps');
            // General filter code - start
            foreach( $getField as $key => $value ) {
                $conditionReq = 'search_string_condition_'.$key;
                $sortReq = 'search_string_sort_'.$key;

                if( isset( request()->$conditionReq ) ) {
                    $typeReq = 'search_string_type_'.$key;
                    $type = request()->$typeReq;

                    if( $type == 'string' ) {
                        Common::getStringFilterResult( $data, $key );
                    }

                    if( $type == 'date' ) {
                        Common::getDateFilterResult( $data, $key );
                    }
                }

                if( isset( request()->$sortReq ) ) {
                    $nameReq = 'search_string_name_'.$key;
                    $sortReq = 'search_string_sort_'.$key;
                    $typeReq = 'search_string_type_'.$key;
                    $tableNameReq = 'search_table_name_'.$key;
                    $colAliasReq = 'search_string_col_alias_'.$key;

                    $origData = request()->$nameReq;
                    $condition_sort = request()->$sortReq;
                    $type = request()->$typeReq;
                    $tableName = isset( request()->$tableNameReq ) ? request()->$tableNameReq : '';
                    $colAlias = isset( request()->$colAliasReq ) ? request()->$colAliasReq : '';

                    if( $type == 'string' ) {
                        if( isset( $condition_sort ) ) {
                            if( $colAlias != '' ) {
                                $data->orderBy( $tableName.'.'.$colAlias, $condition_sort );
                            } else {
                                if( $tableName != '' ) {
                                    $data->orderBy( $tableName.'.'.$origData, $condition_sort );
                                } else {
                                    $data->orderBy( $origData, $condition_sort );
                                }
                            }
                        }
                    }
                }
            }
            $data->get();
            // General filter code - end
            return Datatables::of($data)
                ->editColumn('field_name', function($row){
                    $fieldName = Str::beforeLast($row->field_name, '_');

                    if(in_array($fieldName, ['insurance_file', 'deduction_file', 'paid_time_off_file', 'passenger_file', 'pet_file', 'medical_file', 'profile_insurance_file', 'additional_insurance_file', 'document_profile_file', 'additional_document_file'])){
                        // This Condition add for Upload Multiple file with same name
                        return $row->source.' - '.getRequestDocumentsList($fieldName,'field_name')['file_type'];
                    }else{
                        return $row->source.' - '.getRequestDocumentsList($row->field_name, 'field_name')['name'];
                    }
                })
                ->editColumn('approved_by', function($row){
                    return empty($row->approved_by) ? 'None' : getFullNameByid($row->approved_by, $row->approved_by_type) ;
                })
                ->editColumn('created_by', function($row){
                    return empty($row->created_by) ? 'None' : getFullNameByid($row->created_by, $row->created_by_type) ;
                })
                ->editColumn('requested_by', function($row){
                    return empty($row->requested_by) ? 'None' : getFullNameByid($row->requested_by, $row->requested_by_type) ;
                })
                ->editColumn('status', function($row){
                    if($row->status == 'pending'){
                        return '<span class="status-pending">Pending</span>';
                    }
                    if($row->status == 'approved'){
                        return '<span class="status-approved">Approved</span>';
                    }
                    if($row->status == 'review'){
                        return '<span class="status-review">Review</span>';
                    }
                })
                ->editColumn('access', function($row){
                    if($row->access == 1){
                        return 'Managers';
                    }
                    if($row->access == 3){
                        return 'Dispatchers';
                    }
                    if($row->access == 3){
                        return 'Drivers';
                    }
                    return 'All User';
                })
                ->addIndexColumn()
                ->addColumn('action', function($row){
                    //$btn = '<a href="'.route('company.admin.request-documents.show', $row->id).'" class="mr-4"><img src="'.asset('theme/img/eye.png').'" alt=""></a>';
                    $btn = '<a href="#"  class="mr-4 gallaedit" data-id="'.$row->action_id.'" data-source="'.$row->source.'" data-field="'.$row->field_name.'" data-toggle="modal" data-target="#galleryModal"><img src="'.asset("theme/img/eye.png").'" alt=""></a>';

                    $btn = $btn.' <a href="javascript:" class="destroy" data-action="'.route('company.admin.request-documents.destroy',$row->id).'" data-id="'.$row->id.'"><img src="'.asset('theme/img/delete-icon.png').'" alt=""></a>';
                    return $btn;
                })
                ->rawColumns(['action','status','access'])
                ->make(true);
        }

        $tableName = 'settings.table_request_documents';
        return view('companyAdmin.gallery.index', compact('getField','tableName'));
    }

    public function edit(Gallery $gallery){
        return redirect()->route('company.admin.request-documents.index');
    }

    public function show(Gallery $gallery){
        return view('companyAdmin.gallery.show', compact('gallery'));
    }

    public function getFiles(Request $request){
        $getTimeZoneId  = $this->timeZoneId;
        $getGallery     = Gallery::IsCompany()->where('action_id', $request->action_id)->where('source', $request->source)->where('field_name', $request->field_name)->whereNOtNull('image')->orderBy('id', 'desc')->get();
        $view           = view('companyAdmin.gallery.view', compact('getGallery','getTimeZoneId'))->render();
        $getCurrent     = Gallery::IsCompany()->where('action_id', $request->action_id)->where('source', $request->source)->where('field_name', $request->field_name)->whereNOtNull('image')->where('status', 'approved')->orderBy('id', 'desc')->first();
        $currentImage   = view('companyAdmin.gallery.currentImage', compact('getCurrent'))->render();
        $getfileUpload  = Gallery::IsCompany()->where('action_id', $request->action_id)->where('source', $request->source)->where('field_name', $request->field_name)->whereNull('image')->orderBy('id', 'desc')->get();
        $fileUpload     = view('companyAdmin.gallery.fileUpload', compact('getfileUpload'))->render();
        return response()->json(['view' => $view,'currentImage' => $currentImage,'fileUpload' => $fileUpload]);
    }

    public function store(Request $request){
        if(empty($request->image)){
            if ($request->ajax()) {
                return 0;
            }else{
                notification('error', $this->crudMessage('create', 'Upload File not found.'));
                return redirect()->back();
            }
        }

        $gallery                                = Gallery::find($request->gallery_id);

        $input                                  = $request->all();
        $input['uploaded_date']                 = Carbon::now()->format('m/d/Y H:i');
        $input['created_by']                    = auth()->guard('company-admin')->user()->id;
        $input['created_by_type']               = auth()->guard('company-admin')->user()->type;
        $input['status']                        = 'approved';

        $fieldName = Str::beforeLast($request->field_name, '_');

        if(in_array($fieldName, ['insurance_file', 'deduction_file', 'paid_time_off_file', 'passenger_file', 'pet_file', 'medical_file', 'profile_insurance_file', 'additional_insurance_file', 'document_profile_file', 'additional_document_file'])){
            // This Condition add for Upload Multiple file with same name
            $input['file_type'] = getRequestDocumentsList($fieldName,'field_name')['file_type'];
        }else{
            $input['file_type'] = getRequestDocumentsList($request->field_name,'field_name')['file_type'];
        }

        if($input['file_type'] == 3){
            $file_temp                          = [];
            $image_array                        = [];
            foreach($request->image as $image){
                $seme                           = FileUpload::upload('companyAdmin/temp', $image);
                $stopath                        = public_path('storage/companyAdmin/temp/'.$seme);
                $data                           = file_get_contents($stopath);
                $type                           = pathinfo($stopath, PATHINFO_EXTENSION);
                if($type == 'png' || $type == 'jpeg' || $type == 'jpg' || $type == 'gif'){
                    $base64                     = 'data:image/' . $type . ';base64,' . base64_encode($data);
                    $file_temp[]                = $base64;
                }
            }
            if(count($file_temp) > 0){
                $fileName                       = 'document_pdf';
                $input['image']                 = FileUpload::PDFupload('companyAdmin/gallery', ['data' => $file_temp], $fileName);
            }else{
                $input['image']                 = null;
            }
            if(!is_null($input['image'])){
                if(!empty($request->gallery_id)){
                    if($gallery->id){
                        if($gallery->requires_approval == 'yes'){
                            $input['status']    = 'review';
                        }
                        $gallery->update($input);
                    }
                }else{
                    Gallery::create($input);
                }
            }else{
                if ($request->ajax()) {
                    return 0;
                }else{
                    notification('error', 'Oops! Something went wrong..');
                    return redirect()->back();
                }
            }
        }else{
            foreach($request->image as $image){
                if (isset($image)) {
                    $input['image']             = FileUpload::upload('companyAdmin/gallery', $image);
                }
                if(!empty($request->gallery_id)){
                    if($gallery->id){
                        if($gallery->requires_approval == 'yes'){
                            $input['status']    = 'review';
                        }
                        $gallery->update($input);

                        $description = "";
                        if($gallery->created_by_type == 3){
                            $getDriver          = Driver::find($gallery->created_by);
                            $description        = 'Document Added by '.$getDriver->full_name;
                        }
                        if($gallery->created_by_type == 2){
                            $companyAdmin       = CompanyAdmin::find($gallery->created_by);
                            $description        = 'Document Added by '.$companyAdmin->full_name;
                        }
                        createNotification(
                            14, // source
                            'Document Added', // name
                            $gallery->requested_by, // user_id
                            $gallery->requested_by_type, // user_type
                            1, // type
                            $gallery->id, // action_id
                            $description // description
                        );
                    }
                }else{
                    Gallery::create($input);
                }
            }
        }

        if ($request->ajax()) {
            return 1;
        }else{
            notification('success', $this->crudMessage('create', 'Documents Added'));
            return redirect()->back();
        }
    }

    public function requestDocumentsSave(Request $request){
        $input                              = $request->all();
        $input['company_id']                = auth()->guard('company-admin')->user()->company_id;
        $input['requested_by']              = auth()->guard('company-admin')->user()->id;
        $input['requested_by_type']         = auth()->guard('company-admin')->user()->type;
        $input['date']                      = date('m/d/Y');
        $input['status']                    = 'pending';

        $reminder_on = $input['req_reminder_on'] ?? null;
        if (is_array($reminder_on)) {
            $reminder_on = !empty($reminder_on) ? implode(',', $reminder_on) : null;
        }
        $input['reminder_on'] = $reminder_on;
        $input['reminder_type'] = $input['req_reminder_type'] ?? null;
        if($input['reminder_type'] == 'Custom'){
            $input['reminder_custom_hours'] = $input['req_reminder_custom_hours'];
        }
        $input['reminder_repeat'] = $input['req_reminder_repeat'] ?? 0;
        if($input['reminder_repeat'] == 1){
            $input['reminder_repeat_date_time'] = Carbon::now();
        }

        if(!isset($request->share)){
            $input['created_by_type']   = 3;
            $input['created_by']        = $request->setdriver;
        }else{
            if($request->share == '1'){
                $input['created_by_type']   = 3;
                $input['created_by']        = $request->setdriver;
            }

            if($request->share == '2'){
                $input['created_by_type']   = 2;
                $input['created_by']        = $request->setdispatcher;
            }
        }

        $count                          = count($request->field_name);
        if($count > 0){
            for ($x = 0; $x < $count; $x++) {
                $input['field_name']    = $request->field_name[$x];
                $input['file_type']     = getRequestDocumentsList($request->field_name[$x],'field_name')['file_type'];
                $input['file_name']     = $request->file_name[$x];

                $gallery = Gallery::create($input);

                documentRequestReminder($gallery);

                $description            = 'Request Document by '.auth()->guard('company-admin')->user()->full_name;
                createNotification(
                    13, // source
                    'Request Document', // name
                    $gallery->created_by, // user_id
                    $gallery->created_by_type, // user_type
                    1, // type
                    $gallery->id, // action_id
                    $description // description
                );
            }
        }
        notification('success', $this->crudMessage('create', 'Request Documents'));
        return redirect()->back();
    }

    public function destroy($id, Request $request){
        $gallery    = Gallery::find($id);
        $path       = 'storage/companyAdmin/gallery/'.$gallery->image;
        if (File::exists($path)) {
            File::delete($path);
        }
        $gallery->delete();
        if ($request->ajax()) {
            return 1;
        }else{
            notification('success', $this->crudMessage('delete', 'File deleted'));
            return redirect()->back();
        }
        return 1;
    }

     function getFileDownload($id){
        $gallery    = Gallery::find($id);
        $path       = 'storage/companyAdmin/gallery/'.$gallery->image;
        return response()->download($path);
    }

    function getUpdateStatus(Request $request){
        $input      = $request->all();
        $gallery    = Gallery::find($request->id);
        $gallery->update(['status' => $request->status]);
        return 1;
    }

    function getUpdateAccess(Request $request){
        $input      = $request->all();
        $gallery    = Gallery::find($request->id);
        $gallery->update(['access' => $request->access]);
        return 1;
    }

    function getUpdateFilename(Request $request){
        $input      = $request->all();
        $gallery    = Gallery::find($request->id);
        $gallery->update(['file_name' => $request->file_name]);
        return 1;
    }

    function galleryImagesView(Request $request){
        $input      = $request->all();
        $getGallery = Gallery::IsCompany()->where('action_id', $request->action_id)->where('source', $request->source)->where('field_name', $request->filed_name)->whereNotNull('image')->latest()->get();
        $view       = view('companyAdmin.gallery.gridView', compact('getGallery'))->render();
        return response()->json(['view' => $view]);
    }

}
