<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;
use App\Models\GalleryDocumentName;
use App\Models\Bookmark;

use DataTables;
use Validator;
use Carbon\Carbon;

class GalleryDocumentNameController extends CompanyAdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        Carbon::setWeekStartsAt(Carbon::SUNDAY);
        Carbon::setWeekEndsAt(Carbon::SATURDAY);
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {

        $getField = '';

        $getCompanyAdmin = auth()->guard('company-admin')->user();
        $isCheck = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','gallery_document_name')->first();

        if(!empty($isCheck->id)){
            $getField = unserialize($isCheck->config);
        }else{
            $getField = config('settings.table_gallery_document_name_first');
        }

        if ($request->ajax()) {
            $data = GalleryDocumentName::isCompany()->select('*');
            return Datatables::of($data)
                    ->addIndexColumn()
                    ->addColumn('week', function($row){
                        return "<span class='ml-4'>Week ".$row->week."</span><br/>".$row->start_date." - ".$row->end_date;
                    })
                    ->orderColumn("week", function ($query, $order) {
                        $query->orderByRaw(
                            "week $order,start_date $order,end_date $order"
                        );
                    })
                    ->filterColumn("week", function ($query, $keyword) {
                        $query->where('week', 'like', '%'.$keyword.'%')
                            ->orWhereRaw("DATE_FORMAT(start_date,'%c/%e/%Y') LIKE ?",["%$keyword%"])
                            ->orWhereRaw("DATE_FORMAT(end_date,'%c/%e/%y') LIKE ?",["%$keyword%"]);
                    })
                    ->editColumn('fuel_surcharge', function($row){
                        return "$".number_format($row->fuel_surcharge,2);
                    })
                    ->addColumn('action', function($row){
                        $btn = '<a href="#" class="edit-btn mr-4" data-id="'.$row->id.'" data-toggle="modal" data-target="#editModal"><img src="'.asset('theme/img/edit-icon.png').'" alt=""></a>';
                        $btn = $btn.' <a href="#" class="destroy" data-action="'.route('company.admin.gallery-document-names.destroy',$row->id).'" data-id="'.$row->id.'"><img src="'.asset('theme/img/delete-icon.png').'" alt=""></a>';
                        return $btn;
                    })
                    ->rawColumns(['action','week','fuel_surcharge'])
                    ->make(true);
        }

        return view('companyAdmin.galleryDocumentName.index', compact('getField'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $input = $request->all();

        $validator = Validator::make($input,[
            "name" => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $input['company_id'] = auth()->guard('company-admin')->user()->company_id;
        GalleryDocumentName::create($input);

        notification('success', $this->crudMessage('create', 'Document Name'));

        return response()->json(['success' => "Document Name created successfully"]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function editFormView(Request $request)
    {
        $galleryDocumentName = GalleryDocumentName::find($request->id);

        $view = view('companyAdmin.galleryDocumentName.editFormView', compact('galleryDocumentName'))->render();

        return response()->json(['view' => $view, 'data' => $galleryDocumentName]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $input = $request->all();

        $validator = Validator::make($input,[
            "name" => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        GalleryDocumentName::find($id)->update($input);
        notification('success', $this->crudMessage('update', 'Document Name'));

        return response()->json(['success' => "Document Name updated successfully"]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(GalleryDocumentName $galleryDocumentName)
    {
        $galleryDocumentName->delete();

        notification('success', $this->crudMessage('delete', 'Document Name'));
        
        return redirect()->back();
    }
}
