<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;
use App\Http\Requests\CompanyAdmin\LeaveTypeStoreRequest;
use App\Http\Requests\CompanyAdmin\LeaveTypeUpdateRequest;
use App\Models\LeaveType;
use App\Models\Bookmark;
use App\Helpers\Common;

use Hash;
use DataTables;
use Carbon\Carbon;
use Illuminate\Support\Str;

class LeaveTypeController extends CompanyAdminController
{
    /**

     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $getField = '';

        $getCompanyAdmin = auth()->guard('company-admin')->user();
        $isCheck = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','leave_types')->first();

        if(!empty($isCheck->id)){
            //$getField = unserialize($isCheck->config);
            $getField = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_leave_types_first'));
        }else{
            $getField = config('settings.table_leave_types_first');
        }

        if ($request->ajax()) {
            $data = LeaveType::isCompany();
            // General filter code - start
            foreach( $getField as $key => $value ) {
                $conditionReq = 'search_string_condition_'.$key;
                $sortReq = 'search_string_sort_'.$key;

                if( isset( request()->$conditionReq ) ) {
                    $typeReq = 'search_string_type_'.$key;
                    $type = request()->$typeReq;

                    if( $type == 'string' ) {
                        Common::getStringFilterResult( $data, $key );
                    }

                    if( $type == 'date' ) {
                        Common::getDateFilterResult( $data, $key );
                    }
                }

                if( isset( request()->$sortReq ) ) {
                    $nameReq = 'search_string_name_'.$key;
                    $sortReq = 'search_string_sort_'.$key;
                    $typeReq = 'search_string_type_'.$key;
                    $tableNameReq = 'search_table_name_'.$key;
                    $colAliasReq = 'search_string_col_alias_'.$key;

                    $origData = request()->$nameReq;
                    $condition_sort = request()->$sortReq;
                    $type = request()->$typeReq;
                    $tableName = isset( request()->$tableNameReq ) ? request()->$tableNameReq : '';
                    $colAlias = isset( request()->$colAliasReq ) ? request()->$colAliasReq : '';

                    if( $type == 'string' ) {
                        if( isset( $condition_sort ) ) {
                            if( $colAlias != '' ) {
                                $data->orderBy( $tableName.'.'.$colAlias, $condition_sort );
                            } else {
                                if( $tableName != '' ) {
                                    $data->orderBy( $tableName.'.'.$origData, $condition_sort );
                                } else {
                                    $data->orderBy( $origData, $condition_sort );
                                }
                            }
                        }
                    }
                }
            }
            $data->get();
            // General filter code - end
            return Datatables::of($data)
                    ->addIndexColumn()
                    ->editColumn('color', function($row){
                        return '<div class="bgcolro" style="background-color:'.$row->color.';">'.$row->color.'</div>';
                    })
                    ->editColumn('half_day_request', function ($row) {
                        if ($row->half_day_request == '1') {
                            return '<label class="active">Active</label>';
                        } else {
                            return '<label class="inactive">Inactive</label>';
                        }

                    })
                    ->editColumn('register_in_the_past', function ($row) {
                        if ($row->register_in_the_past == '1') {
                            return '<label class="active">Active</label>';
                        } else {
                            return '<label class="inactive">Inactive</label>';
                        }

                    })
                    ->editColumn('enforce_allowance', function ($row) {
                        if ($row->enforce_allowance == '1') {
                            return '<label class="active">Active</label>';
                        } else {
                            return '<label class="inactive">Inactive</label>';
                        }

                    })
                    ->addColumn('action', function($row){
                        $action = '<a href="'.route('company.admin.leave-type.edit', base64Encode($row->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-pencil" aria-hidden="true"></i></a>';
                        $action .= '<a href="javascript:void(0);" class="btn btn-sm btn-outline-black-trash destroy" data-action="'.route('company.admin.leave-type.destroy',$row->id).'" data-id="'.$row->id.'"><i class="fa fa-trash" aria-hidden="true"></i></a>';

                        return $action;
                    })
                    ->rawColumns(['action','color','half_day_request','register_in_the_past','enforce_allowance'])
                    ->make(true);
        }

        $tableName = 'settings.table_leave_types';
        return view('companyAdmin.leaveType.index', compact('getField','tableName'));

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('companyAdmin.leaveType.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(LeaveTypeStoreRequest $request)
    {
        $input = $request->all();
        $input['company_id'] = auth()->guard('company-admin')->user()->company_id;
        LeaveType::create($input);

        notification('success', $this->crudMessage('create', 'Company holiday'));
        return redirect()->route('company.admin.leave-type.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $id = base64Decode($id);
        $leaveType = LeaveType::findOrFail($id);
       return redirect()->route('company.admin.leave-type.index');
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $id = base64Decode($id);
        $leaveType = LeaveType::findOrFail($id);
        return view('companyAdmin.leaveType.edit', compact('leaveType'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(LeaveTypeUpdateRequest $request, LeaveType $leaveType)
    {
        $input = $request->all();

        if(!isset($request->half_day_request)){
            $input['half_day_request'] = '0';
        }
        if(!isset($request->register_in_the_past)){
            $input['register_in_the_past'] = '0';
        }
        if(!isset($request->enforce_allowance)){
            $input['enforce_allowance'] = '0';
        }

        $input['company_id'] = auth()->guard('company-admin')->user()->company_id;
        $leaveType->update($input);
        notification('success', $this->crudMessage('update', 'Holiday'));
        return redirect()->route('company.admin.leave-type.index');
    }

    public function destroy(LeaveType $leaveType)
    {
        $leaveType->delete();

        notification('success', $this->crudMessage('delete', 'Holiday'));

        return redirect()->route('company.admin.leave-type.index');
    }

}
