<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

use App\Models\Note;
use App\Models\Bookmark;
use App\Models\MaintenanceAppointment;

use App\Models\Truck;
use App\Models\Trailer;

use Arr;
use Validator;
use DataTables;
use Carbon\Carbon;

class MaintenanceAppointmentController extends CompanyAdminController{

    /**
     * Create a new controller instance.
     *
     * @return void
     */

    public $timeZoneId;

    public function __construct(){
        parent::__construct();

        $this->middleware(function ($request, $next) {
            $this->timeZoneId   = getTimeZoneId();

            return $next($request);
        });
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request){
        $getTimeZoneId  = $this->timeZoneId;
        $data           = MaintenanceAppointment::where('maintenance_id', $request->maintenance_id)->where('company_id', auth()->guard('company-admin')->user()->company_id)->get();
        $html           = view('companyAdmin.maintenance.modal.AppointmentView', compact('data','getTimeZoneId'))->render();
        return response()->json(['data' => $html]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(){
        return view('companyAdmin.maintenance.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request){
        $input      = $request->except([]);
        // dd( $input);

        $validator  = Validator::make($input,['summary' => 'required']);
        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $input['company_id']                = auth()->guard('company-admin')->user()->company_id;
        $input['do_not_email_invitation']   = isset($request->do_not_email_invitation) ? 1 : 0;
        $input['all_days']                  = isset($request->all_days) ? 1 : 0;
        if($request->address_verified==1){
            $timezone                       = null;
            $timezone_offset                = null;
            if(isset($input['timezone_abbr'])){
                $timezone                   = timezone_name_from_abbr($input['timezone_abbr']);
                $timezone_offset            = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['timezone']              = $timezone;
            $input['timezone_offset']       = $timezone_offset;
        }

        if(isset($request->attendees) && count($request->attendees)){
            $input['attendees'] =  implode(',',$request->attendees);    
        }

        $maintenanceAppointment= MaintenanceAppointment::create($input);
      
        return response()->json(['success' => "Appointment created successfully"]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Request $request){
        $getTimeZoneId                  = $this->timeZoneId;
        $maintenanceAppointments        = MaintenanceAppointment::find($request->id);
        $html                           = view('companyAdmin.maintenance.modal.editAppointmentsFrom', compact('maintenanceAppointments','getTimeZoneId'))->render();
        return response()->json(['data' => $html]);
    }

    /**
     * Display the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(MaintenanceAppointment $maintenance){
        $getTimeZoneId                  = $this->timeZoneId;
        return view('companyAdmin.maintenance.show', compact('maintenance','getTimeZoneId'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id){
        $input      = $request->except([]);
        $validator  = Validator::make($input,['summary' => 'required']);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $input['company_id']                = auth()->guard('company-admin')->user()->company_id;
        $input['do_not_email_invitation']   = isset($request->do_not_email_invitation) ? 1 : 0;
        $input['all_days']                  = isset($request->all_days) ? 1 : 0;
        if($request->address_verified==1){
            $timezone                       = null;
            $timezone_offset                = null;
            if(isset($input['timezone_abbr'])){
                $timezone                   = timezone_name_from_abbr($input['timezone_abbr']);
                $timezone_offset            = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['timezone']              = $timezone;
            $input['timezone_offset']       = $timezone_offset;
        }else{
            $input['latitude']              = null;
            $input['longitude']             = null;
            $input['timezone']              = null;
            $input['timezone_offset']       = null;
            $input['timezone_abbr']         = null;
        }
        if(isset($request->attendees) && count($request->attendees)){
            $input['attendees'] =  implode(',',$request->attendees);    
        }

        $MaintenanceAppointment             = MaintenanceAppointment::find($id);
        $MaintenanceAppointment->update($input);
        return response()->json(['success' => "Appointment updated successfully"]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request){
        $data = MaintenanceAppointment::find($request->id);
        $data->delete();
        return response()->json(['success' => "Appointment deleted successfully"]);
    }
}
