<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

use App\Http\Requests\CompanyAdmin\ManageTypeStoreRequest;
use App\Http\Requests\CompanyAdmin\ManageTypeUpdateRequest;

use App\Models\Company;
use App\Models\CompanyAdmin;

use App\Models\ManageType;
use App\Models\ManageTypeCategory;
use App\Models\ManageCompanyType;

use App\Models\Bookmark;

use Mail;
use Hash;
use DataTables;
use Carbon\Carbon;
use App\Helpers\Common;

class ManageTypeController extends CompanyAdminController{

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(){
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request){
        $getCompanyAdmin    = auth()->guard('company-admin')->user();
        $getField           = '';
        $isCheck            = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','manage_types')->first();

        if(!empty($isCheck->id)){
            //$getField       = unserialize($isCheck->config);
            $getField       = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_manage_types_first'));
        }else{
            $getField       = config('settings.table_manage_types_first');
        }

        if ($request->ajax()) {
            $data           = ManageCompanyType::leftJoin('manage_type_categories as mc', function($join) {
                    $join->on('manage_company_types.category_id', '=', 'mc.id');
                })
                ->select('manage_company_types.*','mc.name as category_name')
                ->where('manage_company_types.company_id',auth()->guard('company-admin')->user()->company_id);

            // General filter code - start
                foreach( $getField as $key => $value ) {
                    $conditionReq = 'search_string_condition_'.$key;
                    $sortReq = 'search_string_sort_'.$key;

                    $conditionDateReq = 'search_date_condition_'.$key;
                    $sortDateReq = 'search_date_sort_'.$key;

                    // String filter
                    if( isset( request()->$conditionReq ) ) {
                        $typeReq = 'search_string_type_'.$key;
                        $type = request()->$typeReq;

                        if( $type == 'string' ) {
                            Common::getStringFilterResult( $data, $key );
                        }
                    }

                    // Date filter
                    if( isset( request()->$conditionDateReq ) ) {
                        $typeReq = 'search_date_type_'.$key;
                        $type = request()->$typeReq;

                        if( $type == 'date' ) {
                            Common::getDateFilterResult( $data, $key );
                        }
                    }

                    // String sort only
                    if( isset( request()->$sortReq ) ) {
                        Common::sortStringFilter( $data, $key );
                    }

                    // Date sort only
                    if( isset( request()->$sortDateReq ) ) {
                        Common::sortDateFilter( $data, $key );
                    }
                }
            // General filter code - end

            $data->get();

            return Datatables::of($data)
                    ->addIndexColumn()
                    ->addColumn('action', function($row){
                        $action = '<a href="'.route('company.admin.manage-type.edit', base64Encode($row->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-pencil" aria-hidden="true"></i></a>';
                        $action .= '<a href="javascript:void(0);" class="btn btn-sm btn-outline-black-trash destroy" data-action="'.route('company.admin.manage-type.destroy',$row->id).'" data-id="'.$row->id.'"><i class="fa fa-trash" aria-hidden="true"></i></a>';

                        return $action;
                    })
                    ->rawColumns(['action'])
                    ->make(true);
        }

        $tableName = 'settings.table_manage_types';
        // return view('companyAdmin.manageType.index', compact('getField'));
        return view('companyAdmin.manageType.temp', compact('getField','tableName'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(){
        return view('companyAdmin.manageType.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(ManageTypeStoreRequest $request){
        $input          = $request->except(['_token']);
        $manage_type    = ManageCompanyType::create($input);

        notification('success', $this->crudMessage('create', ''));

        return redirect()->route('company.admin.manage-type.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(){
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id){
        $manageCompanyType = ManageCompanyType::findOrFail(base64Decode($id));
        return view('companyAdmin.manageType.edit', compact('manageCompanyType'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(ManageTypeUpdateRequest $request,$id){
        $input              = $request->except(['_token','_method']);
        $manageCompanyType  = ManageCompanyType::findOrFail($id);
        $manageCompanyType->update($input);

        notification('success', $this->crudMessage('update', ''));

        return redirect()->route('company.admin.manage-type.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request){
        $data               = ManageCompanyType::find($request->id);
        $data->delete();

        notification('success', $this->crudMessage('delete', ''));

        return redirect()->route('company.admin.manage-type.index');
    }
}
