<?php
namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

use App\Http\Requests\CompanyAdmin\ManagerStoreRequest;
use App\Http\Requests\CompanyAdmin\ManagerUpdateRequest;

use App\Mail\CompanyAdmin\NewPasswordMailToManager;
use App\Mail\CompanyAdmin\WelcomeMailToManager;

use App\Models\CompanyAdmin;
use App\Models\FileUpload;

use App\Models\Event;
use App\Models\Bookmark;
use App\Models\LeaveUserType;
use App\Models\Maintenance;
use App\Models\CompanyAdminStatusLog;


use Mail;
use Auth;
use Hash;
use Session;
use DataTables;
use Carbon\Carbon;
use Twilio\Rest\Client;
use App\Helpers\Common;

class ManagerController extends CompanyAdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */

    public $timeZone;
    public $timeZoneId;
    public $offset;

    public function __construct(){
        parent::__construct();

        $this->middleware(function ($request, $next) {
            $this->timeZone     = getTimeZone();
            $this->timeZoneId   = getTimeZoneId();
            $this->offset       = getTimeZoneOffset();

            return $next($request);
        });
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $getField           = '';
        $getCompanyAdmin    = auth()->guard('company-admin')->user();
        $isCheck            = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','managers')->first();
        if(!empty($isCheck->id)){
            //$getField       = unserialize($isCheck->config);
            $getField       = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_managers_first'));
        }else{
            $getField       = config('settings.table_managers_first');
        }
        if ($request->ajax()) {
            $getFilter      = $request->session()->get('cutFilter');

            if($getFilter == '1' || empty($getFilter)){
                $data       = CompanyAdmin::company()->manager();
            }elseif($getFilter == '2'){
                $data       = CompanyAdmin::company()->manager()->onlyTrashed();
            }elseif($getFilter == '3'){
                $data       = CompanyAdmin::company()->manager()->withTrashed();
            }

            // General filter code - start
            foreach( $getField as $key => $value ) {
                $conditionReq = 'search_string_condition_'.$key;
                $sortReq = 'search_string_sort_'.$key;

                if( isset( request()->$conditionReq ) ) {
                    $typeReq = 'search_string_type_'.$key;
                    $type = request()->$typeReq;

                    if( $type == 'string' ) {
                        Common::getStringFilterResult( $data, $key );
                    }

                    if( $type == 'date' ) {
                        Common::getDateFilterResult( $data, $key );
                    }
                }

                if( isset( request()->$sortReq ) ) {
                    $nameReq = 'search_string_name_'.$key;
                    $sortReq = 'search_string_sort_'.$key;
                    $typeReq = 'search_string_type_'.$key;
                    $tableNameReq = 'search_table_name_'.$key;
                    $colAliasReq = 'search_string_col_alias_'.$key;

                    $origData = request()->$nameReq;
                    $condition_sort = request()->$sortReq;
                    $type = request()->$typeReq;
                    $tableName = isset( request()->$tableNameReq ) ? request()->$tableNameReq : '';
                    $colAlias = isset( request()->$colAliasReq ) ? request()->$colAliasReq : '';

                    if( $type == 'string' ) {
                        if( isset( $condition_sort ) ) {
                            if( $colAlias != '' ) {
                                $data->orderBy( $tableName.'.'.$colAlias, $condition_sort );
                            } else {
                                if( $tableName != '' ) {
                                    $data->orderBy( $tableName.'.'.$origData, $condition_sort );
                                } else {
                                    $data->orderBy( $origData, $condition_sort );
                                }
                            }
                        }
                    }
                }
            }
            $data->select('*');
            /// end

            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function($row){
                    $action = '<a href="'.route('company.admin.managers.show', base64Encode($row->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-eye" aria-hidden="true"></i></a>';
                    $action .= '<a href="'.route('company.admin.managers.edit', base64Encode($row->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-pencil" aria-hidden="true"></i></a>';
                    $action .= '<a href="javascript:void(0);" class="btn btn-sm btn-outline-black-trash termination" data-action="'.route('company.admin.managers.destroy',$row->id).'" data-id="'.$row->id.'"><i class="fa fa-trash" aria-hidden="true"></i></a>';

                    if(auth()->guard('admin')->check()){
                        $action .= '<a href="'.route('company.admin.login.to.manager',base64Encode($row->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-random" aria-hidden="true"></i></a>';
                    }

                    return $action;
                })
                ->rawColumns(['action'])
                ->make(true);
        }else{
            $request->session()->put('cutFilter',request()->get('f'));
        }
        $tableName = 'settings.table_managers';
        return view('companyAdmin.manager.index', compact('getField','tableName'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('companyAdmin.manager.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(ManagerStoreRequest $request)
    {
        $input                          = $request->all();
        if($request->address_verified==1){
            $timezone                   = null;
            $timezone_offset            = null;
            if(isset($input['timezone_abbr'])){
                $timezone               = timezone_name_from_abbr($input['timezone_abbr']);
                $timezone_offset        = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['timezone']          = $timezone;
            $input['timezone_offset']   = $timezone_offset;
        }

        $input['company_id']            = auth()->guard('company-admin')->user()->company_id;
        $password                       = $input['password'];
        $input['password']              = Hash::make($password);
        $input['type']                  = 1;
        if (isset($input['profile_image'])) {
            $input['profile_image']     = FileUpload::upload('companyAdmin/profile', $input['profile_image']);
        }
        $companyAdmin = CompanyAdmin::create($input);

        $logdata = [];
        $logdata['company_id'] = auth()->guard('company-admin')->user()->company_id;
        $logdata['company_admin_id'] = $companyAdmin->id;
        $logdata['type'] = $companyAdmin->type;
        $logdata['status_id'] = $companyAdmin->status;
        CompanyAdminStatusLog::create($logdata);

        

        // send mail
        $mailData                       = [];
        $mailData['company_id']         = auth()->guard('company-admin')->user()->company_id;
        $mailData['name']               = $input['first_name'].' '.$input['last_name'];
        $mailData['email']              = $input['email'];
        $mailData['password']           = $password;
        //Mail::to($input['email'])->send(new WelcomeMailToManager($mailData));
        sendEmail($input['email'], new WelcomeMailToManager($mailData));

        // send sms
        if (isset($input['sms']) && isset($input['cell_phone'])) {
            // Twilio's credentials are fetched from company table
            $getCompanyTwilioData       = getCompanyTwilioData();
            if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
                $message                = "Your account has been created successfully on NGD. Click here to login: ".route('company.admin.login');
                sendSMS($input['cell_phone'], $message, $getCompanyTwilioData);
            }
        }

        notification('success', $this->crudMessage('create', 'Manager'));
        return redirect()->route('company.admin.managers.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $id = base64Decode($id);
        $companyAdmin           = CompanyAdmin::findOrFail($id);
        $getLeaveUserType       = LeaveUserType::where('company_admins_id',$id)->where('year',date('Y'))->get();

        $now                    = Carbon::now();
        $month_name             = $now->format('F');
        $month                  = $now->format('m');
        $year                   = $now->format('Y');
        return view('companyAdmin.manager.show', compact('companyAdmin','getLeaveUserType','month_name','month','year'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $id = base64Decode($id);
        $companyAdmin           = CompanyAdmin::findOrFail($id);
        return view('companyAdmin.manager.edit', compact('companyAdmin'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(ManagerUpdateRequest $request, $id)
    {
        $input                          = $request->all();

        if($request->address_verified==1){
            $timezone                   = null;
            $timezone_offset            = null;
            if(isset($input['timezone_abbr'])){
                $timezone               = timezone_name_from_abbr($input['timezone_abbr']);
                $timezone_offset        = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['timezone']          = $timezone;
            $input['timezone_offset']   = $timezone_offset;
        }else{
            $input['latitude']          = null;
            $input['longitude']         = null;
            $input['timezone']          = null;
            $input['timezone_offset']   = null;
            $input['timezone_abbr']     = null;
        }

        if ($input['password']) {
            $password                   = $input['password'];
            $input['password']          = Hash::make($password);
        } else {
            unset($input['password']);
        }

        if (isset($input['profile_image'])) {
            $input['profile_image']     = FileUpload::upload('companyAdmin/profile', $input['profile_image']);
        }

        $input['sms']                   = $input['sms'] ?? 0;
        $input['allow_login']           = $input['allow_login'] ?? 0;
        $companyAdmin = CompanyAdmin::find($id)->update($input);

        if($companyAdmin->wasChanged()){
            if(isset($companyAdmin->getChanges()['status'])){
                $logdata = [];
                $logdata['company_id'] = auth()->guard('company-admin')->user()->company_id;
                $logdata['company_admin_id'] = $companyAdmin->id;
                $logdata['type'] = $companyAdmin->type;
                $logdata['status_id'] = $companyAdmin->status;
                CompanyAdminStatusLog::create($logdata);
            }
        }

        // send new pwd mail
        if (isset($input['password'])) {
            $mailData                   = [];
            $mailData['company_id']  = auth()->guard('company-admin')->user()->company_id;
            $mailData['name']           = $input['first_name'].' '.$input['last_name'];
            $mailData['email']          = $input['email'];
            $mailData['password']       = $password;
            //Mail::to($input['email'])->send(new NewPasswordMailToManager($mailData));
            sendEmail($input['email'], new NewPasswordMailToManager($mailData));
        }

        notification('success', $this->crudMessage('update', 'Manager'));
        return redirect()->route('company.admin.managers.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $input                              = $request->except(['_token','button']);

        $Company_admin                      = CompanyAdmin::withTrashed()->where('id',$input['id'])->first();
        if($request->button == 'delete'){
            $input['termination_date']      = Carbon::createFromFormat('m/d/Y',$request->termination_date)->format('Y-m-d');
            $Company_admin->update($input);
            $Company_admin->delete();
        }elseif($request->button == 'forcedelete'){
            $Company_admin->restore();
            $Company_admin->forceDelete();
        }elseif($request->button == 'restore'){
            $input['termination_date']      = Null;
            $input['termination_reason']    = Null;
            $input['termination_rehire']    = Null;
            $input['termination_equipment'] = Null;
            $input['termination_none']      = Null;
            $Company_admin->update($input);
            $Company_admin->restore();
        }

        if ($request->ajax()) {
            return response()->json(['success' => "Termination successfully"]);
        }

        notification('success', $this->crudMessage('delete', 'Dispatcher'));

        return redirect()->route('company.admin.managers.index');
    }

    public function getTermiForm(Request $request)
    {
        $Company_admin                          = CompanyAdmin::withTrashed()->where('id',$request->id)->first();
        if(!empty($Company_admin->termination_date)){
            $Company_admin->termination_date    = Carbon::createFromFormat('Y-m-d',$Company_admin->termination_date)->format('m/d/Y');
        }
        $is_disabled                            = '0';
        if(!empty($Company_admin->deleted_at)){
            $is_disabled                        = '1';
        }

        $view                                   = view('companyAdmin.manager.view.terminateform', compact('Company_admin','is_disabled'))->render();
        return response()->json(['view' => $view]);

    }

    public function getEvents(Request $request){

        $input                  = $request->all();

        $driver_id              = isset($input['driver_id']) ? $input['driver_id'] : Null;
        $companyAdminId         = isset($input['companyAdminId']) ? $input['companyAdminId'] : Null;
        $calendarEvent          = isset($input['calendarEvent']) ? $input['calendarEvent'] : Null;
        $birthdays              = isset($input['birthdays']) ? $input['birthdays'] : Null;
        $expirations            = isset($input['expirations']) ? $input['expirations'] : Null;
        $maintenanceTrucks      = isset($input['maintenanceTrucks']) ? $input['maintenanceTrucks'] : Null;
        $maintenanceTrailers    = isset($input['maintenanceTrailers']) ? $input['maintenanceTrailers'] : Null;
        $selectCompnay          = isset($input['selectCompnay']) ? $input['selectCompnay'] : Null;
        $selectTeam             = isset($input['selectTeam']) ? $input['selectTeam'] : Null;
        $hidePersonalEvents     = isset($input['hidePersonalEvents']) ? $input['hidePersonalEvents'] : Null;
        $driverleaves           = isset($input['driverleaves']) ? $input['driverleaves'] : Null;
        $myLeaves               = isset($input['myLeaves']) ? $input['myLeaves'] : Null;
        $dispatcherLeaves       = isset($input['dispatcherLeaves']) ? $input['dispatcherLeaves'] : Null;
        $maintenanceTicket      = isset($input['maintenanceTicket']) ? $input['maintenanceTicket'] : Null;

        $getEvent               = getCompanyAdminEventFullCalendar($companyAdminId,$calendarEvent,$birthdays,$expirations,$maintenanceTrucks,$maintenanceTrailers,$selectCompnay,$selectTeam,$hidePersonalEvents,$driverleaves,$myLeaves,$dispatcherLeaves,$maintenanceTicket);
        return response()->json(['view' => $getEvent]);
        //return $getEvent;
    }

    //---------------------------
    public function removeEdit(Request $request)
    {
        $eventData              = Event::where('id',$request->event_id)->first();
        $view                   = view('companyAdmin.manager.editEvent-PopUp',compact('eventData'))->render();
        return response()->json(['status' => 1, 'html' => $view, 'message', '']);
    }

    //---Show Event
    public function showEvent(Request $request)
    {
        if(!empty($request->maintenance_event_id)){
            $maintenance_id = $request->maintenance_event_id;
            $eventData = Maintenance::where('id',$maintenance_id)->first();
            $view = view('companyAdmin.manager.showEvent-PopUp',compact('eventData'))->render();
            return response()->json(['status' => 1, 'html' => $view, 'message', '']);
        }
    }

    public function getEventsUpdates(Request $request)
    {
        $from_date              = dateTimeFormatter($request->from_date,'Y-m-d H:i:s',getTimeLayout());
        $to_date                = dateTimeFormatter($request->to_date,'Y-m-d H:i:s',getTimeLayout());
        Event::where('id',$request->id)->update([
            'name'              => $request->name,
            'address'           => $request->address,
            'type'              => $request->type,
            'from_date'         => $from_date,
            'to_date'           => $to_date,
            'is_repeat'         => $request->is_repeat,
            'notes'             => $request->notes
        ]);

        return redirect()->back();
    }

    /**
     * Login to company manager.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function login($id)
    {
        $id = base64Decode($id);
        // $last_login_user = ['id'=>auth()->guard('company-admin')->user()->id,
        //     'name'=> auth()->guard('company-admin')->user()->first_name.' '.auth()->guard('company-admin')->user()->last_name,
        //     'user_type' => 'company-admin',
        //     'last_user_guard_type' => auth()->guard('company-admin')->user()->type
        // ];
        // $last_login_user=json_encode($last_login_user);
        $last_user      = Session::get('last_user');

        $companyAdmin   = CompanyAdmin::where('id', $id)->first();
        Session::put('impersonate_user', $companyAdmin);

        // Session::put('previous_user_id', $previousUser);
        // Session::put('previous_user_type', 'companyAdmin');

        auth()->guard('company-admin')->loginUsingId($companyAdmin->id);

        // return redirect()->route('company.admin.home');
        return redirect()->route('company.admin.home');
    }
}
