<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

use App\Models\Notification;
use App\Models\LoadDetention;

use Illuminate\Support\Facades\DB;
use Yajra\DataTables\Facades\DataTables;
use Carbon\Carbon;

class NotificationController extends CompanyAdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */

    public $timeZoneId;
    public $offset;

    public function __construct(){
        parent::__construct();

        $this->middleware(function ($request, $next) {
            $this->timeZoneId   = getTimeZoneId();
            $this->offset       = getTimeZoneOffset();

            return $next($request);
        });
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $offset         = $this->offset;
            $search         = $request->search['value'] ?? '';
            $id             = auth()->guard('company-admin')->user()->id;
            $type           = auth()->guard('company-admin')->user()->type;
            $notifications  = Notification::select('id', 'module', 'type', 'source', 'action_id', 'name', 'description', 'properties', DB::raw('CONVERT_TZ(notifications.read_at,"+00:00","'.$offset.'") as read_at'), DB::raw('CONVERT_TZ(notifications.created_at,"+00:00","'.$offset.'") as created_at'))
                ->isCompany()
                //->where('module','Notification')
                ->where('user_id',$id)
                ->where('user_type',$type)
                ->orderby('id', 'DESC');
            return Datatables::of($notifications)
                ->addIndexColumn()
                ->editColumn('source', function($notification){
                    return isset(getNotiSourceList($notification->source, 'id')['name']) ? getNotiSourceList($notification->source, 'id')['name'] : '';
                })
                ->editColumn('name', function($notification){
                    $href           = '';
                    if(in_array($notification->source,[7,8])){ // leaves
                        $getLeave   = \App\Models\Leave::where('id',$notification->action_id)->first();
                        if($getLeave){
                            if(isset($getLeave->driver_id)){
                                $href               = route('company.admin.drivers.show', base64Encode($getLeave->driver_id));
                            }
                            if(isset($getLeave->company_admins_id)){
                                $actionId           = $getLeave->company_admins_id;
                                $getCompanyAdmin    = \App\Models\CompanyAdmin::find($actionId);
                                if($getCompanyAdmin->type == 1){
                                    $href           = route('company.admin.managers.show', base64Encode($getCompanyAdmin->id));
                                }elseif ($getCompanyAdmin->type == 2) {
                                    $href           = route('company.admin.dispatchers.show', base64Encode($getCompanyAdmin->id));
                                }
                            }
                        }
                    }elseif (in_array($notification->source,[1,2,3,4])) { // loads
                        $loadDetail                 = \App\Models\LoadDetail::where('load_id',$notification->action_id)->first();
                        if ($loadDetail) {
                            $href                   = route('company.admin.'.getNotiSourceList($notification->source, 'id')['slug'].'.show', base64Encode($loadDetail->id));
                        }
                    }elseif ($notification->source==5) { // drivers
                        if($notification->action_id)
                            $href                   = route('company.admin.'.getNotiSourceList($notification->source, 'id')['slug'].'.show', base64Encode($notification->action_id));
                    }elseif ($notification->source==6) { // liner fleet calendar
                        $href                       = route('company.admin.'.getNotiSourceList($notification->source, 'id')['slug'].'.index');
                        $param                      = '';
                        if(isset($notification->properties) && $notification->properties!=''){
                            $properties             = json_decode($notification->properties,true);
                            unset($properties['user_type']);
                            if(!empty($properties)){
                                $p = 0;
                                foreach ($properties as $pkey => $propertie) {
                                    if($p==0){
                                        $param      .= '?';
                                    }
                                    if($p!=0){
                                        $param      .= '&';
                                    }
                                    if($pkey=='user_id'){
                                        $param      .= 'manager='.$propertie;
                                    }
                                    if($pkey=='previous_date'){
                                        $date       = \Carbon\Carbon::createFromFormat('Y-m-d', $propertie);
                                        $month      = $date->format('m');
                                        $monthName  = $date->format('F');
                                        $year       = $date->format('Y');
                                        $param      .= 'year='.$year.'&month='.$month;
                                    }
                                    $p++;
                                }
                            }
                        }
                        if($param!=''){
                            $href                   .= $param;
                        }
                    }elseif ($notification->source==9) { // dispatch-pro-announcement
                        $href                       = route('company.admin.'.getNotiSourceList($notification->source, 'id')['slug'].'.show', base64Encode($notification->action_id));
                    }elseif ($notification->source==10) { // company-announcements
                        $href                       = route('company.admin.announcement.show', base64Encode($notification->action_id));
                    }elseif (in_array($notification->source, [17,18,19,20,21])) { // detentions
                        $detention                  = LoadDetention::whereId($notification->action_id)->first();
                        if($detention){
                            $href                   = route('company.admin.'.getNotiSourceList($notification->source, 'id')['slug'].'.edit', base64Encode($detention->load_detail->load_id)).'?detention_id='.$detention->id;
                        }
                    }else{ // etc ex-brokers
                        $href                       = route('company.admin.'.getNotiSourceList($notification->source, 'id')['slug'].'.edit', base64Encode($notification->action_id));
                    }

                    $textType                       = 'text-primary';
                    if($notification->type==2 && $notification->module=='Alert'){
                        if(empty($notification->read_at)){
                            $textType               = 'text-danger';
                        }
                    }

                    if($href!=''){
                        return '<a href="'.$href.'" class="'.$textType.'">'.$notification->name;
                    }else{
                        return '<a class="'.$textType.'">'.$notification->name;
                    }
                })
                ->editColumn('description', function ($notification) {
                    return stringDateToday(strip_tags($notification->description)); // Str::limit(stringDateToday(strip_tags($notification->description)), 50);
                })
                ->editColumn('read_at', function($notification){
                    if(auth()->guard('company-admin')->user()->time_format=='12'){
                        return !is_null($notification->read_at) ? Carbon::parse($notification->read_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($notification->read_at) ? Carbon::parse($notification->read_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('read_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('company-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(notifications.read_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(notifications.read_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->editColumn('created_at', function($notification){
                    if(auth()->guard('company-admin')->user()->time_format=='12'){
                        return !is_null($notification->created_at) ? Carbon::parse($notification->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($notification->created_at) ? Carbon::parse($notification->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('created_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('company-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(notifications.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(notifications.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->rawColumns(['name','source','created_at'])
                ->make(true);
        }
        return view('companyAdmin.notification.index');
    }
}
