<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Helpers\Common;
use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use App\Models\Bookmark;
use App\Models\BrokerContact;
use App\Models\Offer;
use Illuminate\Http\Request;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\DB;
use Yajra\DataTables\Facades\DataTables;

class ProRoutesController extends CompanyAdminController
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $getCompanyAdmin        = auth()->guard('company-admin')->user();

        // Offers
        $getField = '';
        $isCheck = Bookmark::where('company_id', getUserCompnayId())->where('user_id', $getCompanyAdmin->id)->where('user_type', $getCompanyAdmin->type)->where('table_id', 'offers1')->first();
        if(!empty($isCheck->id)){
            //$getField = unserialize($isCheck->config);
            $getField = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_offers1_first'));
        }else{
            $getField = config('settings.table_offers1_first');
        }

        // Favorites
        $getField2 = '';
        $isCheck2 = Bookmark::where('company_id', getUserCompnayId())->where('user_id', $getCompanyAdmin->id)->where('user_type', $getCompanyAdmin->type)->where('table_id', 'offers2')->first();
        if(!empty($isCheck2->id)){
            //$getField2          = unserialize($isCheck2->config);
            $getField2          = adjustTableColumnsSorting(unserialize($isCheck2->config), config('settings.table_offers2_first'));
        }else{
            $getField2          = config('settings.table_offers2_first');
        }

        $isProRoutePage = 1; $isMulitpleTable = 1;

        $tables = array(
            0 => array(
                "name" => 'table1', /// Offers
                "id" => 'collapsable1',
                "class" => 'offers-data-table',
                "table" => 'settings.table_offers1',
                "route" => route('company.admin.pro-routes.offer.list'),
                "getField" => $getField,
            ),
            1 => array(
                "name" => 'table2', /// Favorites
                "id" => 'collapsable2',
                "class" => 'favorites-data-table',
                "table" => 'settings.table_offers2',
                "route" => route('company.admin.pro-routes.favorite.list'),
                "getField" => $getField2,
            ),
        );

        return view('companyAdmin.proRoutes.index', compact('getField', 'getField2', 'isMulitpleTable', 'tables', 'isProRoutePage'));
    }

    public function offerList(Request $request)
    {
        $getCompanyAdmin = auth()->guard('company-admin')->user();

        $getField = '';
        $isCheck = Bookmark::where('company_id', getUserCompnayId())->where('user_id', $getCompanyAdmin->id)->where('user_type', $getCompanyAdmin->type)->where('table_id', 'offers1')->first();
        if(!empty($isCheck->id)){
            //$getField = unserialize($isCheck->config);
            $getField = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_offers1_first'));
        }else{
            $getField = config('settings.table_offers1_first');
        }

        if ($request->ajax()) {
            //$data = Offer::where('driver_id', 0)->where('favorite', 'No')->where('status', '!=', 4);
            $data = Offer::select('offers.*', 'brokers.name as broker_name', DB::raw('COUNT(offer_stops.id) as extra_stops'), 'trailer_types.name as mile_trailer_type')
                ->leftJoin('brokers', 'brokers.id', '=', 'offers.broker_id')
                ->leftJoin('offer_stops', 'offer_stops.offer_id', '=', 'offers.id')
                ->leftJoin('trailer_types', 'trailer_types.id', '=', 'offers.m_trailer_type')
                ->where('driver_id', 0)->where('favorite', 'No')->where('status', '!=', 4)
                ->groupBy('offers.id');

            // General filter code - start
            foreach($getField as $key => $value) {
                $conditionReq       = 'search_string_condition_'.$key;
                $sortReq            = 'search_string_sort_'.$key;
                $conditionDateReq   = 'search_date_condition_'.$key;
                $sortDateReq        = 'search_date_sort_'.$key;
                $conditionStatusReq = 'search_status_condition_'.$key;
                $sortStatusReq      = 'search_status_sort_'.$key;

                // String filter
                if( isset( request()->$conditionReq ) ) {
                    $typeReq        = 'search_string_type_'.$key;
                    $type           = request()->$typeReq;

                    if( $type == 'string' ) {
                        Common::getStringFilterResult( $data, $key );
                    }
                }

                // Status filter
                if( isset( request()->$conditionStatusReq ) && request()->$conditionStatusReq == 1 ) {
                    Common::getStatusFilterResult( $data, $key );
                }

                // Date filter
                if( isset( request()->$conditionDateReq ) ) {
                    $typeReq        = 'search_date_type_'.$key;
                    $type           = request()->$typeReq;

                    if( $type == 'date' ) {
                        Common::getDateFilterResult( $data, $key );
                    }
                }

                // String sort only
                if( isset( request()->$sortReq ) ) {
                    Common::sortStringFilter( $data, $key );
                }

                // Date sort only
                if( isset( request()->$sortDateReq ) ) {
                    Common::sortDateFilter( $data, $key );
                }

                // Status sort only
                if( isset( request()->$sortStatusReq ) ) {
                    Common::sortStatusFilter( $data, $key );
                }
            }
            // General filter code - end

           // $data = $data->get();

            return DataTables::of($data)
                    ->addIndexColumn()
                    /*->addColumn('broker_name', function($row){
                        return (isset($row->broker)) ? $row->broker->name : '';
                    })*/
                    ->addColumn('shipper_date_time', function($row){
                        return (!is_null($row->shipper_date_time)) ? Carbon::parse($row->shipper_date_time)->timezone(getTimeZone())->format(getTimeLayout()) : '';
                    })
                    ->addColumn('origin', function($row){
                        $Origin = null;
                        if(!is_null($row->shipper_city)){
                            $Origin[] = $row->shipper_city;
                        }
                        if(!is_null($row->shipper_state)){
                            $Origin[] = $row->shipper_state;
                        }
                        if(is_null($row->shipper_city) && is_null($row->shipper_state) && !is_null($row->shipper_zip)){
                            $Origin[] = $row->shipper_zip;
                        }

                        return (count($Origin) > 0) ? implode(', ', $Origin) : $Origin;
                    })
                    ->addColumn('delivery_date_time', function($row){
                        return (!is_null($row->delivery_date_time)) ? Carbon::parse($row->delivery_date_time)->timezone(getTimeZone())->format(getTimeLayout()) : '';
                    })
                    ->addColumn('destination', function($row){
                        $Destination = null;
                        if(!is_null($row->delivery_city)){
                            $Destination[] = $row->delivery_city;
                        }
                        if(!is_null($row->delivery_state)){
                            $Destination[] = $row->delivery_state;
                        }
                        if(is_null($row->delivery_city) && is_null($row->delivery_state) && !is_null($row->delivery_zip)){
                            $Destination[] = $row->delivery_zip;
                        }

                        return (count($Destination) > 0) ? implode(', ', $Destination) : $Destination;
                    })
                    /*->addColumn('extra_stops', function($row){
                        return (isset($row->stops)) ? $row->stops->count() : 0;
                    })*/
                    ->addColumn('cpm', function($row){
                        $cpm = '0';
                        $finalRate = (!is_null($row->rate)) ? $row->rate : '';
                        if(($finalRate != '' && $finalRate > 0) && (isset($row->loaded_miles) && $row->loaded_miles != '' && $row->loaded_miles > 0)) {
                            $cpm = number_format($finalRate/$row->loaded_miles, 2, '.', ',');
                        }

                        return '$'.number_format($cpm, 2, '.', ',');
                    })
                    ->addColumn('rate_offered', function($row){
                        return (isset($row->rate_offered)) ? '$'.number_format($row->rate_offered, 2, '.', ',') : 0;
                    })
                    ->addColumn('m_trailer_type', function($row){
                        return (!is_null($row->mile_trailer_type)) ? $row->mile_trailer_type : null;
                    })
                    ->addColumn('action', function($row){
                        $action = '<a href="'.route('company.admin.book.offer', ['id' => base64Encode($row->id), 'useAsTemplate' => 1]).'" class="btn btn-sm btn-outline-black-action" title="Use as Template"><i class="fa fa-file-text-o" aria-hidden="true"></i></a>';
                        $action .= '<a href="'.route('company.admin.book.offer', ['id' => base64Encode($row->id)]).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-pencil" aria-hidden="true"></i></a>';
                        $action .= '<a href="javascript:void(0);" class="btn btn-sm btn-outline-black-trash destroyOffer" data-action="'.route('company.admin.book.offer.delete', $row->id).'" data-table="offers-data-table" title="Delete"><i class="fa fa-trash" aria-hidden="true"></i></a>';

                        return $action;
                    })
                    ->rawColumns(['action'])
                    ->make(true);
        }

        return view('companyAdmin.dispatchHub.index');
    }

    public function favoriteList(Request $request)
    {
        $getCompanyAdmin = auth()->guard('company-admin')->user();

        $getField2 = '';
        $isCheck = Bookmark::where('company_id', getUserCompnayId())->where('user_id', $getCompanyAdmin->id)->where('user_type', $getCompanyAdmin->type)->where('table_id', 'offers2')->first();
        if(!empty($isCheck->id)){
            //$getField2 = unserialize($isCheck->config);
            $getField2 = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_offers2_first'));
        }else{
            $getField2 = config('settings.table_offers2_first');
        }

        if ($request->ajax()) {
            //$data = Offer::where('favorite', 'Yes')->where('status', '!=', 4);
            $data = Offer::select('offers.*', 'brokers.name as broker_name', DB::raw('COUNT(offer_stops.id) as extra_stops'), 'trailer_types.name as mile_trailer_type')
                ->leftJoin('brokers', 'brokers.id', '=', 'offers.broker_id')
                ->leftJoin('offer_stops', 'offer_stops.offer_id', '=', 'offers.id')
                ->leftJoin('trailer_types', 'trailer_types.id', '=', 'offers.m_trailer_type')
                ->where('favorite', 'Yes')->where('status', '!=', 4)
                ->groupBy('offers.id');

            // General filter code - start
            foreach($getField2 as $key => $value) {
                $conditionReq       = 'search_string_condition_'.$key;
                $sortReq            = 'search_string_sort_'.$key;
                $conditionDateReq   = 'search_date_condition_'.$key;
                $sortDateReq        = 'search_date_sort_'.$key;
                $conditionStatusReq = 'search_status_condition_'.$key;
                $sortStatusReq      = 'search_status_sort_'.$key;

                // String filter
                if( isset( request()->$conditionReq ) ) {
                    $typeReq        = 'search_string_type_'.$key;
                    $type           = request()->$typeReq;

                    if( $type == 'string' ) {
                        Common::getStringFilterResult( $data, $key );
                    }
                }

                // Status filter
                if( isset( request()->$conditionStatusReq ) && request()->$conditionStatusReq == 1 ) {
                    Common::getStatusFilterResult( $data, $key );
                }

                // Date filter
                if( isset( request()->$conditionDateReq ) ) {
                    $typeReq        = 'search_date_type_'.$key;
                    $type           = request()->$typeReq;

                    if( $type == 'date' ) {
                        Common::getDateFilterResult( $data, $key );
                    }
                }

                // String sort only
                if( isset( request()->$sortReq ) ) {
                    Common::sortStringFilter( $data, $key );
                }

                // Date sort only
                if( isset( request()->$sortDateReq ) ) {
                    Common::sortDateFilter( $data, $key );
                }

                // Status sort only
                if( isset( request()->$sortStatusReq ) ) {
                    Common::sortStatusFilter( $data, $key );
                }
            }
            // General filter code - end

            $data = $data->get();

            return DataTables::of($data)
                ->addIndexColumn()
                /*->addColumn('broker_name', function($row){
                    return (isset($row->broker)) ? $row->broker->name : '';
                })*/
                ->addColumn('shipper_date_time', function($row){
                    return (!is_null($row->shipper_date_time)) ? Carbon::parse($row->shipper_date_time)->timezone(getTimeZone())->format(getTimeLayout()) : '';
                })
                ->addColumn('origin', function($row){
                    $Origin = null;
                    if(!is_null($row->shipper_city)){
                        $Origin[] = $row->shipper_city;
                    }
                    if(!is_null($row->shipper_state)){
                        $Origin[] = $row->shipper_state;
                    }
                    if(is_null($row->shipper_city) && is_null($row->shipper_state) && !is_null($row->shipper_zip)){
                        $Origin[] = $row->shipper_zip;
                    }

                    return (count($Origin) > 0) ? implode(', ', $Origin) : $Origin;
                })
                ->addColumn('delivery_date_time', function($row){
                    return (!is_null($row->delivery_date_time)) ? Carbon::parse($row->delivery_date_time)->timezone(getTimeZone())->format(getTimeLayout()) : '';
                })
                ->addColumn('destination', function($row){
                    $Destination = null;
                    if(!is_null($row->delivery_city)){
                        $Destination[] = $row->delivery_city;
                    }
                    if(!is_null($row->delivery_state)){
                        $Destination[] = $row->delivery_state;
                    }
                    if(is_null($row->delivery_city) && is_null($row->delivery_state) && !is_null($row->delivery_zip)){
                        $Destination[] = $row->delivery_zip;
                    }

                    return (count($Destination) > 0) ? implode(', ', $Destination) : $Destination;
                })
                /*->addColumn('extra_stops', function($row){
                    return (isset($row->stops)) ? $row->stops->count() : 0;
                })*/
                ->addColumn('cpm', function($row){
                    $cpm = '0';
                    $finalRate = (!is_null($row->rate)) ? $row->rate : '';
                    if(($finalRate != '' && $finalRate > 0) && (isset($row->loaded_miles) && $row->loaded_miles != '' && $row->loaded_miles > 0)) {
                        $cpm = number_format($finalRate/$row->loaded_miles, 2, '.', ',');
                    }

                    return '$'.number_format($cpm, 2, '.', ',');
                })
                ->addColumn('rate_offered', function($row){
                    return (isset($row->rate_offered)) ? '$'.number_format($row->rate_offered, 2, '.', ',') : 0;
                })
                ->addColumn('m_trailer_type', function($row){
                    return (!is_null($row->mile_trailer_type)) ? $row->mile_trailer_type : null;
                })
                ->addColumn('action', function($row){
                    $action = '<a href="'.route('company.admin.book.offer', ['id' => base64Encode($row->id), 'useAsTemplate' => 1]).'" class="btn btn-sm btn-outline-black-action" title="Use as Template"><i class="fa fa-file-text-o" aria-hidden="true"></i></a>';
                    $action .= '<a href="'.route('company.admin.book.offer', ['id' => base64Encode($row->id)]).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-pencil" aria-hidden="true"></i></a>';
                    $action .= '<a href="javascript:void(0);" class="btn btn-sm btn-outline-black-trash destroyOffer" data-action="'.route('company.admin.book.offer.delete', $row->id).'" data-table="offers-data-table" title="Delete"><i class="fa fa-trash" aria-hidden="true"></i></a>';

                    return $action;
                })
                ->rawColumns(['action'])
                ->make(true);
        }

        return view('companyAdmin.dispatchHub.index');
    }

    public function bookOffer($id)
    {
        $offer                                      = Offer::findOrFail(base64Decode($id));

        $rep_contact_html                           = '';
        if(isset($offer->broker)){
            $broker                                 = $offer->broker;
            $getBrokerContact                       = BrokerContact::where('source', 'broker')->where('action_id', $broker->id)->get();
            if(!empty($broker->dispatch_contact_name)){
                $rep_contact_html                   .= '<option value="'.$broker->dispatch_contact_name.'" data-phone="'.$broker->dispatch_contact_phone.'" data-ext="'.$broker->dispatch_contact_contact_ext.'" data-email="'.$broker->dispatch_contact_email.'">'.$broker->dispatch_contact_name.'</option>';
            }
            foreach($getBrokerContact as $cdata){
                $rep_contact_html                   .= '<option value="'.$cdata->name.'" data-phone="'.$cdata->phone_number.'" data-ext="'.$cdata->ext.'" data-email="'.$cdata->email.'">'.$cdata->name.'</option>';
            }
        }
        return view('companyAdmin.dispatchHub.offer.create', compact('offer','rep_contact_html'));
    }
}
