<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;

use Illuminate\Support\Str;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;

use App\Models\FileUpload;
use App\Models\CompanyAdmin;
use App\Models\LeaveUserType;

use Carbon\Carbon;
use DataTables;
use File;
use Hash;

class ProfileController extends CompanyAdminController
{

   /***
    *   Developed by: Sanni Mistry
    *   Description: Validate edit profile request
    ***/
    public function validator($request)
    {
        return Validator::make($request->all(), [
            'first_name'            => 'required|string|max:255',
            'last_name'             => 'required|string|max:255',
            'profile_picture'       => 'image|max:5120',
            'fsg_file'              => 'sometimes|nullable|max:10000|mimes:pdf',
            'resignation_letter'    => 'sometimes|nullable|max:10000|mimes:pdf',
      ]);
    }

    /***
    *   Developed by: Sanni Mistry
    *   Description: Display edit profile page
    ***/
    public function editProfile(){
        $companyAdmin   = CompanyAdmin::findOrFail( auth()->guard('company-admin')->user()->id);
        $days           = [];
        $start_time     = '';
        $end_time       = '';
        /*foreach($companyAdmin->notificationDaytime as $day){
            $days[]     = $day->day;
            $start_time = $day->start_time;
            $end_time   = $day->end_time;
        }*/
        return view('companyAdmin.profile.edit')->with(compact('companyAdmin','days','start_time','end_time'));
    }

    /***
    *   Developed by: Sanni Mistry
    *   Description: Save updated profile details in database
    ***/
    public function updateProfile(Request $request)
    {
        $validator                  = $this->validator($request);
        if ($validator->passes()) {
            $input                  = $request->except(['_token','email']);
            $companyAdmin           = CompanyAdmin::findOrFail(Auth::guard('company-admin')->user()->id);
            if (isset($input['profile_image'])) {
                $input['profile_image'] = FileUpload::upload('companyAdmin/profile', $input['profile_image']);
            }
            $input['sms']           = $input['sms'] ?? 0;
            $input['notify_email']  = $input['notify_email'] ?? 0;

            if($request->address_verified==1){
                $timezone                   = null;
                $timezone_offset            = null;
                if(isset($input['timezone_abbr'])){
                    $timezone               = timezone_name_from_abbr($input['timezone_abbr']);
                    $timezone_offset        = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
                }
                $input['timezone']          = $timezone;
                $input['timezone_offset']   = $timezone_offset;
            }else{
                $input['latitude']          = null;
                $input['longitude']         = null;
                $input['timezone']          = null;
                $input['timezone_offset']   = null;
                $input['timezone_abbr']     = null;
            }

            $companyAdmin->update($input);
            notification('success', $this->crudMessage('update', 'Profile'));
            return redirect()->back();
        }else{
            return redirect()->back()->withErrors($validator)->withInput();
        }
    }

    /***
    *   Developed by: Sanni Mistry
    *   Description: Validate change password request
    ***/
    public function passwordValidator($request, $companyAdmin)
    {
        return $this->validate($request, [
            'current_password'      => ['required','min:6', function ($attribute, $value, $fail) use ($companyAdmin) {
                if (!Hash::check($value, $companyAdmin->password)) {
                    return $fail( __('messages.invalidCurrentPassword'));
                }
            }],
            'password'              => 'required|min:6|confirmed|different:current_password',
            'password_confirmation' => 'required|min:6',
      ]);
    }

     /***
    *   Developed by: Sanni Mistry
    *   Description: Display change password page
    ***/
    public function changePassword()
    {
        return view('companyAdmin.profile.changePassword');
    }

    /***
    *   Developed by: Sanni Mistry
    *   Description: Save updated passowrd in database
    ***/
    public function updatePassword(Request $request)
    {
        $companyAdmin           = CompanyAdmin::findOrFail(Auth::guard('company-admin')->user()->id);
        if ($this->passwordValidator($request, $companyAdmin)) {
            $input['password']  = bcrypt($request->password);
            $companyAdmin->update($input);
            notification('success', $this->crudMessage('update', 'Password'));
            return redirect()->back();
        }
    }

    /***
    *   Developed by: Sanni Mistry
    *   Description: Send email on new email address on update email request
    ***/
    public function updateEmail($email)
    {
        $found  = Advisor::where('email','=',$email)->first();
        try{
            if(!$found){
                $data['email']  = $email;
                $data['user']   = 'advisor';
                $data['userId'] = Auth::guard('advisor')->user()->id;

                /*** Send verification email to advisor ***/
                //\Mail::to($email)->send(new \App\Mail\VerifyNewEmail($data));
                sendEmail($email, new \App\Mail\VerifyNewEmail($data));

                /*** Send email update notification to advisor ***/
                $advisor        = Advisor::find(Auth::guard('advisor')->user()->id);
                $advisor->sendUpdateEmailNotification($advisor);

                 return redirect()->route('advisor.editProfile')->with('success',__('messages.emailUpdateMailSentSuccess'));
            }
        }catch (\Exception $e) {
            return redirect(route('advisor.editProfile'))->withErrors([__('messages.serverError')]);
        }
    }

    /***
    *   Developed by: Sanni Mistry
    *   Description: Check for dupicate email of advisor while update email
    ***/
    public function checkDuplicateEmail(Request $request)
    {
        $email  = $request->get('email');
        $client = Advisor::where('email','=',$email)->first();
        if($client)
            echo "false";
        else
            echo "true";
    }

    /***
    *   Developed by: Sanni Mistry
    *   Description: Crop and upload Profile picture and return uploaded image name
    ***/
    public function cropProfilePicture(Request $request)
    {
        $data           = $request->image;
        $image_array_1  = explode(";", $data);
        $image_array_2  = explode(",", $image_array_1[1]);
        $data           = base64_decode($image_array_2[1]);
        $fileName       = "picture_".time().".". 'png';
        $imageName      = config('settings.advisor_picture_folder')."/".$fileName;
        file_put_contents($imageName, $data);
        echo $fileName;
    }

    public function viewProfile(Request $request){
        try {
            $data                       = [];
            $data['companyAdmin']       = Auth::guard('company-admin')->user();
            $data['getLeaveUserType']   = LeaveUserType::where('company_admins_id',auth()->guard('company-admin')->user()->id)->where('year',date('Y'))->get();
            $data['activeTab']          = ($request->has('activeTab') && $request->activeTab!='')?$request->activeTab:'';
            $year                       = ($request->has('year') && $request->year!='')?$request->year:'';
            $month                      = ($request->has('month') && $request->month!='')?$request->month:'';
            if($year!='' && $month!=''){
                $now                    = Carbon::create($year, $month)->startOfMonth();
                $data['gotoDate']       = $now->format('Y-m-d');
            }else{
                $now                    = Carbon::now();
            }
            $data['now']                = $now;
            $data['month_name']         = $now->format('F');
            $data['month']              = $now->format('m');
            $data['year']               = $now->format('Y');
            if(auth()->guard('company-admin')->user()->type==0){
                return view('companyAdmin.profile.view',$data);
            }elseif (auth()->guard('company-admin')->user()->type==1) {
                return view('companyAdmin.profile.manager',$data);
            }else{
                return view('companyAdmin.profile.dispatcher',$data);
            }
        } catch (\Exception $e) {
            return abort(404);
        }
    }

}
