<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;
use App\Http\Requests\CompanyAdmin\ShipperStoreRequest;
use App\Http\Requests\CompanyAdmin\ShipperUpdateRequest;
use App\Models\Shipper;
use DataTables;
use Validator;

class ShipperController extends CompanyAdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $data = Shipper::isCompany()->select('*');
            return Datatables::of($data)
                    ->addIndexColumn()
                    ->addColumn('action', function($row){
                        //$btn = '<a href="'.route('company.admin.shipper.show', $row->id).'" class="mr-4"><img src="'.asset('theme/img/eye.png').'" alt=""></a>';
                        $btn = ' <a href="'.route('company.admin.shipper.edit', $row->id).'" class="mr-4"><img src="'.asset('theme/img/edit-icon.png').'" alt=""></a>';
                        $btn = $btn.' <a href="javascript:" class="destroy" data-action="'.route('company.admin.shipper.destroy',$row->id).'" data-id="'.$row->id.'"><img src="'.asset('theme/img/delete-icon.png').'" alt=""></a>';
                        return $btn;
                    })
                    ->rawColumns(['action'])
                    ->make(true);
        }

        return view('companyAdmin.shipper.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('companyAdmin.shipper.create');   
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(ShipperStoreRequest $request)
    {
        $input = $request->all();

        $input['company_id'] = auth()->guard('company-admin')->user()->company_id;

        Shipper::create($input);

        notification('success', $this->crudMessage('create', 'Shipper'));

        return redirect()->route('company.admin.shippers.index');
    }

    public function storeAjax(Request $request)
    {
        $input = $request->all();

        $validator = Validator::make($input,[
            "name" => "required",
            "address" => "required",
            "phone_number" => "required",
            'mc_number' => 'required|unique:shippers,mc_number'
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $input['company_id'] = auth()->guard('company-admin')->user()->company_id;
        Shipper::create($input);

        notification('success', $this->crudMessage('create', 'Shipper'));

        return response()->json(['success' => "Shipper created successfully"]);
    }

    /**
     * Display the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Shipper $shipper)
    {
        return view('companyAdmin.shipper.show', compact('shipper'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Shipper $shipper)
    {
        return view('companyAdmin.shipper.edit', compact('shipper'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(ShipperUpdateRequest $request, Shipper $shipper)
    {
        $input = $request->all();

        $shipper->update($input);

        notification('success', $this->crudMessage('update', 'Shipper'));

        return redirect()->route('company.admin.shipper.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Shipper $shipper)
    {
        $shipper->delete();

        notification('success', $this->crudMessage('delete', 'Shipper'));

        return redirect()->route('company.admin.shipper.index');
    }

    public function getStoreList()
    {
        $getList = getShipperList();

        $html = '<option value="" >Select Shipper</option>';
        foreach($getList as $key => $list){
            $html .= '<option value="'.$key.'" >"'.$list.'"</option>';
        }

        return $html;

    }


    
}
