<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;
use DataTables;
use App\Models\Team;
use App\Models\CompanyAdmin;
use App\Models\FileUpload;
use App\Models\Bookmark;
use Validator;
use Illuminate\Support\Facades\DB;
use App\Helpers\Common;

class TeamController extends CompanyAdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {

        $getField = '';

        $getCompanyAdmin = auth()->guard('company-admin')->user();
        $isCheck = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','teams')->first();

        if(!empty($isCheck->id)){
            //$getField = unserialize($isCheck->config);
            $getField = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_teams_first'));
        }else{
            $getField = config('settings.table_teams_first');
        }

        if ($request->ajax()) {
            if ($request->view == "table") {
                $data = Team::select('teams.*', DB::raw('CONCAT(company_admins.first_name," ",company_admins.last_name) as head'), DB::raw('COUNT(drivers.id) as total_drivers'))
                    ->leftJoin('drivers', function ($join) {
                        $join->on('teams.id', '=', 'drivers.team_id')
                            ->whereNull('drivers.deleted_at');
                    })
                    ->leftJoin('company_admins', 'company_admins.id', '=', 'teams.head_id')
                    ->where('teams.company_id', auth()->guard('company-admin')->user()->company_id)
                    ->groupBY('teams.id');
                // General filter code - start
                foreach( $getField as $key => $value ) {
                    $conditionReq = 'search_string_condition_'.$key;
                    $sortReq = 'search_string_sort_'.$key;

                    if( isset( request()->$conditionReq ) ) {
                        $typeReq = 'search_string_type_'.$key;
                        $type = request()->$typeReq;

                        if( $type == 'string' ) {
                            Common::getStringFilterResult( $data, $key );
                        }

                        if( $type == 'date' ) {
                            Common::getDateFilterResult( $data, $key );
                        }
                    }

                    if( isset( request()->$sortReq ) ) {
                        $nameReq = 'search_string_name_'.$key;
                        $sortReq = 'search_string_sort_'.$key;
                        $typeReq = 'search_string_type_'.$key;
                        $tableNameReq = 'search_table_name_'.$key;
                        $colAliasReq = 'search_string_col_alias_'.$key;

                        $origData = request()->$nameReq;
                        $condition_sort = request()->$sortReq;
                        $type = request()->$typeReq;
                        $tableName = isset( request()->$tableNameReq ) ? request()->$tableNameReq : '';
                        $colAlias = isset( request()->$colAliasReq ) ? request()->$colAliasReq : '';

                        if( $type == 'string' ) {
                            if( isset( $condition_sort ) ) {
                                if( $colAlias != '' ) {
                                    $data->orderBy( $tableName.'.'.$colAlias, $condition_sort );
                                } else {
                                    if( $tableName != '' ) {
                                        $data->orderBy( $tableName.'.'.$origData, $condition_sort );
                                    } else {
                                        $data->orderBy( $origData, $condition_sort );
                                    }
                                }
                            }
                        }
                    }
                }
                //$data->select('*');
                /// end

                return Datatables::of($data)
                        ->addIndexColumn()
                        /*->addColumn('head', function($row){
                            if (!is_null($row->dispatcher)) {
                                $head = $row->dispatcher->first_name.' '.$row->dispatcher->last_name;
                            } else {
                                $head = '';
                            }

                            return $head;
                        })*/
                        ->filterColumn('head', function ($query, $keyword) {
                            $query->whereHas('dispatcher', function ($q) use ($keyword) {
                                $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                            });
                        })
                        /*->addColumn('total_drivers', function($row){
                            return $row->drivers()->count();
                        })*/
                        ->addColumn('action', function($row){
                            $action = '<a href="javascript:void(0);" class="btn btn-sm btn-outline-black-action edit-btn" data-id="'.$row->id.'" data-toggle="modal" data-target="#editTeamModal"><i class="fa fa-pencil" aria-hidden="true"></i></a>';
                            $action .= '<a href="javascript:void(0);" class="btn btn-sm btn-outline-black-trash destroy" data-action="'.route('company.admin.teams.destroy',$row->id).'" data-id="'.$row->id.'"><i class="fa fa-trash" aria-hidden="true"></i></a>';

                            return $action;
                        })
                        ->rawColumns(['action'])
                        ->make(true);
            } else {
                $teams = Team::company()->filter($request->all())->latest()->get();

                $view = view('companyAdmin.team.gridView', compact('teams'))->render();

                return response()->json(['view' => $view]);
            }
        }
        $tableName = 'settings.table_teams';
        return view('companyAdmin.team.index', compact('getField','tableName'));
    }

    /**
     * Render the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function createFormView()
    {
        $dispatcherList = CompanyAdmin::select(DB::raw("CONCAT(first_name,' ',last_name) AS first_name"), 'id')->company()->dispatcher()->pluck('first_name','id')->all();

        $view = view('companyAdmin.team.createFormView', compact('dispatcherList'))->render();

        return response()->json(['view' => $view]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $input = $request->all();

        $validator = Validator::make($input,[
            "name" => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $input['company_id'] = auth()->guard('company-admin')->user()->company_id;

        if (isset($input['image'])) {
            $input['image'] = FileUpload::upload('companyAdmin/team', $input['image']);
        }

        Team::create($input);

        notification('success', $this->crudMessage('create', 'Team'));

        return response()->json(['success' => "Team created successfully"]);
    }

    /**
     * Render the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function editFormView(Request $request)
    {
        $dispatcherList = CompanyAdmin::select(DB::raw("CONCAT(first_name,' ',last_name) AS first_name"), 'id')->company()->dispatcher()->pluck('first_name','id')->all();

        $team = Team::find($request->id);

        $view = view('companyAdmin.team.editFormView', compact('team', 'dispatcherList'))->render();

        return response()->json(['view' => $view]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Team $team)
    {
        $input = $request->all();

        $validator = Validator::make($input,[
            "name" => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        if (!is_null($input['image'])) {
            $input['image'] = FileUpload::upload('companyAdmin/team', $input['image']);
        } else {
            unset($input['image']);
        }

        $team->update($input);

        notification('success', $this->crudMessage('update', 'Team'));

        return response()->json(['success' => "Team updated successfully"]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Team $team)
    {
        $team->delete();

        notification('success', $this->crudMessage('delete', 'Team'));

        return redirect()->back();
    }
}
