<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;

use App\Http\Requests\CompanyAdmin\TerminalStoreRequest;
use App\Http\Requests\CompanyAdmin\TerminalUpdateRequest;

use App\Models\Terminal;
use App\Models\BrokerContact;

use App\Models\Bookmark;
use App\Models\FileUpload;

use File;
use DataTables;
use Carbon\Carbon;
use App\Helpers\Common;

class TerminalController extends CompanyAdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(){
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request){
        $getCompanyAdmin    = auth()->guard('company-admin')->user();
        $getField           = '';
        $isCheck            = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','terminals')->first();
        if(!empty($isCheck->id)){
            //$getField       = unserialize($isCheck->config);
            $getField       = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_terminals_first'));
        }else{
            $getField       = config('settings.table_terminals_first');
        }
        if ($request->ajax()) {
            $data = Terminal::isCompany();

            // General filter code - start
            foreach( $getField as $key => $value ) {
                $conditionReq = 'search_string_condition_'.$key;
                $sortReq = 'search_string_sort_'.$key;

                if( isset( request()->$conditionReq ) ) {
                    $typeReq = 'search_string_type_'.$key;
                    $type = request()->$typeReq;

                    if( $type == 'string' ) {
                        Common::getStringFilterResult( $data, $key );
                    }

                    if( $type == 'date' ) {
                        Common::getDateFilterResult( $data, $key );
                    }
                }

                if( isset( request()->$sortReq ) ) {
                    $nameReq = 'search_string_name_'.$key;
                    $sortReq = 'search_string_sort_'.$key;
                    $typeReq = 'search_string_type_'.$key;
                    $tableNameReq = 'search_table_name_'.$key;
                    $colAliasReq = 'search_string_col_alias_'.$key;

                    $origData = request()->$nameReq;
                    $condition_sort = request()->$sortReq;
                    $type = request()->$typeReq;
                    $tableName = isset( request()->$tableNameReq ) ? request()->$tableNameReq : '';
                    $colAlias = isset( request()->$colAliasReq ) ? request()->$colAliasReq : '';

                    if( $type == 'string' ) {
                        if( isset( $condition_sort ) ) {
                            if( $colAlias != '' ) {
                                $data->orderBy( $tableName.'.'.$colAlias, $condition_sort );
                            } else {
                                if( $tableName != '' ) {
                                    $data->orderBy( $tableName.'.'.$origData, $condition_sort );
                                } else {
                                    $data->orderBy( $origData, $condition_sort );
                                }
                            }
                        }
                    }
                }
            }
            $data->select('*');
            /// end

            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function($row){
                    $action = '<a href="'.route('company.admin.terminals.show', base64Encode($row->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-eye" aria-hidden="true"></i></a>';
                    $action .= '<a href="'.route('company.admin.terminals.edit', base64Encode($row->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-pencil" aria-hidden="true"></i></a>';
                    $action .= '<a href="javascript:void(0);" class="btn btn-sm btn-outline-black-trash destroy" data-action="'.route('company.admin.terminals.destroy',$row->id).'" data-id="'.$row->id.'"><i class="fa fa-trash" aria-hidden="true"></i></a>';

                    return $action;
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        $tableName = 'settings.table_terminals';
        return view('companyAdmin.terminal.index', compact('getField','tableName'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(){
        return view('companyAdmin.terminal.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(TerminalStoreRequest $request)
    {


        $input                                  = $request->all();

        if(isset($input['account_number']) && count($input['account_number'])){
            foreach ($input['account_number'] as $key=>$account){
                $input['account_number'][$key]=base64_encode($account);
            }
        }
        if(isset($input['routing_number']) && count($input['routing_number'])){
            foreach ($input['routing_number'] as $key1=>$number){
                $input['routing_number'][$key1]=base64_encode($number);
            }
        }


        if($request->address_verified==1){
            $timezone                           = null;
            $timezone_offset                    = null;
            if(isset($input['timezone_abbr'])){
                $timezone                       = timezone_name_from_abbr($input['timezone_abbr']);
                $timezone_offset                = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['timezone']                  = $timezone;
            $input['timezone_offset']           = $timezone_offset;
        }
        if($request->billing_address_verified==1){
            $billing_timezone                   = null;
            $billing_timezone_offset            = null;
            if(isset($input['billing_timezone_abbr'])){
                $billing_timezone               = timezone_name_from_abbr($input['billing_timezone_abbr']);
                $billing_timezone_offset        = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['billing_timezone']          = $billing_timezone;
            $input['billing_timezone_offset']   = $billing_timezone_offset;
        }

        $input['company_id']                    = auth()->guard('company-admin')->user()->company_id;

        $input['generate_1099']                 = $input['generate_1099'] ?? 0;
        if (isset($input['documents'])) {
            $input['documents']                 = FileUpload::upload('companyAdmin/terminal', $input['documents']);
        }

        $input['bank_name']                     = serialize($request->bank_name);
        $input['account_number']                    = serialize($input['account_number'] ?? "");
        $input['routing_number']                    = serialize($input['routing_number'] ?? "");
        $input['bank_contact_name']             = serialize($request->bank_contact_name);
        $input['bank_contact_email']            = serialize($request->bank_contact_email);
        $input['name_on_account']               = serialize($request->name_on_account);

        /*
        if (isset($request->picture_of_voided_check) && !empty($request->picture_of_voided_check[0])) {
            $file_temp                          = [];
            $image_array                        = [];
            foreach($request->picture_of_voided_check as $image){
                $seme                           = FileUpload::upload('companyAdmin/temp', $image);
                $stopath                        = public_path('storage/companyAdmin/temp/'.$seme);
                $data                           = file_get_contents($stopath);
                $type                           = pathinfo($stopath, PATHINFO_EXTENSION);
                if($type == 'png' || $type == 'jpeg' || $type == 'jpg' || $type == 'gif'){
                    $base64                     = 'data:image/' . $type . ';base64,' . base64_encode($data);
                    $file_temp[]                = $base64;
                }else{
                    $image_array[] = $seme = FileUpload::upload('companyAdmin/terminal', $image);
                }
            }

            if(count($file_temp) > 0){
                $fileName                       = 'terminal_';
                $image_array[]                  = FileUpload::PDFupload('companyAdmin/terminal', ['data' => $file_temp], $fileName);
            }

            $input['picture_of_voided_check']   = serialize($image_array);
        }
        */

        $file_input_id = $request->file_input_id; $bank_active_status = array(); $picture_of_voided_check = array();

        for($i = 0; $i < count($request->account_number); $i++) {
            $bank_active_status[$i] = $request->bank_status[$i];

            if($request->file('picture_of_voided_check_'.$file_input_id[$i])){
                $file_temp                      = [];
                $image_array                    = [];
                foreach ($request->file('picture_of_voided_check_'.$file_input_id[$i]) as $image){
                    $seme                       = FileUpload::upload('companyAdmin/temp', $image);
                    $stopath                    = public_path('storage/companyAdmin/temp/'.$seme);
                    $data                       = file_get_contents($stopath);
                    $type                       = pathinfo($stopath, PATHINFO_EXTENSION);
                    if($type == 'png' || $type == 'jpeg' || $type == 'jpg' || $type == 'gif'){
                        $base64                 = 'data:image/' . $type . ';base64,' . base64_encode($data);
                        $file_temp[]            = $base64;
                    }else{
                        $image_array[]  = $seme = FileUpload::upload('companyAdmin/terminal', $image);
                    }
                }

                if(count($file_temp) > 0){
                    $fileName                   = 'terminal_'.$terminal->id;
                    $image_array[]              = FileUpload::PDFupload('companyAdmin/terminal', ['data' => $file_temp], $fileName);
                }

                $picture_of_voided_check[$i]    = $image_array;
            }else{
                $picture_of_voided_check[$i]    = [];
            }
        }

        $input['picture_of_voided_check']       = serialize($picture_of_voided_check);
        $input['bank_active_status']            = serialize($bank_active_status);
        $input['bank_contact']                  = serialize($request->bank_contact);
        $input['bank_phone']                    = serialize($request->bank_phone);
        $input['bext']                          = serialize($request->bext);
        $input['bank_email']                    = serialize($request->bank_email);

        $terminal                               = Terminal::create($input);

        $brokerContact                          = count($request->adepartment);
        if($brokerContact > 0){
            for ($x = 0; $x < $brokerContact; $x++){
                $broker_contact                 = [];
                $broker_contact['source']       = 'terminal';
                $broker_contact['action_id']    = $terminal->id;
                $broker_contact['department']   = $request->adepartment[$x];
                $broker_contact['name']         = $request->aname[$x];
                $broker_contact['phone_number'] = $request->aphone_number[$x];
                $broker_contact['ext']          = $request->aext[$x];
                $broker_contact['email']        = $request->aemail[$x];
                BrokerContact::create($broker_contact);
            }
        }

        notification('success', $this->crudMessage('create', 'Terminal'));

        return redirect()->route('company.admin.terminals.index');
    }

    /**
     * Display the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id){
        $id = base64Decode($id);
        $terminal = Terminal::findOrFail($id);
        $terminal['bank_count']                 = 0;
        if(is_serialized($terminal->account_number)){
            $terminal['bank_active_status']     = unserialize($terminal->bank_active_status);
            $terminal['bank_name']              = unserialize($terminal->bank_name);
            $terminal['account_number']         = unserialize($terminal->account_number);
            $terminal['routing_number']         = unserialize($terminal->routing_number);
            $terminal['bank_contact_name']      = unserialize($terminal->bank_contact_name);
            $terminal['bank_contact_email']     = unserialize($terminal->bank_contact_email);
            $terminal['name_on_account']        = unserialize($terminal->name_on_account);
            $terminal['bank_contact']           = unserialize($terminal->bank_contact);
            $terminal['bank_phone']             = unserialize($terminal->bank_phone);
            $terminal['bext']                   = unserialize($terminal->bext);
            $terminal['bank_email']             = unserialize($terminal->bank_email);
            $terminal['picture_of_voided_check'] = unserialize($terminal->picture_of_voided_check);
            $terminal['bank_count']             = count($terminal->account_number);
        }
        return view('companyAdmin.terminal.show', compact('terminal'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id){
        $id = base64Decode($id);
        $terminal = Terminal::findOrFail($id);
        $terminal['bank_count']             = 0;
        if(is_serialized($terminal->account_number)){
            $terminal['bank_active_status'] = unserialize($terminal->bank_active_status);
            $terminal['bank_name']          = unserialize($terminal->bank_name);
            $terminal['account_number']     = unserialize($terminal->account_number);
            $terminal['routing_number']     = unserialize($terminal->routing_number);
            $terminal['bank_contact_name']  = unserialize($terminal->bank_contact_name);
            $terminal['bank_contact_email'] = unserialize($terminal->bank_contact_email);
            $terminal['name_on_account']    = unserialize($terminal->name_on_account);
            $terminal['bank_contact']       = unserialize($terminal->bank_contact);
            $terminal['bank_phone']         = unserialize($terminal->bank_phone);
            $terminal['bext']               = unserialize($terminal->bext);
            $terminal['bank_email']         = unserialize($terminal->bank_email);
            $terminal['picture_of_voided_check'] = unserialize($terminal->picture_of_voided_check);
            $terminal['bank_count']         = count($terminal->account_number);

            $account_number=[];
            if(isset($terminal['account_number']) && count($terminal['account_number'])){
                foreach ($terminal['account_number'] as $key=>$account){
                    $account_number[$key]=base64_decode($account);
                }
            }
            $terminal['account_number']=$account_number;

            $routing_number=[];
            if(isset($terminal['routing_number']) && count($terminal['routing_number'])){
                foreach ($terminal['routing_number'] as $key1=>$number){
                    $routing_number[$key1]=base64_decode($number);
                }
            }
            $terminal['routing_number']=$routing_number;



        }
        return view('companyAdmin.terminal.edit', compact('terminal'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(TerminalUpdateRequest $request, Terminal $terminal){
        $input                                      = $request->all();

        if(isset($input['account_number']) && count($input['account_number'])){
            foreach ($input['account_number'] as $key=>$account){
                $input['account_number'][$key]=base64_encode($account);
            }
        }
        if(isset($input['routing_number']) && count($input['routing_number'])){
            foreach ($input['routing_number'] as $key1=>$number){
                $input['routing_number'][$key1]=base64_encode($number);
            }
        }


        if($request->address_verified==1){
            $timezone                               = null;
            $timezone_offset                        = null;
            if(isset($input['timezone_abbr'])){
                $timezone                           = timezone_name_from_abbr($input['timezone_abbr']);
                $timezone_offset                    = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['timezone']                      = $timezone;
            $input['timezone_offset']               = $timezone_offset;
        }else{
            $input['latitude']                      = null;
            $input['longitude']                     = null;
            $input['timezone']                      = null;
            $input['timezone_offset']               = null;
            $input['timezone_abbr']                 = null;
        }
        if($request->billing_address_verified==1){
            $billing_timezone                       = null;
            $billing_timezone_offset                = null;
            if(isset($input['billing_timezone_abbr'])){
                $billing_timezone                   = timezone_name_from_abbr($input['billing_timezone_abbr']);
                $billing_timezone_offset            = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['billing_timezone']              = $billing_timezone;
            $input['billing_timezone_offset']       = $billing_timezone_offset;
        }else{
            $input['billing_latitude']              = null;
            $input['billing_longitude']             = null;
            $input['billing_timezone']              = null;
            $input['billing_timezone_offset']       = null;
            $input['billing_timezone_abbr']         = null;
        }

        $input['generate_1099']                     = $input['generate_1099'] ?? 0;

        if (isset($input['documents'])) {
            $input['documents']                     = FileUpload::upload('companyAdmin/terminal', $input['documents']);
        }else{
            if(!empty($input['remove_image'])){
                $input['documents']                 = null;
            }
        }

        $input['bank_name']                         = serialize($request->bank_name);
        $input['account_number']                    = serialize($input['account_number'] ?? "");
        $input['routing_number']                    = serialize($input['routing_number'] ?? "");
        $input['bank_contact_name']                 = serialize($request->bank_contact_name);
        $input['bank_contact_email']                = serialize($request->bank_contact_email);
        $input['name_on_account']                   = serialize($request->name_on_account);

        /*
        if (isset($request->picture_of_voided_check) && !empty($request->picture_of_voided_check[0])) {
            $file_temp                              = [];
            $image_array                            = [];
            foreach($request->picture_of_voided_check as $image){
                $seme                               = FileUpload::upload('companyAdmin/temp', $image);

                $stopath                            = public_path('storage/companyAdmin/temp/'.$seme);
                $data                               = file_get_contents($stopath);
                $type                               = pathinfo($stopath, PATHINFO_EXTENSION);
                if($type == 'png' || $type == 'jpeg' || $type == 'jpg' || $type == 'gif'){
                    $base64                         = 'data:image/' . $type . ';base64,' . base64_encode($data);
                    $file_temp[]                    = $base64;
                }else{
                    $image_array[] = $seme = FileUpload::upload('companyAdmin/terminal', $image);
                }
            }

            if(count($file_temp) > 0){
                $fileName                           = 'terminal_'.$terminal->id;
                $image_array[]                      = FileUpload::PDFupload('companyAdmin/terminal', ['data' => $file_temp], $fileName);
            }

            $input['picture_of_voided_check']       = serialize($image_array);
        }
        */

        $file_input_id = $request->file_input_id; $bank_active_status = array(); $picture_of_voided_check = array();
        for($i = 0; $i < count($request->account_number); $i++){
            $bank_active_status[$i] = $request->bank_status[$i];

            if($request->file('picture_of_voided_check_'.$file_input_id[$i])){
                $file_temp                          = [];
                $image_array                        = [];
                foreach ($request->file('picture_of_voided_check_'.$file_input_id[$i]) as $image){
                    $seme                           = FileUpload::upload('companyAdmin/temp', $image);
                    $stopath                        = public_path('storage/companyAdmin/temp/'.$seme);
                    $data                           = file_get_contents($stopath);
                    $type                           = pathinfo($stopath, PATHINFO_EXTENSION);

                    if($type == 'png' || $type == 'jpeg' || $type == 'jpg' || $type == 'gif'){
                        $base64                     = 'data:image/' . $type . ';base64,' . base64_encode($data);
                        $file_temp[]                = $base64;
                    }else{
                        $image_array[] = $seme  = FileUpload::upload('companyAdmin/terminal', $image);
                    }
                }

                if(count($file_temp) > 0){
                    $fileName                       = 'terminal_'.$terminal->id;
                    $image_array[]                  = FileUpload::PDFupload('companyAdmin/terminal', ['data' => $file_temp], $fileName);
                }

                $picture_of_voided_check[$i]        = $image_array;
            }else{
                $filesArr = unserialize($terminal->picture_of_voided_check);
                $picture_of_voided_check[$i] = (isset($filesArr[$file_input_id[$i]])) ? $filesArr[$file_input_id[$i]] : [];
            }
        }

        $input['picture_of_voided_check']           = serialize($picture_of_voided_check);
        $input['bank_active_status']                = serialize($bank_active_status);
        $input['bank_contact']                      = serialize($request->bank_contact);
        $input['bank_phone']                        = serialize($request->bank_phone);
        $input['bext']                              = serialize($request->bext);
        $input['bank_email']                        = serialize($request->bank_email);

        $terminal->update($input);

        BrokerContact::where('action_id',$terminal->id)->where('source','terminal')->delete();

        $brokerContact = count($request->adepartment);
        if($brokerContact > 0){
            for ($x = 0; $x < $brokerContact; $x++){
                $broker_contact                     = [];
                $broker_contact['source']           = 'terminal';
                $broker_contact['action_id']        = $terminal->id;
                $broker_contact['department']       = $request->adepartment[$x];
                $broker_contact['name']             = $request->aname[$x];
                $broker_contact['phone_number']     = $request->aphone_number[$x];
                $broker_contact['ext']              = $request->aext[$x];
                $broker_contact['email']            = $request->aemail[$x];
                BrokerContact::create($broker_contact);
            }
        }

        notification('success', $this->crudMessage('update', 'Terminal'));

        return redirect()->route('company.admin.terminals.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Terminal $terminal){
        $terminal->delete();

        notification('success', $this->crudMessage('delete', 'Terminal'));

        return redirect()->route('company.admin.terminals.index');
    }
}
