<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

use App\Models\Truck;
use App\Models\Trailer;
use App\Models\TrailerMaintenanceLog;
use App\Models\TrailerMaintenanceLogFile;

use App\Models\Driver;
use App\Models\DriverInformation;

use App\Models\Gallery;
use App\Models\Bookmark;
use App\Models\FileUpload;
use App\Models\IntegrationSetting;

use App\Models\TrailerStatusLog;

use App\Http\Requests\CompanyAdmin\TruckStoreRequest;
use App\Http\Requests\CompanyAdmin\TruckUpdateRequest;
use App\Http\Requests\CompanyAdmin\TrailerStoreRequest;
use App\Http\Requests\CompanyAdmin\TrailerUpdateRequest;

use DB;
use File;
use DataTables;
use Carbon\Carbon;
use App\Helpers\Common;

class TrailerController extends CompanyAdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(){
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request){
        $getCompanyAdmin            = auth()->guard('company-admin')->user();

        $getField                   = '';
        $isCheck                    = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','trailers')->first();
        if(!empty($isCheck->id)){
            //$getField               = unserialize($isCheck->config);
            $getField               = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_trailers_first'));
        }else{
            $getField               = config('settings.table_trailers_first');
        }

        if ($request->ajax()) {
            $data                   = Trailer::isCompany();

            // General filter code - start
            foreach( $getField as $key => $value ) {
                $conditionReq       = 'search_string_condition_'.$key;
                $sortReq            = 'search_string_sort_'.$key;

                if( isset( request()->$conditionReq ) ) {
                    $typeReq        = 'search_string_type_'.$key;
                    $type           = request()->$typeReq;

                    if( $type == 'string' ) {
                        Common::getStringFilterResult( $data, $key );
                    }

                    if( $type == 'date' ) {
                        Common::getDateFilterResult( $data, $key );
                    }
                }

                if( isset( request()->$sortReq ) ) {
                    $nameReq        = 'search_string_name_'.$key;
                    $sortReq        = 'search_string_sort_'.$key;
                    $typeReq        = 'search_string_type_'.$key;
                    $tableNameReq   = 'search_table_name_'.$key;
                    $colAliasReq    = 'search_string_col_alias_'.$key;

                    $origData       = request()->$nameReq;
                    $condition_sort = request()->$sortReq;
                    $type           = request()->$typeReq;
                    $tableName      = isset( request()->$tableNameReq ) ? request()->$tableNameReq : '';
                    $colAlias       = isset( request()->$colAliasReq ) ? request()->$colAliasReq : '';

                    if( $type == 'string' ) {
                        if( isset( $condition_sort ) ) {
                            if( $colAlias != '' ) {
                                $data->orderBy( $tableName.'.'.$colAlias, $condition_sort );
                            } else {
                                if( $tableName != '' ) {
                                    $data->orderBy( $tableName.'.'.$origData, $condition_sort );
                                } else {
                                    $data->orderBy( $origData, $condition_sort );
                                }
                            }
                        }
                    }
                }
            }
            $data->select('*');
            /// end
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function($row){
                    $action = '<a href="'.route('company.admin.trailers.show', base64Encode($row->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-eye" aria-hidden="true"></i></a>';
                    $action .= '<a href="'.route('company.admin.trailers.edit', base64Encode($row->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-pencil" aria-hidden="true"></i></a>';
                    $action .= '<a href="javascript:void(0);" class="btn btn-sm btn-outline-black-trash destroy" data-action="'.route('company.admin.trailers.destroy',$row->id).'" data-id="'.$row->id.'"><i class="fa fa-trash" aria-hidden="true"></i></a>';

                    return $action;
                })
                ->rawColumns(['action'])
                ->make(true);
        }

        $tableName                  = 'settings.table_trailers';
        return view('companyAdmin.trailer.index', compact('getField','tableName'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(){
        $data                           = [];
        $data['getDriverListByCompany'] = Driver::IsCompany()
            ->select(DB::raw("CONCAT(last_name,', ',first_name) AS name"), 'id')
            ->orderByRaw('drivers.last_name ASC, drivers.first_name ASC')
            ->get();
        return view('companyAdmin.trailer.create', $data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(TrailerStoreRequest $request){
        $input                                          = $request->all();

        if(!is_null($input['current_assigned_driver'])){
            DriverInformation::where('driver_id', $input['current_assigned_driver'])->update(['trailer_number' => $input['trailer_id']]);
        }

        if(!is_null($input['current_assigned_truck'])){
            $truck                                      = Truck::where('id', $input['current_assigned_truck'])->first();
            if($truck->trailer != ""){
                $truckTrailers = array_filter(explode(',', $truck->trailer));
                $truckTrailers[] = $input['trailer_id'];
                $truck->trailer                         = (count($truckTrailers) > 1) ? implode(',', $truckTrailers) : $truckTrailers[0];
            }else{
                $truck->trailer                         = $input['trailer_id'];
            }
            $truck->save();
        }

        if($request->last_location_address_verified == 1){
            $timezone                                   = null;
            $timezone_offset                            = null;
            if(isset($input['last_location_timezone_abbr'])){
                $timezone                               = timezone_name_from_abbr($input['last_location_timezone_abbr']);
                $timezone_offset                        = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['last_location_timezone']            = $timezone;
            $input['last_location_timezone_offset']     = $timezone_offset;
        }

        $input['spread_axie']                           = $input['spread_axie'] ?? 0;
        $input['logistics_post']                        = $input['logistics_post'] ?? 0;
        $input['drop_trailer_pool']                     = $input['drop_trailer_pool'] ?? 0;
        $input['vented']                                = $input['vented'] ?? 0;
        $input['plated_interior']                       = $input['plated_interior'] ?? 0;
        $input['etrack']                                = $input['etrack'] ?? 0;
        $input['spare_tire_rank']                       = $input['spare_tire_rank'] ?? 0;

        if(!empty($request->onboard_equipment) && count($request->onboard_equipment) > 0){
            $input['onboard_equipment']                 = serialize($request->onboard_equipment);
        }else{
            $input['onboard_equipment']                 = null;
        }

        $input['company_id']                            = auth()->guard('company-admin')->user()->company_id;

        $trailer                                        = Trailer::create($input);

        $logdata = [];
        $logdata['company_id'] = auth()->guard('company-admin')->user()->company_id;
        $logdata['trailer_id'] = $trailer->id;
        $logdata['status_id'] = $request->status;
        TrailerStatusLog::create($logdata);

        if(!is_null($input['dummy_id']) && isset($input['dummy_id'])){
            $dummyloadid                                = $input['dummy_id'];
            Gallery::where('action_id', $dummyloadid)->update(['action_id' => $trailer->id]);
        }

        $company_id                                     = auth()->guard('company-admin')->user()->company_id;
        $getAPIKey                                      = IntegrationSetting::where('company_id', $company_id)->where('carrier_id', $trailer->carrier_id)->where('app_center_id', config('settings.app_id.samsara'))->where('sync_trailers', '1')->first();
        if(isset($getAPIKey->api_key) && !empty($getAPIKey->api_key)){
            $samsara_api_key                            = $getAPIKey->api_key;
            $endCursor                                  = 0;
            return redirect()->route('company.admin.trailer.sync.getsynctrailers', ['samsara_api_key' => $samsara_api_key, 'endCursor' => $endCursor]);
        }else{
            notification('success', $this->crudMessage('create', 'Trailer'));
            return redirect()->route('company.admin.trailers.index');
        }
    }

    /**
     * Display the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id){
        $trailer                                        = Trailer::find(base64Decode($id));
        return view('companyAdmin.trailer.show', compact('trailer'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id){
        $trailer                                        = Trailer::find(base64Decode($id));
        if($trailer){
            $currentLoad                                = $trailer->load_details()->latest('created_at')->first();
            $trailer->current_load                      = (!empty($currentLoad)) ? $currentLoad : null;
        }
        $getDriverListByCompany                         = Driver::IsCompany()
            ->select(DB::raw("CONCAT(last_name,', ',first_name) AS name"), 'id')
            ->orderByRaw('drivers.last_name ASC, drivers.first_name ASC')
            ->get();
        return view('companyAdmin.trailer.edit', compact('trailer', 'getDriverListByCompany'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(TrailerUpdateRequest $request, Trailer $trailer){
        $input                                          = $request->all();

        if(!is_null($input['current_assigned_driver'])){
            DriverInformation::where('driver_id', $input['current_assigned_driver'])->update(['trailer_number' => $input['trailer_id']]);
            DriverInformation::where('driver_id', '!=', $input['current_assigned_driver'])->where('trailer_number', $input['trailer_id'])->update(['trailer_number' => null]);
        }else{
            if(!is_null($trailer->current_assigned_driver)){
                DriverInformation::where('driver_id', $trailer->current_assigned_driver)->update(['trailer_number' => null]);
            }else{
                DriverInformation::where('trailer_number', $input['trailer_id'])->update(['trailer_number' => null]);
            }
        }

        if(!is_null($input['current_assigned_truck'])){
            $truck                                      = Truck::where('id', $input['current_assigned_truck'])->first();
            if($truck->trailer != ""){
                $truckTrailers = array_filter(explode(',', $truck->trailer));
                $truckTrailers[] = $input['trailer_id'];
                $truck->trailer                         = (count($truckTrailers) > 1) ? implode(',', $truckTrailers) : $truckTrailers[0];
            }else{
                $truck->trailer                         = $input['trailer_id'];
            }
            $truck->save();
        }else if(is_null($input['current_assigned_truck']) && !is_null($trailer->current_assigned_truck)){
            $truck                                      = Truck::where('id', $trailer->current_assigned_truck)->first();
            if($truck->trailer != ""){
                $truckTrailers = array_filter(explode(',', $truck->trailer));
                if (in_array($input['trailer_id'], $truckTrailers)) {
                    unset($truckTrailers[array_search($input['trailer_id'], $truckTrailers)]);
                }
                $truck->trailer                         = (count($truckTrailers) > 1) ? implode(',', $truckTrailers) : ((count($truckTrailers) > 0) ? $truckTrailers[0] : null);
            }
            $truck->save();
        }

        if($request->last_location_address_verified == 1){
            $timezone                                   = null;
            $timezone_offset                            = null;
            if(isset($input['last_location_timezone_abbr'])){
                $timezone                               = timezone_name_from_abbr($input['last_location_timezone_abbr']);
                $timezone_offset                        = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['last_location_timezone']            = $timezone;
            $input['last_location_timezone_offset']     = $timezone_offset;
        }else{
            $input['last_location_latitude']            = null;
            $input['last_location_longitude']           = null;
            $input['last_location_timezone']            = null;
            $input['last_location_timezone_offset']     = null;
            $input['last_location_timezone_abbr']       = null;
        }

        $input['spread_axie']                           = $input['spread_axie'] ?? 0;
        $input['logistics_post']                        = $input['logistics_post'] ?? 0;
        $input['drop_trailer_pool']                     = $input['drop_trailer_pool'] ?? 0;
        $input['vented']                                = $input['vented'] ?? 0;
        $input['plated_interior']                       = $input['plated_interior'] ?? 0;
        $input['etrack']                                = $input['etrack'] ?? 0;
        $input['spare_tire_rank']                       = $input['spare_tire_rank'] ?? 0;

        if(!empty($request->onboard_equipment) && count($request->onboard_equipment) > 0){
            $input['onboard_equipment']                 = serialize($request->onboard_equipment);
        }else{
            $input['onboard_equipment']                 = null;
        }
        $trailer->update($input);

        if($trailer->wasChanged()){
            if(isset($trailer->getChanges()['status'])){
                $logdata = [];
                $logdata['company_id'] = auth()->guard('company-admin')->user()->company_id;
                $logdata['trailer_id'] = $trailer->id;
                $logdata['status_id'] = $request->status;
                TrailerStatusLog::create($logdata);
            }
        }

        notification('success', $this->crudMessage('update', 'Trailer'));
        return redirect()->route('company.admin.trailers.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Trailer $trailer){
        $trailer->delete();

        notification('success', $this->crudMessage('delete', 'Trailer'));

        return redirect()->route('company.admin.trailers.index');
    }

    public function maintenanceSave(Request $request){
        $input                                          = $request->all();

        if(!empty($request->trailer_id)){
            if($request->due_on == 'date'){
                $input['due_date']                      = $request->due_date;
                $input['due_miles']                     = null;
            }else{
                $input['due_date']                      = null;
                $input['due_miles']                     = $request->due_miles;
            }
            if($request->waranty_on == 'date'){
                $input['waranty_date']                  = $request->waranty_date;
                $input['waranty_miles']                 = null;
            }else{
                $input['waranty_date']                  = null;
                $input['waranty_miles']                 = $request->waranty_miles;
            }

            $getdata                                    = TrailerMaintenanceLog::create($input);

            if (!empty($request->myfile) && isset($request->myfile) && $request->myfile != 'undefined') {
                $input_file                             = [];
                $input_file['trailer_maintenance_log_id'] = $getdata->id;
                $input_file['name']                     = $request->file_name;
                $input_file['file']                     = FileUpload::upload('companyAdmin/trailerfile', $request->myfile);
                TrailerMaintenanceLogFile::create($input_file);
            }
            if (!empty($request->myfile1) && isset($request->myfile1) && $request->myfile1 != 'undefined') {
                $input_file                             = [];
                $input_file['trailer_maintenance_log_id'] = $getdata->id;
                $input_file['name']                     = $request->file_name1;
                $input_file['file']                     = FileUpload::upload('companyAdmin/trailerfile', $request->myfile1);
                TrailerMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile2) && !empty($request->myfile2) && $request->myfile2 != 'undefined') {
                $input_file                             = [];
                $input_file['trailer_maintenance_log_id'] = $getdata->id;
                $input_file['name']                     = $request->file_name2;
                $input_file['file']                     = FileUpload::upload('companyAdmin/trailerfile', $request->myfile2);
                TrailerMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile3) && !empty($request->myfile3) && $request->myfile3 != 'undefined') {
                $input_file                             = [];
                $input_file['trailer_maintenance_log_id'] = $getdata->id;
                $input_file['name']                     = $request->file_name3;
                $input_file['file']                     = FileUpload::upload('companyAdmin/trailerfile', $request->myfile3);
                TrailerMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile4) && !empty($request->myfile4) && $request->myfile4 != 'undefined') {
                $input_file                             = [];
                $input_file['trailer_maintenance_log_id'] = $getdata->id;
                $input_file['name']                     = $request->file_name4;
                $input_file['file']                     = FileUpload::upload('companyAdmin/trailerfile', $request->myfile4);
                TrailerMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile5) && !empty($request->myfile5) && $request->myfile5 != 'undefined') {
                $input_file                             = [];
                $input_file['trailer_maintenance_log_id'] = $getdata->id;
                $input_file['name']                     = $request->file_name5;
                $input_file['file']                     = FileUpload::upload('companyAdmin/trailerfile', $request->myfile5);
                TrailerMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile6) && !empty($request->myfile6) && $request->myfile6 != 'undefined') {
                $input_file                             = [];
                $input_file['trailer_maintenance_log_id'] = $getdata->id;
                $input_file['name']                     = $request->file_name6;
                $input_file['file']                     = FileUpload::upload('companyAdmin/trailerfile', $request->myfile6);
                TrailerMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile7) && !empty($request->myfile7) && $request->myfile7 != 'undefined') {
                $input_file                             = [];
                $input_file['trailer_maintenance_log_id'] = $getdata->id;
                $input_file['name']                     = $request->file_name7;
                $input_file['file']                     = FileUpload::upload('companyAdmin/trailerfile', $request->myfile7);
                TrailerMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile8) && !empty($request->myfile8) && $request->myfile8 != 'undefined') {
                $input_file                             = [];
                $input_file['trailer_maintenance_log_id'] = $getdata->id;
                $input_file['name']                     = $request->file_name8;
                $input_file['file']                     = FileUpload::upload('companyAdmin/trailerfile', $request->myfile8);
                TrailerMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile9) && !empty($request->myfile9) && $request->myfile9 != 'undefined') {
                $input_file                             = [];
                $input_file['trailer_maintenance_log_id'] = $getdata->id;
                $input_file['name']                     = $request->file_name9;
                $input_file['file']                     = FileUpload::upload('companyAdmin/trailerfile', $request->myfile9);
                TrailerMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile10) && !empty($request->myfile10) && $request->myfile10 != 'undefined') {
                $input_file                             = [];
                $input_file['trailer_maintenance_log_id'] = $getdata->id;
                $input_file['name']                     = $request->file_name10;
                $input_file['file']                     = FileUpload::upload('companyAdmin/trailerfile', $request->myfile10);
                TrailerMaintenanceLogFile::create($input_file);
            }
            return 1;
        }
        return 0;
    }

    public function maintenanceView(Request $request){
        $getLog                                         = TrailerMaintenanceLog::where('trailer_id',$request->id)->orderBy('id','desc')->get();
        $view                                           = view('companyAdmin.trailer.log.view', compact('getLog'))->render();
        return response()->json(['view' => $view]);
    }

    public function maintenanceIsCompleted($id){
        $getLog                                         = TrailerMaintenanceLog::find($id);
        $save_array                                     = [];
        if($getLog->is_completed == 0){
            $save_array['is_completed']                 = 1;
        }else{
            $save_array['is_completed']                 = 0;
        }
        $getLog->update($save_array);
        return 1;
    }

    public function destroyMaintenance($id){
        $getFile = TrailerMaintenanceLog::find($id);
        foreach($getFile->Uploadfile as $Uploadfile){
            File::delete('storage/companyAdmin/trailerfile/'.$Uploadfile->file);
        }
        $getFile->delete();
        return 1;
    }

    public function getSyncTrailers($samsara_api_key,$endCursor){
        $data                                           = '';
        $company_id                                     = auth()->guard('company-admin')->user()->company_id;

        if(!empty($samsara_api_key)){
            $client                                     = new \GuzzleHttp\Client();
            if(empty($endCursor)){
                $api_url                                = 'https://api.samsara.com/fleet/trailers?limit=100';
            }else{
                $api_url                                = 'https://api.samsara.com/fleet/trailers?limit=100&after='.$endCursor;
            }

            $response                                   = $client->request('GET', $api_url, [
                'headers'                               => [
                    'Accept'                            => 'application/json',
                    'Authorization'                     => 'Bearer '.$samsara_api_key,
                ],
            ]);
            $data                                       = json_decode($response->getBody());


            $endCursor                                  = $data->pagination->endCursor;
            $data                                       = $data->data;

            foreach($data as $trailer){
                if(isset($trailer->name)){
                    $getTrailer                         = Trailer::where('trailer_id', $trailer->name)->where('company_id',$company_id)->first();
                    if(!empty($getTrailer->id)){
                        $trailer_data                   = [];
                        $trailer_data['samsara_id']     = $trailer->id;
                        $getTrailer->update($trailer_data);
                    }
                }
            }

            if(!empty($endCursor)){
                return redirect()->route('company.admin.trailer.sync.getsynctrailers', ['samsara_api_key' => $samsara_api_key, 'endCursor' => $endCursor]);
            }else{
                notification('success', $this->crudMessage('create', 'Trailer'));
                return redirect()->route('company.admin.trailers.index');
            }
        }
    }

    public function getRequestDocuments(Request $request){
        if ($request->ajax()) {
            $data                                       = Gallery::isCompany()->where('source','trailers')->where('action_id',$request->id)->whereNotNull('requested_by')->orderBy('id', 'desc');
            return Datatables::of($data)
                ->editColumn('field_name', function($row){
                    return getRequestDocumentsList($row->field_name, 'field_name')['name'];
                })
                ->editColumn('approved_by', function($row){
                    return empty($row->approved_by) ? 'None' : getFullNameByid($row->approved_by, $row->approved_by_type) ;
                })
                ->editColumn('created_by', function($row){
                    return empty($row->created_by) ? 'None' : getFullNameByid($row->created_by, $row->created_by_type) ;
                })
                ->editColumn('access', function($row){
                    if($row->access == 1){
                        return 'Managers';
                    }
                    if($row->access == 3){
                        return 'Dispatchers';
                    }
                    if($row->access == 3){
                        return 'Drivers';
                    }
                    return 'All User';
                })
                ->editColumn('status', function($row){
                    if($row->status == 'pending'){
                        return '<span class="status-pending">Pending</span>';
                    }
                    if($row->status == 'approved'){
                        return '<span class="status-approved">Approved</span>';
                    }
                    if($row->status == 'review'){
                        return '<span class="status-review">Review</span>';
                    }

                })

                ->editColumn('requested_by', function($row){
                    return empty($row->requested_by) ? 'None' : getFullNameByid($row->requested_by, $row->requested_by_type) ;
                })
                ->addIndexColumn()
                ->addColumn('action', function($row){

                    $btn = '<a href="#"  class="gallary-edit mr-2" data-id="'.$row->action_id.'" data-source="trailers" data-field="'.$row->field_name.'" data-toggle="modal" data-target="#galleryModal"><img src="'.asset('theme/img/eye.png').'" alt=""></a>';

                    //$btn = '<a href="'.route('company.admin.request-documents.show', $row->id).'" class="mr-2"><img src="'.asset('theme/img/eye.png').'" alt=""></a>';
                    //$btn = $btn.' <a href="'.route('company.admin.request-documents.edit', $row->id).'" class="mr-4"><img src="'.asset('theme/img/edit-icon.png').'" alt=""></a>';
                    $btn = $btn.'<a href="'.route('company.admin.gallery.download.file',$row->id).'" class="mr-2"><img src="'.asset("theme/img/download-cloud.png").'" alt=""></a>';

                    $btn = $btn.' <a href="javascript:" class="destroy" data-action="'.route('company.admin.request-documents.destroy',$row->id).'" data-id="'.$row->id.'"><img src="'.asset('theme/img/delete-icon.png').'" alt=""></a>';
                    return $btn;
                })
                ->rawColumns(['action','field_name','approved_by','created_by','requested_by','status','access'])
                ->make(true);
        }
    }

    public function getTrailerDetails(Request $request){
        $trailer                                        = Trailer::find($request->trailer_id);
        return response()->json($trailer);
    }
}
