<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;
use App\Models\TrailerType;
use App\Models\Bookmark;

use DataTables;
use Illuminate\Support\Facades\DB;
use Validator;
use Carbon\Carbon;
use App\Helpers\Common;
class TrailerTypeController extends CompanyAdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        Carbon::setWeekStartsAt(Carbon::SUNDAY);
        Carbon::setWeekEndsAt(Carbon::SATURDAY);
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {

        $getField = '';

        $getCompanyAdmin = auth()->guard('company-admin')->user();
        $isCheck = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','trailer_type')->first();

        if(!empty($isCheck->id)){
            //$getField = unserialize($isCheck->config);
            $getField = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_trailer_type_first'));
        }else{
            $getField = config('settings.table_trailer_type_first');
        }

        if ($request->ajax()) {
            $data = TrailerType::isCompany()->select('id', 'company_id', 'name', DB::raw('IF(is_temp_required = 0, "No", "Yes") as is_temp_required'));
            // General filter code - start
            foreach( $getField as $key => $value ) {
                $conditionReq = 'search_string_condition_'.$key;
                $sortReq = 'search_string_sort_'.$key;

                if( isset( request()->$conditionReq ) ) {
                    $typeReq = 'search_string_type_'.$key;
                    $type = request()->$typeReq;

                    if( $type == 'string' ) {
                        Common::getStringFilterResult( $data, $key );
                    }

                    if( $type == 'date' ) {
                        Common::getDateFilterResult( $data, $key );
                    }
                }

                if( isset( request()->$sortReq ) ) {
                    $nameReq = 'search_string_name_'.$key;
                    $sortReq = 'search_string_sort_'.$key;
                    $typeReq = 'search_string_type_'.$key;
                    $tableNameReq = 'search_table_name_'.$key;
                    $colAliasReq = 'search_string_col_alias_'.$key;

                    $origData = request()->$nameReq;
                    $condition_sort = request()->$sortReq;
                    $type = request()->$typeReq;
                    $tableName = isset( request()->$tableNameReq ) ? request()->$tableNameReq : '';
                    $colAlias = isset( request()->$colAliasReq ) ? request()->$colAliasReq : '';

                    if( $type == 'string' ) {
                        if( isset( $condition_sort ) ) {
                            if( $colAlias != '' ) {
                                $data->orderBy( $tableName.'.'.$colAlias, $condition_sort );
                            } else {
                                if( $tableName != '' ) {
                                    $data->orderBy( $tableName.'.'.$origData, $condition_sort );
                                } else {
                                    $data->orderBy( $origData, $condition_sort );
                                }
                            }
                        }
                    }
                }
            }
            //$data->select('*');
            // General filter code - end


            return Datatables::of($data)
                    ->addIndexColumn()
                    /*->addColumn('is_temp_required', function($row){
                        return ($row->is_temp_required == 0) ? 'No' : 'Yes';
                    })*/
                    ->addColumn('action', function($row){
                        $action = '';
                        if($row->company_id != 0){
                            $action .= '<a href="javascript:void(0);" class="btn btn-sm btn-outline-black-action edit-btn" data-id="'.$row->id.'" data-toggle="modal" data-target="#editModal"><i class="fa fa-pencil" aria-hidden="true"></i></a>';
                            $action .= '<a href="javascript:void(0);" class="btn btn-sm btn-outline-black-trash destroy" data-action="'.route('company.admin.trailer-types.destroy',$row->id).'" data-id="'.$row->id.'"><i class="fa fa-trash" aria-hidden="true"></i></a>';
                        }
                        return $action;
                    })
                    ->rawColumns(['action','is_temp_required'])
                    ->make(true);
        }
        $tableName = 'settings.table_trailer_type';
        return view('companyAdmin.trailerType.index', compact('getField','tableName'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $input = $request->all();

        $validator = Validator::make($input,[
            "name" => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }
        $input['company_id'] = auth()->guard('company-admin')->user()->company_id;
        TrailerType::create($input);

        notification('success', $this->crudMessage('create', 'Trailer Type created'));

        return response()->json(['success' => "Trailer Type created successfully"]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function editFormView(Request $request)
    {
        $trailerType = TrailerType::find($request->id);

        $view = view('companyAdmin.trailerType.editFormView', compact('trailerType'))->render();

        return response()->json(['view' => $view, 'data' => $trailerType]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $input = $request->all();
        $validator = Validator::make($input,[
            "name" => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }
        TrailerType::find($id)->update($input);

        notification('success', $this->crudMessage('update', 'Weekly Fuel Surcharge'));

        return response()->json(['success' => "weekly Fuel Surcharge updated successfully"]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(TrailerType $trailerType)
    {
        $trailerType->delete();

        notification('success', $this->crudMessage('delete', 'Weekly Fuel Surcharge'));

        return redirect()->back();
    }
}
