<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use App\Models\Carrier;
use App\Models\CompanyAdmin;
use App\Models\CompanyDocumentProfile;
use App\Models\CompanyDropLocation;
use App\Models\CompanyEquipmentProfile;
use App\Models\CompanyInsuranceProfile;
use App\Models\CompanyPmServiceProfile;
use App\Models\CompanyPmServiceWarrantyProfile;
use App\Models\Diagnostics;
use App\Models\Driver;
use App\Models\DriverHosViolation;
use App\Models\LoadDetail;
use App\Models\State;
use App\Models\Trailer;
use App\Models\TruckAdditionalDocument;
use App\Models\TruckAdditionalEquipment;
use App\Models\TruckAdditionalInsurance;
use App\Models\TruckAdditionalPmService;
use App\Models\TruckAvoidState;
use App\Models\TruckDiagnostics;
use App\Models\TruckIntegration;
use App\Models\TruckProfileDocument;
use App\Models\TruckProfileEquipment;
use App\Models\TruckProfileInsurance;
use App\Models\TruckProfilePmService;
use App\Models\TruckRestrictedState;
use App\Models\TruckWarrantyPmService;
use App\Models\Vendor;
use Carbon\CarbonPeriod;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;

use App\Http\Requests\CompanyAdmin\TruckStoreRequest;
use App\Http\Requests\CompanyAdmin\TruckUpdateRequest;

use App\Models\Truck;
use App\Models\TruckMaintenanceLog;
use App\Models\TruckMaintenanceLogFile;

use App\Models\Gallery;
use App\Models\FileUpload;

use App\Models\Bookmark;
use App\Models\IntegrationSetting;
use App\Models\TruckStatusLog;

use App\Helpers\Common;

use File;
use DataTables;
use Carbon\Carbon;

class TruckController extends CompanyAdminController{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(){
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request){
        $getField                   = '';
        $getCompanyAdmin            = auth()->guard('company-admin')->user();
        $isCheck                    = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','trucks')->first();
        if(!empty($isCheck->id)){
            //$getField               = unserialize($isCheck->config);
            $getField               = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_trucks_first'));
        }else{
            $getField               = config('settings.table_trucks_first');
        }

        if ($request->ajax()) {
            $data = Truck::select('trucks.*', DB::raw('CONCAT(drivers.last_name," ",drivers.first_name) as driver'))
                    ->where('trucks.company_id', auth()->guard('company-admin')->user()->company_id)
                    ->leftJoin('drivers', 'trucks.driver', '=', 'drivers.id');

            // General filter code - start
            foreach( $getField as $key => $value ) {
                $conditionReq       = 'search_string_condition_'.$key;
                $sortReq            = 'search_string_sort_'.$key;

                if( isset( request()->$conditionReq ) ) {
                    $typeReq        = 'search_string_type_'.$key;
                    $type           = request()->$typeReq;

                    if( $type == 'string' ) {
                        Common::getStringFilterResult( $data, $key );
                    }

                    if( $type == 'date' ) {
                        Common::getDateFilterResult( $data, $key );
                    }
                }

                if( isset( request()->$sortReq ) ) {
                    $nameReq        = 'search_string_name_'.$key;
                    $sortReq        = 'search_string_sort_'.$key;
                    $typeReq        = 'search_string_type_'.$key;
                    $tableNameReq   = 'search_table_name_'.$key;
                    $colAliasReq    = 'search_string_col_alias_'.$key;

                    $origData       = request()->$nameReq;
                    $condition_sort = request()->$sortReq;
                    $type           = request()->$typeReq;
                    $tableName      = isset( request()->$tableNameReq ) ? request()->$tableNameReq : '';
                    $colAlias       = isset( request()->$colAliasReq ) ? request()->$colAliasReq : '';
                    if( $type == 'string' ) {
                        if( isset( $condition_sort ) ) {
                            if( $colAlias != '' ) {
                                $data->orderBy( $tableName.'.'.$colAlias, $condition_sort );
                            } else {
                                if( $tableName != '' ) {
                                    $data->orderBy( $tableName.'.'.$origData, $condition_sort );
                                } else {
                                    $data->orderBy( $origData, $condition_sort );
                                }
                            }
                        }
                    }
                }
            }
            /// end
            return Datatables::of($data)
                    ->addIndexColumn()
                    ->addColumn('action', function($row){
                        $action = '<a href="'.route('company.admin.trucks.show', base64Encode($row->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-eye" aria-hidden="true"></i></a>';
                        $action .= '<a href="'.route('company.admin.trucks.edit', base64Encode($row->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-pencil" aria-hidden="true"></i></a>';
                        $action .= '<a href="javascript:void(0);" class="btn btn-sm btn-outline-black-trash destroy" data-action="'.route('company.admin.trucks.destroy',$row->id).'" data-id="'.$row->id.'"><i class="fa fa-trash" aria-hidden="true"></i></a>';

                        return $action;
                    })
                    ->filterColumn('name', function ($query, $keyword) {
                        $query->where(DB::raw("CONCAT(last_name, ', ', first_name)"), 'LIKE', "%" . $keyword . "%");
                    })
                    ->rawColumns(['action'])
                    ->make(true);
        }
        $tableName                  = 'settings.table_trucks';
        return view('companyAdmin.truck.index', compact('getField','tableName'));

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    /*
    public function create(){
        return view('companyAdmin.truck.create_bk_07092023');
    }
    */

    public function create()
    {
        $assignedTrailers = Trailer::IsCompany()->whereNotNull('current_assigned_truck')->pluck('trailer_id')->all();

        return view('companyAdmin.truck.create', compact('assignedTrailers'));
    }

    public function saveGeneralInfo(Request $request)
    {
        $input = $request->all();

        $input['company_id'] = auth()->guard('company-admin')->user()->company_id;
        $input['trailer'] = array_values(array_filter($input['trailer']));

        if(!is_null($request->truck_id)){
            $validate = Validator::make($request->all(), [
                'unit' => 'required|unique:trucks,unit,'.$request->truck_id.',id,company_id,'.auth()->guard('company-admin')->user()->company_id.',deleted_at,NULL',
                'vin_number' => 'unique:trucks,vin_number,'.$request->truck_id.',id,company_id,'.auth()->guard('company-admin')->user()->company_id.',deleted_at,NULL',
            ]);

            if($validate->errors()->count() > 0) {
                return response()->json(['success' => false, 'msg' => $validate->errors()->first()]);
            }else{
                $truck = Truck::IsCompany()->where('id', $request->truck_id)->first();

                if($truck->driver != ""){
                    $truck->driver_assign_date = null;
                    $truck->driver_assign_by =  null;

                    $driver = Driver::find($truck->driver);
                    $driver->driver_information->update(['truck_number' => null]);
                }

                if($input['driver'] != ""){
                    $truck->driver_assign_date = Carbon::now()->format('m/d/Y');
                    $truck->driver_assign_by = auth()->guard('company-admin')->user()->id;

                    $driver = Driver::find($input['driver']);
                    $driver->driver_information->update(['truck_number' => $truck->unit]);
                }else{
                    $input['driver'] = null;
                    $input['driver_assign_date'] = null;
                    $input['driver_assign_by'] = null;
                }

                if($truck->co_driver != ""){
                    $truck->co_driver_assign_date = null;
                    $truck->co_driver_assign_by =  null;

                    $driver = Driver::find($truck->co_driver);
                    $driver->driver_information->update(['truck_number' => null]);
                }

                if($input['co_driver'] != ""){
                    $truck->co_driver_assign_date = Carbon::now()->format('m/d/Y');
                    $truck->co_driver_assign_by = auth()->guard('company-admin')->user()->id;

                    $driver = Driver::find($input['co_driver']);
                    $driver->driver_information->update(['truck_number' => $truck->unit]);
                }else{
                    $input['co_driver'] = null;
                    $input['co_driver_assign_date'] = null;
                    $input['co_driver_assign_by'] = null;
                }

                $existingTruckTrailers = array_filter(explode(',', $truck->trailer));

                if(count($existingTruckTrailers) > 0){
                    foreach ($existingTruckTrailers as $trailerId){
                        $trailer = Trailer::IsCompany()->where('trailer_id', $trailerId)->first();
                        $trailer->current_assigned_truck = null;
                        $trailer->save();
                    }
                }

                if(count($input['trailer']) > 0){
                    foreach ($input['trailer'] as $trailerId){
                        $trailer = Trailer::IsCompany()->where('trailer_id', $trailerId)->first();
                        $trailer->current_assigned_truck = $request->truck_id;
                        $trailer->save();
                    }

                    $input['trailer'] = (count($input['trailer']) > 1) ? implode(',', $input['trailer']) : $input['trailer'][0];
                    $input['trailer_assign_date'] = Carbon::now()->format('m/d/Y');
                    $input['trailer_assign_by'] = auth()->guard('company-admin')->user()->id;
                }else{
                    $input['trailer'] = null;
                    $input['trailer_assign_date'] = null;
                    $input['trailer_assign_by'] = null;
                }

                if(is_null($truck->truck_unique_id)){
                    $input['truck_unique_id'] = getCompIdentifier().$truck->id;
                }
                $truck->update($input);

                if($truck->wasChanged()){
                    if(isset($truck->getChanges()['status'])){
                        $logdata = [];
                        $logdata['company_id'] = auth()->guard('company-admin')->user()->company_id;
                        $logdata['truck_id'] = $truck->id;
                        $logdata['status_id'] = $request->status;
                        TruckStatusLog::create($logdata);
                    }
                }
            }
        }else{
            $validate = Validator::make($request->all(), [
                'unit' => 'required|unique:trucks,unit,NULL,id,company_id,'.auth()->guard('company-admin')->user()->company_id.',deleted_at,NULL',
                'vin_number' => 'nullable|unique:trucks,vin_number,NULL,id,company_id,'.auth()->guard('company-admin')->user()->company_id.',deleted_at,NULL',
            ]);

            if($validate->errors()->count() > 0) {
                return response()->json(['success' => false, 'msg' => $validate->errors()->first()]);
            }else{
                if(count($input['trailer']) > 0){
                    $input['trailer'] = (count($input['trailer']) > 1) ? implode(',', $input['trailer']) : $input['trailer'][0];
                }else{
                    $input['trailer'] = null;
                }

                $truck = Truck::create($input);
                if($truck->wasChanged()){
                    if(isset($truck->getChanges()['status'])){
                        $logdata = [];
                        $logdata['company_id'] = auth()->guard('company-admin')->user()->company_id;
                        $logdata['truck_id'] = $truck->id;
                        $logdata['status_id'] = $request->status;
                        TruckStatusLog::create($logdata);
                    }
                }

                if($truck->driver != ""){
                    $truck->driver_assign_date = Carbon::now()->format('m/d/Y');
                    $truck->driver_assign_by = auth()->guard('company-admin')->user()->id;

                    $driver = Driver::find($truck->driver);
                    $driver->driver_information->update(['truck_number' => $truck->unit]);
                }

                if($truck->co_driver != ""){
                    $truck->co_driver_assign_date = Carbon::now()->format('m/d/Y');
                    $truck->co_driver_assign_by = auth()->guard('company-admin')->user()->id;

                    $driver = Driver::find($truck->co_driver);
                    $driver->driver_information->update(['truck_number' => $truck->unit]);
                }

                if($truck->trailer != ""){
                    $trailers = explode(',', $truck->trailer);
                    foreach ($trailers as $trailerId){
                        $trailer = Trailer::IsCompany()->where('trailer_id', $trailerId)->first();
                        $trailer->current_assigned_truck = $truck->id;
                        $trailer->save();
                    }
                }

                $truck->truck_unique_id = getCompIdentifier().$truck->id;
                $truck->save();
            }
        }

        if($truck){
            return response()->json(['success' => true, 'msg' => 'Truck General Info saved successfully', 'truckId' => $truck->id]);
        }else{
            return response()->json(['success' => false, 'msg' => 'Error, on save Truck General Info']);
        }
    }

    public function saveOwnership(Request $request){
        $input                                      = $request->all();

        $input['company_id']                        = auth()->guard('company-admin')->user()->company_id;

        $pay_type                                   = null;
        $pay_id                                     = null;
        if(isset($input['pay_to']) && !is_null($input['pay_to'])){
            $pay_arry                               = explode('_', $input['pay_to']);
            if(isset($pay_arry[0])){
                if($pay_arry[0]=='carriers'){
                    $pay_type                       = 1;
                    $pay_id                         = $pay_arry[1];
                }else{
                    $pay_type                       = 2;
                    $pay_id                         = $pay_arry[2];
                }
            }
        }
        $input['owner_type']                        = $pay_type;
        $input['owner_id']                          = $pay_id;

        $ownership                                  = $input['ownership'];

        if($ownership == '0' || $ownership == '3'){
            // $input['owner_id']                   = (isset($input['owner']) && count(array_filter($input['owner'])) > 0) ? implode(',', $input['owner']) : null;
            $input['ownership_id']                  = $input['owner'];

            $input['leasing_company']               = null;
            $input['lease_start']                   = null;
            $input['lease_end']                     = null;
            $input['lease_agreement_on_file']       = null;

            $input['rental_company']                = null;
            $input['rental_start']                  = null;
            $input['rental_end']                    = null;
            $input['rental_agreement_on_file']      = null;

            $input['billing_type']                  = null;
            $input['payment_amount']                = null;
            $input['security_deposit']              = null;
        }elseif($ownership == '1' || $ownership == '4'){
            // $input['leasing_company']            = (isset($input['leasing_company']) && count(array_filter($input['leasing_company'])) > 0) ? implode(',', $input['leasing_company']) : null;
            $input['leasing_company']               = $input['leasing_company'];

            $input['ownership_id']                  = null;
            $input['owner_purchase_date']           = null;
            $input['owner_purchase_price']          = null;
            $input['down_payment']                  = null;
            $input['balance_due']                   = null;
            $input['purchase_agreement_on_file']    = null;

            $input['rental_company']                = null;
            $input['rental_start']                  = null;
            $input['rental_end']                    = null;
            $input['rental_agreement_on_file']      = null;
        }elseif($ownership == '2' || $ownership == '5'){
            // $input['rental_company']             = (isset($input['rental_company']) && count(array_filter($input['rental_company'])) > 0) ? implode(',', $input['rental_company']) : null;
            $input['rental_company']                = $input['rental_company'];

            $input['ownership_id']                  = null;
            $input['owner_purchase_date']           = null;
            $input['owner_purchase_price']          = null;
            $input['down_payment']                  = null;
            $input['balance_due']                   = null;
            $input['purchase_agreement_on_file']    = null;

            $input['leasing_company']               = null;
            $input['lease_start']                   = null;
            $input['lease_end']                     = null;
            $input['lease_agreement_on_file']       = null;
        }

        if(!is_null($input['truck_id'])){
            $truck                                  = Truck::updateOrCreate(['id' => $input['truck_id'], 'company_id' => auth()->guard('company-admin')->user()->company_id], $input);

            if($truck->wasChanged()){
                if(isset($truck->getChanges()['status'])){
                    $logdata = [];
                    $logdata['company_id'] = auth()->guard('company-admin')->user()->company_id;
                    $logdata['truck_id'] = $truck->id;
                    $logdata['status_id'] = $request->status;
                    TruckStatusLog::create($logdata);
                }
            }

            if(!is_null($input['dummy_id']) && isset($input['dummy_id']) && $input['dummy_id'] != $input['truck_id']){
                $dummyloadid                        = $input['dummy_id'];
                Gallery::where('action_id', $dummyloadid)->update(['action_id' => $truck->id]);
            }

            if($truck){
                return response()->json(['success' => true, 'msg' => 'Truck Ownership saved successfully', 'truckId' => $truck->id]);
            }else{
                return response()->json(['success' => false, 'msg' => 'Error, on save Truck Ownership']);
            }
        }else{
            return response()->json(['success' => false, 'msg' => 'Error, on save Truck Ownership']);
        }
    }

    public function addInsuranceProfile(Request $request)
    {
        $profileName = $request->profile_name;
        $insuranceTypes = (count(array_filter($request->insurance_types)) > 0) ? implode(',', array_filter($request->insurance_types)) : null;

        $createInsuranceProfile = CompanyInsuranceProfile::create([
            'company_id' => auth()->guard('company-admin')->user()->company_id,
            'profile_name' => $profileName,
            'insurance_types' => $insuranceTypes,
        ]);

        if($createInsuranceProfile){
            $insuranceProfileHtml = '<option value="" data-insurance-types="">Select Insurance Profile</option>';
            foreach(getCompanyInsuranceProfiles() as $insuranceProfile){
                $insuranceProfileHtml .= '<option value="'.$insuranceProfile->id.'" data-insurance-types="'.$insuranceProfile->insurance_types.'">'.$insuranceProfile->profile_name.'</option>';
            }

            return response()->json(['success' => true, 'msg' => 'Insurance Profile saved successfully', 'insuranceProfileHtml' => $insuranceProfileHtml, 'new_profile_id' => $createInsuranceProfile->id]);
        }else{
            return response()->json(['success' => false, 'msg' => 'Error, on save Insurance Profile']);
        }
    }

    public function insuranceProfileView(Request $request)
    {
        $insuranceTypes = array_filter(explode(',', $request->insuranceTypes));
        $insuranceProfile = $request->insuranceProfile;
        $vendors = Vendor::IsCompany()->get();

        $preViewHtml = '';

        $i = 0;

        $preViewHtml .= '<input type="hidden" name="dummy_id" value="'.time().'">';
        $preViewHtml .= '<div class="row pt-2">';
        $preViewHtml .= '<div class="col-md-12">';
        $preViewHtml .= '<div class="form-group">';
        $preViewHtml .= '<h6 class="section-heading">'.$insuranceProfile.'</h6>';
        $preViewHtml .= '</div>';
        $preViewHtml .= '</div>';
        $preViewHtml .= '</div>';

        foreach ($insuranceTypes as $insuranceType){
            $preViewHtml .= '<div class="row pt-2">';
            $preViewHtml .= '<div class="col-md-3 ins-prev-custom-grid pr-1">';
            $preViewHtml .= '<div class="form-group">';
            $preViewHtml .= '<label for="insurance-types" class="mb-1">'.getCompanyInsuranceTypes()[$insuranceType].'</label>';
            $preViewHtml .= '<select class="form-control select2" name="insurance_vendor[]">';
            $preViewHtml .= '<option value="">Select Insurance Vendor</option>';
            foreach ($vendors as $vendor){
                $preViewHtml .= '<option value="'.$vendor->id.'">'.$vendor->name.'</option>';
            }
            $preViewHtml .= '</select>';
            $preViewHtml .= '<input type="hidden" name="insurance_type[]" value="'.$insuranceType.'">';
            $preViewHtml .= '</div>';
            $preViewHtml .= '</div>';
            $preViewHtml .= '<div class="col-md-3 ins-prev-custom-grid pl-1 pr-1">';
            $preViewHtml .= '<div class="form-group">';
            $preViewHtml .= '<label for="policy-number" class="mb-1">Policy No.</label>';
            $preViewHtml .= '<input class="form-control" placeholder="Enter" name="policy_number[]" type="text">';
            $preViewHtml .= '</div>';
            $preViewHtml .= '</div>';
            $preViewHtml .= '<div class="col-md-3 ins-prev-custom-grid pl-1 pr-1">';
            $preViewHtml .= '<div class="form-group">';
            $preViewHtml .= '<label for="value" class="mb-1">Value</label>';
            $preViewHtml .= '<div class="input-group pre-append">';
            $preViewHtml .= '<div class="input-group-prepend">';
            $preViewHtml .= '<span class="input-group-text">$</span>';
            $preViewHtml .= '</div>';
            $preViewHtml .= '<input class="form-control border-radius-none integer-input comma-integer-input" placeholder="Enter" name="value[]" type="text">';
            $preViewHtml .= '</div>';
            $preViewHtml .= '</div>';
            $preViewHtml .= '</div>';
            $preViewHtml .= '<div class="col-md-3 ins-prev-custom-grid pl-1 pr-1">';
            $preViewHtml .= '<div class="form-group">';
            $preViewHtml .= '<label for="date-added" class="mb-1">Date Added</label>';
            $preViewHtml .= '<div class="input-group">';
            $preViewHtml .= '<input class="form-control date" placeholder="Enter" name="date_added[]" type="text">';
            $preViewHtml .= '<img src="'.asset('theme/images/date-calender.svg').'" alt="icon">';
            $preViewHtml .= '</div>';
            $preViewHtml .= '</div>';
            $preViewHtml .= '</div>';
            $preViewHtml .= '<div class="col-md-3 ins-prev-custom-grid pl-1 pr-1">';
            $preViewHtml .= '<div class="form-group">';
            $preViewHtml .= '<label for="expiration-date" class="mb-1">Expiration Date</label>';
            $preViewHtml .= '<div class="input-group">';
            $preViewHtml .= '<input class="form-control date" placeholder="Enter" name="expiration_date[]" type="text">';
            $preViewHtml .= '<img src="'.asset('theme/images/date-calender.svg').'" alt="icon">';
            $preViewHtml .= '</div>';
            $preViewHtml .= '</div>';
            $preViewHtml .= '</div>';
            $preViewHtml .= '<div class="pl-1 mt-4">';
            $preViewHtml .= '<div class="form-group d-flex">';
            $preViewHtml .= '<div>';
            $preViewHtml .= '<a href="javascript:void(0);" class="insuranceFile">';
            $preViewHtml .= '<i class="fa fa-picture-o profileInsuranceFile gallary-edit" aria-hidden="true" data-id="'.time().'" data-source="truck" data-field="profile_insurance_file_'.$i.'" data-toggle="modal" data-target="#galleryModal" title="Insurance File"></i>';
            $preViewHtml .= '</a>';
            $preViewHtml .= '</div>';
            $preViewHtml .= '<div>';
            $preViewHtml .= '<a href="javascript:void(0);" class="removeMoreProfileRows">';
            $preViewHtml .= '<i class="fa fa-minus-square" aria-hidden="true"></i>';
            $preViewHtml .= '</a>';
            $preViewHtml .= '</div>';
            $preViewHtml .= '</div>';
            $preViewHtml .= '</div>';
            $preViewHtml .= '</div>';

            $i++;
        }

        return response()->json(['success'=> true, 'preViewHtml' => $preViewHtml]);
    }

    public function saveInsurance(Request $request)
    {
        $input = $request->all();
        $section = $request->section;
        $truckId = $request->truck_id;

        if($truckId != ""){
            $truck = Truck::find($truckId);
            $truck->status =  $request->status; // Update Truck Status If changed
            $truck->save();

            if($truck->wasChanged()){
                if(isset($truck->getChanges()['status'])){
                    $logdata = [];
                    $logdata['company_id'] = auth()->guard('company-admin')->user()->company_id;
                    $logdata['truck_id'] = $truck->id;
                    $logdata['status_id'] = $request->status;
                    TruckStatusLog::create($logdata);
                }
            }

            $truckCompanyId = $truck->company_id;

            if($section == '1'){
                $isExists = TruckProfileInsurance::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->count();

                if($isExists > 0){
                    TruckProfileInsurance::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->delete();
                }

                $insuranceProfileId = $input['insurance_profile'];

                if(isset($input['insurance_type'])){
                    $insuranceTypes = $input['insurance_type'];
                    $insuranceVendors = $input['insurance_vendor'];
                    $policyNumbers = $input['policy_number'];
                    $values = $input['value'];
                    $datesAdded = $input['date_added'];
                    $expirationDates = $input['expiration_date'];

                    foreach ($insuranceTypes as $key => $value){
                        TruckProfileInsurance::create([
                            'company_id' => $truckCompanyId,
                            'truck_id' => $truckId,
                            'insurance_profile' => $insuranceProfileId,
                            'insurance_type' => (isset($insuranceTypes[$key]) && !is_null($insuranceTypes[$key])) ? $insuranceTypes[$key] : null,
                            'insurance_vendor' => (isset($insuranceVendors[$key]) && !is_null($insuranceVendors[$key])) ? $insuranceVendors[$key] : null,
                            'policy_number' => (isset($policyNumbers[$key]) && !is_null($policyNumbers[$key])) ? $policyNumbers[$key] : null,
                            'value' => (isset($values[$key]) && !is_null($values[$key])) ? $values[$key] : null,
                            'date_added' => (isset($datesAdded[$key]) && !is_null($datesAdded[$key])) ? $datesAdded[$key] : null,
                            'expiration_date' => (isset($expirationDates[$key]) && !is_null($expirationDates[$key])) ? $expirationDates[$key] : null,
                        ]);
                    }

                    if(isset($input['dummy_id']) && !is_null($input['dummy_id']) && $input['dummy_id'] != $truckId){
                        $dummyloadid = $input['dummy_id'];
                        Gallery::where('action_id', $dummyloadid)->update(['action_id' => $truckId]);
                    }
                }
            }else if($section === '2'){
                $isExists = TruckAdditionalInsurance::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->count();

                if($isExists > 0){
                    TruckAdditionalInsurance::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->delete();
                }

                if(isset($input['insurance_type'])){
                    $insuranceTypes = $input['insurance_type'];
                    $insuranceVendors = $input['insurance_vendor'];
                    $policyNumbers = $input['policy_number'];
                    $values = $input['value'];
                    $datesAdded = $input['date_added'];
                    $expirationDates = $input['expiration_date'];

                    foreach ($insuranceTypes as $key => $value){
                        TruckAdditionalInsurance::create([
                            'company_id' => $truckCompanyId,
                            'truck_id' => $truckId,
                            'insurance_type' => (isset($insuranceTypes[$key]) && !is_null($insuranceTypes[$key])) ? $insuranceTypes[$key] : null,
                            'insurance_vendor' => (isset($insuranceVendors[$key]) && !is_null($insuranceVendors[$key])) ? $insuranceVendors[$key] : null,
                            'policy_number' => (isset($policyNumbers[$key]) && !is_null($policyNumbers[$key])) ? $policyNumbers[$key] : null,
                            'value' => (isset($values[$key]) && !is_null($values[$key])) ? $values[$key] : null,
                            'date_added' => (isset($datesAdded[$key]) && !is_null($datesAdded[$key])) ? $datesAdded[$key] : null,
                            'expiration_date' => (isset($expirationDates[$key]) && !is_null($expirationDates[$key])) ? $expirationDates[$key] : null,
                        ]);
                    }

                    if(isset($input['dummy_id']) && !is_null($input['dummy_id']) && $input['dummy_id'] != $truckId){
                        $dummyloadid = $input['dummy_id'];
                        Gallery::where('action_id', $dummyloadid)->update(['action_id' => $truckId]);
                    }
                }
            }

            return response()->json(['success' => true, 'truckId' => $truck->id]);
        }else{
            return response()->json(['success' => false, 'msg' => 'Error, on save Truck Insurance']);
        }
    }

    public function saveCompliance(Request $request)
    {
        $input = $request->all();

        $input['company_id'] = auth()->guard('company-admin')->user()->company_id;

        $input['apply_ifta'] = (isset($input['apply_ifta'])) ? $input['apply_ifta'] : '0';
        $input['apply_nyhut'] = (isset($input['apply_nyhut'])) ? $input['apply_nyhut'] : '0';
        $input['apply_kyu'] = (isset($input['apply_kyu'])) ? $input['apply_kyu'] : '0';
        $input['apply_new_mexico'] = (isset($input['apply_new_mexico'])) ? $input['apply_new_mexico'] : '0';
        $input['apply_oregon'] = (isset($input['apply_oregon'])) ? $input['apply_oregon'] : '0';

        if(!is_null($input['truck_id'])){
            $truck = Truck::updateOrCreate(['id' => $input['truck_id'], 'company_id' => auth()->guard('company-admin')->user()->company_id], $input);

            if($truck->wasChanged()){
                if(isset($truck->getChanges()['status'])){
                    $logdata = [];
                    $logdata['company_id'] = auth()->guard('company-admin')->user()->company_id;
                    $logdata['truck_id'] = $truck->id;
                    $logdata['status_id'] = $request->status;
                    TruckStatusLog::create($logdata);
                }
            }

            if(!is_null($input['dummy_id']) && isset($input['dummy_id']) && $input['dummy_id'] != $input['truck_id']){
                $dummyloadid = $input['dummy_id'];
                Gallery::where('action_id', $dummyloadid)->update(['action_id' => $truck->id]);
            }

            if($truck){
                return response()->json(['success' => true, 'msg' => 'Truck Compliance saved successfully', 'truckId' => $truck->id]);
            }else{
                return response()->json(['success' => false, 'msg' => 'Error, on save Truck Compliance']);
            }
        }else{
            return response()->json(['success' => false, 'msg' => 'Error, on save Truck Compliance']);
        }
    }

    public function pmServiceProfile(Request $request)
    {
        if(isset($request->pmServiceProfile) && isset($request->pmTypes)){
            $pmServiceProfile = $request->pmServiceProfile;
            $pmTypes = unserialize(base64_decode($request->pmTypes));
            $pmServiceTypes = unserialize(base64_decode($request->pmServiceTypes));
            $pmIntervalTypes = unserialize(base64_decode($request->pmIntervalTypes));
            $pmSchedules = unserialize(base64_decode($request->pmSchedules));

            $view = view('companyAdmin.truck.ajax-view.pm-service-profile', compact('pmServiceProfile', 'pmTypes', 'pmServiceTypes', 'pmIntervalTypes', 'pmSchedules'))->render();

            return response()->json(['success' => true, 'preViewHtml' => $view]);
        }else{
            $view = view('companyAdmin.truck.ajax-view.pm-service-profile')->render();

            return response()->json(['success' => true, 'view' => $view]);
        }
    }

    public function addPmServiceProfile(Request $request)
    {
        $profileName = $request->profile_name;
        $types = serialize($request->types);
        $serviceTypes = serialize($request->service_type);
        $intervalTypes = serialize($request->interval_type);
        $schedules = serialize($request->schedule);

        $createPmServiceProfile = CompanyPmServiceProfile::create([
            'company_id' => auth()->guard('company-admin')->user()->company_id,
            'profile_name' => $profileName,
            'types' => $types,
            'service_types' => $serviceTypes,
            'interval_types' => $intervalTypes,
            'schedules' => $schedules,
        ]);

        if($createPmServiceProfile){
            $pmServiceProfileHtml = '<option value="" data-pm-types="">Select PM/Service Profile</option>';
            foreach(getCompanyPmServiceProfiles() as $pmServiceProfile){
                $pmServiceProfileHtml .= '<option value="'.$pmServiceProfile->id.'" data-pm-types="'.base64_encode($pmServiceProfile->types).'" data-pm-service-types="'.base64_encode($pmServiceProfile->service_types).'" data-pm-interval-types="'.base64_encode($pmServiceProfile->interval_types).'" data-pm-schedules="'.base64_encode($pmServiceProfile->schedules).'">'.$pmServiceProfile->profile_name.'</option>';
            }

            return response()->json(['success' => true, 'msg' => 'PM Maintenance & Service Profile saved successfully', 'pmServiceProfileHtml' => $pmServiceProfileHtml, 'new_profile_id' => $createPmServiceProfile->id]);
        }else{
            return response()->json(['success' => false, 'msg' => 'Error, on save PM Maintenance & Service']);
        }
    }

    public function pmServiceAdditional(Request $request)
    {
        $rowIndex = $request->rowIndex;
        $view = view('companyAdmin.truck.ajax-view.additional-pm-service', compact('rowIndex'))->render();

        return response()->json(['success' => true, 'view' => $view]);
    }

    public function addPmServiceWarrantyProfile(Request $request)
    {
        $profileName = $request->warranty_profile_name;
        $warrantyProvider = serialize($request->warranty_provider);

        $createPmServiceWarrantyProfile = CompanyPmServiceWarrantyProfile::create([
            'company_id' => auth()->guard('company-admin')->user()->company_id,
            'profile_name' => $profileName,
            'warranty_providers' => $warrantyProvider
        ]);

        if($createPmServiceWarrantyProfile){
            $pmServiceWarrantyProfileHtml = '<div class="col-md-3 warranty-pm-service-custom-grid">';
            $pmServiceWarrantyProfileHtml .= '<div class="form-group mb-1">';
            $pmServiceWarrantyProfileHtml .= '<div class="d-flex align-items-center">';
            $pmServiceWarrantyProfileHtml .= '<div class="mr-auto">';
            $pmServiceWarrantyProfileHtml .= '<label for="pm-service-profile pr-1">Warranty Profile</label>';
            $pmServiceWarrantyProfileHtml .= '</div>';
            $pmServiceWarrantyProfileHtml .= '<div class="d-flex">';
            $pmServiceWarrantyProfileHtml .= '<a href="javascript:void(0);" class="custom-top-label addWarranty">Add +</a>';
            $pmServiceWarrantyProfileHtml .= '</div>';
            $pmServiceWarrantyProfileHtml .= '</div>';
            $pmServiceWarrantyProfileHtml .= '<select class="form-control select2" id="pm-service-warranty-profile" name="pm_service_warranty_profile">';
            $pmServiceWarrantyProfileHtml .= '<option value="" data-warranty-providers="">Select Warranty Profile</option>';
            foreach(getCompanyPmServiceWarrantyProfiles() as $pmServiceWarrantyProfile){
                $pmServiceWarrantyProfileHtml .= '<option value="'.$pmServiceWarrantyProfile->id.'" data-warranty-providers="'.base64_encode($pmServiceWarrantyProfile->warranty_providers).'">'.$pmServiceWarrantyProfile->profile_name.'</option>';
            }
            $pmServiceWarrantyProfileHtml .= '</select>';
            $pmServiceWarrantyProfileHtml .= '</div>';
            $pmServiceWarrantyProfileHtml .= '</div>';

            return response()->json(['success' => true, 'msg' => 'Warranty Profile saved successfully', 'pmServiceWarrantyProfileHtml' => $pmServiceWarrantyProfileHtml, 'new_profile_id' => $createPmServiceWarrantyProfile->id]);
        }else{
            return response()->json(['success' => false, 'msg' => 'Error, on save Warranty Profile']);
        }
    }

    public function pmServiceWarranty(Request $request)
    {
        if(isset($request->pmServiceWarrantyProfile) && isset($request->pmServiceWarrantyProviders)){
            $pmServiceWarrantyProfile = $request->pmServiceWarrantyProfile;
            $pmServiceWarrantyProviders = unserialize(base64_decode($request->pmServiceWarrantyProviders));

            $view = view('companyAdmin.truck.ajax-view.warranty-pm-service', compact(['pmServiceWarrantyProfile', 'pmServiceWarrantyProviders']))->render();

            return response()->json(['success' => true, 'preViewHtml' => $view]);
        }else{
            $view = view('companyAdmin.truck.ajax-view.warranty-pm-service')->render();

            return response()->json(['success' => true, 'view' => $view]);
        }
    }

    public function savePmMaintenanceService(Request $request)
    {
        $input = $request->all();
        $section = $request->section;
        $truckId = $request->truck_id;

        if($truckId != ""){
            $truck = Truck::find($truckId);
            $truck->status =  $request->status; // Update Truck Status If changed
            $truck->save();

            if($truck->wasChanged()){
                if(isset($truck->getChanges()['status'])){
                    $logdata = [];
                    $logdata['company_id'] = auth()->guard('company-admin')->user()->company_id;
                    $logdata['truck_id'] = $truck->id;
                    $logdata['status_id'] = $request->status;
                    TruckStatusLog::create($logdata);
                }
            }

            $truckCompanyId = $truck->company_id;

            if($section == '1'){
                $isExists = TruckProfilePmService::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->count();

                if($isExists > 0){
                    TruckProfilePmService::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->delete();
                }

                $pmServiceProfile = $input['pm_service_profile'];

                if(isset($input['types'])){
                    $types = $input['types'];
                    $serviceTypes = $input['service_type'];
                    $intervalType = $input['interval_type'];
                    $schedules = $input['schedule'];
                    if($input['interval_type'] == "3"){
                        $dueDates = Carbon::parse($input['due_date'])->format('m/d/Y');
                        $lastPerformed = Carbon::parse($input['last_performed'])->format('m/d/Y');
                    }else{
                        $dueDates = $input['due_date'];
                        $lastPerformed = $input['last_performed'];
                    }

                    foreach ($types as $key => $value){
                        TruckProfilePmService::create([
                            'company_id' => $truckCompanyId,
                            'truck_id' => $truckId,
                            'pm_service_profile' => $pmServiceProfile,
                            'type' => (isset($types[$key]) && !is_null($types[$key])) ? $types[$key] : null,
                            'service_type' => (isset($serviceTypes[$key]) && !is_null($serviceTypes[$key])) ? $serviceTypes[$key] : null,
                            'interval_type' => (isset($intervalType[$key]) && !is_null($intervalType[$key])) ? $intervalType[$key] : null,
                            'schedule' => (isset($schedules[$key]) && !is_null($schedules[$key])) ? $schedules[$key] : null,
                            'due_date' => (isset($dueDates[$key]) && !is_null($dueDates[$key])) ? $dueDates[$key] : null,
                            'last_performed' => (isset($lastPerformed[$key]) && !is_null($lastPerformed[$key])) ? $lastPerformed[$key] : null,
                        ]);
                    }
                }
            }else if($section == '2'){
                $isExists = TruckAdditionalPmService::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->count();

                if($isExists > 0){
                    TruckAdditionalPmService::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->delete();
                }

                if(isset($input['types']) && count($input['types']) > 0){
                    $types = $input['types'];
                    $serviceTypes = $input['service_type'];
                    $intervalType = $input['interval_type'];
                    $schedules = $input['schedule'];
                    if($input['interval_type'] == "3"){
                        $dueDates = Carbon::parse($input['due_date'])->format('m/d/Y');
                        $lastPerformed = Carbon::parse($input['last_performed'])->format('m/d/Y');
                    }else{
                        $dueDates = $input['due_date'];
                        $lastPerformed = $input['last_performed'];
                    }

                    foreach ($types as $key => $value){
                        TruckAdditionalPmService::create([
                            'company_id' => $truckCompanyId,
                            'truck_id' => $truckId,
                            'type' => (isset($types[$key]) && !is_null($types[$key])) ? $types[$key] : null,
                            'service_type' => (isset($serviceTypes[$key]) && !is_null($serviceTypes[$key])) ? $serviceTypes[$key] : null,
                            'interval_type' => (isset($intervalType[$key]) && !is_null($intervalType[$key])) ? $intervalType[$key] : null,
                            'schedule' => (isset($schedules[$key]) && !is_null($schedules[$key])) ? $schedules[$key] : null,
                            'due_date' => (isset($dueDates[$key]) && !is_null($dueDates[$key])) ? $dueDates[$key] : null,
                            'last_performed' => (isset($lastPerformed[$key]) && !is_null($lastPerformed[$key])) ? $lastPerformed[$key] : null,
                        ]);
                    }
                }
            }else if($section == '3'){
                $isExists = TruckWarrantyPmService::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->count();

                if($isExists > 0){
                    TruckWarrantyPmService::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->delete();
                }

                $pmServiceWarrantyProfile = $input['pm_service_warranty_profile'] ?? '';

                if(isset($input['warranty_provider']) && count($input['warranty_provider']) > 0){
                    $warrantyProviders = $input['warranty_provider'];
                    $descriptions = $input['description'];
                    $types = $input['type'];
                    $terms = $input['term'];
                    if($input['type'] == "3"){
                        $warrantyStarts = Carbon::parse($input['warranty_start'])->format('m/d/Y');
                        $warrantyExps = Carbon::parse($input['warranty_start'])->format('m/d/Y');
                    }else{
                        $warrantyStarts = $input['warranty_start'];
                        $warrantyExps = $input['warranty_exp'];
                    }

                    foreach ($warrantyProviders as $key => $value){
                        TruckWarrantyPmService::create([
                            'company_id' => $truckCompanyId,
                            'truck_id' => $truckId,
                            'pm_service_warranty_profile' => $pmServiceWarrantyProfile,
                            'warranty_provider' => (isset($warrantyProviders[$key]) && !is_null($warrantyProviders[$key])) ? $warrantyProviders[$key] : null,
                            'description' => (isset($descriptions[$key]) && !is_null($descriptions[$key])) ? $descriptions[$key] : null,
                            'type' => (isset($types[$key]) && !is_null($types[$key])) ? $types[$key] : null,
                            'term' => (isset($terms[$key]) && !is_null($terms[$key])) ? $terms[$key] : null,
                            'warranty_start' => (isset($warrantyStarts[$key]) && !is_null($warrantyStarts[$key])) ? $warrantyStarts[$key] : null,
                            'warranty_exp' => (isset($warrantyExps[$key]) && !is_null($warrantyExps[$key])) ? $warrantyExps[$key] : null,
                        ]);
                    }
                }
            }

            return response()->json(['success' => true, 'truckId' => $truck->id]);
        }else{
            return response()->json(['success' => false, 'msg' => 'Error, on save PM Maintenance & Service']);
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(TruckStoreRequest $request){
        $input                                          = $request->all();

        $owner_type                                     = null;
        $owner_id                                       = null;
        if(isset($input['owner_id']) && !is_null($input['owner_id'])){
            $owner_arry                                 = array_filter(explode('_', $input['owner_id']));
            if(isset($owner_arry[0])){
                if($owner_arry[0]=='carriers'){
                    $owner_type                         = 1;
                    $owner_id                           = $owner_arry[1];
                }else{
                    $owner_type                         = 2;
                    $owner_id                           = $owner_arry[2];
                }
            }
        }
        $input['owner_type']                            = $owner_type;
        $input['owner_id']                              = $owner_id;

        $input['company_id']                            = auth()->guard('company-admin')->user()->company_id;

        if (isset($input['truck_image'])) {
            $input['truck_image']                       = FileUpload::upload('companyAdmin/truck', $input['truck_image']);
        }

        if($request->last_location_address_verified==0){
            $input['last_location_latitude']            = null;
            $input['last_location_longitude']           = null;
            $input['last_location_timezone']            = null;
            $input['last_location_timezone_offset']     = null;
            $input['last_location_timezone_abbr']       = null;
        }else{
            $last_location_timezone                     = null;
            $last_location_timezone_offset              = null;
            if(!is_null($input['last_location_timezone_abbr'])){
                $last_location_timezone                 = timezone_name_from_abbr($input['last_location_timezone_abbr']);
                $last_location_timezone_offset          = Carbon::createFromTimestamp(time(), $last_location_timezone)->getOffsetString();
            }
            $input['last_location_timezone']            = $last_location_timezone;
            $input['last_location_timezone_offset']     = $last_location_timezone_offset;
        }

        $truck                                          = Truck::create($input);

        if($truck->wasChanged()){
            if(isset($truck->getChanges()['status'])){
                $logdata = [];
                $logdata['company_id'] = auth()->guard('company-admin')->user()->company_id;
                $logdata['truck_id'] = $truck->id;
                $logdata['status_id'] = $request->status;
                TruckStatusLog::create($logdata);
            }
        }

        if(!is_null($input['dummy_truck_id']) && isset($input['dummy_truck_id'])){
            $dummyloadid                                = $input['dummy_truck_id'];
            Gallery::where('action_id', $dummyloadid)->update(['action_id' => $truck->id]);
        }

        $company_id                                     = auth()->guard('company-admin')->user()->company_id;
        $getAPIKey                                      = IntegrationSetting::where('company_id', $company_id)->where('carrier_id', $truck->carrier_id)->where('app_center_id', config('settings.app_id.samsara'))->where('sync_vehicles', '1')->first();

        if(isset($getAPIKey->api_key) && !empty($getAPIKey->api_key)){
            $samsara_api_key                            = $getAPIKey->api_key;
            $endCursor                                  = 0;
            return redirect()->route('company.admin.truck.sync.getsyncvehicles', ['samsara_api_key' => $samsara_api_key, 'endCursor' => $endCursor]);
        }else{
            notification('success', $this->crudMessage('create', 'Truck'));
            return redirect()->route('company.admin.trucks.index');
        }
    }

    /**
     * Display the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id){
        $truck                                          = Truck::find(base64Decode($id));

        $currentDate                                    = Carbon::now()->format('m/d/Y');

        $truck->trailer                                 = array_filter(explode(',', $truck->trailer));
        if(isset($truck->driver)){
            $truck->driver_samsara_info                 = getDriverSamsaraInfo($truck->driver_details);
        }
        if(isset($truck->co_driver)){
            $truck->co_driver_samsara_info              = getDriverSamsaraInfo($truck->co_driver_details);
        }
        $truckLastLocation                              = getTruckLastLocation($truck);

        $ownersDetails                                  = [];
        if($truck->ownership != ""){
            if(in_array($truck->ownership, ['0', '3'])) {
                if($truck->ownership_id != ""){
                    if($truck->ownership == '3'){
                        $ownder                         = Driver::IsCompany()->findOrFail($truck->ownership_id);

                        $ownersDetails['owner_name']    = $ownder->fullname ?? '';
                        $ownersDetails['physical_address']  = concateAddress($ownder) ?? '';
                        $ownersDetails['phone']         = $ownder->cell_phone ?? '';
                        $ownersDetails['email']         = $ownder->email ?? '';
                    }else{
                        $ownder                         = Carrier::IsCompany()->findOrFail($truck->ownership_id);

                        $ownersDetails['owner_name']    = $ownder->name ?? '';
                        $ownersDetails['physical_address']  = concateAddress($ownder) ?? '';

                        if(isset($ownder->carrier_contacts) && count(array_filter($ownder->carrier_contacts->pluck('phone_number')->toArray())) > 0){
                            $ownersDetails['phone']     = implode(',', array_filter($ownder->carrier_contacts->pluck('phone_number')->toArray())) ?? '';
                        }else{
                            $ownersDetails['phone']     = '';
                        }

                        if(isset($ownder->carrier_contacts) && count(array_filter($ownder->carrier_contacts->pluck('email')->toArray())) > 0){
                            $ownersDetails['email']     = implode(',', array_filter($ownder->carrier_contacts->pluck('email')->toArray())) ?? '';
                        }else{
                            $ownersDetails['email']     = '';
                        }
                    }
                }else{
                    $ownersDetails['owner_name']        = '';
                    $ownersDetails['physical_address']  = '';
                    $ownersDetails['phone']             = '';
                    $ownersDetails['email']             = '';
                }
            } else {
                if(in_array($truck->ownership, ['1', '4'])){
                    if($truck->leasing_company != ""){
                        $ownder                         = Vendor::IsCompany()->findOrFail($truck->leasing_company);

                        $ownersDetails['owner_name']    = $ownder->name ?? '';
                        $ownersDetails['physical_address'] = concateAddress($ownder) ?? '';
                        $ownersDetails['phone']         = $ownder->phone ?? '';
                        $ownersDetails['email']         = $ownder->email ?? '';
                    }else{
                        $ownersDetails['owner_name']    = '';
                        $ownersDetails['physical_address'] = '';
                        $ownersDetails['phone']         = '';
                        $ownersDetails['email']         = '';
                    }
                }else{
                    if($truck->rental_company != ""){
                        $ownder                         = Vendor::IsCompany()->findOrFail($truck->rental_company);

                        $ownersDetails['owner_name']    = $ownder->name ?? '';
                        $ownersDetails['physical_address'] = concateAddress($ownder) ?? '';
                        $ownersDetails['phone']         = $ownder->phone ?? '';
                        $ownersDetails['email']         = $ownder->email ?? '';
                    }else{
                        $ownersDetails['owner_name']    = '';
                        $ownersDetails['physical_address'] = '';
                        $ownersDetails['phone']         = '';
                        $ownersDetails['email']         = '';
                    }
                }
            }
        }else{
            $ownersDetails['owner_name']                = '';
            $ownersDetails['physical_address']          = '';
            $ownersDetails['phone']                     = '';
            $ownersDetails['email']                     = '';
        }

        $getField                                       = '';
        $isCheck                                        = Bookmark::where('company_id',getUserCompnayId())->where('user_id', auth()->guard('company-admin')->user()->id)->where('user_type', auth()->guard('company-admin')->user()->type)->where('table_id','truck_view_loads')->first();
        if(!empty($isCheck->id)) {
            //$getField                                   = unserialize($isCheck->config);
            $getField                                   = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_truck_view_loads_first'));
        } else {
            $getField                                   = config('settings.table_truck_view_loads_first');
        }
        $tableName                                      = 'settings.table_truck_view_loads';

        $truckIntegrations                              = TruckIntegration::IsCompany()->where('truck_id', $truck->id)->get();
        $truckLifetimeEarnings                          = getLoadGrossRevenueBYTruck("", "", $truck->unit);

        $diagnostics                                    = Diagnostics::get(['id as diagnostic_id', 'diagnostic_key', 'diagnostic_name', 'is_disabled']);
        $truckDiagnostics                               = TruckDiagnostics::IsCompany()->where('truck_id', $truck->id)->orderBy('display_no', 'ASC')->get(['diagnostic_id', 'display_no', 'is_active']);

        $truckDiagnosticsData = []; $odometer = 0; $engineHours = 0;
        if($truck->samsara_id != ""){
            $truckDiagnosticsData                       = getTruckDiagnosticsData($truck);

            if($truckDiagnostics->count() > 0){
                foreach ($truckDiagnostics as $truckDiagnostic){
                    if($truckDiagnostic->diagnostic->diagnostic_key == "fuelPercents"){
                        $rowHtml                        = '';

                        $rowHtml                        .= '<div class="row align-items-center">';
                        $rowHtml                        .= '<div class="col-6">';
                        $rowHtml                        .= '<div class="progress">';
                        $rowHtml                        .= '<div class="progress-bar bg-success" role="progressbar" style="width: '.($truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['value'] ?? 0).'%" aria-valuenow="'.($truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['value'] ?? 0).'" aria-valuemin="0" aria-valuemax="100"></div>';
                        $rowHtml                        .= '</div>';
                        $rowHtml                        .= '</div>';
                        $rowHtml                        .= '<div class="col-6">';
                        $rowHtml                        .= '<p>'.($truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['value'] ?? '0').'%</p>';
                        $rowHtml                        .= '</div>';
                        $rowHtml                        .= '</div>';

                        $truckDiagnostic['value']       = $rowHtml;
                        $truckDiagnostic['timestamp']   = $truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['time'] ?? '';
                        $truckDiagnostic['isHtml']      = true;
                    }else if($truckDiagnostic->diagnostic->diagnostic_key == "defLevelMilliPercent"){
                        $rowHtml                        = '';

                        $rowHtml                        .= '<div class="row align-items-center">';
                        $rowHtml                        .= '<div class="col-6">';
                        $rowHtml                        .= '<div class="progress">';
                        $rowHtml                        .= '<div class="progress-bar bg-warning" role="progressbar" style="width: '.($truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['value'] ?? 0).'%" aria-valuenow="'.($truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['value'] ?? 0).'" aria-valuemin="0" aria-valuemax="100"></div>';
                        $rowHtml                        .= '</div>';
                        $rowHtml                        .= '</div>';
                        $rowHtml                        .= '<div class="col-6">';
                        $rowHtml                        .= '<p>'.($truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['value'] ?? '0').'%</p>';
                        $rowHtml                        .= '</div>';
                        $rowHtml                        .= '</div>';

                        $truckDiagnostic['value']       = $rowHtml;
                        $truckDiagnostic['timestamp']   = $truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['time'] ?? '';
                        $truckDiagnostic['isHtml']      = true;
                    }else{
                        $truckDiagnostic['value']       = $truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['value'] ?? '';
                        $truckDiagnostic['timestamp']   = $truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['time'] ?? '';
                        $truckDiagnostic['isHtml']      = false;
                    }
                }
            }else{
                foreach ($diagnostics as $diagnostic){
                    if($diagnostic->diagnostic_key == "fuelPercents"){
                        $rowHtml                        = '';

                        $rowHtml                        .= '<div class="row align-items-center">';
                        $rowHtml                        .= '<div class="col-6">';
                        $rowHtml                        .= '<div class="progress">';
                        $rowHtml                        .= '<div class="progress-bar bg-success" role="progressbar" style="width: '.($truckDiagnosticsData[$diagnostic->diagnostic_key]['value'] ?? 0).'%" aria-valuenow="'.($truckDiagnosticsData[$diagnostic->diagnostic_key]['value'] ?? 0).'" aria-valuemin="0" aria-valuemax="100"></div>';
                        $rowHtml                        .= '</div>';
                        $rowHtml                        .= '</div>';
                        $rowHtml                        .= '<div class="col-6">';
                        $rowHtml                        .= '<p>'.($truckDiagnosticsData[$diagnostic->diagnostic_key]['value'] ?? '0').'%</p>';
                        $rowHtml                        .= '</div>';
                        $rowHtml                        .= '</div>';

                        $diagnostic['value']            = $rowHtml;
                        $diagnostic['timestamp']        = $truckDiagnosticsData[$diagnostic->diagnostic_key]['time'] ?? '';
                        $diagnostic['isHtml']           = true;
                    }else if($diagnostic->diagnostic_key == "defLevelMilliPercent"){
                        $rowHtml                        = '';

                        $rowHtml                        .= '<div class="row align-items-center">';
                        $rowHtml                        .= '<div class="col-6">';
                        $rowHtml                        .= '<div class="progress">';
                        $rowHtml                        .= '<div class="progress-bar bg-warning" role="progressbar" style="width: '.($truckDiagnosticsData[$diagnostic->diagnostic_key]['value'] ?? 0).'%" aria-valuenow="'.($truckDiagnosticsData[$diagnostic->diagnostic_key]['value'] ?? 0).'" aria-valuemin="0" aria-valuemax="100"></div>';
                        $rowHtml                        .= '</div>';
                        $rowHtml                        .= '</div>';
                        $rowHtml                        .= '<div class="col-6">';
                        $rowHtml                        .= '<p>'.($truckDiagnosticsData[$diagnostic->diagnostic_key]['value'] ?? '0').'%</p>';
                        $rowHtml                        .= '</div>';
                        $rowHtml                        .= '</div>';

                        $diagnostic['value']            = $rowHtml;
                        $diagnostic['timestamp']        = $truckDiagnosticsData[$diagnostic->diagnostic_key]['time'] ?? '';
                        $diagnostic['isHtml']           = true;
                    }else{
                        $diagnostic['value']            = $truckDiagnosticsData[$diagnostic->diagnostic_key]['value'] ?? '';
                        $diagnostic['timestamp']        = $truckDiagnosticsData[$diagnostic->diagnostic_key]['time'] ?? '';
                        $diagnostic['isHtml']           = false;
                    }
                }
            }

            if(isset($truckDiagnosticsData['obdOdometerMeters'])){
                $odometer                               = $truckDiagnosticsData['obdOdometerMeters']['original_value'] ?? '';
            }
            if(isset($truckDiagnosticsData['obdOdometerMeters'])){
                $engineHours                            = $truckDiagnosticsData['obdEngineSeconds']['original_value'] ?? '';
            }
        }

        $driverHosViolations = []; $driverNonViolations = []; $driverAccidents = []; $driverHosViolationsCheckCitations = [];
        if($truck->driver_details){
            $driverHosViolations                        = $truck->driver_details->driver_hos_violations()->latest()->take(3)->get();
            $driverNonViolations                        = $truck->driver_details->driver_non_violations()->latest()->take(3)->get();
            $driverAccidents                            = $truck->driver_details->driver_accidents()->latest()->take(3)->get();
            $driverHosViolationsCheckCitations          = DriverHosViolation::join('driver_hos_violations_datas as dhvd', function ($join) {
                $join->on('driver_hos_violations.id', '=', 'dhvd.driver_hos_violation_id')->whereIn('dhvd.unit_type', [2,3]);
            })->where('driver_hos_violations.driver_id', $truck->driver)->groupBy('driver_hos_violations.id')->select('driver_hos_violations.*')->get();
        }

        $truck->restricted_states                       = json_encode($truck->truck_restricted_states()->pluck('state_id')->toArray());
        $truck->avoid_states                            = json_encode($truck->truck_avoid_states()->pluck('state_id')->toArray());

        $truckGalleries                                 = $truck->galleries->toArray();
        $existingTruckDocuments                         = array_column($truckGalleries, 'field_name');
        return view('companyAdmin.truck.show', compact('truck', 'currentDate', 'truckLastLocation', 'ownersDetails', 'getField', 'tableName', 'truckIntegrations', 'truckLifetimeEarnings', 'diagnostics', 'truckDiagnostics', 'truckDiagnosticsData', 'driverHosViolations', 'driverHosViolationsCheckCitations', 'driverAccidents', 'driverNonViolations', 'truckGalleries', 'existingTruckDocuments', 'odometer', 'engineHours'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    /*
    public function edit($id){
        $truck                          = Truck::find(base64Decode($id));
        if($truck){
            $currentLoad                = $truck->load_details()->latest('created_at')->first();
            if(!is_null($currentLoad)){
                $truck->current_load    = $currentLoad;
            }else{
                $truck->current_load    = null;
            }
        }
        return view('companyAdmin.truck.edit', compact('truck'));
    }
    */

    public function edit($id){
        

        $truck = Truck::find(base64Decode($id));
        $truck->trailer = array_filter(explode(',', $truck->trailer));

        $truckProfileInsurance = TruckProfileInsurance::where('company_id', $truck->company_id)->where('truck_id', $truck->id)->orderBy('id')->get();
        $truck->truckProfileInsurance = (count($truckProfileInsurance) > 0) ? $truckProfileInsurance : null;

        $truckAdditionalInsurance = TruckAdditionalInsurance::where('company_id', $truck->company_id)->where('truck_id', $truck->id)->orderBy('id')->get();
        $truck->truckAdditionalInsurance = (count($truckAdditionalInsurance) > 0) ? $truckAdditionalInsurance : null;

        /*
        $ownerIds = explode(',', $truck->owner_id);
        if(count($ownerIds) > 1){
            $truck->owner_id = explode(',', $truck->owner_id);
        }
        $leasingCompanyIds = explode(',', $truck->leasing_company);
        if(count($leasingCompanyIds) > 1){
            $truck->leasing_company = explode(',', $truck->leasing_company);
        }
        $rentalCompanyIds = explode(',', $truck->rental_company);
        if(count($rentalCompanyIds) > 1){
            $truck->rental_company = explode(',', $truck->rental_company);
        }
        */

        $truckProfilePmServices = TruckProfilePmService::where('company_id', $truck->company_id)->where('truck_id', $truck->id)->orderBy('id')->get();
        $truck->truckProfilePmServices = (count($truckProfilePmServices) > 0) ? $truckProfilePmServices : null;

        $truckAdditionalPmService = TruckAdditionalPmService::where('company_id', $truck->company_id)->where('truck_id', $truck->id)->orderBy('id')->get();
        $truck->truckAdditionalPmService = (count($truckAdditionalPmService) > 0) ? $truckAdditionalPmService : null;

        $truckWarrantyPmServices = TruckWarrantyPmService::where('company_id', $truck->company_id)->where('truck_id', $truck->id)->orderBy('id')->get();
        $truck->truckWarrantyPmServices = (count($truckWarrantyPmServices) > 0) ? $truckWarrantyPmServices : null;

        $truckIntegrations = TruckIntegration::IsCompany()->where('truck_id', $truck->id)->get();

        $truckProfileEquipments = TruckProfileEquipment::where('company_id', $truck->company_id)->where('truck_id', $truck->id)->orderBy('id')->get();
        $truck->truckProfileEquipments = (count($truckProfileEquipments) > 0) ? $truckProfileEquipments : null;

        $truckAdditionalEquipments = TruckAdditionalEquipment::where('company_id', $truck->company_id)->where('truck_id', $truck->id)->orderBy('id')->get();
        $truck->truckAdditionalEquipments = (count($truckAdditionalEquipments) > 0) ? $truckAdditionalEquipments : null;

        $truck->restricted_states = json_encode($truck->truck_restricted_states()->pluck('state_id')->toArray());
        $truck->avoid_states = json_encode($truck->truck_avoid_states()->pluck('state_id')->toArray());

        $truckProfileDocuments = TruckProfileDocument::where('company_id', $truck->company_id)->where('truck_id', $truck->id)->orderBy('id')->get();
        $truck->truckProfileDocuments = (count($truckProfileDocuments) > 0) ? $truckProfileDocuments : null;

        $truckAdditionalDocuments = TruckAdditionalDocument::where('company_id', $truck->company_id)->where('truck_id', $truck->id)->orderBy('id')->get();
        $truck->truckAdditionalDocuments = (count($truckAdditionalDocuments) > 0) ? $truckAdditionalDocuments : null;

        $assignedTrailers = Trailer::IsCompany()->whereNotNull('current_assigned_truck')->pluck('trailer_id')->all();

        $getAPIKey = IntegrationSetting::where('company_id', $truck->company_id)->where('carrier_id', $truck->carrier_id)->where('app_center_id', config('settings.app_id.samsara'))->where('sync_vehicles', '1')->first();

        return view('companyAdmin.truck.create', compact('truck', 'truckIntegrations', 'assignedTrailers', 'getAPIKey'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(TruckUpdateRequest $request, Truck $truck){
        $input                                          = $request->all();

        $owner_type                                     = null;
        $owner_id                                       = null;
        if(isset($input['owner_id']) && !is_null($input['owner_id'])){
            $owner_arry                                 = array_filter(explode('_', $input['owner_id']));
            if(isset($owner_arry[0])){
                if($owner_arry[0]=='carriers'){
                    $owner_type                         = 1;
                    $owner_id                           = $owner_arry[1];
                }else{
                    $owner_type                         = 2;
                    $owner_id                           = $owner_arry[2];
                }
            }
        }
        $input['owner_type']                            = $owner_type;
        $input['owner_id']                              = $owner_id;
        if (isset($input['truck_image'])) {
            $input['truck_image']                       = FileUpload::upload('companyAdmin/truck', $input['truck_image']);
        }

        if($request->last_location_address_verified==0){
            $input['last_location_latitude']            = null;
            $input['last_location_longitude']           = null;
            $input['last_location_timezone']            = null;
            $input['last_location_timezone_offset']     = null;
            $input['last_location_timezone_abbr']       = null;
        }else{
            $last_location_timezone                     = null;
            $last_location_timezone_offset              = null;
            if(!is_null($input['last_location_timezone_abbr'])){
                $last_location_timezone                 = timezone_name_from_abbr($input['last_location_timezone_abbr']);
                $last_location_timezone_offset          = Carbon::createFromTimestamp(time(), $last_location_timezone)->getOffsetString();
            }
            $input['last_location_timezone']            = $last_location_timezone;
            $input['last_location_timezone_offset']     = $last_location_timezone_offset;
        }

        $truck->update($input);

        notification('success', $this->crudMessage('update', 'Truck'));
        return redirect()->route('company.admin.trucks.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Truck $truck){
        $truck->delete();

        notification('success', $this->crudMessage('delete', 'Truck'));

        return redirect()->route('company.admin.trucks.index');
    }

    public function maintenanceView(Request $request){
        $getLog = TruckMaintenanceLog::where('truck_id',$request->id)->orderBy('id','desc')->get();
        $view   = view('companyAdmin.truck.log.view', compact('getLog'))->render();
        return response()->json(['view' => $view]);
    }

    public function maintenanceSave(Request $request){
        $input                          = $request->all();
        if(!empty($request->truck_id)){
            if($request->due_on == 'date'){
                $input['due_date']      = $request->due_date;
                $input['due_miles']     = null;
            }else{
                $input['due_date']      = null;
                $input['due_miles']     = $request->due_miles;
            }
            if($request->waranty_on == 'date'){
                $input['waranty_date']  = $request->waranty_date;
                $input['waranty_miles'] = null;
            }else{
                $input['waranty_date']  = null;
                $input['waranty_miles'] = $request->waranty_miles;
            }

            $getdata                    = TruckMaintenanceLog::create($input);

            if (!empty($request->myfile) && isset($request->myfile) && $request->myfile != 'undefined') {
                $input_file             = [];
                $input_file['truck_maintenance_log_id'] = $getdata->id;
                $input_file['name']     = $request->file_name;
                $input_file['file']     = FileUpload::upload('companyAdmin/truckfile', $request->myfile);
                TruckMaintenanceLogFile::create($input_file);
            }

            if (!empty($request->myfile1) && isset($request->myfile1) && $request->myfile1 != 'undefined') {
                $input_file             = [];
                $input_file['truck_maintenance_log_id'] = $getdata->id;
                $input_file['name']     = $request->file_name1;
                $input_file['file']     = FileUpload::upload('companyAdmin/truckfile', $request->myfile1);
                TruckMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile2) && !empty($request->myfile2) && $request->myfile2 != 'undefined') {
                $input_file             = [];
                $input_file['truck_maintenance_log_id'] = $getdata->id;
                $input_file['name']     = $request->file_name2;
                $input_file['file']     = FileUpload::upload('companyAdmin/truckfile', $request->myfile2);
                TruckMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile3) && !empty($request->myfile3) && $request->myfile3 != 'undefined') {
                $input_file             = [];
                $input_file['truck_maintenance_log_id'] = $getdata->id;
                $input_file['name']     = $request->file_name3;
                $input_file['file']     = FileUpload::upload('companyAdmin/truckfile', $request->myfile3);
                TruckMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile4) && !empty($request->myfile4) && $request->myfile4 != 'undefined') {
                $input_file             = [];
                $input_file['truck_maintenance_log_id'] = $getdata->id;
                $input_file['name']     = $request->file_name4;
                $input_file['file']     = FileUpload::upload('companyAdmin/truckfile', $request->myfile4);
                TruckMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile5) && !empty($request->myfile5) && $request->myfile5 != 'undefined') {
                $input_file             = [];
                $input_file['truck_maintenance_log_id'] = $getdata->id;
                $input_file['name']     = $request->file_name5;
                $input_file['file']     = FileUpload::upload('companyAdmin/truckfile', $request->myfile5);
                TruckMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile6) && !empty($request->myfile6) && $request->myfile6 != 'undefined') {
                $input_file             = [];
                $input_file['truck_maintenance_log_id'] = $getdata->id;
                $input_file['name']     = $request->file_name6;
                $input_file['file']     = FileUpload::upload('companyAdmin/truckfile', $request->myfile6);
                TruckMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile7) && !empty($request->myfile7) && $request->myfile7 != 'undefined') {
                $input_file             = [];
                $input_file['truck_maintenance_log_id'] = $getdata->id;
                $input_file['name']     = $request->file_name7;
                $input_file['file']     = FileUpload::upload('companyAdmin/truckfile', $request->myfile7);
                TruckMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile8) && !empty($request->myfile8) && $request->myfile8 != 'undefined') {
                $input_file             = [];
                $input_file['truck_maintenance_log_id'] = $getdata->id;
                $input_file['name']     = $request->file_name8;
                $input_file['file']     = FileUpload::upload('companyAdmin/truckfile', $request->myfile8);
                TruckMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile9) && !empty($request->myfile9) && $request->myfile9 != 'undefined') {
                $input_file             = [];
                $input_file['truck_maintenance_log_id'] = $getdata->id;
                $input_file['name']     = $request->file_name9;
                $input_file['file']     = FileUpload::upload('companyAdmin/truckfile', $request->myfile9);
                TruckMaintenanceLogFile::create($input_file);
            }
            if (isset($request->myfile10) && !empty($request->myfile10) && $request->myfile10 != 'undefined') {
                $input_file             = [];
                $input_file['truck_maintenance_log_id'] = $getdata->id;
                $input_file['name']     = $request->file_name10;
                $input_file['file']     = FileUpload::upload('companyAdmin/truckfile', $request->myfile10);
                TruckMaintenanceLogFile::create($input_file);
            }
            return 1;
        }
        return 0;
    }

    public function maintenanceIsCompleted($id){
        $getLog     = TruckMaintenanceLog::find($id);
        $save_array = [];
        if($getLog->is_completed == 0){
            $save_array['is_completed'] = 1;
        }else{
            $save_array['is_completed'] = 0;
        }
        $getLog->update($save_array);
        return 1;
    }

    public function destroyMaintenance($id){
        $getFile = TruckMaintenanceLog::find($id);
        foreach($getFile->Uploadfile as $Uploadfile){
            File::delete('storage/companyAdmin/truckfile/'.$Uploadfile->file);
        }
        $getFile->delete();
        return 1;
    }

    public function getTruckDetails(Request $request){
        $truck = Truck::find($request->truck_id);
        return response()->json($truck);
    }

    public function getTruckCurrentLocation(Request $request){
        $response['success']                = false;
        $response['message']                = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $truck                      = Truck::whereId($request->id)->first();
                if($truck){
                    $response['location']   = truckCurrentLocation($truck);
                    $response['success']    = true;
                    $response['message']    = "Locations retrieved successfully.";
                }else{
                    $response['success']    = false;
                    $response['message']    = "Truck not found.";
                }
            }catch (\Exception $e) {
                $response['success']        = false;
                $response['message']        = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function getSyncVehicles($samsara_api_key, $endCursor){
        $data               = '';
        $company_id         = auth()->guard('company-admin')->user()->company_id;
        if(!empty($samsara_api_key)){
            $client         = new \GuzzleHttp\Client();
            if(empty($endCursor)){
                $api_url    = 'https://api.samsara.com/fleet/vehicles?limit=100';
            }else{
                $api_url    = 'https://api.samsara.com/fleet/vehicles?limit=100&after='.$endCursor;
            }
            $response       = $client->request('GET', $api_url, [
                'headers'   => [
                    'Accept'        => 'application/json',
                    'Authorization' => 'Bearer '.$samsara_api_key,
                ],
            ]);
            $data           = json_decode($response->getBody());

            $endCursor      = $data->pagination->endCursor;
            $data           = $data->data;

            foreach($data as $vehicle){
                if(isset($vehicle->vin)){
                    $getVehicle                     = Truck::where('vin_number', $vehicle->vin)->where('company_id',$company_id)->first();
                    if(!empty($getVehicle->id)){
                        $vehicle_data               = [];
                        $vehicle_data['samsara_id'] = $vehicle->id;
                        $getVehicle->update($vehicle_data);
                    }
                }
            }

            if(!empty($endCursor)){
                return redirect()->route('company.admin.truck.sync.getsyncvehicles', ['samsara_api_key' => $samsara_api_key, 'endCursor' => $endCursor]);
            }else{
                notification('success', $this->crudMessage('create', 'Truck'));
                return redirect()->route('company.admin.trucks.index');
            }
        }
    }

    public function getUpdateDataVehicles(Request $request){
        $input              = $request->all();
        $company_id         = auth()->guard('company-admin')->user()->company_id;
        $getAPIKey          = IntegrationSetting::where('company_id', $company_id)->where('carrier_id', $request->carrier_id)->where('app_center_id', config('settings.app_id.samsara'))->where('sync_vehicles', '1')->first();
        $data               = '';
        $OdometerMeters     = '';
        $EngineSeconds      = '';
        if(!empty($getAPIKey->api_key)){
            $client         = new \GuzzleHttp\Client();
            $api_url        = 'https://api.samsara.com/fleet/vehicles/samsara.vin:'.$request->vin_number;
            $response       = $client->request('GET', $api_url, [
                'headers'   => [
                    'Accept'        => 'application/json',
                    'Authorization' => 'Bearer '.$getAPIKey->api_key,
                ],
            ]);
            $data           = $response->getBody();
            $data           = @json_decode($response->getBody());
            if($data->data->id){
                $client     = new \GuzzleHttp\Client();
                $api_url    = 'https://api.samsara.com/fleet/vehicles/stats?tagIds=460454&vehicleIds='.$data->data->id.'&types=obdEngineSeconds,obdOdometerMeters';
                $response   = $client->request('GET', $api_url, [
                    'headers'           => [
                        'Accept'        => 'application/json',
                        'Authorization' => 'Bearer '.$getAPIKey->api_key,
                    ],
                ]);
                $data2      = $response->getBody();
                $data2      = @json_decode($response->getBody());

                if(isset($data2->data[0]->obdOdometerMeters->value) && !empty($data2->data[0]->obdOdometerMeters->value)){
                    $meter          = $data2->data[0]->obdOdometerMeters->value;
                    $OdometerMeters = round($meter * 0.000621371192);
                }

                if(isset($data2->data[0]->obdEngineSeconds->value) && !empty($data2->data[0]->obdEngineSeconds->value)){
                    $EngineSeconds  = $data2->data[0]->obdEngineSeconds->value;
                    $hours          = floor($EngineSeconds / 3600);
                    $minutes        = floor(($EngineSeconds / 60) % 60);
                    $EngineSeconds  = $hours.'h '.$minutes.'m';
                }
            }
        }
        return ['data' => $data, 'OdometerMeters' => $OdometerMeters, 'EngineSeconds' => $EngineSeconds];
    }

    public function getRequestDocuments(Request $request){
        if ($request->ajax()) {
            $data = Gallery::isCompany()->where('source','trucks')->where('action_id',$request->id)->whereNotNull('requested_by')->orderBy('id', 'desc');
            return Datatables::of($data)
                ->editColumn('field_name', function($row){
                    return getRequestDocumentsList($row->field_name, 'field_name')['name'];
                })
                ->editColumn('approved_by', function($row){
                    return empty($row->approved_by) ? 'None' : getFullNameByid($row->approved_by, $row->approved_by_type) ;
                })
                ->editColumn('created_by', function($row){
                    return empty($row->created_by) ? 'None' : getFullNameByid($row->created_by, $row->created_by_type) ;
                })
                ->editColumn('access', function($row){
                    if($row->access == 1){
                        return 'Managers';
                    }
                    if($row->access == 3){
                        return 'Dispatchers';
                    }
                    if($row->access == 3){
                        return 'Drivers';
                    }
                    return 'All User';
                })
                ->editColumn('status', function($row){
                    if($row->status == 'pending'){
                        return '<span class="status-pending">Pending</span>';
                    }
                    if($row->status == 'approved'){
                        return '<span class="status-approved">Approved</span>';
                    }
                    if($row->status == 'review'){
                        return '<span class="status-review">Review</span>';
                    }
                })
                ->editColumn('requested_by', function($row){
                    return empty($row->requested_by) ? 'None' : getFullNameByid($row->requested_by, $row->requested_by_type) ;
                })
                ->addIndexColumn()
                ->addColumn('action', function($row){
                    $btn = '<a href="#"  class="gallary-edit mr-2" data-id="'.$row->action_id.'" data-source="trucks" data-field="'.$row->field_name.'" data-toggle="modal" data-target="#galleryModal"><img src="'.asset('theme/img/eye.png').'" alt=""></a>';
                    //$btn = '<a href="'.route('company.admin.request-documents.show', $row->id).'" class="mr-2"><img src="'.asset('theme/img/eye.png').'" alt=""></a>';
                    //$btn = $btn.' <a href="'.route('company.admin.request-documents.edit', $row->id).'" class="mr-4"><img src="'.asset('theme/img/edit-icon.png').'" alt=""></a>';
                    $btn = $btn.'<a href="'.route('company.admin.gallery.download.file',$row->id).'" class="mr-2"><img src="'.asset("theme/img/download-cloud.png").'" alt=""></a>';

                    $btn = $btn.' <a href="javascript:" class="destroy" data-action="'.route('company.admin.request-documents.destroy',$row->id).'" data-id="'.$row->id.'"><img src="'.asset('theme/img/delete-icon.png').'" alt=""></a>';
                    return $btn;
                })
                ->rawColumns(['action','field_name','approved_by','created_by','requested_by','status','access'])
                ->make(true);
        }
    }

    public function UpdateTruckImage(Request $request){
        $input                          = $request->all();
        $truck                          = Truck::find($request->truck_id);
        if (isset($input['truck_image'])) {
            $input['truck_image']       = FileUpload::upload('companyAdmin/truck', $input['truck_image']);
        }
        $truck->update($input);

        notification('success', $this->crudMessage('update', 'Truck'));
        return redirect()->back();
    }

    public function remvoeTruckImage($id){
        $input                          = [];
        $truck                          = Truck::find($id);
        $input['truck_image']           = null;
        $truck->update($input);

        notification('success', $this->crudMessage('Delete', 'Truck'));
        return redirect()->back();
    }

    public function getEldVinNumber(Request $request){
        $truck = Truck::find($request->truckId);

        if(!is_null($truck)){
            $vinNumber = (!is_null($truck->vin_number)) ? $truck->vin_number : '';

            return response()->json(['success' => true, 'vinNumber' => $vinNumber]);
        }else{
            return response()->json(['success' => false]);
        }
    }

    public function eldConnect(Request $request)
    {
        $truck = Truck::find($request->truckId);

        $company_id = auth()->guard('company-admin')->user()->company_id;

        if(!is_null($truck)){
            $eldProvider = $request->eldProvider;
            $vinNumber = $request->vinNumber;
            $eldId = '';
            $isConnected = 0;

            if($eldProvider == '3'){ // Samsara
                $eldId = (!is_null($truck->samsara_id)) ? $truck->samsara_id : '';

                if($eldId === ''){
                    $getAPIKey = IntegrationSetting::where('company_id', $company_id)->where('carrier_id', $truck->carrier_id)->where('app_center_id', config('settings.app_id.samsara'))->where('sync_vehicles', '1')->first();

                    $data = '';
                    if(!is_null($getAPIKey) && !is_null($getAPIKey->api_key)){
                        try {
                            $client = new \GuzzleHttp\Client(['verify' => false]);

                            $api_url = 'https://api.samsara.com/fleet/vehicles/samsara.vin:'.$vinNumber;

                            $response = $client->request('GET', $api_url, [
                                'headers' => [
                                    'Accept' => 'application/json',
                                    'Authorization' => 'Bearer '.$getAPIKey->api_key,
                                ],
                            ]);

                            $data = json_decode($response->getBody());

                            if(isset($data->data->id)) {
                                $isConnected = 1;
                                $eldId = $data->data->id;

                                $truck->samsara_id = $eldId;
                                $truck->save();

                                return response()->json(['success' => true, 'eldId' => $eldId, 'connected' => $isConnected]);
                            }else{
                                return response()->json(['success' => false, 'msg' => 'Vin number doesn\'t match with samsara registration.']);
                            }
                        }catch (\Exception $e) {
                            return response()->json(['success' => false, 'msg' => 'Vin number doesn\'t match with samsara registration.']);
                        }
                    }else{
                        return response()->json(['success' => false, 'msg' => 'Samsara API key doesn\'t found.']);
                    }
                }else{
                    $isConnected = '1';
                    return response()->json(['success' => true, 'eldId' => $eldId, 'connected' => $isConnected]);
                }
            }
        }else{
            return response()->json(['success' => false, 'msg' => 'Truck details doesn\'t found.']);
        }
    }

    public function getIntegrationView($truckId)
    {
        $truckIntegrations = TruckIntegration::IsCompany()->where('truck_id', $truckId)->get();

        return [
          'allIntegrations'  => view('companyAdmin.truck.ajax-view.all-Integrations', compact('truckIntegrations'))->render(),
          'connectedIntegrations'  => view('companyAdmin.truck.ajax-view.connected-Integrations', compact('truckIntegrations'))->render()
        ];
    }

    public function integrationSave(Request $request)
    {
        $input = $request->all();

        $input['company_id'] = auth()->guard('company-admin')->user()->company_id;
        $input['vin_number_auto_populate'] = (isset($input['vin_number_auto_populate'])) ? $input['vin_number_auto_populate'] : '0';

        $truckIntegration = TruckIntegration::create($input);

        if($truckIntegration){
            return response()->json(['success' => true, 'msg' => 'ELD Provider save successfully.', 'viewHtml' => $this->getIntegrationView($truckIntegration->truck_id)]);
        }else{
            return response()->json(['success' => false, 'msg' => 'Error on ELD Provider save.']);
        }
    }

    public function destroyIntegrations($id)
    {
        $deleteTruckIntegration = TruckIntegration::find($id);
        $truck = Truck::find($deleteTruckIntegration->truck_id);

        $deleteTruckIntegration->delete();

        if($deleteTruckIntegration){
            return response()->json(['success' => true, 'msg' => 'ELD Provider deleted successfully.', 'viewHtml' => $this->getIntegrationView($truck->id)]);
        }else{
            return response()->json(['success' => false, 'msg' => 'Error on delete ELD Provider.']);
        }
    }

    public function equipmentProfile(Request $request)
    {
        if(isset($request->equipmentProfile) && isset($request->equipmentTitles)){
            $equipmentProfile = $request->equipmentProfile;
            $equipmentTitles = array_filter(explode(',', $request->equipmentTitles));

            $view = view('companyAdmin.truck.ajax-view.equipment-profile', compact('equipmentProfile', 'equipmentTitles'))->render();

            return response()->json(['success' => true, 'preViewHtml' => $view]);
        }else{
            $view = view('companyAdmin.truck.ajax-view.equipment-profile')->render();

            return response()->json(['success' => true, 'view' => $view]);
        }
    }

    public function addEquipmentProfile(Request $request)
    {
        $profileName = $request->profile_name;
        $titles = (count(array_filter($request->titles)) > 0) ? implode(',', array_filter($request->titles)) : null;

        $createEquipmentProfile = CompanyEquipmentProfile::create([
            'company_id' => auth()->guard('company-admin')->user()->company_id,
            'profile_name' => $profileName,
            'titles' => $titles,
        ]);

        if($createEquipmentProfile){
            $equipmentProfileHtml = '<option value="" data-equipment-titles="">Select Equipment Profile</option>';
            foreach(getCompanyEquipmentProfiles() as $equipmentProfile){
                $equipmentProfileHtml .= '<option value="'.$equipmentProfile->id.'" data-equipment-titles="'.$equipmentProfile->titles.'">'.$equipmentProfile->profile_name.'</option>';
            }

            return response()->json(['success' => true, 'msg' => 'Equipment Profile saved successfully', 'equipmentProfileHtml' => $equipmentProfileHtml, 'new_profile_id' => $createEquipmentProfile->id]);
        }else{
            return response()->json(['success' => false, 'msg' => 'Error, on save Equipment Profile.']);
        }
    }

    public function equipmentAdditional(Request $request)
    {
        $rowIndex = $request->rowIndex;
        $view = view('companyAdmin.truck.ajax-view.additional-equipment', compact('rowIndex'))->render();

        return response()->json(['success' => true, 'view' => $view]);
    }

    public function saveEquipment(Request $request)
    {
        $input = $request->all();
        $section = $request->section;
        $truckId = $request->truck_id;

        if($truckId != ""){
            $truck = Truck::find($truckId);
            $truck->status =  $request->status; // Update Truck Status If changed
            $truck->save();

            if($truck->wasChanged()){
                if(isset($truck->getChanges()['status'])){
                    $logdata = [];
                    $logdata['company_id'] = auth()->guard('company-admin')->user()->company_id;
                    $logdata['truck_id'] = $truck->id;
                    $logdata['status_id'] = $request->status;
                    TruckStatusLog::create($logdata);
                }
            }

            $truckCompanyId = $truck->company_id;

            if($section == '1'){
                $isExists = TruckProfileEquipment::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->count();

                if($isExists > 0){
                    TruckProfileEquipment::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->delete();
                }

                $equipmentProfile = $input['equipment_profile'];

                if(isset($input['titles'])){
                    $titles = $input['titles'];
                    $qty = $input['qty'];
                    $value = $input['value'];
                    $description = $input['description'];
                    $enteredBy = $input['entered_by'];
                    $dateEntered = $input['date_entered'];

                    foreach ($titles as $key => $title){
                        TruckProfileEquipment::create([
                            'company_id' => $truckCompanyId,
                            'truck_id' => $truckId,
                            'equipment_profile' => $equipmentProfile,
                            'title' => (isset($titles[$key]) && !is_null($titles[$key])) ? $titles[$key] : null,
                            'qty' => (isset($qty[$key]) && !is_null($qty[$key])) ? $qty[$key] : null,
                            'value' => (isset($value[$key]) && !is_null($value[$key])) ? $value[$key] : null,
                            'description' => (isset($description[$key]) && !is_null($description[$key])) ? $description[$key] : null,
                            'entered_by' => (isset($enteredBy[$key]) && !is_null($enteredBy[$key])) ? $enteredBy[$key] : null,
                            'date_entered' => (isset($dateEntered[$key]) && !is_null($dateEntered[$key])) ? $dateEntered[$key] : null,
                        ]);
                    }
                }
            }else if($section == '2'){
                $isExists = TruckAdditionalEquipment::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->count();

                if($isExists > 0){
                    TruckAdditionalEquipment::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->delete();
                }

                if(isset($input['titles'])){
                    $titles = $input['titles'];
                    $qty = $input['qty'];
                    $value = $input['value'];
                    $description = $input['description'];
                    $enteredBy = $input['entered_by'];
                    $dateEntered = $input['date_entered'];

                    foreach ($titles as $key => $title){
                        TruckAdditionalEquipment::create([
                            'company_id' => $truckCompanyId,
                            'truck_id' => $truckId,
                            'title' => (isset($titles[$key]) && !is_null($titles[$key])) ? $titles[$key] : null,
                            'qty' => (isset($qty[$key]) && !is_null($qty[$key])) ? $qty[$key] : null,
                            'value' => (isset($value[$key]) && !is_null($value[$key])) ? $value[$key] : null,
                            'description' => (isset($description[$key]) && !is_null($description[$key])) ? $description[$key] : null,
                            'entered_by' => (isset($enteredBy[$key]) && !is_null($enteredBy[$key])) ? $enteredBy[$key] : null,
                            'date_entered' => (isset($dateEntered[$key]) && !is_null($dateEntered[$key])) ? $dateEntered[$key] : null,
                        ]);
                    }
                }
            }

            return response()->json(['success' => true, 'truckId' => $truck->id]);
        }else{
            return response()->json(['success' => false, 'msg' => 'Error, on save Equipment']);
        }
    }

    public function saveStateMap(Request $request)
    {
        $input = $request->all();

        if($request->truck_id != ''){
            $input['restricted_states'] = [];
            $input['states_to_avoid'] = [];

            foreach (json_decode($input['dataArr']) as $data){
                if ($data->value === ''){
                    $input['restricted_states'][] = $data->region;
                }else if($data->value === '1'){
                    $input['states_to_avoid'][] = $data->region;
                }
            }

            $truck = Truck::updateOrCreate(['id' => $request->truck_id, 'company_id' => auth()->guard('company-admin')->user()->company_id], ['status' => $input['status']]);

            if($truck->wasChanged()){
                if(isset($truck->getChanges()['status'])){
                    $logdata = [];
                    $logdata['company_id'] = auth()->guard('company-admin')->user()->company_id;
                    $logdata['truck_id'] = $truck->id;
                    $logdata['status_id'] = $request->status;
                    TruckStatusLog::create($logdata);
                }
            }

            if (!empty($input['restricted_states'])) {
                foreach ($input['restricted_states'] as $restrictedState) {
                    $rsIds[] = $restrictedState;
                    $rsExist = TruckRestrictedState::where('truck_id', $truck->id)->where('state_id', $restrictedState)->first();
                    if (is_null($rsExist)) {
                        TruckRestrictedState::create([
                            'truck_id' => $truck->id,
                            'state_id' => $restrictedState
                        ]);
                    }
                }
                TruckRestrictedState::where('truck_id', $truck->id)->whereNotIn('state_id', $rsIds)->delete();
            } else {
                TruckRestrictedState::where('truck_id', $truck->id)->delete();
            }

            if (!empty($input['states_to_avoid'])) {
                foreach ($input['states_to_avoid'] as $avoidState) {
                    $asIds[]                    = $avoidState;
                    $asExist                    = TruckAvoidState::where('truck_id', $truck->id)->where('state_id', $avoidState)->first();
                    if (is_null($asExist)) {
                        TruckAvoidState::create([
                            'truck_id'         => $truck->id,
                            'state_id'          => $avoidState
                        ]);
                    }
                }
                TruckAvoidState::where('truck_id', $truck->id)->whereNotIn('state_id', $asIds)->delete();
            } else {
                TruckAvoidState::where('truck_id', $truck->id)->delete();
            }

            if($truck){
                return response()->json(['success' => true, 'msg' => 'Truck State Map saved successfully', 'truckId' => $truck->id]);
            }else{
                return response()->json(['success' => false, 'msg' => 'Error, on save Truck State Map']);
            }
        }else{
            return response()->json(['success' => false, 'msg' => 'Error, on save Truck State Map']);
        }
    }

    public function stateListForMap(Request $request)
    {
        $states         = State::get();
        $data           = [];
        foreach ($states as $key => $state) {
            if (!is_null($request->restricted_states) && in_array($state->id, $request->restricted_states)) {
                $data[] = [$state->code, 2, $state->name, 'Block'];
            } elseif (!is_null($request->avoid_states) && in_array($state->id, $request->avoid_states)) {
                $data[] = [$state->code, 1, $state->name, 'Preferred'];
            } else {
                $data[] = [$state->code, 0, $state->name, 'Open'];
            }
        }
        return response()->json(['data' => $data]);
    }

    public function documentProfile(Request $request)
    {
        if(isset($request->documentProfile) && isset($request->documentTitles)){
            $documentProfile = $request->documentProfile;
            $documentTitles = array_filter(explode(',', $request->documentTitles));

            $view = view('companyAdmin.truck.ajax-view.document-profile', compact('documentProfile', 'documentTitles'))->render();

            return response()->json(['success' => true, 'preViewHtml' => $view]);
        }else{
            $view = view('companyAdmin.truck.ajax-view.document-profile')->render();

            return response()->json(['success' => true, 'view' => $view]);
        }
    }

    public function addDocumentProfile(Request $request)
    {
        $profileName = $request->profile_name;
        $titles = (count(array_filter($request->titles)) > 0) ? implode(',', array_filter($request->titles)) : null;

        $createDocumentProfile = CompanyDocumentProfile::create([
            'company_id' => auth()->guard('company-admin')->user()->company_id,
            'profile_name' => $profileName,
            'titles' => $titles,
        ]);

        if($createDocumentProfile){
            $documentProfileHtml = '<option value="" data-document-titles="">Select Document Profile</option>';
            foreach(getCompanyDocumentProfiles() as $documentProfile){
                $documentProfileHtml .= '<option value="'.$documentProfile->id.'" data-document-titles="'.$documentProfile->titles.'">'.$documentProfile->profile_name.'</option>';
            }

            return response()->json(['success' => true, 'msg' => 'Document Profile saved successfully', 'documentProfileHtml' => $documentProfileHtml, 'new_profile_id' => $createDocumentProfile->id]);
        }else{
            return response()->json(['success' => false, 'msg' => 'Error, on save Document Profile.']);
        }
    }

    public function documentAdditional(Request $request)
    {
        $rowIndex = $request->rowIndex;
        $dummyId = $request->dummyId;
        $view = view('companyAdmin.truck.ajax-view.additional-document', compact('rowIndex', 'dummyId'))->render();

        return response()->json(['success' => true, 'view' => $view]);
    }

    public function saveDocument(Request $request)
    {
        $input = $request->all();
        $section = $request->section;
        $truckId = $request->truck_id;

        if($truckId != ""){
            $truck = Truck::find($truckId);
            $truck->status =  $request->status; // Update Truck Status If changed
            $truck->save();

            if($truck->wasChanged()){
                if(isset($truck->getChanges()['status'])){
                    $logdata = [];
                    $logdata['company_id'] = auth()->guard('company-admin')->user()->company_id;
                    $logdata['truck_id'] = $truck->id;
                    $logdata['status_id'] = $request->status;
                    TruckStatusLog::create($logdata);
                }
            }

            $truckCompanyId = $truck->company_id;

            if($section == '1'){
                $isExists = TruckProfileDocument::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->count();

                if($isExists > 0){
                    TruckProfileDocument::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->delete();
                }

                $documentProfile = $input['document_profile'];

                if(isset($input['titles'])){
                    $titles = $input['titles'];
                    $dotRequired = $input['dot_required'];
                    $expDates = $input['exp_dates'];
                    $docTypes = $input['doc_types'];

                    foreach ($titles as $key => $title){
                        TruckProfileDocument::create([
                            'company_id' => $truckCompanyId,
                            'truck_id' => $truckId,
                            'document_profile' => $documentProfile,
                            'title' => (isset($titles[$key]) && !is_null($titles[$key])) ? $titles[$key] : null,
                            'dot_required' => (isset($dotRequired[$key]) && !is_null($dotRequired[$key])) ? $dotRequired[$key] : null,
                            'exp_date' => (isset($expDates[$key]) && !is_null($expDates[$key])) ? $expDates[$key] : null,
                            'doc_type' => (isset($docTypes[$key]) && !is_null($docTypes[$key])) ? $docTypes[$key] : null,
                        ]);
                    }

                    if(isset($input['dummy_id']) && !is_null($input['dummy_id']) && $input['dummy_id'] != $truckId){
                        $dummyloadid = $input['dummy_id'];
                        Gallery::where('action_id', $dummyloadid)->update(['action_id' => $truckId]);
                    }
                }
            }else if($section == '2'){
                $isExists = TruckAdditionalDocument::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->count();

                if($isExists > 0){
                    TruckAdditionalDocument::where('company_id', $truckCompanyId)->where('truck_id', $truckId)->delete();
                }

                if(isset($input['titles'])){
                    $titles = $input['titles'];
                    $dotRequired = $input['dot_required'];
                    $expDates = $input['exp_dates'];
                    $docTypes = $input['doc_types'];

                    foreach ($titles as $key => $title){
                        TruckAdditionalDocument::create([
                            'company_id' => $truckCompanyId,
                            'truck_id' => $truckId,
                            'title' => (isset($titles[$key]) && !is_null($titles[$key])) ? $titles[$key] : null,
                            'dot_required' => (isset($dotRequired[$key]) && !is_null($dotRequired[$key])) ? $dotRequired[$key] : null,
                            'exp_date' => (isset($expDates[$key]) && !is_null($expDates[$key])) ? $expDates[$key] : null,
                            'doc_type' => (isset($docTypes[$key]) && !is_null($docTypes[$key])) ? $docTypes[$key] : null,
                        ]);
                    }

                    if(isset($input['dummy_id']) && !is_null($input['dummy_id']) && $input['dummy_id'] != $truckId){
                        $dummyloadid = $input['dummy_id'];
                        Gallery::where('action_id', $dummyloadid)->update(['action_id' => $truckId]);
                    }
                }
            }

            return response()->json(['success' => true, 'truckId' => $truck->id]);
        }else{
            return response()->json(['success' => false, 'msg' => 'Error, on save Document']);
        }
    }

    public function updateProfileImage(Request $request)
    {
        $input = $request->all();

        if (isset($input['profile_image'])) {
            $truck = Truck::findOrFail($input['truck_id']);
            $truck->profile_image = FileUpload::upload('companyAdmin/truck', $input['profile_image']);
            $truck->profile_image_upload_by = auth()->guard('company-admin')->user()->id;
            $truck->profile_image_update_date = Carbon::now()->format('m/d/Y');
            $truck->save();

            if($truck){
                return response()->json(['type' => 'success', 'msg' => 'Profile Image updated successfully', 'url' => asset('storage/companyAdmin/truck/'.$truck->profile_image)]);
            }else{
                return response()->json(['type' => 'error', 'msg' => 'Error on update Profile Image']);
            }
        }else{
            return response()->json(['type' => 'error', 'msg' => 'Something went wrong!']);
        }
    }

    public function updateTruckStatus(Request $request)
    {
        $truck_id = $request->truck_id;
        $status = $request->status;

        $truck = Truck::find($truck_id);
        $truck->status = $status;
        $truck->save();

        if($truck->wasChanged()){
            if(isset($truck->getChanges()['status'])){
                $logdata = [];
                $logdata['company_id'] = auth()->guard('company-admin')->user()->company_id;
                $logdata['truck_id'] = $truck->id;
                $logdata['status_id'] = $request->status;
                TruckStatusLog::create($logdata);
            }
        }

        if($truck){
            return response()->json(['success' => true, 'message' => 'Truck Status updated successfully.']);
        }else{
            return response()->json(['success' => false, 'message' => 'Oops! Something went wrong..']);
        }
    }

    public function truckLastLocation(Request $request){
        $response['success']                    = false;
        $response['message']                    = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $truck                         = Truck::where('id', $request->id)->first();
                if(!is_null($truck)){
                    $response['data']           = getTruckLastLocation($truck);
                    $response['success']        = true;
                    $response['message']        = "Truck last location retrieved successfully.";
                }
            }catch (\Exception $e) {
                $response['success']            = false;
                $response['message']            = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function truckAttachTrailer(Request $request)
    {
        $input = $request->all();

        $truck = Truck::find($input['truck_id']);

        if(is_null($truck->trailer)){
            $truck->trailer = $input['trailer'];
            $truck->trailer_assign_date = $input['assign_date'];
            $truck->trailer_assign_by = $input['assign_by'];
            $truck->save();

            if($truck){
                $trailer = Trailer::IsCompany()->where('trailer_id', $input['trailer'])->first();
                $trailer->current_assigned_truck = $truck->id;
                $trailer->save();
            }
        }else{
            $existingTruckTrailers = array_filter(explode(',', $truck->trailer));

            if(!in_array($input['trailer'], $existingTruckTrailers)){
                $trailer = Trailer::IsCompany()->where('trailer_id', $input['trailer'])->first();
                $trailer->current_assigned_truck = $truck->id;
                $trailer->save();

                $existingTruckTrailers[] = $input['trailer'];

                $truck->trailer = (count($input['trailer']) > 1) ? implode(',', $input['trailer']) : $input['trailer'][0];
                $truck->trailer_assign_date = $input['assign_date'];
                $truck->trailer_assign_by = $input['assign_by'];
                $truck->save();
            }
        }

        return redirect()->route('company.admin.trucks.show', base64Encode($truck->id));
    }

    public function truckDropAttachTrailer(Request $request)
    {
        $input = $request->all();

        $trailerArray = [];
        if(isset($input['drop_location']) && !is_null($input['drop_location'])){
            $dropLocationDetails = CompanyDropLocation::find($input['drop_location']);

            $trailerArray['last_location_address'] = $dropLocationDetails->address;
            $trailerArray['last_location_address_2'] = $dropLocationDetails->address_2;
            $trailerArray['last_location_city'] = $dropLocationDetails->city;
            $trailerArray['last_location_state'] = $dropLocationDetails->state;
            $trailerArray['last_location_zip'] = $dropLocationDetails->zip;
            $trailerArray['last_location_latitude'] = $dropLocationDetails->latitude;
            $trailerArray['last_location_longitude'] = $dropLocationDetails->longitude;
            $trailerArray['last_location_timezone'] = $dropLocationDetails->timezone;
            $trailerArray['last_location_timezone_offset'] = $dropLocationDetails->timezone_offset;
            $trailerArray['last_location_timezone_abbr'] = $dropLocationDetails->timezone_abbr;
            $trailerArray['last_location_address_verified'] = $dropLocationDetails->address_verified;
        }else{
            if($input['address_verified'] == 1){
                $timezone                               = null;
                $timezone_offset                        = null;
                if(isset($input['timezone_abbr'])){
                    $timezone                           = timezone_name_from_abbr($input['timezone_abbr']);
                    $timezone_offset                    = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
                }
                $input['timezone']                      = $timezone;
                $input['timezone_offset']               = $timezone_offset;
            }else{
                $input['latitude']                      = null;
                $input['longitude']                     = null;
                $input['timezone']                      = null;
                $input['timezone_offset']               = null;
                $input['timezone_abbr']                 = null;
            }

            $trailerArray['last_location_address'] = $input['address'];
            $trailerArray['last_location_address_2'] = $input['address_2'];
            $trailerArray['last_location_city'] = $input['city'];
            $trailerArray['last_location_state'] = $input['state'];
            $trailerArray['last_location_zip'] = $input['zip'];
            $trailerArray['last_location_latitude'] = $input['latitude'];
            $trailerArray['last_location_longitude'] = $input['longitude'];
            $trailerArray['last_location_timezone'] = $input['timezone'];
            $trailerArray['last_location_timezone_offset'] = $input['timezone_offset'];
            $trailerArray['last_location_timezone_abbr'] = $input['timezone_abbr'];
            $trailerArray['last_location_address_verified'] = $input['address_verified'];
        }

        Trailer::IsCompany()->where('trailer_id', $input['current_trailer'])->update($trailerArray);

        if(!is_null($input['new_trailer'])){
            $truck = Truck::IsCompany()->find($input['truck_id']);

            $existingTruckTrailers = array_filter(explode(',', $truck->trailer));

            if(!in_array($input['new_trailer'], $existingTruckTrailers)){
                $currentTrailer = Trailer::IsCompany()->where('trailer_id', $input['current_trailer'])->first();
                $currentTrailer->current_assigned_truck = null;
                $currentTrailer->save();

                $newTrailer = Trailer::IsCompany()->where('trailer_id', $input['new_trailer'])->first();
                $newTrailer->current_assigned_truck = $truck->id;
                $newTrailer->save();

                if (in_array($input['current_trailer'], $existingTruckTrailers)) {
                    unset($existingTruckTrailers[array_search($input['current_trailer'], $existingTruckTrailers)]);
                }
                array_push($existingTruckTrailers, $input['new_trailer']);
                $existingTruckTrailers = array_values($existingTruckTrailers);

                $truck->trailer = (count($existingTruckTrailers) > 1) ? implode(',', $existingTruckTrailers) : $existingTruckTrailers[0];
                $truck->trailer_assign_date = $input['assign_date'];
                $truck->trailer_assign_by = $input['assign_by'];
                $truck->save();
            }
        }

        return redirect()->route('company.admin.trucks.show', base64Encode($input['truck_id']));
    }

    public function truckAssignDriverAndCoDriver(Request $request)
    {
        $input = $request->all();

        $truck = Truck::find($input['truck_id']);

        if(isset($input['driver']) && $input['driver'] != ""){
            $truck->driver = $input['driver'];
            $truck->driver_assign_date = $input['driver_assign_date'];
            $truck->driver_assign_by = $input['driver_assign_by'];
            $truck->save();

            if($truck->wasChanged()){
                if(isset($truck->getChanges()['status'])){
                    $logdata = [];
                    $logdata['company_id'] = auth()->guard('company-admin')->user()->company_id;
                    $logdata['truck_id'] = $truck->id;
                    $logdata['status_id'] = $request->status;
                    TruckStatusLog::create($logdata);
                }
            }

            if($truck){
                $driver = Driver::find($truck->driver);
                $driver->driver_information->update(['truck_number' => $truck->unit]);
            }
        }

        if(isset($input['co_driver']) && $input['co_driver'] != ""){
            $truck->co_driver = $input['co_driver'];
            $truck->co_driver_assign_date = $input['co_driver_assign_date'];
            $truck->co_driver_assign_by = $input['co_driver_assign_by'];
            $truck->save();

            if($truck){
                $coDriver = Driver::find($truck->co_driver);
                $coDriver->driver_information->update(['truck_number' => $truck->unit]);
            }
        }

        return redirect()->route('company.admin.trucks.show', base64Encode($truck->id));
    }

    public function getTruckUpcomingEvents(Request $request)
    {
        $truckId = $request->truck_id;
        $startDate = Carbon::parse($request->start_date);
        $endDate = Carbon::parse($request->end_date);

        $period = CarbonPeriod::create($startDate, $endDate);

        $getEvents = truckUpcomingEvents($truckId);

        $events = [];
        foreach ($getEvents as $eventData) {
            foreach ($period as $date) {
                if(@$date->between($eventData['start'], @$eventData['end'])) {
                    $events[] = $eventData;
                }
            }
        }

        if(count($events) > 0) {
            $events = array_unique($events, SORT_REGULAR);
            foreach($events as $key => $part) {
                $sort[$key] = strtotime($part['start']);
            }
            array_multisort($sort, SORT_DESC, $events);
        }

        $view = view('companyAdmin.truck.ajax-view.eventsView', compact('events'))->render();

        return response()->json(['eventList' => $view]);
    }

    public function getTrailerWarnings(Request $request)
    {
        $trailerId = $request->trailer_id;

        $trailer = Trailer::IsCompany()->where('trailer_id', $trailerId)->first();

        $servicesRepairsDue = '';
        if($trailer->next_service_date != ""){
            $now  = Carbon::now();
            $end  = Carbon::parse($trailer->next_service_date);

            if($now < $end){
                $servicesRepairsDue = $now->diffInDays($end);
            }
        }

        $warningViewHtml = '';

        if($servicesRepairsDue != ""){
            $warningViewHtml .= '<div class="row px-3">';
            $warningViewHtml .= '<div class="col-md-12">';
            $warningViewHtml .= '<div class="form-group">';
            $warningViewHtml .= '<h6>Services & Repairs Due</h6>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '<hr class="mt-0 mb-2" />';
            $warningViewHtml .= '<div class="row px-3">';
            $warningViewHtml .= '<div class="col-md-2"></div>';
            $warningViewHtml .= '<div class="col-md-5">';
            $warningViewHtml .= '<div class="form-group">';
            $warningViewHtml .= '<label>Services & Repairs Due:</label>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '<div class="col-md-3">';
            $warningViewHtml .= '<div class="form-group">';
            $warningViewHtml .= '<label>'.$servicesRepairsDue.' Days</label>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '<div class="col-md-2"></div>';
            $warningViewHtml .= '<div class="col-md-2"></div>';
            $warningViewHtml .= '<div class="col-md-5">';
            $warningViewHtml .= '<div class="form-group">';
            $warningViewHtml .= '<label>PM Service Due:</label>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '<div class="col-md-3">';
            $warningViewHtml .= '<div class="form-group">';
            $warningViewHtml .= '<label>-</label>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '<div class="col-md-2"></div>';
            $warningViewHtml .= '<div class="col-md-2"></div>';
            $warningViewHtml .= '<div class="col-md-5">';
            $warningViewHtml .= '<div class="form-group">';
            $warningViewHtml .= '<label>Warranty Expiration:</label>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '<div class="col-md-3">';
            $warningViewHtml .= '<div class="form-group">';
            $warningViewHtml .= '<label>-</label>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '<div class="col-md-2"></div>';
            $warningViewHtml .= '<div class="col-md-2"></div>';
            $warningViewHtml .= '<div class="col-md-5">';
            $warningViewHtml .= '<div class="form-group">';
            $warningViewHtml .= '<label>Repairs:</label>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '<div class="col-md-3">';
            $warningViewHtml .= '<div class="form-group">';
            $warningViewHtml .= '<label>-</label>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '</div>';
            $warningViewHtml .= '<div class="col-md-2"></div>';
            $warningViewHtml .= '</div>';
        }

        return response()->json(['warningView' => $warningViewHtml]);
    }

    public function getLoads(Request $request)
    {
        $getCompanyAdmin = auth()->guard('company-admin')->user();

        $getField = '';
        $isCheck = Bookmark::where('company_id', getUserCompnayId())->where('user_id', $getCompanyAdmin->id)->where('user_type', $getCompanyAdmin->type)->where('table_id', 'truck_view_loads')->first();
        if (!empty($isCheck->id)) {
            //$getField = unserialize($isCheck->config);
            $getField = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_truck_view_loads_first'));
        } else {
            $getField = config('settings.table_truck_view_loads_first');
        }

        if ($request->ajax()) {
            $startDate = $request->start_date;
            $endDate = $request->end_date;

            $data = LoadDetail::select('load_details.*', DB::raw('CONCAT(drivers.first_name," ",drivers.last_name) as driver'), 'drivers.cell_phone as phone_number', 'brokers.name as broker_name')
                ->leftJoin('drivers', 'load_details.driver_id', '=', 'drivers.id')
                ->leftJoin('brokers', 'load_details.brokerage_firm', '=', 'brokers.id')
                ->where('truck_number', $request->truck_number)
                ->whereNull('load_details.deleted_at')
                ->where(function ($query) use ($endDate, $startDate) {
                    $query->where(DB::raw('DATE_FORMAT(actual_shipper_date, "%Y-%m-%d")'), '<=', $endDate)
                        ->where(DB::raw('DATE_FORMAT(actual_delivery_date, "%Y-%m-%d")'), '>=', $startDate)
                        ->orWhere(DB::raw('DATE_FORMAT(actual_delivery_date, "%Y-%m-%d")'), $startDate)
                        ->orWhere(DB::raw('DATE_FORMAT(actual_shipper_date, "%Y-%m-%d")'), $endDate);
                })
                ->whereHas('loads', function ($q) {
                    $q->where('loads.company_id', auth()->guard('company-admin')->user()->company_id)->whereNull('loads.deleted_at');
                });

            // General filter code - start
            foreach ($getField as $key => $value) {
                $conditionReq = 'search_string_condition_' . $key;
                $sortReq = 'search_string_sort_' . $key;
                $conditionDateReq = 'search_date_condition_' . $key;
                $sortDateReq = 'search_date_sort_' . $key;
                $conditionStatusReq = 'search_status_condition_' . $key;
                $sortStatusReq = 'search_status_sort_' . $key;

                // String filter
                if (isset(request()->$conditionReq)) {
                    $typeReq = 'search_string_type_' . $key;
                    $type = request()->$typeReq;
                    if ($type == 'string') {
                        Common::getStringFilterResult($data, $key);
                    }
                }
                // String sort only
                if (isset(request()->$sortReq)) {
                    Common::sortStringFilter($data, $key);
                }

                // Status filter
                if (isset(request()->$conditionStatusReq) && request()->$conditionStatusReq == 1) {
                    Common::getStatusFilterResult($data, $key);
                }
                // Status sort only
                if (isset(request()->$sortStatusReq)) {
                    Common::sortStatusFilter($data, $key);
                }
            }

            $data->orderBy('load_id', 'DESC')->orderBy('id', 'ASC')->get();

            return Datatables::of($data)
                ->addIndexColumn()
                ->editColumn('load_number', function ($row) {
                    if ($row->is_disable == 0) {
                        if (in_array($row->load_type, ['0', '6'])) {
                            if ($row->load_type == 0) {
                                return '<a href="' . route('company.admin.loads.show', base64Encode($row->id)) . '" class="mr-1 load-edit-link">' . $row->load_number . '</a>';
                            } else {
                                return '<a href="' . route('company.admin.loads.show', base64Encode($row->id)) . '" class="mr-1 load-edit-link">' . getLoadTypeList()[$row->load_type] . '</a>';
                            }
                        } else {
                            return '<a href="' . route('company.admin.loads.edit', base64Encode($row->load_id)) . '" class="mr-1 load-edit-link">' . getLoadTypeList()[$row->load_type] . '</a>';
                        }
                    } else {
                        if ($row->load_type == 0) {
                            return '<a href="' . route('company.admin.loads.show', base64Encode($row->id)) . '" class="mr-1 load-edit-link">' . $row->load_number . '</a>';
                        } else {
                            return '<a href="' . route('company.admin.loads.show', base64Encode($row->id)) . '" class="mr-1 load-edit-link">' . getLoadTypeList()[$row->load_type] . '</a>';
                        }
                    }
                })
                ->filterColumn('driver', function ($query, $keyword) {
                    $query->whereHas('driver', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(drivers.first_name, ' ', drivers.last_name)"), 'LIKE', "%" . $keyword . "%");
                    });
                })
                ->filterColumn('broker_name', function ($query, $keyword) {
                    $query->whereHas('broker', function ($q) use ($keyword) {
                        $q->where("brokers.name", 'LIKE', "%" . $keyword . "%");
                    });
                })
                ->filterColumn('phone_number', function ($query, $keyword) {
                    $query->whereHas('driver', function ($q) use ($keyword) {
                        $q->where("drivers.cell_phone", 'LIKE', "%" . $keyword . "%");
                    });
                })
                ->addColumn('dispatcher', function ($row) {
                    return getLoadDispatcherName($row->booked_by);
                })
                ->filterColumn('dispatcher', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%" . $keyword . "%");
                    });
                })
                ->editColumn('shipper_location', function ($row) {
                    $html = [];
                    if ($row->shipper_address_one) {
                        $html[0] = $row->shipper_address_one;
                    }
                    if ($row->shipper_address_two) {
                        $html[1] = $row->shipper_address_two;
                    }
                    if ($row->shipper_city) {
                        $html[2] = $row->shipper_city;
                    }
                    if ($row->shipper_state) {
                        $html[3] = $row->shipper_state;
                    }
                    if ($row->shipper_zip) {
                        $html[4] = $row->shipper_zip;
                    }
                    if (count($html) == 0) {
                        return $row->shipper_location;
                    } else {
                        return implode(', ', $html);
                    }
                })
                ->editColumn('delivery_location', function ($row) {
                    $html = [];
                    if ($row->delivery_address_one) {
                        $html[0] = $row->delivery_address_one;
                    }
                    if ($row->delivery_address_two) {
                        $html[1] = $row->delivery_address_two;
                    }
                    if ($row->delivery_city) {
                        $html[2] = $row->delivery_city;
                    }
                    if ($row->delivery_state) {
                        $html[3] = $row->delivery_state;
                    }
                    if ($row->delivery_zip) {
                        $html[4] = $row->delivery_zip;
                    }
                    if (count($html) == 0) {
                        return $row->delivery_location;
                    } else {
                        return implode(', ', $html);
                    }
                })
                ->addColumn('status', function ($row) {
                    return getLoadStatus($row->load_status, $row->is_on_hold);
                })
                ->filterColumn('status', function ($query, $keyword) {
                    if (Str::contains('pending', Str::lower($keyword))) {
                        $query = $query->where('load_status', 0);
                    }
                    if (Str::contains('accepted', Str::lower($keyword))) {
                        $query = $query->where('load_status', 1);
                    }
                    if (Str::contains('preplaned', Str::lower($keyword))) {
                        $query = $query->where('load_status', 2);
                    }
                    if (Str::contains('confirmed', Str::lower($keyword))) {
                        $query = $query->where('load_status', 3);
                    }
                    if (Str::contains('in transit', Str::lower($keyword))) {
                        $query = $query->where('load_status', 4);
                    }
                    if (Str::contains('delivered', Str::lower($keyword))) {
                        $query = $query->where('load_status', 5);
                    }
                    if (Str::contains('ready to bill', Str::lower($keyword))) {
                        $query = $query->where('load_status', 6);
                    }
                    if (Str::contains('on hold', Str::lower($keyword))) {
                        $query = $query->where('load_status', 7);
                    }
                    if (Str::contains('complete', Str::lower($keyword))) {
                        $query = $query->where('load_status', 8);
                    }
                    if (Str::contains('cancelled', Str::lower($keyword))) {
                        $query = $query->where('load_status', 9);
                    }
                    return $query;
                })
                ->editColumn('total_bill', function ($row) {
                    return getPrice($row->total_bill);
                })
                ->editColumn('booked_by', function ($row) {
                    if ($row->booked_by == 0) {
                        return 'Self Dispatch';
                    } else {
                        return $row->dispatcher->full_name;
                    }
                })
                ->filterColumn('booked_by', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%" . $keyword . "%");
                    });
                })
                ->editColumn('trailer_type', function ($row) {
                    return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                })
                ->rawColumns(['load_number'])
                ->make(true);
        }
    }

    public function syncOdometer(Request $request)
    {
        $truck = Truck::find($request->truckId);

        if($truck->samsara_id != ''){
            $carrierId = (isset($truck->carrier_id)) ? $truck->carrier_id : '';

            if($carrierId != ''){
                $getAPIKey = IntegrationSetting::where('company_id', $truck->company_id)->where('carrier_id', $carrierId)->where('app_center_id', config('settings.app_id.samsara'))->where('sync_vehicles', '1')->first();

                if(isset($getAPIKey->api_key) && !empty($getAPIKey->api_key)){
                    $url                    = 'https://api.samsara.com/fleet/vehicles/stats?vehicleIds='.$truck->samsara_id.'&types=obdOdometerMeters';
                    $client                 = new \GuzzleHttp\Client(['verify' => false]);
                    $response               = $client->request('GET', $url, [
                        'headers'           => [
                            'Accept'        => 'application/json',
                            'Authorization' => 'Bearer '.$getAPIKey->api_key,
                        ],
                    ]);
                    // Check if response status code is OK (200)
                    if ($response->getStatusCode() == 200) {
                        $body = json_decode($response->getBody());
                        // Do something with the response body
                        if(isset($body)){
                            $data = isset($body->data[0])?$body->data[0]:null;
                            if(isset($data)){
                                $currentOdometer = "";
                                if(isset($data->obdOdometerMeters->value) && $data->obdOdometerMeters->value != ""){
                                    $currentOdometer = number_format(round($data->obdOdometerMeters->value * 0.000621371));
                                }
                                return response()->json(['type' => 'success', 'msg' => 'Truck Current Odometer synced successfully', 'odometer' => $currentOdometer]);
                            }
                        }
                    }
                }else{
                    return response()->json(['type' => 'error', 'msg' => 'EOBR Provider API key not found.']);
                }
            }
        }
        return response()->json(['type' => 'error', 'msg' => 'Something went wrong!']);
    }

    public function informationTabReports(Request $request)
    {
        $input = $request->all();

        $centPerMile = 0;

        $truck = Truck::findOrFail($input['truck_id']);
        $truckNumber = $truck->unit;
        $startDate = Carbon::parse($input['start_date'])->format('Y-m-d');
        $endDate = Carbon::parse($input['end_date'])->format('Y-m-d');

        $getLoadMileage = getLoadTotalMileageByTruck($startDate, $endDate, $truckNumber);
        $getLoadGrossRevenue = getLoadGrossRevenueBYTruck($startDate, $endDate, $truckNumber);

        if ($getLoadMileage > 0) {
            $centPerMile = round($getLoadGrossRevenue / $getLoadMileage, 2);
        }

        $loads = getLoadCountByTruckId($startDate, $endDate, $truckNumber); // Loads
        $milesPerGallon = '0'; // Miles Per Gallon
        $averageFuelDiscount = '$0.00'; // Average Fuel Discount
        $averageFuelCost = '$0.00'; // Average Fuel Cost (PPG)
        $totalMiles = number_format($getLoadMileage); // Total Miles
        $totalRevenue = getPrice($getLoadGrossRevenue); // Total Revenue
        $totalCpm = '$'.number_format($centPerMile, 2, '.', ','); // Total CPM

        return response()->json(['loads' => $loads, 'milesPerGallon' => $milesPerGallon, 'averageFuelDiscount' => $averageFuelDiscount, 'averageFuelCost' => $averageFuelCost, 'totalMiles' => $totalMiles, 'totalRevenue' => $totalRevenue, 'totalCpm' => $totalCpm]);
    }

    public function calculatePercentage($preVal, $currVal)
    {
        if($preVal > 0 && $currVal > 0){
            if($currVal > $preVal){
                $percentage = (abs($currVal - $preVal) / $preVal) * 100;
                return '<span class="blue"><img src="'.asset('theme/img/truck/top-arrow.svg').'" alt=""> '.round($percentage).'%</span>';
            }else if($currVal < $preVal){
                $percentage = (abs($preVal - $currVal) / $preVal) * 100;
                return '<span class="orange"><img src="'.asset('theme/img/truck/down-arrow.svg').'" alt=""> '.round($percentage).'%</span>';
            }else{
                return '<span>'.round(0).'%</span>';
            }
        }else{
            return '<span>'.round(0).'%</span>';
        }
    }

    public function loadsTabReports(Request $request)
    {
        $input = $request->all();

        $truck = Truck::findOrFail($input['truck_id']);
        $startDate = Carbon::parse($input['start_date'])->format('Y-m-d');
        $endDate = Carbon::parse($input['end_date'])->format('Y-m-d');

        $reportActiveLoad = '00'; $compareActiveLoad = ''; $reportReadyToBill = '00';  $compareReadyToBill = '';
        $reportDelivered = '00'; $compareDelivered = ''; $reportComplete = '00'; $compareComplete = '';
        $reportOnHold = '00'; $compareOnHold = ''; $reportCancelled = '00'; $compareCancelled = '';
        $reportAllLoads = '00'; $compareAllLoads = ''; $reportCargoClaims = '00'; $compareCargoClaims = '';

        $reportActiveLoad = truckTotalActiveLoads($startDate, $endDate, $truck->unit);
        $reportReadyToBill = truckTotalReadyToBillLoads($startDate, $endDate, $truck->unit);
        $reportDelivered = truckTotalDeliveredLoads($startDate, $endDate, $truck->unit);
        $reportComplete = truckTotalCompletedLoads($startDate, $endDate, $truck->unit);
        $reportOnHold = truckTotalOnHoldLoads($startDate, $endDate, $truck->unit);
        $reportCancelled = truckTotalCancelledLoads($startDate, $endDate, $truck->unit);
        $reportAllLoads = truckTotalLoads($startDate, $endDate, $truck->unit);
        $reportCargoClaims = truckCargoClaimsLoads($startDate, $endDate, $truck->unit);

        if($input['compare'] != ""){
            $compareStartDate = ""; $compareEndDate = "";

            /*
             * 1: Previous Period
             * 2: Previous Period Last Year
            */
            if($input['compare'] == '1'){
                $start = Carbon::parse($startDate);
                $end = Carbon::parse($endDate);
                $days = $start->diffInDays($end) + 1;

                $compareStartDate = Carbon::parse($input['start_date'])->subDays($days)->format('Y-m-d');
                $compareEndDate = Carbon::parse($input['end_date'])->subDays($days)->format('Y-m-d');
            }else if($input['compare'] == '2'){
                $start = Carbon::parse($startDate);
                $end = Carbon::parse($endDate);
                $days = $start->diffInDays($end) + 1;

                $compareStartDate = Carbon::parse($input['start_date'])->subYear(1)->format('Y-m-d');
                $compareEndDate = Carbon::parse($input['end_date'])->subYear(1)->format('Y-m-d');
            }

            $periodActiveLoad = truckTotalActiveLoads($compareStartDate, $compareEndDate, $truck->unit);
            $periodReadyToBill = truckTotalReadyToBillLoads($compareStartDate, $compareEndDate, $truck->unit);
            $periodDelivered = truckTotalDeliveredLoads($compareStartDate, $compareEndDate, $truck->unit);
            $periodComplete = truckTotalCompletedLoads($compareStartDate, $compareEndDate, $truck->unit);
            $periodOnHold = truckTotalOnHoldLoads($compareStartDate, $compareEndDate, $truck->unit);
            $periodCancelled = truckTotalCancelledLoads($compareStartDate, $compareEndDate, $truck->unit);
            $periodAllLoads = truckTotalLoads($compareStartDate, $compareEndDate, $truck->unit);
            $periodCargoClaims = truckCargoClaimsLoads($compareStartDate, $compareEndDate, $truck->unit);

            $compareActiveLoad = $this->calculatePercentage($periodActiveLoad, $reportActiveLoad);
            $compareReadyToBill = $this->calculatePercentage($periodReadyToBill, $reportReadyToBill);
            $compareDelivered = $this->calculatePercentage($periodDelivered, $reportDelivered);
            $compareComplete = $this->calculatePercentage($periodComplete, $reportComplete);
            $compareOnHold = $this->calculatePercentage($periodOnHold, $reportOnHold);
            $compareCancelled = $this->calculatePercentage($periodCancelled, $reportCancelled);
            $compareAllLoads = $this->calculatePercentage($periodAllLoads, $reportAllLoads);
            $compareCargoClaims = $this->calculatePercentage($periodCargoClaims, $reportCargoClaims);
        }

        return response()->json([
            'reportActiveLoad' => $reportActiveLoad, 'compareActiveLoad' => $compareActiveLoad,
            'reportReadyToBill' => $reportReadyToBill, 'compareReadyToBill' => $compareReadyToBill,
            'reportDelivered' => $reportDelivered, 'compareDelivered' => $compareDelivered,
            'reportComplete' => $reportComplete, 'compareComplete' => $compareComplete,
            'reportOnHold' => $reportOnHold, 'compareOnHold' => $compareOnHold,
            'reportCancelled' => $reportCancelled, 'compareCancelled' => $compareCancelled,
            'reportAllLoads' => $reportAllLoads, 'compareAllLoads' => $compareAllLoads,
            'reportCargoClaims' => $reportCargoClaims, 'compareCargoClaims' => $compareCargoClaims,
        ]);
    }

    public function diagnosticsData(Request $request)
    {
        if ($request->ajax()) {
            try {
                $truck = Truck::findOrFail($request->truck_id);
                $dataArray = json_decode($request->dataArr, true);

                foreach ($dataArray as $data){
                    $getTruckDiagnostic = TruckDiagnostics::IsCompany()->where('truck_id', $truck->id)->where('diagnostic_id', $data['diagnosticId'])->first();

                    if($getTruckDiagnostic){
                        $getTruckDiagnostic->diagnostic_id = $data['diagnosticId'];
                        $getTruckDiagnostic->display_no = $data['displayNo'];
                        $getTruckDiagnostic->is_active = ($data['isActive'] == '1') ? '1' : '0';
                        $getTruckDiagnostic->save();
                    }else{
                        $insertArray = [];
                        $insertArray['company_id'] = auth()->guard('company-admin')->user()->company_id;
                        $insertArray['truck_id'] = $truck->id;
                        $insertArray['diagnostic_id'] = $data['diagnosticId'];
                        $insertArray['display_no'] = $data['displayNo'];
                        $insertArray['is_active'] = ($data['isActive'] == '1') ? '1' : '0';

                        TruckDiagnostics::create($insertArray);
                    }
                }

                $activeTruckDiagnostics = TruckDiagnostics::IsCompany()->where('truck_id', $truck->id)->orderBy('display_no', 'ASC')->where('is_active', '1')->orderBy('display_no', 'ASC')->get(['diagnostic_id', 'display_no', 'is_active']);

                $truckDiagnosticsData = [];
                if($truck->samsara_id != ""){
                    $truckDiagnosticsData = getTruckDiagnosticsData($truck);

                    if($activeTruckDiagnostics->count() > 0){
                        foreach ($activeTruckDiagnostics as $truckDiagnostic){
                            if($truckDiagnostic->diagnostic->diagnostic_key == "fuelPercents"){
                                $rowHtml = '';

                                $rowHtml .= '<div class="row align-items-center">';
                                $rowHtml .= '<div class="col-6">';
                                $rowHtml .= '<div class="progress">';
                                $rowHtml .= '<div class="progress-bar bg-success" role="progressbar" style="width: '.($truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['value'] ?? 0).'%" aria-valuenow="'.($truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['value'] ?? 0).'" aria-valuemin="0" aria-valuemax="100"></div>';
                                $rowHtml .= '</div>';
                                $rowHtml .= '</div>';
                                $rowHtml .= '<div class="col-6">';
                                $rowHtml .= '<p>'.($truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['value'] ?? '0').'%</p>';
                                $rowHtml .= '</div>';
                                $rowHtml .= '</div>';

                                $truckDiagnostic['value'] = $rowHtml;
                                $truckDiagnostic['timestamp'] = $truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['time'] ?? '';
                                $truckDiagnostic['isHtml'] = true;
                            }else if($truckDiagnostic->diagnostic->diagnostic_key == "defLevelMilliPercent"){
                                $rowHtml = '';

                                $rowHtml .= '<div class="row align-items-center">';
                                $rowHtml .= '<div class="col-6">';
                                $rowHtml .= '<div class="progress">';
                                $rowHtml .= '<div class="progress-bar bg-warning" role="progressbar" style="width: '.($truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['value'] ?? 0).'%" aria-valuenow="'.($truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['value'] ?? 0).'" aria-valuemin="0" aria-valuemax="100"></div>';
                                $rowHtml .= '</div>';
                                $rowHtml .= '</div>';
                                $rowHtml .= '<div class="col-6">';
                                $rowHtml .= '<p>'.($truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['value'] ?? '0').'%</p>';
                                $rowHtml .= '</div>';
                                $rowHtml .= '</div>';

                                $truckDiagnostic['value'] = $rowHtml;
                                $truckDiagnostic['timestamp'] = $truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['time'] ?? '';
                                $truckDiagnostic['isHtml'] = true;
                            }else{
                                $truckDiagnostic['value'] = $truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['value'] ?? '';
                                $truckDiagnostic['timestamp'] = $truckDiagnosticsData[$truckDiagnostic->diagnostic->diagnostic_key]['time'] ?? '';
                                $truckDiagnostic['isHtml'] = false;
                            }
                        }
                    }
                }

                $updatedContent = '';
                foreach($activeTruckDiagnostics as $truckDiagnostic){
                    if($truckDiagnostic['is_active'] && $truckDiagnostic->diagnostic->is_disabled == '0') {
                        $updatedContent .= '<div class="row px-1 py-2 mx-0">';
                            $updatedContent .= '<div class="col-md-4">';
                                $updatedContent .= '<p>'.$truckDiagnostic->diagnostic->diagnostic_name.'</p>';
                                $updatedContent .= '</div>';
                            $updatedContent .= '<div class="col-md-4">';
                                if($truckDiagnostic->isHtml){
                                    $updatedContent .= $truckDiagnostic->value ?? '<p>-</p>';
                                }else{
                                    $updatedContent .= '<p>'.($truckDiagnostic->value ?? '-').'</p>';
                                }
                            $updatedContent .= '</div>';
                            $updatedContent .= '<div class="col-md-4">';
                                $updatedContent .= '<p>'.($truckDiagnostic->timestamp ?? '').'</p>';
                            $updatedContent .= '</div>';
                        $updatedContent .= '</div>';
                    }
                }

                if(!empty($updatedContent)){
                    $response['updatedContent'] = $updatedContent;
                    $response['success']  = true;
                    $response['message']  = "Diagnostics updated successfully.";
                }else{
                    $response['success'] = false;
                    $response['message'] = "Diagnostics record not found.";
                }
            } catch (\Exception $e) {
                $response['success'] = false;
                $response['message'] = $e->getMessage();
            }
            return response()->json($response);
        }else{
            return abort(404);
        }
    }
}
