<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Session;

use App\Models\CompanyAdmin;
use App\Models\TwoFactorSetting;

class TwoFactorAuthenticationController extends Controller
{
    public function index()
    {
        if(Session::has('companyAdmin-2fa')){
            return redirect()->route('company.admin.home');
        }

        $twoFactorSettings = TwoFactorSetting::IsCompanyAdmin()->first();
        return view('auth.two-factor.companyAdmin.index', compact('twoFactorSettings'));
    }

    public function verifyCode(Request $request)
    {
        $request->validate(
            ['two_factor_secret' => 'required'],
            ['two_factor_secret.required' => 'Please enter 2-factor verification code.']
        );

        $user               = auth()->guard('company-admin')->user();
        $userDetails        = CompanyAdmin::Company()->where('id', $user->id)->where('two_factor_secret', $request->two_factor_secret)->first();
        if (!is_null($userDetails)) {
            Session::put('companyAdmin-2fa', $user->id);

            // Check if the intended URL is set in the session
            $intendedUrl    = Session::has('company.url.intended') ? Session::get('company.url.intended', '/company-admin/home') : '/company-admin/home';
            Session::forget('company.url.intended'); // Clear the stored URL
            return redirect()->intended($intendedUrl); // return redirect()->route('company.admin.home');
        }
        return back()->with('error', 'You entered wrong code.');
    }

    public function resendCode(Request $request)
    {
        auth()->guard('company-admin')->user()->generateTwoFactorCode();
        return back()->with('success', 'We sent you code on your email.');
    }
}
