<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use App\Models\CompanyAdmin;
use App\Models\TwoFactorSetting;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Session;

class TwoFactorSettingController extends CompanyAdminController
{
    public function index()
    {
        $twoFactorSettings = TwoFactorSetting::IsCompanyAdmin()->first();

        return view('companyAdmin.twoFactorSetting.view', compact('twoFactorSettings'));
    }

    public function updateSettings(Request $request)
    {
        $user = auth()->guard('company-admin')->user();

        if($request->enableEmailVerify == '1' && is_null($user->email)){
            return response()->json(['success' => false, 'msg' => 'Please update email id in your profile']);
        }
        if($request->enableSmsVerify == '1' && is_null($user->cell_phone)){
            return response()->json(['success' => false, 'msg' => 'Please update phone number in your profile']);
        }
        if($request->enableSmsVerify == '1' && $user->sms == '0'){
            return response()->json(['success' => false, 'msg' => 'Please ask your company admin to enable SMS option for your user']);
        }

        $updateSettings = TwoFactorSetting::updateOrCreate([
            'company_id' => $user->company_id,
            'user_id' => $user->id,
            'user_type' => $user->type,
        ], [
            'enable_two_factor' => $request->enableTwoFactor,
            'enable_email_verify' => $request->enableEmailVerify,
            'enable_sms_verify' => $request->enableSmsVerify,
        ]);

        if($updateSettings){
            if($request->enableTwoFactor){
                Session::put('companyAdmin-2fa', $user->id);
            }else{
                Session::forget('companyAdmin-2fa');
            }
            return response()->json(['success' => true, 'msg' => 'Settings updated successfully']);
        }else{
            return response()->json(['success' => false, 'msg' => 'Something went wrong!']);
        }
    }
}
