<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;

use App\Http\Requests\CompanyAdmin\VendorStoreRequest;
use App\Http\Requests\CompanyAdmin\VendorUpdateRequest;

use App\Models\Vendor;
use App\Models\Bookmark;
use App\Models\FileUpload;

use File;
use Validator;
use DataTables;
use Carbon\Carbon;
use App\Helpers\Common;

class VendorController extends CompanyAdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(){
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request){
        $getCompanyAdmin        = auth()->guard('company-admin')->user();
        $getField               = '';
        $isCheck                = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','vendors')->first();
        if(!empty($isCheck->id)){
            //$getField           = unserialize($isCheck->config);
            $getField           = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_vendors_first'));
        }else{
            $getField           = config('settings.table_vendors_first');
        }
        if ($request->ajax()) {
            $data = Vendor::isCompany();

            // General filter code - start
            foreach( $getField as $key => $value ) {
                $conditionReq = 'search_string_condition_'.$key;
                $sortReq = 'search_string_sort_'.$key;

                if( isset( request()->$conditionReq ) ) {
                    $typeReq = 'search_string_type_'.$key;
                    $type = request()->$typeReq;

                    if( $type == 'string' ) {
                        Common::getStringFilterResult( $data, $key );
                    }

                    if( $type == 'date' ) {
                        Common::getDateFilterResult( $data, $key );
                    }
                }

                if( isset( request()->$sortReq ) ) {
                    $nameReq = 'search_string_name_'.$key;
                    $sortReq = 'search_string_sort_'.$key;
                    $typeReq = 'search_string_type_'.$key;
                    $tableNameReq = 'search_table_name_'.$key;
                    $colAliasReq = 'search_string_col_alias_'.$key;

                    $origData = request()->$nameReq;
                    $condition_sort = request()->$sortReq;
                    $type = request()->$typeReq;
                    $tableName = isset( request()->$tableNameReq ) ? request()->$tableNameReq : '';
                    $colAlias = isset( request()->$colAliasReq ) ? request()->$colAliasReq : '';

                    if( $type == 'string' ) {
                        if( isset( $condition_sort ) ) {
                            if( $colAlias != '' ) {
                                $data->orderBy( $tableName.'.'.$colAlias, $condition_sort );
                            } else {
                                if( $tableName != '' ) {
                                    $data->orderBy( $tableName.'.'.$origData, $condition_sort );
                                } else {
                                    $data->orderBy( $origData, $condition_sort );
                                }
                            }
                        }
                    }
                }
            }
            $data->select('*');
            /// end

            return Datatables::of($data)
                    ->addIndexColumn()
                    ->addColumn('action', function($row){
                        $action = '<a href="'.route('company.admin.vendors.show', base64Encode($row->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-eye" aria-hidden="true"></i></a>';
                        $action .= '<a href="'.route('company.admin.vendors.edit', base64Encode($row->id)).'" class="btn btn-sm btn-outline-black-action"><i class="fa fa-pencil" aria-hidden="true"></i></a>';
                        $action .= '<a href="javascript:void(0);" class="btn btn-sm btn-outline-black-trash destroy" data-action="'.route('company.admin.vendors.destroy',$row->id).'" data-id="'.$row->id.'"><i class="fa fa-trash" aria-hidden="true"></i></a>';

                        return $action;
                    })
                    ->rawColumns(['action'])
                    ->make(true);
        }
        $tableName = 'settings.table_vendors';
        return view('companyAdmin.vendor.index', compact('getField','tableName'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(){
        return view('companyAdmin.vendor.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(VendorStoreRequest $request){
        $input                              = $request->all();

        if($request->address_verified==1){
            $timezone                           = null;
            $timezone_offset                    = null;
            if(isset($input['timezone_abbr'])){
                $timezone                       = timezone_name_from_abbr($input['timezone_abbr']);
                $timezone_offset                = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['timezone']                  = $timezone;
            $input['timezone_offset']           = $timezone_offset;
        }
        if($request->billing_address_verified==1){
            $billing_timezone                   = null;
            $billing_timezone_offset            = null;
            if(isset($input['billing_timezone_abbr'])){
                $billing_timezone               = timezone_name_from_abbr($input['billing_timezone_abbr']);
                $billing_timezone_offset        = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['billing_timezone']          = $billing_timezone;
            $input['billing_timezone_offset']   = $billing_timezone_offset;
        }

        $input['company_id']                    = auth()->guard('company-admin')->user()->company_id;
        if (isset($input['logo'])) {
            $input['logo']                      = FileUpload::upload('companyAdmin/vendors', $input['logo']);
        }

        if(isset($input['account_number']) && $input['account_number']!=""){
            $input['account_number']   = base64_encode($input['account_number']);
        }

        $vendor                                 = Vendor::create($input);
        notification('success', $this->crudMessage('create', 'Vendor'));
        return redirect()->route('company.admin.vendors.index');
    }

    /**
     * Display the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id){
        $id = base64Decode($id);
        $vendor = Vendor::findOrFail($id);
        return view('companyAdmin.vendor.show', compact('vendor'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id){
        $id = base64Decode($id);
        $vendor = Vendor::findOrFail($id);
        if(isset($vendor) && $vendor->account_number!=""){
            $vendor->account_number  = base64_decode($vendor->account_number);
        }

        return view('companyAdmin.vendor.edit', compact('vendor'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(VendorUpdateRequest $request, Vendor $vendor){
        $input                                      = $request->all();

        if($request->address_verified==1){
            $timezone                               = null;
            $timezone_offset                        = null;
            if(isset($input['timezone_abbr'])){
                $timezone                           = timezone_name_from_abbr($input['timezone_abbr']);
                $timezone_offset                    = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['timezone']                      = $timezone;
            $input['timezone_offset']               = $timezone_offset;
        }else{
            $input['latitude']                      = null;
            $input['longitude']                     = null;
            $input['timezone']                      = null;
            $input['timezone_offset']               = null;
            $input['timezone_abbr']                 = null;
        }
        if($request->billing_address_verified==1){
            $billing_timezone                       = null;
            $billing_timezone_offset                = null;
            if(isset($input['billing_timezone_abbr'])){
                $billing_timezone                   = timezone_name_from_abbr($input['billing_timezone_abbr']);
                $billing_timezone_offset            = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['billing_timezone']              = $billing_timezone;
            $input['billing_timezone_offset']       = $billing_timezone_offset;
        }else{
            $input['billing_latitude']              = null;
            $input['billing_longitude']             = null;
            $input['billing_timezone']              = null;
            $input['billing_timezone_offset']       = null;
            $input['billing_timezone_abbr']         = null;
        }

        if (isset($input['logo'])) {
            $input['logo']                          = FileUpload::upload('companyAdmin/vendors', $input['logo']);
        }else{
            if(!empty($input['remove_image'])){
                $input['logo']                      = null;
            }
        }

        if(isset($input['account_number']) && $input['account_number']!=""){
            $input['account_number']   = base64_encode($input['account_number']);
        }

        $vendor->update($input);
        notification('success', $this->crudMessage('update', 'Vendor'));
        return redirect()->route('company.admin.vendors.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Vendor $vendor){
        $vendor->delete();
        notification('success', $this->crudMessage('delete', 'Vendor'));
        return redirect()->route('company.admin.vendors.index');
    }

    public function storeAjax(Request $request){
        $input          = $request->all();

        $validator      = Validator::make($input,[
            "name"      => "required",
            "address"   => "required",
            "phone"     => "required",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $input['company_id']            = auth()->guard('company-admin')->user()->company_id;
        if($request->address_verified==1){
            $timezone                   = null;
            $timezone_offset            = null;
            if(isset($input['timezone_abbr'])){
                $timezone               = timezone_name_from_abbr($input['timezone_abbr']);
                $timezone_offset        = Carbon::createFromTimestamp(time(), $timezone)->getOffsetString();
            }
            $input['timezone']          = $timezone;
            $input['timezone_offset']   = $timezone_offset;
        }
        $vendor                         = Vendor::create($input);
        return response()->json(['success' => "Customer created successfully",'id' => $vendor->id]);
    }

    public function getVendorList(Request $request){
        $name       = $request->get('data');
        $getList    = getVendorList();

        $html       = '<option value="" >Select '.$name.'</option>';
        foreach($getList as $key => $list){
            $html   .= '<option value="'.$key.'" >"'.$list.'"</option>';
        }
        return $html;
    }

    public function getVendorByID(Request $request){
        $input          = $request->all();
        $getList        = Vendor::find($request->id);
        $getList->url   = route('company.admin.vendors.update', $getList->id);
        return response()->json(['data' => $getList]);
    }
}
