<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;
use Illuminate\Http\Request;
use App\Models\WeeklyFuelSurcharge;
use App\Models\Bookmark;

use DataTables;
use Validator;
use Carbon\Carbon;
use App\Helpers\Common;

class WeeklyFuelSurchargeController extends CompanyAdminController
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        Carbon::setWeekStartsAt(Carbon::SUNDAY);
        Carbon::setWeekEndsAt(Carbon::SATURDAY);
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {

        $getField = '';

        $getCompanyAdmin = auth()->guard('company-admin')->user();
        $isCheck = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','weekly_fuel_surcharge')->first();

        if(!empty($isCheck->id)){
            //$getField = unserialize($isCheck->config);
            $getField = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_weekly_fuel_surcharge_first'));
        }else{
            $getField = config('settings.table_weekly_fuel_surcharge_first');
        }

        if ($request->ajax()) {
            $data = WeeklyFuelSurcharge::isCompany();
            // General filter code - start
                foreach( $getField as $key => $value ) {
                    $conditionReq = 'search_string_condition_'.$key;
                    $sortReq = 'search_string_sort_'.$key;

                    $conditionDateReq = 'search_date_condition_'.$key;
                    $sortDateReq = 'search_date_sort_'.$key;

                    // String filter
                    if( isset( request()->$conditionReq ) ) {
                        $typeReq = 'search_string_type_'.$key;
                        $type = request()->$typeReq;

                        if( $type == 'string' ) {
                            Common::getStringFilterResult( $data, $key );
                        }
                    }

                    // Date filter
                    if( isset( request()->$conditionDateReq ) ) {
                        $typeReq = 'search_date_type_'.$key;
                        $type = request()->$typeReq;

                        if( $type == 'date' ) {
                            Common::getDateFilterResult( $data, $key );
                        }
                    }

                    // String sort only
                    if( isset( request()->$sortReq ) ) {
                        Common::sortStringFilter( $data, $key );
                    }

                    // Date sort only
                    if( isset( request()->$sortDateReq ) ) {
                        Common::sortDateFilter( $data, $key );
                    }
                }
            // General filter code - end

            $data->get();

            return Datatables::of($data)
                    ->addIndexColumn()
                    ->editColumn('fuel_surcharge', function($row){
                        return "$".number_format($row->fuel_surcharge,2);
                    })
                    ->filterColumn("start_date", function ($query, $keyword) {
                        $query->whereRaw(
                            "DATE_FORMAT(start_date,'%m/%d/%Y') LIKE ?",
                            ["%$keyword%"]
                        );
                    })
                    ->filterColumn("end_date", function ($query, $keyword) {
                        $query->whereRaw(
                            "DATE_FORMAT(end_date,'%m/%d/%Y') LIKE ?",
                            ["%$keyword%"]
                        );
                    })
                    ->addColumn('action', function($row){
                        $action = '<a href="'.route('company.admin.trucks.edit', base64Encode($row->id)).'" class="btn btn-sm btn-outline-black-action edit-btn" data-id="'.$row->id.'" data-toggle="modal" data-target="#editModal"><i class="fa fa-pencil" aria-hidden="true"></i></a>';
                        $action .= '<a href="javascript:void(0);" class="btn btn-sm btn-outline-black-trash destroy" data-action="'.route('company.admin.weekly-fuel-surcharges.destroy',$row->id).'" data-id="'.$row->id.'"><i class="fa fa-trash" aria-hidden="true"></i></a>';

                        return $action;
                    })
                    ->rawColumns(['action','week','fuel_surcharge'])
                    ->make(true);
        }

        $tableName = 'settings.table_weekly_fuel_surcharge';
        return view('companyAdmin.weeklyFuelSurcharge.index', compact('getField', 'tableName'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $input = $request->all();
        $validator = Validator::make($input,[
            "date" => "required",
            "fuel_surcharge" => "required|numeric",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $input['company_id'] = auth()->guard('company-admin')->user()->company_id;
        $input['start_date'] = Carbon::parse($input['date'])->startOfWeek();
        $input['end_date'] = Carbon::parse($input['date'])->endOfWeek();
        $input['week'] = Carbon::createFromFormat('m/d/Y',$input['date'])->startOfWeek()->week();

        WeeklyFuelSurcharge::create($input);

        notification('success', $this->crudMessage('create', 'Weekly Fuel Surcharge'));

        return response()->json(['success' => "Weekly Fuel Surcharge created successfully"]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function editFormView(Request $request)
    {
        $weeklyFuelSurcharge = WeeklyFuelSurcharge::find($request->id);

        $view = view('companyAdmin.weeklyFuelSurcharge.editFormView', compact('weeklyFuelSurcharge'))->render();

        return response()->json(['view' => $view, 'data' => $weeklyFuelSurcharge]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $input = $request->all();
        $validator = Validator::make($input,[
            "date" => "required",
            "fuel_surcharge" => "required|numeric",
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $input['start_date'] = Carbon::parse($input['date'])->startOfWeek();
        $input['end_date'] = Carbon::parse($input['date'])->endOfWeek();
        $input['week'] = Carbon::createFromFormat('m/d/Y',$input['date'])->startOfWeek()->week();

        WeeklyFuelSurcharge::find($id)->update($input);

        notification('success', $this->crudMessage('update', 'Weekly Fuel Surcharge'));

        return response()->json(['success' => "weekly Fuel Surcharge updated successfully"]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(WeeklyFuelSurcharge $weeklyFuelSurcharge)
    {
        $weeklyFuelSurcharge->delete();

        notification('success', $this->crudMessage('delete', 'Weekly Fuel Surcharge'));

        return redirect()->back();
    }
}
