<?php

namespace App\Http\Controllers\DriverAdmin;

use App\Http\Controllers\DriverAdmin\DriverAdminController;
use Illuminate\Http\Request;

use App\Mail\DetentionRequestBroker;

use App\Models\FileUpload;

use App\Models\Bookmark;
use App\Models\IntegrationSetting;

use App\Models\Load;
use App\Models\LoadFile;
use App\Models\LoadStop;
use App\Models\LoadReject;
use App\Models\LoadDetail;
use App\Models\LoadDetention;
use App\Models\LoadAccessorial;

use App\Models\Truck;
use App\Models\Broker;
use App\Models\Gallery;

use App\Traits\AuditLoagTrait;

use DB;
use Mail;
use File;
use DataTables;
use Carbon\Carbon;

class LoadController extends DriverAdminController{

    use AuditLoagTrait;
    /**
     * Create a new controller instance.
     *
     * @return void
     */

    public $timeZone;
    public $timeZoneId;
    public $offset;

    public function __construct(){
        parent::__construct();

        $this->middleware(function ($request, $next) {
            $this->timeZone     = getTimeZone();
            $this->timeZoneId   = getTimeZoneId();
            $this->offset       = getTimeZoneOffset();

            return $next($request);
        });
    }

    /**
     * Display a listing of active loads.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request){
        $getDriverAdmin = auth()->guard('driver-admin')->user();
        $getField       = '';
        $isCheck        = Bookmark::where('company_id', $getDriverAdmin->company_id)
            ->where('user_id', $getDriverAdmin->id)
            ->where('user_type', 3)
            ->where('table_id','loads_active')
            ->first();
        if(!empty($isCheck->id)){
            //$getField   = unserialize($isCheck->config);
            $getField   = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_loads_active_first'));
        }else{
            $getField   = config('settings.table_loads_active_first');
            unset($getField['driver'],$getField['phone_number'],$getField['status']);
        }
        return view('driverAdmin.load.index', compact('getField'));
    }

    public function pending(Request $request){
        if ($request->ajax()) {
            $offset     = $this->offset;
            $search     = $request->search['value'] ?? '';
            $data       = LoadDetail::query()
                ->select(
                    '*',
                    DB::raw('CONVERT_TZ(load_details.created_at,"+00:00","'.$offset.'") as created_at'),
                    DB::raw('CONVERT_TZ(load_details.updated_at,"+00:00","'.$offset.'") as updated_at')
                )
                ->where('driver_id', auth()->guard('driver-admin')->user()->id)
                ->where('load_status', 2)
                ->where(function($q) {
                    $q->whereNull('is_on_hold')->orWhere('is_on_hold', 0);
                });
                //->whereIn('load_status', [0,1,2]); // 0 = Pending, 1 = Accepted, 2 = Preplaned
                //->where('load_status', 0); // 0 = Pending //->whereNotIn('load_status',[7,8,9]); // '7' => 'On Hold', '8' => 'Complete', '9' => 'Cancelled'
            return Datatables::of($data)
                ->addIndexColumn()
                ->editColumn('load_number', function($row){
                    return '<a href="'.route('driver.admin.loads.show',base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                })
                ->addColumn('broker_name', function($row){
                    return isset($row->broker->name) ? $row->broker->name : '';
                })
                ->filterColumn('broker_name', function ($query, $keyword) {
                    $query->whereHas('broker', function ($q) use ($keyword) {
                        $q->where("brokers.name", 'LIKE', "%".$keyword."%");
                    });
                })
                ->editColumn('actual_delivery_date', function($row){
                    return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date.' '.$row->delivery_timezone_abbr : '';
                })
                ->filterColumn('actual_delivery_date', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
                    }
                })
                ->editColumn('created_at', function($row){
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('created_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->editColumn('updated_at', function($row){
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('updated_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.updated_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.updated_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->editColumn('booked_by', function($row){
                    if($row->booked_by == 0){
                        return 'Self Dispatch';
                    }else{
                        return $row->dispatcher->full_name;
                    }
                })
                ->filterColumn('booked_by', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                    });
                })
                ->editColumn('trailer_type', function($row){
                    return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                })
                ->addColumn('dispatcher', function($row){
                    return getLoadDispatcherName($row->booked_by);
                })
                ->filterColumn('dispatcher', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                    });
                })
                ->addColumn('last_location', function($row){
                    return 'Seattle, WA, USA';
                })
                ->editColumn('total_bill', function($row){
                    return getPrice($row->total_bill);
                })
                ->editColumn('shipper_location', function($row){
                    $html           = [];
                    if($row->shipper_address_one){
                        $html[0]    = $row->shipper_address_one;
                    }
                    if($row->shipper_address_two){
                        $html[1]    = $row->shipper_address_two;
                    }
                    if($row->shipper_city){
                        $html[2]    = $row->shipper_city;
                    }
                    if($row->shipper_state){
                        $html[3]    = $row->shipper_state;
                    }
                    if($row->shipper_zip){
                        $html[4]    = $row->shipper_zip;
                    }
                    if(count($html) == 0){
                        return $row->shipper_location;
                    }else{
                        return implode(', ', $html);
                    }
                })
                ->editColumn('delivery_location', function($row){
                    $html           = [];
                    if($row->delivery_address_one){
                        $html[0]    = $row->delivery_address_one;
                    }
                    if($row->delivery_address_two){
                        $html[1]    = $row->delivery_address_two;
                    }
                    if($row->delivery_city){
                        $html[2]    = $row->delivery_city;
                    }
                    if($row->delivery_state){
                        $html[3]    = $row->delivery_state;
                    }
                    if($row->delivery_zip){
                        $html[4]    = $row->delivery_zip;
                    }
                    if(count($html) == 0){
                        return $row->delivery_location;
                    }else{
                        return implode(', ', $html);
                    }
                })
                ->rawColumns(['load_number'])
                ->make(true);
        }
    }

    public function accepted(Request $request){
        if ($request->ajax()) {
            $offset     = $this->offset;
            $search     = $request->search['value'] ?? '';
            $data       = LoadDetail::query()
                ->select(
                    '*',
                    DB::raw('CONVERT_TZ(load_details.created_at,"+00:00","'.$offset.'") as created_at'),
                    DB::raw('CONVERT_TZ(load_details.updated_at,"+00:00","'.$offset.'") as updated_at')
                )
                ->where('driver_id', auth()->guard('driver-admin')->user()->id)
                ->where('load_status', 3)
                ->where(function($q) {
                    $q->whereNull('is_on_hold')->orWhere('is_on_hold', 0);
                }); // 3 = Confirmed
                //->where('load_status', 1); // 1 = Accepted
            return Datatables::of($data)
                ->addIndexColumn()
                ->editColumn('load_number', function($row){
                    return '<a href="'.route('driver.admin.loads.show',base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                })
                ->addColumn('broker_name', function($row){
                    return isset($row->broker->name) ? $row->broker->name : '';
                })
                ->filterColumn('broker_name', function ($query, $keyword) {
                    $query->whereHas('broker', function ($q) use ($keyword) {
                        $q->where("brokers.name", 'LIKE', "%".$keyword."%");
                    });
                })
                ->editColumn('actual_delivery_date', function($row){
                    return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date.' '.$row->delivery_timezone_abbr : '';
                })
                ->filterColumn('actual_delivery_date', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
                    }
                })
                ->editColumn('created_at', function($row){
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('created_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->editColumn('updated_at', function($row){
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('updated_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.updated_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.updated_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->editColumn('booked_by', function($row){
                    if($row->booked_by == 0){
                        return 'Self Dispatch';
                    }else{
                        return $row->dispatcher->full_name;
                    }
                })
                ->filterColumn('booked_by', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                    });
                })
                ->editColumn('trailer_type', function($row){
                    return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                })
                ->addColumn('dispatcher', function($row){
                    return getLoadDispatcherName($row->booked_by);
                })
                ->filterColumn('dispatcher', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                    });
                })
                ->addColumn('last_location', function($row){
                    return 'Seattle, WA, USA';
                })
                ->editColumn('total_bill', function($row){
                    return getPrice($row->total_bill);
                })
                ->editColumn('shipper_location', function($row){
                    $html           = [];
                    if($row->shipper_address_one){
                        $html[0]    = $row->shipper_address_one;
                    }
                    if($row->shipper_address_two){
                        $html[1]    = $row->shipper_address_two;
                    }
                    if($row->shipper_city){
                        $html[2]    = $row->shipper_city;
                    }
                    if($row->shipper_state){
                        $html[3]    = $row->shipper_state;
                    }
                    if($row->shipper_zip){
                        $html[4]    = $row->shipper_zip;
                    }
                    if(count($html) == 0){
                        return $row->shipper_location;
                    }else{
                        return implode(', ', $html);
                    }
                })
                ->editColumn('delivery_location', function($row){
                    $html           = [];
                    if($row->delivery_address_one){
                        $html[0]    = $row->delivery_address_one;
                    }
                    if($row->delivery_address_two){
                        $html[1]    = $row->delivery_address_two;
                    }
                    if($row->delivery_city){
                        $html[2]    = $row->delivery_city;
                    }
                    if($row->delivery_state){
                        $html[3]    = $row->delivery_state;
                    }
                    if($row->delivery_zip){
                        $html[4]    = $row->delivery_zip;
                    }
                    if(count($html) == 0){
                        return $row->delivery_location;
                    }else{
                        return implode(', ', $html);
                    }
                })
                ->rawColumns(['load_number'])
                ->make(true);
        }
    }

    public function inTransit(Request $request){
        if ($request->ajax()) {
            $offset     = $this->offset;
            $search     = $request->search['value'] ?? '';
            $data       = LoadDetail::query()
                ->select(
                    '*',
                    DB::raw('CONVERT_TZ(load_details.created_at,"+00:00","'.$offset.'") as created_at'),
                    DB::raw('CONVERT_TZ(load_details.updated_at,"+00:00","'.$offset.'") as updated_at')
                )
                ->where('driver_id', auth()->guard('driver-admin')->user()->id)
                ->where('load_status', 4)
                ->where(function($q) {
                    $q->whereNull('is_on_hold')->orWhere('is_on_hold', 0);
                }); // 4 = In Transit
            return Datatables::of($data)
                ->addIndexColumn()
                ->editColumn('load_number', function($row){
                    return '<a href="'.route('driver.admin.loads.show',base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                })
                ->addColumn('broker_name', function($row){
                    return isset($row->broker->name) ? $row->broker->name : '';
                })
                ->filterColumn('broker_name', function ($query, $keyword) {
                    $query->whereHas('broker', function ($q) use ($keyword) {
                        $q->where("brokers.name", 'LIKE', "%".$keyword."%");
                    });
                })
                ->editColumn('actual_delivery_date', function($row){
                    return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date.' '.$row->delivery_timezone_abbr : '';
                })
                ->filterColumn('actual_delivery_date', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
                    }
                })
                ->editColumn('created_at', function($row){
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('created_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->editColumn('updated_at', function($row){
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('updated_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.updated_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.updated_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->editColumn('booked_by', function($row){
                    if($row->booked_by == 0){
                        return 'Self Dispatch';
                    }else{
                        return $row->dispatcher->full_name;
                    }
                })
                ->filterColumn('booked_by', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                    });
                })
                ->editColumn('trailer_type', function($row){
                    return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                })
                ->addColumn('dispatcher', function($row){
                    return getLoadDispatcherName($row->booked_by);
                })
                ->filterColumn('dispatcher', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                    });
                })
                ->addColumn('last_location', function($row){
                    return 'Seattle, WA, USA';
                })
                ->editColumn('total_bill', function($row){
                    return getPrice($row->total_bill);
                })
                ->editColumn('shipper_location', function($row){
                    $html           = [];
                    if($row->shipper_address_one){
                        $html[0]    = $row->shipper_address_one;
                    }
                    if($row->shipper_address_two){
                        $html[1]    = $row->shipper_address_two;
                    }
                    if($row->shipper_city){
                        $html[2]    = $row->shipper_city;
                    }
                    if($row->shipper_state){
                        $html[3]    = $row->shipper_state;
                    }
                    if($row->shipper_zip){
                        $html[4]    = $row->shipper_zip;
                    }
                    if(count($html) == 0){
                        return $row->shipper_location;
                    }else{
                        return implode(', ', $html);
                    }
                })
                ->editColumn('delivery_location', function($row){
                    $html           = [];
                    if($row->delivery_address_one){
                        $html[0]    = $row->delivery_address_one;
                    }
                    if($row->delivery_address_two){
                        $html[1]    = $row->delivery_address_two;
                    }
                    if($row->delivery_city){
                        $html[2]    = $row->delivery_city;
                    }
                    if($row->delivery_state){
                        $html[3]    = $row->delivery_state;
                    }
                    if($row->delivery_zip){
                        $html[4]    = $row->delivery_zip;
                    }
                    if(count($html) == 0){
                        return $row->delivery_location;
                    }else{
                        return implode(', ', $html);
                    }
                })
                ->rawColumns(['load_number'])
                ->make(true);
        }
    }

    public function rejected(Request $request){
        if ($request->ajax()) {
            $offset     = $this->offset;
            $search     = $request->search['value'] ?? '';
            $data       = LoadDetail::query()
                ->select(
                    '*',
                    DB::raw('CONVERT_TZ(load_details.created_at,"+00:00","'.$offset.'") as created_at'),
                    DB::raw('CONVERT_TZ(load_details.updated_at,"+00:00","'.$offset.'") as updated_at')
                )
                ->where('driver_id', auth()->guard('driver-admin')->user()->id)
                ->where(function($q) {
                    $q->where('load_status', 7)
                        ->orWhere('is_on_hold', 1);
                        //->orWhere('preplaned_rejected_by', auth()->guard('driver-admin')->user()->id)
                        //->orWhere('confirmed_rejected_by', auth()->guard('driver-admin')->user()->id)
                        //->orWhere('in_transit_rejected_by', auth()->guard('driver-admin')->user()->id)
                        //->orWhere('delivered_rejected_by', auth()->guard('driver-admin')->user()->id);
                })
                ->whereHas('loads.load_rejects', function ($q) {
                    $q->where('load_rejects.driver_id', auth()->guard('driver-admin')->user()->id);
                });
            return Datatables::of($data)
                ->addIndexColumn()
                ->editColumn('load_number', function($row){
                    return '<a href="'.route('driver.admin.loads.show',base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                })
                ->addColumn('broker_name', function($row){
                    return isset($row->broker->name) ? $row->broker->name : '';
                })
                ->filterColumn('broker_name', function ($query, $keyword) {
                    $query->whereHas('broker', function ($q) use ($keyword) {
                        $q->where("brokers.name", 'LIKE', "%".$keyword."%");
                    });
                })
                ->editColumn('actual_delivery_date', function($row){
                    return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date.' '.$row->delivery_timezone_abbr : '';
                })
                ->filterColumn('actual_delivery_date', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
                    }
                })
                ->editColumn('created_at', function($row){
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('created_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->editColumn('updated_at', function($row){
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('updated_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.updated_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.updated_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->editColumn('booked_by', function($row){
                    if($row->booked_by == 0){
                        return 'Self Dispatch';
                    }else{
                        return $row->dispatcher->full_name;
                    }
                })
                ->filterColumn('booked_by', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                    });
                })
                ->editColumn('trailer_type', function($row){
                    return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                })
                ->addColumn('dispatcher', function($row){
                    return getLoadDispatcherName($row->booked_by);
                })
                ->filterColumn('dispatcher', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                    });
                })
                ->addColumn('last_location', function($row){
                    return 'Seattle, WA, USA';
                })
                ->editColumn('total_bill', function($row){
                    return getPrice($row->total_bill);
                })
                ->editColumn('shipper_location', function($row){
                    $html           = [];
                    if($row->shipper_address_one){
                        $html[0]    = $row->shipper_address_one;
                    }
                    if($row->shipper_address_two){
                        $html[1]    = $row->shipper_address_two;
                    }
                    if($row->shipper_city){
                        $html[2]    = $row->shipper_city;
                    }
                    if($row->shipper_state){
                        $html[3]    = $row->shipper_state;
                    }
                    if($row->shipper_zip){
                        $html[4]    = $row->shipper_zip;
                    }
                    if(count($html) == 0){
                        return $row->shipper_location;
                    }else{
                        return implode(', ', $html);
                    }
                })
                ->editColumn('delivery_location', function($row){
                    $html           = [];
                    if($row->delivery_address_one){
                        $html[0]    = $row->delivery_address_one;
                    }
                    if($row->delivery_address_two){
                        $html[1]    = $row->delivery_address_two;
                    }
                    if($row->delivery_city){
                        $html[2]    = $row->delivery_city;
                    }
                    if($row->delivery_state){
                        $html[3]    = $row->delivery_state;
                    }
                    if($row->delivery_zip){
                        $html[4]    = $row->delivery_zip;
                    }
                    if(count($html) == 0){
                        return $row->delivery_location;
                    }else{
                        return implode(', ', $html);
                    }
                })
                ->rawColumns(['load_number'])
                ->make(true);
        }
    }

    public function complete(Request $request){
        if ($request->ajax()) {
            $offset     = $this->offset;
            $search     = $request->search['value'] ?? '';
            $data       = LoadDetail::query()
                ->select(
                    '*',
                    DB::raw('CONVERT_TZ(load_details.created_at,"+00:00","'.$offset.'") as created_at'),
                    DB::raw('CONVERT_TZ(load_details.updated_at,"+00:00","'.$offset.'") as updated_at')
                )
                ->where('driver_id', auth()->guard('driver-admin')->user()->id)
                ->where('load_type', 0) //->whereIn('load_type', [0,6,4]) // 0 = Occupied, 6 = Tonu, 4 = No Dispatch
                ->where('load_status', 8)
                ->where(function($q) {
                    $q->whereNull('is_on_hold')->orWhere('is_on_hold', 0);
                }); // 8 = Complete
            return Datatables::of($data)
                ->addIndexColumn()
                ->editColumn('load_number', function($row){
                    return '<a href="'.route('driver.admin.loads.show',base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                })
                ->addColumn('broker_name', function($row){
                    return isset($row->broker->name) ? $row->broker->name : '';
                })
                ->filterColumn('broker_name', function ($query, $keyword) {
                    $query->whereHas('broker', function ($q) use ($keyword) {
                        $q->where("brokers.name", 'LIKE', "%".$keyword."%");
                    });
                })
                ->editColumn('actual_delivery_date', function($row){
                    return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date.' '.$row->delivery_timezone_abbr : '';
                })
                ->filterColumn('actual_delivery_date', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
                    }
                })
                ->editColumn('created_at', function($row){
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('created_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->editColumn('updated_at', function($row){
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('updated_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.updated_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.updated_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->editColumn('booked_by', function($row){
                    if($row->booked_by == 0){
                        return 'Self Dispatch';
                    }else{
                        return $row->dispatcher->full_name;
                    }
                })
                ->filterColumn('booked_by', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                    });
                })
                ->editColumn('trailer_type', function($row){
                    return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                })
                ->addColumn('dispatcher', function($row){
                    return getLoadDispatcherName($row->booked_by);
                })
                ->filterColumn('dispatcher', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                    });
                })
                ->addColumn('last_location', function($row){
                    return 'Seattle, WA, USA';
                })
                ->editColumn('total_bill', function($row){
                    return getPrice($row->total_bill);
                })
                ->editColumn('shipper_location', function($row){
                    $html           = [];
                    if($row->shipper_address_one){
                        $html[0]    = $row->shipper_address_one;
                    }
                    if($row->shipper_address_two){
                        $html[1]    = $row->shipper_address_two;
                    }
                    if($row->shipper_city){
                        $html[2]    = $row->shipper_city;
                    }
                    if($row->shipper_state){
                        $html[3]    = $row->shipper_state;
                    }
                    if($row->shipper_zip){
                        $html[4]    = $row->shipper_zip;
                    }
                    if(count($html) == 0){
                        return $row->shipper_location;
                    }else{
                        return implode(', ', $html);
                    }
                })
                ->editColumn('delivery_location', function($row){
                    $html           = [];
                    if($row->delivery_address_one){
                        $html[0]    = $row->delivery_address_one;
                    }
                    if($row->delivery_address_two){
                        $html[1]    = $row->delivery_address_two;
                    }
                    if($row->delivery_city){
                        $html[2]    = $row->delivery_city;
                    }
                    if($row->delivery_state){
                        $html[3]    = $row->delivery_state;
                    }
                    if($row->delivery_zip){
                        $html[4]    = $row->delivery_zip;
                    }
                    if(count($html) == 0){
                        return $row->delivery_location;
                    }else{
                        return implode(', ', $html);
                    }
                })
                ->rawColumns(['load_number'])
                ->make(true);
        }
    }

    public function cancelled(Request $request){
        if ($request->ajax()) {
            $offset     = $this->offset;
            $search     = $request->search['value'] ?? '';
            $data       = LoadDetail::query()
                ->select(
                    '*',
                    DB::raw('CONVERT_TZ(load_details.created_at,"+00:00","'.$offset.'") as created_at'),
                    DB::raw('CONVERT_TZ(load_details.updated_at,"+00:00","'.$offset.'") as updated_at')
                )
                ->where('driver_id', auth()->guard('driver-admin')->user()->id)
                ->where('load_type', 0) //->whereIn('load_type', [0,6,4]) // 0 = Occupied, 6 = Tonu, 4 = No Dispatch
                ->where(function($q) {
                    $q->where('load_status', 9)->orWhere('is_on_hold', 2);
                }); // 9 = cancelled
            return Datatables::of($data)
                ->addIndexColumn()
                ->editColumn('load_number', function($row){
                    return '<a href="'.route('driver.admin.loads.show',base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                })
                ->addColumn('broker_name', function($row){
                    return isset($row->broker->name) ? $row->broker->name : '';
                })
                ->filterColumn('broker_name', function ($query, $keyword) {
                    $query->whereHas('broker', function ($q) use ($keyword) {
                        $q->where("brokers.name", 'LIKE', "%".$keyword."%");
                    });
                })
                ->editColumn('actual_delivery_date', function($row){
                    return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date.' '.$row->delivery_timezone_abbr : '';
                })
                ->filterColumn('actual_delivery_date', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
                    }
                })
                ->editColumn('created_at', function($row){
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('created_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->editColumn('updated_at', function($row){
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('updated_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.updated_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.updated_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->editColumn('booked_by', function($row){
                    if($row->booked_by == 0){
                        return 'Self Dispatch';
                    }else{
                        return $row->dispatcher->full_name;
                    }
                })
                ->filterColumn('booked_by', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                    });
                })
                ->editColumn('trailer_type', function($row){
                    return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                })
                ->addColumn('dispatcher', function($row){
                    return getLoadDispatcherName($row->booked_by);
                })
                ->filterColumn('dispatcher', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                    });
                })
                ->addColumn('last_location', function($row){
                    return 'Seattle, WA, USA';
                })
                ->editColumn('total_bill', function($row){
                    return getPrice($row->total_bill);
                })
                ->editColumn('shipper_location', function($row){
                    $html           = [];
                    if($row->shipper_address_one){
                        $html[0]    = $row->shipper_address_one;
                    }
                    if($row->shipper_address_two){
                        $html[1]    = $row->shipper_address_two;
                    }
                    if($row->shipper_city){
                        $html[2]    = $row->shipper_city;
                    }
                    if($row->shipper_state){
                        $html[3]    = $row->shipper_state;
                    }
                    if($row->shipper_zip){
                        $html[4]    = $row->shipper_zip;
                    }
                    if(count($html) == 0){
                        return $row->shipper_location;
                    }else{
                        return implode(', ', $html);
                    }
                })
                ->editColumn('delivery_location', function($row){
                    $html           = [];
                    if($row->delivery_address_one){
                        $html[0]    = $row->delivery_address_one;
                    }
                    if($row->delivery_address_two){
                        $html[1]    = $row->delivery_address_two;
                    }
                    if($row->delivery_city){
                        $html[2]    = $row->delivery_city;
                    }
                    if($row->delivery_state){
                        $html[3]    = $row->delivery_state;
                    }
                    if($row->delivery_zip){
                        $html[4]    = $row->delivery_zip;
                    }
                    if(count($html) == 0){
                        return $row->delivery_location;
                    }else{
                        return implode(', ', $html);
                    }
                })
                ->rawColumns(['load_number'])
                ->make(true);
        }
    }

    public function unoccupied(Request $request){
        if ($request->ajax()) {
            $offset     = $this->offset;
            $search     = $request->search['value'] ?? '';
            $data       = LoadDetail::query()
                ->select(
                    '*',
                    DB::raw('CONVERT_TZ(load_details.created_at,"+00:00","'.$offset.'") as created_at'),
                    DB::raw('CONVERT_TZ(load_details.updated_at,"+00:00","'.$offset.'") as updated_at')
                )
                ->where('driver_id', auth()->guard('driver-admin')->user()->id)
                ->whereIn('load_type', [1,2,3,4,5,6]) // 1 = Maintenance, 2 = Unauthorized, 3 = Hos, 5 = Time Off
                ->whereNotIn('load_status', [0,1]);
            return Datatables::of($data)
                ->addIndexColumn()
                ->editColumn('load_number', function($row){
                    return '<a href="'.route('driver.admin.loads.show',base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                })
                ->addColumn('broker_name', function($row){
                    return isset($row->broker->name) ? $row->broker->name : '';
                })
                ->filterColumn('broker_name', function ($query, $keyword) {
                    $query->whereHas('broker', function ($q) use ($keyword) {
                        $q->where("brokers.name", 'LIKE', "%".$keyword."%");
                    });
                })
                ->editColumn('actual_delivery_date', function($row){
                    return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date.' '.$row->delivery_timezone_abbr : '';
                })
                ->filterColumn('actual_delivery_date', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
                    }
                })
                ->editColumn('created_at', function($row){
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('created_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->editColumn('updated_at', function($row){
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('updated_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.updated_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.updated_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->editColumn('booked_by', function($row){
                    if($row->booked_by == 0){
                        return 'Self Dispatch';
                    }else{
                        return $row->dispatcher->full_name;
                    }
                })
                ->filterColumn('booked_by', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                    });
                })
                ->editColumn('trailer_type', function($row){
                    return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                })
                ->addColumn('dispatcher', function($row){
                    return getLoadDispatcherName($row->booked_by);
                })
                ->filterColumn('dispatcher', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                    });
                })
                ->addColumn('last_location', function($row){
                    return 'Seattle, WA, USA';
                })
                ->editColumn('total_bill', function($row){
                    return getPrice($row->total_bill);
                })
                ->editColumn('shipper_location', function($row){
                    $html           = [];
                    if($row->shipper_address_one){
                        $html[0]    = $row->shipper_address_one;
                    }
                    if($row->shipper_address_two){
                        $html[1]    = $row->shipper_address_two;
                    }
                    if($row->shipper_city){
                        $html[2]    = $row->shipper_city;
                    }
                    if($row->shipper_state){
                        $html[3]    = $row->shipper_state;
                    }
                    if($row->shipper_zip){
                        $html[4]    = $row->shipper_zip;
                    }
                    if(count($html) == 0){
                        return $row->shipper_location;
                    }else{
                        return implode(', ', $html);
                    }
                })
                ->editColumn('delivery_location', function($row){
                    $html           = [];
                    if($row->delivery_address_one){
                        $html[0]    = $row->delivery_address_one;
                    }
                    if($row->delivery_address_two){
                        $html[1]    = $row->delivery_address_two;
                    }
                    if($row->delivery_city){
                        $html[2]    = $row->delivery_city;
                    }
                    if($row->delivery_state){
                        $html[3]    = $row->delivery_state;
                    }
                    if($row->delivery_zip){
                        $html[4]    = $row->delivery_zip;
                    }
                    if(count($html) == 0){
                        return $row->delivery_location;
                    }else{
                        return implode(', ', $html);
                    }
                })
                ->rawColumns(['load_number'])
                ->make(true);
        }
    }

    public function all(Request $request){
        if ($request->ajax()) {
            $offset     = $this->offset;
            $search     = $request->search['value'] ?? '';
            $data       = LoadDetail::query()
                ->select(
                    '*',
                    DB::raw('CONVERT_TZ(load_details.created_at,"+00:00","'.$offset.'") as created_at'),
                    DB::raw('CONVERT_TZ(load_details.updated_at,"+00:00","'.$offset.'") as updated_at')
                )
                ->where('driver_id', auth()->guard('driver-admin')->user()->id)
                ->whereNotIn('load_status', [0,1]);
            return Datatables::of($data)
                ->addIndexColumn()
                ->editColumn('load_number', function($row){
                    return '<a href="'.route('driver.admin.loads.show',base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                })
                ->addColumn('broker_name', function($row){
                    return isset($row->broker->name) ? $row->broker->name : '';
                })
                ->filterColumn('broker_name', function ($query, $keyword) {
                    $query->whereHas('broker', function ($q) use ($keyword) {
                        $q->where("brokers.name", 'LIKE', "%".$keyword."%");
                    });
                })
                ->editColumn('actual_delivery_date', function($row){
                    return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date.' '.$row->delivery_timezone_abbr : '';
                })
                ->filterColumn('actual_delivery_date', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
                    }
                })
                ->editColumn('created_at', function($row){
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('created_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.created_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->editColumn('updated_at', function($row){
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->filterColumn('updated_at', function ($query, $keyword) use ($search, $offset) {
                    if(auth()->guard('driver-admin')->user()->time_format=='12'){
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.updated_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }else{
                        $query->whereRaw("CONCAT(DATE_FORMAT(CONVERT_TZ(load_details.updated_at,'+00:00','".$offset."'),'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ','".$this->timeZoneId."') like ?", ["%$search%"]);
                    }
                })
                ->editColumn('booked_by', function($row){
                    if($row->booked_by == 0){
                        return 'Self Dispatch';
                    }else{
                        return $row->dispatcher->full_name;
                    }
                })
                ->filterColumn('booked_by', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                    });
                })
                ->editColumn('trailer_type', function($row){
                    return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                })
                ->addColumn('dispatcher', function($row){
                    return getLoadDispatcherName($row->booked_by);
                })
                ->filterColumn('dispatcher', function ($query, $keyword) {
                    $query->whereHas('dispatcher', function ($q) use ($keyword) {
                        $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                    });
                })
                ->addColumn('last_location', function($row){
                    return 'Seattle, WA, USA';
                })
                ->editColumn('total_bill', function($row){
                    return getPrice($row->total_bill);
                })
                ->editColumn('shipper_location', function($row){
                    $html           = [];
                    if($row->shipper_address_one){
                        $html[0]    = $row->shipper_address_one;
                    }
                    if($row->shipper_address_two){
                        $html[1]    = $row->shipper_address_two;
                    }
                    if($row->shipper_city){
                        $html[2]    = $row->shipper_city;
                    }
                    if($row->shipper_state){
                        $html[3]    = $row->shipper_state;
                    }
                    if($row->shipper_zip){
                        $html[4]    = $row->shipper_zip;
                    }
                    if(count($html) == 0){
                        return $row->shipper_location;
                    }else{
                        return implode(', ', $html);
                    }
                })
                ->editColumn('delivery_location', function($row){
                    $html           = [];
                    if($row->delivery_address_one){
                        $html[0]    = $row->delivery_address_one;
                    }
                    if($row->delivery_address_two){
                        $html[1]    = $row->delivery_address_two;
                    }
                    if($row->delivery_city){
                        $html[2]    = $row->delivery_city;
                    }
                    if($row->delivery_state){
                        $html[3]    = $row->delivery_state;
                    }
                    if($row->delivery_zip){
                        $html[4]    = $row->delivery_zip;
                    }
                    if(count($html) == 0){
                        return $row->delivery_location;
                    }else{
                        return implode(', ', $html);
                    }
                })
                ->rawColumns(['load_number'])
                ->make(true);
        }
    }

    /**
     * Display the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id){
        $id                                                     = base64Decode($id);
        $loadDetail                                             = LoadDetail::find($id);

        $docsArry                                               = [];
        $stop_no                                                = 1;
        if(isset($loadDetail->shipper_files) && is_serialized($loadDetail->shipper_files) && !empty(unserialize($loadDetail->shipper_files))){
            $files                                              = array_filter(unserialize($loadDetail->shipper_files));
            foreach ($files as $key => &$file) {
                $file['ctype']                                  = 1;
            }
            $docsArry[$stop_no]                                 = $files;
        }else{
            if(isset($loadDetail->broker->shipper_files) && is_serialized($loadDetail->broker->shipper_files) && !empty(unserialize($loadDetail->broker->shipper_files))){
                $files                                          = array_filter(unserialize($loadDetail->broker->shipper_files));
                foreach ($files as $key => &$file) {
                    $file['ctype']                              = 1;
                }
                $docsArry[$stop_no]                             = $files;
            }else{
                $files                                          = array_filter(unserialize(config('settings.shipper_files')));
                foreach ($files as $key => &$file) {
                    $file['ctype']                              = 1;
                }
                $docsArry[$stop_no]                             = $files;
            }
        }

        if(isset($loadDetail->loads->load_stops) && $loadDetail->loads->load_stops->isNotEmpty()){
            foreach ($loadDetail->loads->load_stops as $key => $stop) {
                ++$stop_no;
                if($stop->customer_type==2){
                    if(isset($stop->stop_consignee_files) && is_serialized($stop->stop_consignee_files) && !empty(unserialize($stop->stop_consignee_files))){
                        $files                                  = array_filter(unserialize($stop->stop_consignee_files));
                        foreach ($files as $key => &$file) {
                            $file['ctype']                      = $stop->customer_type;
                        }
                        $docsArry[$stop_no]                     = $files;
                    }else{
                        if(isset($loadDetail->broker->consignee_files) && is_serialized($loadDetail->broker->consignee_files) && !empty(unserialize($loadDetail->broker->consignee_files))){
                            $files                              = array_filter(unserialize($loadDetail->broker->consignee_files));
                            foreach ($files as $key => &$file) {
                                $file['ctype']                  = $stop->customer_type;
                            }
                            $docsArry[$stop_no]                 = $files;
                        }else{
                            $files                              = array_filter(unserialize(config('settings.consignee_files')));
                            foreach ($files as $key => &$file) {
                                $file['ctype']                  = $stop->customer_type;
                            }
                            $docsArry[$stop_no]                 = $files;
                        }
                    }
                }else{
                    if(isset($stop->stop_shipper_files) && is_serialized($stop->stop_shipper_files) && !empty(unserialize($stop->stop_shipper_files))){
                        $files                                  = array_filter(unserialize($stop->stop_shipper_files));
                        foreach ($files as $key => &$file) {
                            $file['ctype']                      = $stop->customer_type;
                        }
                        $docsArry[$stop_no]                     = $files;
                    }else{
                        if(isset($loadDetail->broker->shipper_files) && is_serialized($loadDetail->broker->shipper_files) && !empty(unserialize($loadDetail->broker->shipper_files))){
                            $files                              = array_filter(unserialize($loadDetail->broker->shipper_files));
                            foreach ($files as $key => &$file) {
                                $file['ctype']                  = $stop->customer_type;
                            }
                            $docsArry[$stop_no]                 = $files;
                        }else{
                            $files                              = array_filter(unserialize(config('settings.shipper_files')));
                            foreach ($files as $key => &$file) {
                                $file['ctype']                  = $stop->customer_type;
                            }
                            $docsArry[$stop_no]                 = $files;
                        }
                    }
                }
            }
        }

        ++$stop_no;

        if(isset($loadDetail->consignee_files) && is_serialized($loadDetail->consignee_files) && !empty(unserialize($loadDetail->consignee_files))){
            $files                                              = array_filter(unserialize($loadDetail->consignee_files));
            foreach ($files as $key => &$file) {
                $file['ctype']                                  = 2;
            }
            $docsArry[$stop_no]                                 = $files;
        }else{
            if(isset($loadDetail->broker->consignee_files) && is_serialized($loadDetail->broker->consignee_files) && !empty(unserialize($loadDetail->broker->consignee_files))){
                $files                                          = array_filter(unserialize($loadDetail->broker->consignee_files));
                foreach ($files as $key => &$file) {
                    $file['ctype']                              = 2;
                }
                $docsArry[$stop_no]                             = $files;
            }else{
                $files                                          = array_filter(unserialize(config('settings.consignee_files')));
                foreach ($files as $key => &$file) {
                    $file['ctype']                              = 2;
                }
                $docsArry[$stop_no]                             = $files;
            }
        }

        $shipper_array                                          = [];
        $consignee_array                                        = [];
        foreach ($docsArry as $key => $value) {
            $shipper_files                                      = array_filter($value, function($var){
                return ($var['ctype'] == 1);
            });
            if(!empty($shipper_files)){
                foreach ($shipper_files as $key => $row) {
                    $shipper_array[]                            = $row;
                }
            }else{
                foreach ($value as $key => $row) {
                    $consignee_array[]                          = $row;
                }
            }
        }

        $reDocsArry                                             = [];
        $tempShipperArr                                         = array_unique(array_column($shipper_array, 'name'));
        $reDocsArry['shipper']                                  = $tempShipperArr; //array_intersect_key($shipper_array, $tempShipperArr);

        $tempConsigneeArr                                       = array_unique(array_column($consignee_array, 'name'));
        $reDocsArry['consignee']                                = $tempConsigneeArr; //array_intersect_key($consignee_array, $tempConsigneeArr);

        $accessorial_array                                      = [];
        $shipper_accessorials                                   = $loadDetail->shipper_accessorials->where('driver_liable', 1)->where('doc_required', 1)->where('driver_id', auth()->guard('driver-admin')->user()->id);
        if($shipper_accessorials->isNotEmpty()){
            foreach ($shipper_accessorials as $key => $value) {
                if(isset($value->company_accessorial->name)){
                    $accessorial_array[]                        = $value->company_accessorial->name;
                }
            }
        }

        if(isset($loadDetail->loads->load_stops) && $loadDetail->loads->load_stops->isNotEmpty()){
            foreach ($loadDetail->loads->load_stops as $key => $stop) {
                $stop_accessorials                              = $stop->accessorials->where('driver_liable', 1)->where('doc_required', 1)->where('driver_id', auth()->guard('driver-admin')->user()->id);
                if($stop_accessorials->isNotEmpty()){
                    foreach ($stop_accessorials as $key => $value) {
                        if(isset($value->company_accessorial->name)){
                            $accessorial_array[]                        = $value->company_accessorial->name;
                        }
                    }
                }
            }
        }

        $receiver_accessorials                                  = $loadDetail->receiver_accessorials->where('driver_liable', 1)->where('doc_required', 1)->where('driver_id', auth()->guard('driver-admin')->user()->id);
        if($receiver_accessorials->isNotEmpty()){
            foreach ($receiver_accessorials as $key => $value) {
                if(isset($value->company_accessorial->name)){
                    $accessorial_array[]                        = $value->company_accessorial->name;
                }
            }
        }

        $reDocsArry['accessorial']                              = array_unique($accessorial_array);
        // dd($reDocsArry);
        $getTimeZone                                            = $this->timeZone;
        $getTimeZoneId                                          = $this->timeZoneId;
        $getGeoTimeZone                                         = getGeoTimeZone();
        return view('driverAdmin.load.show', compact('loadDetail','docsArry','reDocsArry','getTimeZone','getTimeZoneId','getGeoTimeZone'));
    }

    public function loadFileView(Request $request){
        $getFile    = LoadFile::where('load_id',$request->id)->orderBy('id','desc')->get();
        $view       = view('driverAdmin.load.file.view', compact('getFile'))->render();
        return response()->json(['view' => $view]);
    }

    public function loadFileSave(Request $request){
        $files                          = array_filter($request->file);
        if(!empty($request->load_id) && count($files) > 0){
            $input                      = [];
            $input['load_id']           = $request->load_id;
            $input['load_file_type_id'] = 0;
            $input['filename']          = $request->filename;
            $input['note']              = $request->filenote;
            $input['document']          = $request->file;
            if (isset($files) && !empty($files[0])) {
                $file_temp              = [];
                $image_array            = [];
                foreach($files as $image){
                    $seme               = FileUpload::upload('companyAdmin/temp', $image);

                    $stopath            = public_path('storage/companyAdmin/temp/'.$seme);
                    $data               = file_get_contents($stopath);
                    $type               = pathinfo($stopath, PATHINFO_EXTENSION);
                    if($type == 'png' || $type == 'jpeg' || $type == 'jpg' || $type == 'gif'){
                        $base64         = 'data:image/' . $type . ';base64,' . base64_encode($data);
                        $file_temp[]    = $base64;
                    }else{
                        $image_array[]  = $seme = FileUpload::upload('companyAdmin/loadfile', $image);
                    }
                }
                if(count($file_temp) > 0){
                    $fileName           = 'load_'.$request->load_id;
                    $image_array[]      = FileUpload::PDFupload('companyAdmin/loadfile', ['data' => $file_temp], $fileName);
                }
                $input['document']      = serialize($image_array);
            }
            LoadFile::create($input);
            return 1;
        }
        return 0;
    }

    public function destroyFile($id){
        $getFile    = LoadFile::find($id);
        File::delete('storage/companyAdmin/loadfile/'.$getFile->document);
        $getFile->delete();
        return 1;
    }

    public function requiredFileSave(Request $request){
        $accessorial_upload_docs                                = $request->accessorial_upload_docs;
        if(!empty($accessorial_upload_docs)){
            foreach ($accessorial_upload_docs as $key => $value) {
                $load_accessorial                               = LoadAccessorial::whereId($value['id'])->first();
                $oldData                                        = $load_accessorial->toArray();

                if(isset($value['file'])){
                    $load_accessorial->file_not_provided        = 'off';
                    if(isset($value['file_exists'])){
                        $gallery                                = $load_accessorial->gallery;

                        $file_temp                              = [];
                        $image_array                            = [];
                        foreach($value['file'] as $image){
                            $seme                               = FileUpload::upload('companyAdmin/temp', $image);
                            $stopath                            = public_path('storage/companyAdmin/temp/'.$seme);
                            $data                               = file_get_contents($stopath);
                            $type                               = pathinfo($stopath, PATHINFO_EXTENSION);
                            if($type == 'png' || $type == 'jpeg' || $type == 'jpg' || $type == 'gif'){
                                $base64                         = 'data:image/' . $type . ';base64,' . base64_encode($data);
                                $file_temp[]                    = $base64;
                            }
                        }

                        $gallery->file_name                     = $gallery->file_name;
                        if(count($file_temp) > 0){
                            $path                               = 'storage/companyAdmin/gallery/'.$gallery->image;
                            if (File::exists($path)) {
                                File::delete($path);
                            }
                            $gallery->image                     = FileUpload::PDFupload('companyAdmin/gallery', ['data' => $file_temp], 'document_pdf');
                        }
                        $gallery->created_by                    = auth()->guard('driver-admin')->user()->id;
                        $gallery->created_at                    = Carbon::now();;
                        $gallery->created_by_type               = 3;
                        $gallery->save();
                    }else{
                        $file_temp                              = [];
                        $image_array                            = [];
                        foreach($value['file'] as $image){
                            $seme                               = FileUpload::upload('companyAdmin/temp', $image);
                            $stopath                            = public_path('storage/companyAdmin/temp/'.$seme);
                            $data                               = file_get_contents($stopath);
                            $type                               = pathinfo($stopath, PATHINFO_EXTENSION);
                            if($type == 'png' || $type == 'jpeg' || $type == 'jpg' || $type == 'gif'){
                                $base64                         = 'data:image/' . $type . ';base64,' . base64_encode($data);
                                $file_temp[]                    = $base64;
                            }
                        }

                        if(count($file_temp) > 0){
                            $input                              = [];
                            $input['company_id']                = auth()->guard('driver-admin')->user()->company_id;
                            $input['action_id']                 = $load_accessorial->id;
                            $input['source']                    = 'load_accessorials';
                            $input['field_name']                = 'accessorial_files';
                            $input['file_name']                 = null;
                            $input['file_type']                 = getRequestDocumentsList('load_accessorials','source')['file_type'];
                            $input['image']                     = FileUpload::PDFupload('companyAdmin/gallery', ['data' => $file_temp], 'document_pdf');

                            $input['status']                    = 'approved';
                            $input['created_by']                = auth()->guard('driver-admin')->user()->id;
                            $input['created_by_type']           = 3;
                            $input['uploaded_date']             = Carbon::now()->format('m/d/Y H:i');
                            Gallery::create($input);

                            $load_accessorial->is_received      = 1;
                        }
                    }
                }else{
                    if(isset($value['file_exists'])){
                        $load_accessorial->file_not_provided    = 'off';
                    }else{
                        $load_accessorial->file_not_provided    = isset($value['file_not_provided']) && $value['file_not_provided']=='on' ? 'on' : 'off';
                    }
                }
                //status
                $arry                                           = [];
                $paid_type                                      = $load_accessorial->paid_type;
                $reference                                      = $load_accessorial->reference;
                $driver_liable                                  = $load_accessorial->driver_liable;
                $doc_required                                   = $load_accessorial->doc_required;
                $total                                          = $load_accessorial->total;
                $driver_total                                   = $load_accessorial->driver_total;

                array_push($arry, $paid_type!=''?1:0);
                array_push($arry, $reference!=''?1:0);
                if($driver_liable=='1'){
                    array_push($arry, $total!=''?1:0);
                    array_push($arry, $driver_total!=''?1:0);
                }else{
                    array_push($arry, $total!=''?1:0);
                }

                if(in_array(0, $arry)){
                    $load_accessorial->status                   = 0; // Pending
                }else{
                    if($doc_required=='1'){
                        if($load_accessorial->is_received==1){
                            $load_accessorial->status           = 1; // Completed
                        }else{
                            $load_accessorial->status           = 0; // Pending
                        }
                    }else{
                        $load_accessorial->status               = 1; // Completed
                    }
                }
                if($driver_liable=='1' &&  $load_accessorial->status!=1 && isset($load_accessorial->file_not_provided) && $load_accessorial->file_not_provided=='on'){
                    $load_accessorial->status                   = 2; // Driver Bypass
                }
                //status

                $load_accessorial->updated_at                   = Carbon::now();
                $load_accessorial->save();
                $this->setLoadAudit($load_accessorial->load_id, 'update', 'Load accessorial updated', $load_accessorial->getChanges(), $oldData);
                if(isset($value['file'])){
                    sleep(3); // this should halt for 3 seconds for every loop
                }
            }
        }

        $upload_docs                                            = $request->upload_docs;
        $input                                                  = [];
        if(!empty($upload_docs)){
            $arry                                               = [];
            foreach($upload_docs['name'] as $key => $name){
                $type                                           = isset($upload_docs['type'][$key]) ? $upload_docs['type'][$key] : '';
                $arry[$key]['type']                             = $type;
                $arry[$key]['name']                             = isset($upload_docs['name'][$key]) ? $upload_docs['name'][$key] : '';
                $arry[$key]['fixed']                            = isset($upload_docs['fixed'][$key]) ? $upload_docs['fixed'][$key] : '';
                $arry[$key]['is_required']                      = isset($upload_docs['is_required'][$key]) ? $upload_docs['is_required'][$key] : 'off';
                $arry[$key]['custom']                           = isset($upload_docs['custom'][$key]) && $upload_docs['custom'][$key]=='yes' ? 'yes' : 'no';

                if($type==1){
                    if(isset($upload_docs['file'][$key])){
                        $arry[$key]['file']                     = UploadImagePdf($upload_docs['file'][$key], 'companyAdmin/load_detail_document');
                        $arry[$key]['upload_user_type']         = 3;
                        $arry[$key]['upload_by']                = auth()->guard('driver-admin')->user()->id;
                        $arry[$key]['uploaded_at']              = Carbon::now();

                        $arry[$key]['is_received']              = 'on';
                    }else{
                        if(isset($upload_docs['file_exists'][$key])){
                            $arry[$key]['file']                 = $upload_docs['file_exists'][$key];
                            $arry[$key]['is_received']          = 'on';
                        }else{
                            $arry[$key]['file']                 = null;
                            $arry[$key]['is_received']          = 'off';
                            $arry[$key]['file_not_provided']    = isset($upload_docs['file_not_provided'][$key]) ? $upload_docs['file_not_provided'][$key] : 'off';
                        }
                    }
                }elseif($type==2){
                    $arry[$key]['file']                         = null;
                    $arry[$key]['is_received']                  = isset($upload_docs['is_received'][$key]) ? $upload_docs['is_received'][$key] : 'off';
                }
            }
            if($request->has('is_stop') && $request->is_stop==1){
                if($request->type=='Pickup'){
                    $input['stop_shipper_files_upload']         = serialize($arry);
                }else{
                    $input['stop_consignee_files_upload']       = serialize($arry);
                }
            }else{
                if($request->type=='Pickup'){
                    $input['shipper_files_upload']              = serialize($arry);
                }else{
                    $input['consignee_files_upload']            = serialize($arry);
                }
            }
        }else{
            if($request->has('is_stop') && $request->is_stop==1){
                if($request->type=='Pickup'){
                    $input['stop_shipper_files_upload']         = null;
                }else{
                    $input['stop_consignee_files_upload']       = null;
                }
            }else{
                if($request->type=='Pickup'){
                    $input['shipper_files_upload']              = null;
                }else{
                    $input['consignee_files_upload']            = null;
                }
            }
        }
        if($request->has('is_stop') && $request->is_stop==1){
            $stop                                               = LoadStop::whereId($request->id)->first();
            if(!is_null($stop)){
                foreach ($input as $key => $value) {
                    $stop->$key                                 = $value;
                }
                $stop->save();
                notification('success', 'File upload successfully');
            }else{
                notification('error', 'Oops! Something went wrong..');
            }
        }else{
            $load                                               = Load::whereId($request->id)->first();
            if(!is_null($load)){
                $load->load_detail->update($input);
                notification('success', 'File upload successfully');
            }else{
                notification('error', 'Oops! Something went wrong..');
            }
        }
        return redirect()->back();
    }

    public function changeStatus(Request $request){
        if ($request->ajax()) {
            try {
                if ($request->has('is_stop') && $request->is_stop==1) {
                    $item                                                   = LoadStop::where('id',$request->id)->first();
                    if(!is_null($item)){
                        $item->status                                       = $request->status;
                        $item->status_at                                    = Carbon::now();
                        if($request->type==2){
                            $item->reason                                   = $request->reason;
                        }elseif($request->type==1){
                            $item->is_leaves                                = 1;
                            $item->leaves_at                                = Carbon::now();
                        }
                        $item->updated_at                                   = Carbon::now();
                        if($item->save()){
                            createLoadLog($item->getChanges(), $item, 'edit');
                            $response['success']                            = true;
                            $response['message']                            = "Status has been changed successfully.";
                        }else{
                            $response['success']                            = false;
                            $response['message']                            = "Status has been changed unsuccessfully.";
                        }
                    }else{
                        $response['success']                                = false;
                        $response['message']                                = "Oops! Something went wrong..";
                    }
                }else{
                    $item                                                   = LoadDetail::where('id',$request->id)->first();
                    if(!is_null($item)){
                        $item->load_status                                  = $request->status;
                        if($request->type==2){
                            // 1=preplaned_driver_acknowledgement, 2=confirmed_driver_acknowledgement, 3=intransit_driver_acknowledgement, 4=delivered_driver_acknowledgement
                            $item->is_on_hold                               = 1;
                            $item->notification_reason                      = 5;
                            $item->reason_on_hold                           = $request->reason;
                            LoadReject::create([
                                'load_id'   => $item->load_id,
                                'driver_id' => auth()->guard('driver-admin')->user()->id,
                                'reason'    => $request->reason,
                                'date_time' => Carbon::now()
                            ]);
                        }elseif($request->type==1){
                            if($request->status==4){
                                $item->shipper_is_leaves                    = 1;
                                $item->shipper_leaves_at                    = Carbon::now();
                            }elseif ($request->status==5) {
                                $item->delivery_is_leaves                   = 1;
                                $item->delivery_leaves_at                   = Carbon::now();
                            }
                        }
                        $item->updated_at                                   = Carbon::now();
                        if($item->save()){
                            createLoadLog($item->getChanges(), $item, 'edit');
                            $response['success']                            = true;
                            $response['message']                            = "Status has been changed successfully.";
                        }else{
                            $response['success']                            = false;
                            $response['message']                            = "Status has been changed unsuccessfully.";
                        }
                    }else{
                        $response['success']                                = false;
                        $response['message']                                = "Oops! Something went wrong..";
                    }
                }
            } catch (\Exception $e) {
                $response['success']                                        = false;
                $response['message']                                        = $e->getMessage();
            }
            return response()->json($response);
        }else{
            return abort(404);
        }
    }

    public function arrivedRequest(Request $request){
        $response['success']                                = false;
        $response['message']                                = "Oops! Something went wrong..";
        if ($request->ajax()) {
            try {
                $param                                      = [];
                $param['is_stop']                           = ($request->has('is_stop') && $request->is_stop==1)?1:0;
                $param['shipper_is_arrived']                = ($request->has('shipper_is_arrived') && $request->shipper_is_arrived==1)?1:0;
                $param['delivery_is_arrived']               = ($request->has('delivery_is_arrived') && $request->delivery_is_arrived==1)?1:0;

                if ($param['is_stop']==1) {
                    $item                                   = LoadStop::where('id',$request->id)->first();
                    if(!is_null($item)){
                        $item->is_arrived                   = 1;
                        $item->arrived_at                   = Carbon::now();
                        $item->updated_at                   = Carbon::now();
                        if($item->save()){
                            // truck location update
                            $truck                                          = Truck::where('unit', $item->truck_number)->first();
                            if(!is_null($truck)){
                                $truck->last_location_name                  = $item->location;
                                $truck->last_location_address               = $item->address_one;
                                $truck->last_location_address_2             = $item->address_two;
                                $truck->last_location_city                  = $item->city;
                                $truck->last_location_state                 = $item->state;
                                $truck->last_location_zip                   = $item->zip;

                                $truck->last_location_latitude              = $item->latitude;
                                $truck->last_location_longitude             = $item->longitude;

                                $truck->last_location_timezone              = $item->timezone;
                                $truck->last_location_timezone_offset       = $item->timezone_offset;
                                $truck->last_location_timezone_abbr         = $item->timezone_abbr;
                                $truck->last_location_address_verified      = $item->address_verified;

                                $truck->last_location_notes                 = $item->stop_note;

                                $truck->last_location_load_status           = '0';
                                $truck->updated_at                          = Carbon::now();
                                $truck->save();
                            }

                            createLoadLog($item->getChanges(), $item, 'edit');
                            $response['success']            = true;
                            $response['message']            = "Arrived successfully.";
                        }else{
                            $response['success']            = false;
                            $response['message']            = "Arrived unsuccessfully.";
                        }
                    }
                }else{
                    if ($param['shipper_is_arrived']==1 || $param['delivery_is_arrived']==1) {
                        $query                              = LoadDetail::where('id',$request->id);
                        if($param['shipper_is_arrived']==1){
                            $query->where('shipper_is_arrived', 0)->where('load_status', 3);
                        }else{
                            $query->where('delivery_is_arrived', 0)->where('load_status', 4);
                        }
                        $item                               = $query->first();
                        if(!is_null($item)){
                            if($param['shipper_is_arrived']==1){
                                $item->shipper_is_arrived   = 1;
                                $item->shipper_arrived_at   = Carbon::now();
                            }else{
                                $item->delivery_is_arrived  = 1;
                                $item->delivery_arrived_at  = Carbon::now();
                            }
                            $item->updated_at               = Carbon::now();
                            if($item->save()){
                                // truck location update
                                $truck                                          = Truck::where('unit', $item->truck_number)->first();
                                if(!is_null($truck)){
                                    if($param['shipper_is_arrived']==1){
                                        $truck->last_location_name              = $item->shipper_location;
                                        $truck->last_location_address           = $item->shipper_address_one;
                                        $truck->last_location_address_2         = $item->shipper_address_two;
                                        $truck->last_location_city              = $item->shipper_city;
                                        $truck->last_location_state             = $item->shipper_state;
                                        $truck->last_location_zip               = $item->shipper_zip;

                                        $truck->last_location_latitude          = $item->shipper_latitude;
                                        $truck->last_location_longitude         = $item->shipper_longitude;

                                        $truck->last_location_timezone          = $item->shipper_timezone;
                                        $truck->last_location_timezone_offset   = $item->shipper_timezone_offset;
                                        $truck->last_location_timezone_abbr     = $item->shipper_timezone_abbr;
                                        $truck->last_location_address_verified  = $item->shipper_address_verified;

                                        $truck->last_location_notes             = $item->shipper_note;

                                        $truck->last_location_load_status       = '0';
                                    }else{
                                        $truck->last_location_name              = $item->delivery_location;
                                        $truck->last_location_address           = $item->delivery_address_one;
                                        $truck->last_location_address_2         = $item->delivery_address_two;
                                        $truck->last_location_city              = $item->delivery_city;
                                        $truck->last_location_state             = $item->delivery_state;
                                        $truck->last_location_zip               = $item->delivery_zip;

                                        $truck->last_location_latitude          = $item->delivery_latitude;
                                        $truck->last_location_longitude         = $item->delivery_longitude;

                                        $truck->last_location_timezone          = $item->delivery_timezone;
                                        $truck->last_location_timezone_offset   = $item->delivery_timezone_offset;
                                        $truck->last_location_timezone_abbr     = $item->delivery_timezone_abbr;
                                        $truck->last_location_address_verified  = $item->delivery_address_verified;

                                        $truck->last_location_notes             = $item->delivery_note;

                                        $truck->last_location_load_status       = '0';
                                    }
                                    $truck->updated_at                          = Carbon::now();
                                    $truck->save();
                                }

                                createLoadLog($item->getChanges(), $item, 'edit');
                                $response['success']        = true;
                                $response['message']        = "Arrived successfully.";
                            }else{
                                $response['success']        = false;
                                $response['message']        = "Arrived unsuccessfully.";
                            }
                        }
                    }
                }
            } catch (\Exception $e) {
                $response['success']                        = false;
                $response['message']                        = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function detentionRequest(Request $request){
        $response['success']                                                    = false;
        $response['message']                                                    = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $param                                                          = [];
                $param['is_view']                                               = ($request->has('is_view') && $request->is_view==1)?1:0;
                $param['is_stop']                                               = ($request->has('is_stop') && $request->is_stop==1)?1:0;
                $param['shipper_is_arrived']                                    = ($request->has('shipper_is_arrived') && $request->shipper_is_arrived==1)?1:0;
                $param['delivery_is_arrived']                                   = ($request->has('delivery_is_arrived') && $request->delivery_is_arrived==1)?1:0;

                if ($param['is_stop']==1) {
                    $stop                                                       = LoadStop::where('id',$request->id)->first();
                    if(!is_null($stop)){
                        $whereArray                                             = [];
                        if($request->has('detention_id') && $request->detention_id!=''){
                            $whereArray['id']                                   = $request->detention_id;
                        }else{
                            $whereArray['load_stop_id']                         = $stop->id;
                            //$whereArray['driver_id']                          = $stop->loads->load_detail->driver_id;
                            //$whereArray['broker_id']                          = $stop->loads->load_detail->brokerage_firm;
                            $whereArray['type']                                 = $stop->customer_type;
                            $whereArray['is_stop']                              = 1;
                        }

                        $detentionquery                                         = LoadDetention::query();
                        foreach($whereArray as $field => $value) {
                            $detentionquery->where($field, $value);
                        }
                        $detention                                              = $detentionquery->first();
                        if(!is_null($detention)){
                            $driver                                             = $detention->driver;
                            $broker                                             = $detention->broker;
                        }else{
                            $driver                                             = $stop->loads->load_detail->driver;
                            $broker                                             = $stop->loads->load_detail->broker;
                        }

                        $gpsLocation                                            = null;
                        if(!is_null($driver)){
                            $samsara_id                                         = (isset($driver->samsara_id) && $driver->samsara_id!='')?$driver->samsara_id:'';//4644765
                            if($samsara_id!=''){
                                $carrierId = (isset($driver->driver_information->carrier_id)) ? $driver->driver_information->carrier_id : null;
                                $getAPIKey                                      = IntegrationSetting::where('company_id', $driver->company_id)->where('carrier_id', $carrierId)->where('app_center_id', config('settings.app_id.samsara'))->where('sync_drivers', '1')->first();
                                if(isset($getAPIKey->api_key) && !empty($getAPIKey->api_key)){
                                    $client                                     = new \GuzzleHttp\Client();
                                    $api_url                                    = 'https://api.samsara.com/fleet/hos/clocks?driverIds='.$samsara_id;
                                    $api_response                               = $client->request('GET', $api_url, [
                                        'headers'                               => [
                                            'Accept'                            => 'application/json',
                                            'Authorization'                     => 'Bearer '.$getAPIKey->api_key,
                                        ],
                                    ]);
                                    $api_data                                   = json_decode($api_response->getBody());
                                    if(!empty($api_data)){
                                        $appData                                = $api_data->data[0];
                                        if(!empty($appData)){
                                            $vehicleIds                         = (isset($appData->currentVehicle->id) && $appData->currentVehicle->id!='')?$appData->currentVehicle->id:'';
                                            if($vehicleIds!=''){
                                                $api_url                        = 'https://api.samsara.com/fleet/vehicles/locations?vehicleIds='.$vehicleIds;
                                                $api_response                   = $client->request('GET', $api_url, [
                                                    'headers'                   => [
                                                        'Accept'                => 'application/json',
                                                        'Authorization'         => 'Bearer '.$getAPIKey->api_key,
                                                    ],
                                                ]);
                                                $api_data                       = json_decode($api_response->getBody());
                                                if(!empty($api_data)){
                                                    $appData                    = $api_data->data[0];
                                                    if(!empty($appData) && (isset($appData->location->reverseGeo->formattedLocation) && $appData->location->reverseGeo->formattedLocation!='')){
                                                        $gpsLocation            = $appData->location->reverseGeo->formattedLocation;
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }

                        $getGeoTimeZone                                         = getGeoTimeZone();

                        $html                                                   = view('driverAdmin.load.ajax.detentionRequest', compact('param','stop','driver','broker','gpsLocation','detention','getGeoTimeZone'))->render();
                        $response['success']                                    = true;
                        $response['message']                                    = "Detention request retrieved successfully.";
                        $response['html']                                       = $html;
                    }
                }else{
                    $query                                                      = LoadDetail::where('id',$request->id);
                    if($param['shipper_is_arrived']==1)
                        $query->where('shipper_is_arrived', 1);
                    else
                        $query->where('delivery_is_arrived', 1);
                    $loadDetail                                                 = $query->first();
                    if(!is_null($loadDetail)){
                        $whereArray                                             = [];
                        if($request->has('detention_id') && $request->detention_id!=''){
                            $whereArray['id']                                   = $request->detention_id;
                        }else{
                            $whereArray['load_detail_id']                       = $loadDetail->id;
                            //$whereArray['driver_id']                          = $loadDetail->driver_id;
                            //$whereArray['broker_id']                          = $loadDetail->brokerage_firm;
                            if($param['shipper_is_arrived']==1){
                                $whereArray['type']                             = 1;
                            }elseif($param['delivery_is_arrived']==1){
                                $whereArray['type']                             = 2;
                            }
                            $whereArray['is_stop']                              = 0;
                        }

                        $detentionquery                                         = LoadDetention::query();
                        foreach($whereArray as $field => $value) {
                            $detentionquery->where($field, $value);
                        }
                        $detention                                              = $detentionquery->first();
                        if(!is_null($detention)){
                            $driver                                             = $detention->driver;
                            $broker                                             = $detention->broker;
                        }else{
                            $driver                                             = $loadDetail->driver;
                            $broker                                             = $loadDetail->broker;
                        }

                        $gpsLocation                                            = null;
                        if(!is_null($driver)){
                            $samsara_id                                         = (isset($driver->samsara_id) && $driver->samsara_id!='')?$driver->samsara_id:'';//4644765
                            if($samsara_id!=''){
                                $carrierId = (isset($driver->driver_information->carrier_id)) ? $driver->driver_information->carrier_id : null;
                                $getAPIKey                                      = IntegrationSetting::where('company_id', $driver->company_id)->where('carrier_id', $carrierId)->where('app_center_id', config('settings.app_id.samsara'))->where('sync_drivers', '1')->first();
                                if(isset($getAPIKey->api_key) && !empty($getAPIKey->api_key)){
                                    $client                                     = new \GuzzleHttp\Client();
                                    $api_url                                    = 'https://api.samsara.com/fleet/hos/clocks?driverIds='.$samsara_id;
                                    $api_response                               = $client->request('GET', $api_url, [
                                        'headers'                               => [
                                            'Accept'                            => 'application/json',
                                            'Authorization'                     => 'Bearer '.$getAPIKey->api_key,
                                        ],
                                    ]);
                                    $api_data                                   = json_decode($api_response->getBody());
                                    if(!empty($api_data)){
                                        $appData                                = $api_data->data[0];
                                        if(!empty($appData)){
                                            $vehicleIds                         = (isset($appData->currentVehicle->id) && $appData->currentVehicle->id!='')?$appData->currentVehicle->id:'';
                                            if($vehicleIds!=''){
                                                $api_url                        = 'https://api.samsara.com/fleet/vehicles/locations?vehicleIds='.$vehicleIds;
                                                $api_response                   = $client->request('GET', $api_url, [
                                                    'headers'                   => [
                                                        'Accept'                => 'application/json',
                                                        'Authorization'         => 'Bearer '.$getAPIKey->api_key,
                                                    ],
                                                ]);
                                                $api_data                       = json_decode($api_response->getBody());
                                                if(!empty($api_data)){
                                                    $appData                    = $api_data->data[0];
                                                    if(!empty($appData) && (isset($appData->location->reverseGeo->formattedLocation) && $appData->location->reverseGeo->formattedLocation!='')){
                                                        $gpsLocation            = $appData->location->reverseGeo->formattedLocation;
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }

                        $getGeoTimeZone                                         = getGeoTimeZone();

                        $html                                                   = view('driverAdmin.load.ajax.detentionRequest', compact('param','loadDetail','driver','broker','gpsLocation','detention','getGeoTimeZone'))->render();
                        $response['success']                                    = true;
                        $response['message']                                    = "Detention request retrieved successfully.";
                        $response['html']                                       = $html;
                    }
                }
            }catch (\Exception $e) {
                $response['success']                                            = false;
                $response['message']                                            = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function detentionSave(Request $request){
        $response['success']                                                    = false;
        $response['message']                                                    = "Oops! Something went wrong..";
        if ($request->ajax()) {
            try {
                $getGeoTimeZone                                                 = getGeoTimeZone();

                $param                                                          = [];
                $param['is_stop']                                               = ($request->has('is_stop') && $request->is_stop==1)?1:0;
                $param['shipper_is_arrived']                                    = ($request->has('shipper_is_arrived') && $request->shipper_is_arrived==1)?1:0;
                $param['delivery_is_arrived']                                   = ($request->has('delivery_is_arrived') && $request->delivery_is_arrived==1)?1:0;

                if ($param['is_stop']==1) {
                    $stop                                                       = LoadStop::where('id',$request->id)->first();
                    if(!is_null($stop)){
                        if($request->detention_status==0){
                            $whereArray                                         = [];
                            if($request->has('detention_id') && $request->detention_id!=''){
                                $whereArray['id']                               = $request->detention_id;
                            }else{
                                $whereArray['load_stop_id']                     = $stop->id;
                                $whereArray['driver_id']                        = $request->driver_id;
                                $whereArray['broker_id']                        = $request->broker_id;
                                $whereArray['type']                             = $stop->customer_type;
                                $whereArray['is_stop']                          = 1;
                            }

                            $query                                              = LoadDetention::query();
                            foreach($whereArray as $field => $value) {
                                $query->where($field, $value);
                            }
                            if($query->delete()){
                                $this->setLoadAudit($query->load_detail->load_id, 'delete', 'Load detention deleted', ['deleted_at' => $query->deleted_at], ['deleted_at' => null]);
                                $response['success']                            = true;
                                $response['message']                            = "Detention cancel successfully.";
                            }else{
                                $response['success']                            = false;
                                $response['message']                            = "Detention cancel unsuccessfully.";
                            }
                        }elseif (in_array($request->detention_status, [1,2,3])) {
                            $whereArray                                         = [];
                            if($request->has('detention_id') && $request->detention_id!=''){
                                $whereArray['id']                               = $request->detention_id;
                            }else{
                                $whereArray['load_stop_id']                     = $stop->id;
                                $whereArray['driver_id']                        = $request->driver_id;
                                $whereArray['broker_id']                        = $request->broker_id;
                                $whereArray['type']                             = $stop->customer_type;
                                $whereArray['is_stop']                          = 1;
                            }

                            $array                                              = [];

                            if(isset($request->broker_id) && !empty($request->broker_id)){
                                $getBrokerdata                                  = Broker::find($request->broker_id);
                                $array['free_time']                             = $getBrokerdata->detention_time;
                                $array['rate']                                  = $getBrokerdata->detention_price;
                            }

                            $array['load_detail_id']                            = $stop->loads->load_detail->id;
                            //if(!$request->has('detention_id') || $request->detention_id=='')
                            $array['driver_id']                                 = $request->driver_id;
                            $array['broker_id']                                 = $request->broker_id;
                            $array['load_stop_id']                              = $stop->id;
                            $array['type']                                      = $stop->customer_type;
                            $array['is_stop']                                   = 1;

                            $array['detention_status']                          = $request->detention_status;
                            if($request->detention_status==2){
                                $array['stopped_user_type']                     = 'Driver';
                                $array['stopped_at']                            = Carbon::now();
                                $array['stopped_by']                            = auth()->guard('driver-admin')->user()->id;

                                $array['review_user_type']                      = 'Driver';
                                $array['review_status']                         = 'Detention Stopped - Pending Approval';
                                $array['review_at']                             = Carbon::now();
                                $array['review_by']                             = auth()->guard('driver-admin')->user()->id;
                            }elseif ($request->detention_status==1) {
                                $array['review_user_type']                      = 'Driver';
                                $array['review_status']                         = 'In Progress';
                                $array['review_at']                             = Carbon::now();
                                $array['review_by']                             = auth()->guard('driver-admin')->user()->id;
                            }
                            $array['detention_start_time']                      = ($request->detention_start_time)?convertTimeToUTCzone(['str' => $request->detention_start_time, 'toFormat'=> 'Y-m-d H:i:s', 'fromFormat' => getTimeLayout(), 'userTimezone' => $getGeoTimeZone]):null;
                            if(in_array($request->detention_status, [2,3])){
                                if($request->detention_status==2){
                                    $array['detention_end_time']                = Carbon::now();
                                }else{
                                    $array['detention_end_time']                = ($request->detention_end_time)?convertTimeToUTCzone(['str' => $request->detention_end_time, 'toFormat'=> 'Y-m-d H:i:s', 'fromFormat' => getTimeLayout(), 'userTimezone' => $getGeoTimeZone]):Carbon::now();
                                }
                            }

                            if($request->has('detention_id') && $request->detention_id!=''){
                                $oldData                                        = LoadDetention::query();
                                foreach ($whereArray as $key => $value) {
                                    $oldData->where($key, $value);
                                }
                                $oldData                                        = $oldData->first();
                            }

                            $item                                               = LoadDetention::updateOrCreate($whereArray,$array);
                            if($item){
                                if($item->wasChanged() && isset($oldData)){
                                    $this->setLoadAudit($item->load_detail->load_id, 'update', 'Load detention updated', $item->getChanges(), $oldData->toArray());
                                }
                                if(in_array($item->detention_status, [1,2]) && isset($item->driver)){
                                    $driver                                     = $item->driver;
                                    if(isset($driver->dispatcher)){
                                        $dispatcher                             = $driver->dispatcher;
                                        $name                                   = 'Load: '.$stop->loads->load_detail->load_number.' - Stop ';
                                        if($stop->loads->load_stops->isNotEmpty()){
                                            $stpno                              = '';
                                            $stopIds                            = ($stop->loads->load_stops->pluck('id')->toArray());
                                            foreach ($stopIds as $stkey => $stopId) {
                                                ++$stkey;
                                                if($stop->id==$stopId){
                                                    $stpno                      = $stkey;
                                                }
                                            }
                                            if($stpno!=''){
                                                $name                           .= $stpno.' ';
                                            }
                                        }
                                        if($item->type==1){
                                            $name                              .= 'Pickup';
                                        }else{
                                            $name                              .= 'Delivery';
                                        }
                                        $description                            = '';
                                        if($item->detention_status==1){
                                            $description                        = $driver->full_name.' has started a detention for '.$stop->loads->load_detail->load_number.': '.$stop->loads->load_detail->load_number.' at '.date("Y-m-d H:i:s", strtotime($item->created_at)).' please review';
                                        }else{
                                            $description                        = $driver->full_name.' has stopped a detention for '.$stop->loads->load_detail->load_number.': '.$stop->loads->load_detail->load_number.' at '.date("Y-m-d H:i:s", strtotime($item->stopped_at)).' please review';
                                        }

                                        createNotification(
                                            ($item->detention_status==1)?17:18, // source
                                            $name, // name
                                            $dispatcher->id, // user_id
                                            $dispatcher->type, // user_type
                                            2, // type
                                            $item->id, // action_id
                                            $description, // description
                                            'Notification', // module
                                            [], // properties
                                            $dispatcher->company_id // company_id
                                        );
                                    }
                                }
                                $response['data']                               = $item;
                                $response['success']                            = true;
                                $response['message']                            = "Detention saved successfully.";
                            }else{
                                $response['success']                            = false;
                                $response['message']                            = "Detention saved unsuccessfully.";
                            }
                        }
                    }
                }else{
                    $loadDetail                                                 = LoadDetail::where('id',$request->id)->first();
                    if(!is_null($loadDetail)){
                        if($request->detention_status==0){
                            $whereArray                                         = [];
                            if($request->has('detention_id') && $request->detention_id!=''){
                                $whereArray['id']                               = $request->detention_id;
                            }else{
                                $whereArray['load_detail_id']                   = $loadDetail->id;
                                $whereArray['driver_id']                        = $request->driver_id;
                                $whereArray['broker_id']                        = $request->broker_id;
                                if($param['shipper_is_arrived']==1){
                                    $whereArray['type']                         = 1;
                                }elseif($param['delivery_is_arrived']==1){
                                    $whereArray['type']                         = 2;
                                }
                                $whereArray['is_stop']                          = 0;
                            }

                            $query                                              = LoadDetention::query();
                            foreach($whereArray as $field => $value) {
                                $query->where($field, $value);
                            }
                            if($query->delete()){
                                $this->setLoadAudit($query->load_detail->load_id, 'delete', 'Load detention deleted', ['deleted_at' => $query->deleted_at], ['deleted_at' => null]);
                                $response['success']                            = true;
                                $response['message']                            = "Detention cancel successfully.";
                            }else{
                                $response['success']                            = false;
                                $response['message']                            = "Detention cancel unsuccessfully.";
                            }
                        }elseif (in_array($request->detention_status, [1,2,3])) {
                            $whereArray                                         = [];
                            if($request->has('detention_id') && $request->detention_id!=''){
                                $whereArray['id']                               = $request->detention_id;
                            }else{
                                $whereArray['load_detail_id']                   = $loadDetail->id;
                                $whereArray['driver_id']                        = $request->driver_id;
                                $whereArray['broker_id']                        = $request->broker_id;
                                if($param['shipper_is_arrived']==1){
                                    $whereArray['type']                         = 1;
                                }elseif($param['delivery_is_arrived']==1){
                                    $whereArray['type']                         = 2;
                                }
                                $whereArray['is_stop']                          = 0;
                            }

                            $array                                              = [];

                            if(isset($request->broker_id) && !empty($request->broker_id)){
                                $getBrokerdata                                  = Broker::find($request->broker_id);
                                $array['free_time']                             = $getBrokerdata->detention_time;
                                $array['rate']                                  = $getBrokerdata->detention_price;
                            }

                            $array['load_detail_id']                            = $loadDetail->id;
                            //if(!$request->has('detention_id') || $request->detention_id=='')
                            $array['driver_id']                                 = $request->driver_id;
                            $array['broker_id']                                 = $request->broker_id;
                            if($param['shipper_is_arrived']==1){
                                $array['type']                                  = 1;
                            }elseif($param['delivery_is_arrived']==1){
                                $array['type']                                  = 2;
                            }
                            $array['detention_status']                          = $request->detention_status;
                            if($request->detention_status==2){
                                $array['stopped_user_type']                     = 'Driver';
                                $array['stopped_at']                            = Carbon::now();
                                $array['stopped_by']                            = auth()->guard('driver-admin')->user()->id;

                                $array['review_user_type']                      = 'Driver';
                                $array['review_status']                         = 'Detention Stopped - Pending Approval';
                                $array['review_at']                             = Carbon::now();
                                $array['review_by']                             = auth()->guard('driver-admin')->user()->id;
                            }elseif ($request->detention_status==1) {
                                $array['review_user_type']                      = 'Driver';
                                $array['review_status']                         = 'In Progress';
                                $array['review_at']                             = Carbon::now();
                                $array['review_by']                             = auth()->guard('driver-admin')->user()->id;
                            }
                            $array['detention_start_time']                      = ($request->detention_start_time)?convertTimeToUTCzone(['str' => $request->detention_start_time, 'toFormat'=> 'Y-m-d H:i:s', 'fromFormat' => getTimeLayout(), 'userTimezone' => $getGeoTimeZone]):null;
                            if(in_array($request->detention_status, [2,3])){
                                if($request->detention_status==2){
                                    $array['detention_end_time']                = Carbon::now();
                                }else{
                                    $array['detention_end_time']                = ($request->detention_end_time)?convertTimeToUTCzone(['str' => $request->detention_end_time, 'toFormat'=> 'Y-m-d H:i:s', 'fromFormat' => getTimeLayout(), 'userTimezone' => $getGeoTimeZone]):Carbon::now();
                                }
                            }

                            if($request->has('detention_id') && $request->detention_id!=''){
                                $oldData                                        = LoadDetention::query();
                                foreach ($whereArray as $key => $value) {
                                    $oldData->where($key, $value);
                                }
                                $oldData                                        = $oldData->first();
                            }

                            $item                                               = LoadDetention::updateOrCreate($whereArray,$array);
                            if($item){
                                if($item->wasChanged() && isset($oldData)){
                                    $this->setLoadAudit($item->load_detail->load_id, 'update', 'Load detention updated', $item->getChanges(), $oldData->toArray());
                                }
                                if(in_array($item->detention_status, [1,2]) && isset($item->driver)){
                                    $driver                                     = $item->driver;
                                    if(isset($driver->dispatcher)){
                                        $dispatcher                             = $driver->dispatcher;
                                        $name                                   = 'Load: '.$loadDetail->load_number.' - ';
                                        if($item->type==1){
                                            $name                              .= 'Pickup';
                                        }else{
                                            $name                              .= 'Delivery';
                                        }
                                        $description                            = '';
                                        if($item->detention_status==1){
                                            $description                        = $driver->full_name.' has started a detention for '.$loadDetail->load_number.': '.$loadDetail->load_number.' at '.date("Y-m-d H:i:s", strtotime($item->created_at)).' please review';
                                        }else{
                                            $description                        = $driver->full_name.' has stopped a detention for '.$loadDetail->load_number.': '.$loadDetail->load_number.' at '.date("Y-m-d H:i:s", strtotime($item->stopped_at)).' please review';
                                        }
                                        createNotification(
                                            ($item->detention_status==1)?17:18, // source
                                            $name, // name
                                            $dispatcher->id, // user_id
                                            $dispatcher->type, // user_type
                                            2, // type
                                            $item->id, // action_id
                                            $description, // description
                                            'Notification', // module
                                            [], // properties
                                            $dispatcher->company_id // company_id
                                        );
                                    }
                                }
                                $response['data']                               = $item;
                                $response['success']                            = true;
                                $response['message']                            = "Detention saved successfully.";
                            }else{
                                $response['success']                            = false;
                                $response['message']                            = "Detention saved unsuccessfully.";
                            }
                        }
                    }
                }
            } catch (\Exception $e) {
                $response['success']                                            = false;
                $response['message']                                            = $e->getMessage();
            }
        }
        return response()->json($response);
    }
}
