<?php

namespace App\Http\Controllers\DriverAdmin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Session;

use App\Models\Driver;
use App\Models\TwoFactorSetting;

class TwoFactorAuthenticationController extends Controller
{
    public function index()
    {
        if(Session::has('driverAdmin-2fa')){
            return redirect()->route('driver.admin.home');
        }

        $twoFactorSettings  = TwoFactorSetting::IsDriverAdmin()->first();
        return view('auth.two-factor.driverAdmin.index', compact('twoFactorSettings'));
    }

    public function verifyCode(Request $request)
    {
        $request->validate(
            ['two_factor_secret' => 'required'],
            ['two_factor_secret.required' => 'Please enter 2-factor verification code.']);

        $user               = auth()->guard('driver-admin')->user();
        $userDetails        = Driver::IsDriverCompany()->where('id', $user->id)->where('two_factor_secret', $request->two_factor_secret)->first();
        if (!is_null($userDetails)) {
            Session::put('driverAdmin-2fa', $user->id);

            // Check if the intended URL is set in the session
            $intendedUrl    = Session::has('driver.url.intended') ? Session::get('driver.url.intended', '/driver-admin/home') : '/driver-admin/home';
            Session::forget('driver.url.intended'); // Clear the stored URL
            return redirect()->intended($intendedUrl); // return redirect()->route('driver.admin.home');
        }
        return back()->with('error', 'You entered wrong code.');
    }

    public function resendCode(Request $request)
    {
        auth()->guard('driver-admin')->user()->generateTwoFactorCode();
        return back()->with('success', 'We sent you code on your email.');
    }
}
