<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\FacadesLog;

use App\Post;
use App\Response;
use App\Models\EmailChatHistory;
use App\Models\EmailChatAttachements;
use App\Models\CompanyAdmin;
use App\Models\Driver;
use App\Models\Company; // Added at 18-04-2023
use App\Models\Broker; // Added at 11-04-2023
use App\Models\Customer; // Added at 11-04-2023
use App\Models\BrokerContact; // Added at 11-04-2023

use SendGrid\Mail\To;
use SendGrid\Mail\Cc;
use SendGrid\Mail\Bcc;
use SendGrid\Mail\From;
use SendGrid\Mail\Content;
use SendGrid\Mail\Mail;
use SendGrid\Mail\Personalization;
use SendGrid\Mail\Subject;
use SendGrid\Mail\Header;
use SendGrid\Mail\CustomArg;
use SendGrid\Mail\SendAt;
use SendGrid\Mail\Attachment;
use SendGrid\Mail\Asm;
use SendGrid\Mail\MailSettings;
use SendGrid\Mail\BccSettings;
use SendGrid\Mail\SandBoxMode;
use SendGrid\Mail\BypassListManagement;
use SendGrid\Mail\Footer;
use SendGrid\Mail\SpamCheck;
use SendGrid\Mail\TrackingSettings;
use SendGrid\Mail\ClickTracking;
use SendGrid\Mail\OpenTracking;
use SendGrid\Mail\SubscriptionTracking;
use SendGrid\Mail\Ganalytics;
use SendGrid\Mail\ReplyTo;
use File;
use DB; // Added at 14-04-2023
use Illuminate\Support\Str; // Added at 14-04-2023
use GuzzleHttp\Client;

class SendGridController extends Controller
{
    public function sendEmail(Request $request)
    {
        try {
            $fromDomain = env("SENDGRID_FROM_EMAIL");

        	$sendEmail = \Mail::mailer('sendgrid')
            ->to($request->toAddress, $request->toName)
            ->send(new \App\Mail\FirstEmail($fromDomain, $request->fromName));

        	if( \Mail::failures() != 0) {
                return response()->json([
    				'success' => true,
    		        'message' => 'Success! Your E-mail has been sent.'
        		]);
        	} else {
        		return response()->json([
    				'success' 	=> false,
    		        'message' 	=> 'Failed! Your E-mail has not sent.'
        		]);
        	}
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );
        }
    }

    public function sendChatEmail(Request $request)
    {
        try {
            // Added at 18-04-2023
            $company = Company::where('id', $request->company_id)->first();
            
            $replyToEmail = str_replace(" ", "_", strtolower($company->shortname)).'@info.compellabs.com';

            $data['subject'] = $request->subject;
            
            $data['body'] = nl2br($request->content);

            $apiKey = getenv('SENDGRID_WEB_API_KEY');
            $sg = new \SendGrid($apiKey);

            $mail = new Mail();

            $fromDomain = env("SENDGRID_FROM_EMAIL");

            $personalization = new Personalization();
            $personalization->addTo( new To($request->toAddress, $request->toName) );
            $mail->addPersonalization($personalization);

            $mail->setFrom(new From($fromDomain, $request->fromName));

            $mail->setReplyTo(new ReplyTo($replyToEmail, $company->name));

            $mail->setSubject(new Subject($data['subject']));

            $mail->addContent(new Content("text/html", $data['body']));

            $attachements = [];

            if( isset( $request->totalImages ) && $request->totalImages > 0 ) {
                foreach( $request->images as $key => $file ) {
                    $filename = "attachement_".$key."_".$request->company_id."_".$request->from_id."_".time().".".$file->getClientOriginalExtension();
                    $mimetype = $file->getMimeType();

                    // $folderPath = public_path('companyAdmin/attachment/'.$request->company_id.'/'.$request->from_id);
                    $folderPath = public_path('companyAdmin/attachment/'.$request->company_id);

                    if(!File::exists($folderPath)) {
                        File::makeDirectory($folderPath, $mode = 0777, true, true);
                    }

                    $img_path = $file->move( $folderPath, $filename );
                    
                    $attachements[$key]['path'] = $filename;
                    $attachements[$key]['type'] = $mimetype;

                    $file_encoded = base64_encode(file_get_contents($folderPath.'/'.$filename));

                    $attachment = new Attachment();
                    $attachment->setContent($file_encoded);
                    $attachment->setFilename($filename);
                    $attachment->setType($mimetype);
                    $attachment->setDisposition("attachment");
                    $mail->addAttachment($attachment);
                }
            }

            $tracking_settings = new TrackingSettings();
            $click_tracking = new ClickTracking();
            $click_tracking->setEnable(true);
            $click_tracking->setEnableText(false);
            $tracking_settings->setClickTracking($click_tracking);
            $open_tracking = new OpenTracking();
            $open_tracking->setEnable(true);
            $open_tracking->setSubstitutionTag("%open-track%");
            $tracking_settings->setOpenTracking($open_tracking);
            $mail->setTrackingSettings($tracking_settings);

            $request_body = $mail;

            try {
                $response = $sg->client->mail()->send()->post($request_body);

                if( $response->statusCode() == 202 ) {
                    $headers = $response->headers();
                    $msg_id = explode(": ", $headers[5])[1];

                    $data = array(
                        'company_id' => $request->company_id,
                        'unique_id_sender' => $request->guard.'_'.$request->from_id,
                        'unique_id_receiver' => $request->guard.'_'.$request->to_id,
                        'msg_id' => $msg_id,
                        'type' => 'sent',
                        'from_email' => $fromDomain,
                        'to_email' => $request->toAddress,
                        'subject' => $data['subject'],
                        'msg_body' => $data['body'],
                        'email_date' => now(),
                        'created_at' => now(),
                        'updated_at' => now()
                    );

                    $storeEmail = EmailChatHistory::create( $data );

                    foreach( $attachements as $key => $value ) {
                        $atchArr = array(
                            'chat_email_id' => $storeEmail->id,
                            'file_path' => $value['path'],
                            'file_type' => $value['type'],
                            'created_at' => now(),
                            'updated_at' => now()
                        );

                        $storeAttachement = EmailChatAttachements::insert( $atchArr );
                    }

                    $company_id = $request->company_id;
                    $toAddress = $request->toAddress;
                    $fromAddress = $fromDomain;

                    $skip = 0;
                    $take = 5;

                    $historyEmail = $this->emailHistory( $company_id, $fromAddress, $toAddress, $request->from_id, $skip, $take );

                    $resp['success'] = true;
                    $resp['msg'] = 'Email has been sent successfully';
                    $resp['data'] = $historyEmail;
                    return response()->json($resp);
                } else {
                    $body = json_decode( $response->body() );
                    $err_msg = $body->errors[0]->message;

                    \Log::emergency( $response->headers() );

                    $resp['success'] = false;
                    $resp['msg'] = $err_msg;
                    return response()->json($resp);
                }                
            } catch (Exception $ex) {
                echo 'Caught exception: '.  $ex->getMessage();
            }
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );
        }
    }

    public function getChatEmailHistory(Request $request)
    {
        try {
            $apiKey = getenv('SENDGRID_WEB_API_KEY');
            $sg = new \SendGrid($apiKey);
            $fromDomain = env("SENDGRID_FROM_EMAIL");

            $company_id = $request->company_id;
            $guard = $request->guard;
            $toAddress = $request->toAddress;
            $to_id = $request->to_id;
            $from_id = $request->from_id;
            $fromAddress = $fromDomain;

            $skip = 0;
            $take = $request->take;

            $totalHistoryEmail = EmailChatHistory::with('attachements')->where( 'company_id', $company_id )
            ->where(function ($query) use ( $fromAddress, $toAddress ) {
                $query->where('from_email', '=', $toAddress)
                ->orWhere('to_email', '=', $toAddress);
            })
            ->count();

            $historyEmail = $this->emailHistory( $company_id, $fromAddress, $toAddress, $from_id, $skip, $take );

            $resp['success'] = true;
            $resp['data'] = $historyEmail;
            $resp['total'] = $totalHistoryEmail;
            $resp['msg'] = 'Email communication received';
            return response()->json($resp);
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );
        }
    }

    public function searchChatEmailHistory(Request $request)
    {
        try {
            $apiKey = getenv('SENDGRID_WEB_API_KEY');
            $sg = new \SendGrid($apiKey);
            $fromDomain = env("SENDGRID_FROM_EMAIL");

            $company_id = $request->company_id;
            $guard = $request->guard;
            $toAddress = $request->toAddress;
            $to_id = $request->to_id;
            $from_id = $request->from_id;
            $fromAddress = $fromDomain;

            $totalHistoryEmail = EmailChatHistory::with('attachements')->where( 'company_id', $company_id )
            ->where(function ($query) use ( $toAddress ) {
                $query->where('from_email', '=', $toAddress)
                ->orWhere('to_email', '=', $toAddress);
            })
            ->count();

            $skip = 0;
            $take = $totalHistoryEmail;

            $historyEmail = $this->emailHistory( $company_id, $fromAddress, $toAddress, $from_id, $skip, $take, $request->search_txt );

            $resp['success'] = true;
            $resp['data'] = $historyEmail;
            $resp['total'] = $totalHistoryEmail;
            $resp['msg'] = 'Email communication received';
            return response()->json($resp);
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );
        }
    }

    public function loadMoreChatEmailHistory(Request $request)
    {
        try {
            // dd($request->all());
            $fromDomain = env("SENDGRID_FROM_EMAIL");
            
            $to_id = $request->to_id;
            $from_id = $request->from_id;
            $company_id = $request->company_id;
            $guard = $request->guard;
            $toAddress = $request->toAddress;
            $fromAddress = $fromDomain;

            $skip = 0;
            $take = $request->take;

            $totalHistoryEmail = EmailChatHistory::with('attachements')->where( 'company_id', $company_id )
            ->where(function ($query) use ( $toAddress ) {
                $query->where('from_email', '=', $toAddress)
                ->orWhere('to_email', '=', $toAddress);
            })
            ->count();

            $historyEmail = $this->emailHistory( $company_id, $fromAddress, $toAddress, $from_id, $skip, $take );

            $resp['success'] = true;
            $resp['data'] = $historyEmail;
            $resp['total'] = $totalHistoryEmail;
            $resp['msg'] = 'Email communication received';
            return response()->json($resp);
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );
        }
    }

    public function emailHistory( $company_id, $fromAddress, $toAddress, $from_id, $skip, $take, $search = '' )
    {
        if( $search == '' ) {
            $historyEmail = EmailChatHistory::with('attachements')->where( 'company_id', $company_id )
            ->where(function ($query) use ( $toAddress ) {
                $query->where('from_email', '=', $toAddress)
                ->orWhere('to_email', '=', $toAddress);
            })
            ->skip($skip)->take($take)
            ->orderBy('id', 'DESC')
            ->get()
            ->toArray();
        } else {
            $historyEmail = EmailChatHistory::with('attachements')->where( 'company_id', $company_id )
            ->where(function ($query) use ( $toAddress ) {
                $query->where('from_email', '=', $toAddress)
                ->orWhere('to_email', '=', $toAddress);
            })
            ->where( 'msg_body', 'like', '%'.$search.'%' )
            ->orwhere( 'subject', 'like', '%'.$search.'%' )
            ->skip($skip)->take($take)
            ->orderBy('id', 'DESC')
            ->get()
            ->toArray();
        }
        // dd( $historyEmail );

        if( count( $historyEmail ) > 0 ) {
            foreach( $historyEmail as $key => $value ) {
                // Added at 14-04-2023
                EmailChatHistory::where('id', $value['id'])->update(['is_email_read' => 1]);

                $historyEmail[$key]['msg_align_class'] = $value['type'] == 'sent' ? 'chat-mianRight' : 'chat-mianLeft';
                $historyEmail[$key]['time'] = date( 'd-m-Y H:i:s', strtotime( $value['email_date'] ) );

                $find = ["<p>%open-track%</p>"];
                $replace   = [""];

                $msg_body = '<div class="chat-body text-left">';
                $msg_body .= '<h6 style="font-size:15px">Subject: '.$value['subject'].'</h6></br>';
                $msg_body .= str_replace($find, $replace, $value['msg_body']);
                $msg_body .= '</div>';

                if( count( $value['attachements'] ) > 0 ) {
                    $atch = [];
                    foreach( $value['attachements'] as $k => $v ) {
                        // $folderPath = url('companyAdmin/attachment/'.$value['company_id'].'/'.$from_id).'/'.$v['file_path'];
                        // Added at 14-04-2023
                        $folderPath = url('companyAdmin/attachment/'.$value['company_id']).'/'.$v['file_path'];
                        $atch[] = $folderPath;
                    }

                    $allFiles = implode( "|", $atch );
                    $historyEmail[$key]['files'] = $allFiles;

                    // Added at 14-04-2023
                    $atcClass = 'text-white';
                    if( $value['type'] == 'received' ) {
                        $atcClass = 'text-black';
                    }
                    $msg_body .= '<a href="javascript:void(0)" class="'.$atcClass.' downloadAllFiles" data-urls="'.$allFiles.'"><i class="fa fa-paperclip"></i></a>';
                }

                $historyEmail[$key]['message'] = $msg_body;

                $historyEmail[$key]['files'] = '';                
            }
        }

        return $historyEmail;
    }

    public function handle(Request $request)
    {
        $event = $request->all();
        // Store the relevant information from the event payload
        \Log::info($event);
        return response()->json(['success' => true]);
    }

    public function receiveEmailResponse(Request $request)
    {
        \Log::info('Email response received');
        \Log::info( $request->all() );

        // in any case, return a 200 OK response so SendGrid knows we are done.
        return response()->json(["success" => true]);
    }

    /* Added at 14-04-2023 */
    public function incomingEmail(Request $request)
    {
        try {
            /*$apiKey = getenv('SENDGRID_API_KEY');
            $sg = new \SendGrid($apiKey);

            $request_body = array(
                "url" => "https://59f2-203-192-202-163.ngrok-free.app/incoming-email-sendgrid",
                "hostname" => "compellabs.com",
                "spam_check" => true,
                "send_raw" => true
            );

            try {
                $response = $sg->client->user()->webhooks()->parse()->settings()->post($request_body);
                \Log::info( 'statusCode: '.$response->statusCode() );
            } catch (Exception $ex) {
                \Log::emergency($ex->getMessage());
            }*/

            \Log::info('Email response received');
            $payload = $request->all();
            \Log::emergency($payload);

            $from = $payload['from'];
            $to = $payload['to'];
            $subject = $payload['subject'];
            $body = $request->input('text');
            $bodyhtml = $request->input('html');
            $headers = $request->input('headers');
            $num_attachments = $request->input("attachments");

            preg_match("#<(.*?)>#", $from, $sender);
            $fromAddress = $sender[1];
            
            if( preg_match("#<(.*?)>#", $to, $receipient) ) {
                \log::emergency("***********************************");
                \log::emergency($receipient);
                \log::emergency("***********************************");
                $toAddress = $receipient[1];
            } else {
                $toAddress = $to;
            }

            $company_id = 0;

            if( $toAddress ) {
                $company_shortname = str_replace("_", " ", explode("@", $toAddress)[0]);
                \log::emergency("***********company_shortname************************");
                \log::emergency($company_shortname);
                \log::emergency("**************company_shortname*********************");
                $company = Company::select('id')->where( 'shortname', $company_shortname )->first();
                // $company1 = Company::select('id')->where( 'shortname', $company_shortname )->first()->toSql();
                \log::emergency("***********company************************");
                \log::emergency($company);
                \log::emergency($company->toSql());
                \log::emergency("**************company*********************");
                if( $company ) {
                    $company_id = $company->id;
                }
            }

            $msg_id = $this->getBetween($headers,"Message-ID: <",">");

            $sender_id = 'Unknown_'.$fromAddress;

            // Search above email in company admin table
            $user = CompanyAdmin::where("email", $fromAddress)->first();
            $from_id = 0;

            if( $user ) {
                $sender_id = 'company-admin_'.$user->id;
                $from_id = $user->id;
            } else {
                $user = Driver::where("email", $fromAddress)->first();

                if( $user ) {
                    $sender_id = 'driver-admin_'.$user->id;
                    $from_id = $user->id;
                }
                else{
                    $user = Broker::where("email", $fromAddress)->first();
                        if( $user ) {
                        $sender_id = 'broker_'.$user->id;
                        $from_id = $user->id;
                    }
                    else{
                            $user = BrokerContact::where("email", $fromAddress)->first();
                        if( $user ) {
                            $sender_id = 'broker_contact_'.$user->id;
                            $from_id = $user->id;
                        }
                        else{
                            $user = Customer::where("email", $fromAddress)->first();
                            if( $user ) {
                                $sender_id = 'shipper_consignee_'.$user->id;
                                $from_id = $user->id;
                            }
                        }
                    }
                }
            }

            \Log::emergency( 'fromAddress: '.$fromAddress );
            \Log::emergency( 'toAddress: '.$toAddress );
            \Log::emergency( 'subject: '.$subject );
            \Log::emergency( 'body: '.$body );
            \Log::emergency( 'msg_id: '.$msg_id );
            \Log::emergency( 'sender_id: '.$sender_id );
            \Log::emergency( 'company_id: '.$company_id );
            \Log::emergency( 'from_id: '.$from_id );
            \Log::emergency( 'bodyhtml: '.$bodyhtml );

            $data = array(
                'company_id' => $company_id,
                'unique_id_sender' => $sender_id,
                'unique_id_receiver' => $toAddress,
                'msg_id' => $msg_id,
                'type' => 'received',
                'from_email' => $fromAddress,
                'to_email' => $toAddress,
                'subject' => $subject,
                'msg_body' => $body,
                'is_email_read' => 0,
                'email_date' => now(),
                'created_at' => now(),
                'updated_at' => now()
            );

            $storeEmail = EmailChatHistory::create( $data );

            if( $num_attachments ) {
                for($i = 1; $i <= $num_attachments; $i++) {
                    $file = $request->file('attachment'.$i);
                    $name = Str::random(10) . '-' . Str::random(5) . '-' . Str::random(8);
                    $filename = "attachement_".$i."_".$name.".".$file->getClientOriginalExtension();
                    $mimetype = $file->getMimeType();
                    $folderPath = public_path('companyAdmin/attachment/'.$company_id);

                    if(!File::exists($folderPath)) {
                        File::makeDirectory($folderPath, $mode = 0777, true, true);
                    }

                    $img_path = $file->move( $folderPath, $filename );

                    $atchArr = array(
                        'chat_email_id' => $storeEmail->id,
                        'file_path' => $filename,
                        'file_type' => $mimetype,
                        'created_at' => now(),
                        'updated_at' => now()
                    );

                    $storeAttachement = EmailChatAttachements::insert( $atchArr );
                }
            }

            // in any case, return a 200 OK response so SendGrid knows we are done.
            return response()->json(["success" => true]);
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );
        }
    }

    /* Added at 14-04-2023 */
    public function getUnreadEmails(Request $request)
    {
        try {
            $company_id = $request->company_id;

            $selectedEmails = [];

            if( isset( $request->emails ) ) {
                $selectedEmails = $request->emails;
            }

            $unreadEmail = EmailChatHistory::select('from_email', DB::raw('count(*) as total'))->where( 'company_id', $company_id )
            ->groupBy('from_email')
            ->where('type', 'received')
            // ->whereNotIn('from_email', $selectedEmails)
            ->where('is_email_read', 0)
            ->orderBy('id','DESC')
            ->take(5)
            ->get();

            $data = [];
            $mails = [];

            $mailchaticn = asset("theme/images/mail-chat.png");

            foreach( $unreadEmail as $key => $value ) {
                $sender_id = $value->from_email;

                // Search above email in company admin table
                $user = CompanyAdmin::where("email", $sender_id)->first();
                $guard = '';
                $id = '';
                $name = $sender_id;
                $toemail = $sender_id;

                if( $user ) {
                    $guard = 'company-admin';
                    $id = $user->id;
                    $name = ucwords($user->first_name.' '.$user->last_name);
                } else {
                    $user = Driver::where("email", $sender_id)->first();

                    if( $user ) {
                        $guard = 'driver-admin';
                        $id = $user->id;
                        $name = ucwords($user->first_name.' '.$user->last_name);
                    }
                    else{
                        $user = Broker::where("email", $sender_id)->first();
                         if( $user ) {
                            $guard = 'company-admin';
                            $id = $user->id;
                            $name = ucwords($user->name);
                        }
                        else{
                             $user = BrokerContact::where("email", $sender_id)->first();
                            if( $user ) {
                                $guard = 'company-admin';
                                $id = $user->id;
                                $name = ucwords($user->name);
                            }
                            else{
                                $user = Customer::where("email", $sender_id)->first();
                                if( $user ) {
                                    $guard = 'company-admin';
                                    $id = $user->id;
                                    $name = ucwords($user->name);
                                }
                            }
                        }
                    }
                }

                $getBeforeEmailPart = explode('@', $toemail)[0];
                $li_id = base64_encode($getBeforeEmailPart);
                $datakey = preg_replace('/[^a-zA-Z0-9]/', '', $li_id);

                $mails[] = array(
                    'id' => $id,
                    'guard' => $guard,
                    'toname' => $name,
                    'liid' => $datakey,
                    'toemail' => $toemail,
                    'mailchaticn' => $mailchaticn,
                    'total' => $value->total
                );

                $data[] = '<li id="'.$datakey.'"><a href="javascript:void(0)" data-guard="'. $guard .'" data-id="'. $id .'" data-toname="'. $name .'" data-key="'.$datakey.'" data-toemail="'. $toemail .'" class="receiveEmail"><span class="chatMenu-img" style="background-image:url('. $mailchaticn .');"></span><span>'. $toemail .'</span><div id="urdEmailCnt_'.$datakey.'" title="Unread Emails" class="badge badge-info position-absolute" style="right: 0%;">'.$value->total.'</div></a></li><input type="hidden" name="selectedEmail[]" class="selected_emails" value="'. $toemail .'">';
            }

            $response['success'] = true;
            $response['data'] = $data;
            $response['mails'] = $mails;
            return response()->json( $response );
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );

            $response['success'] = false;
            $response['msg'] = $e->getMessage();
            return response()->json( $response );
        }
    }

    public function checkUnreadEmails(Request $request)
    {
        try {
            $company_id = $request->company_id;

            $data = EmailChatHistory::select('from_email')->where( 'company_id', $company_id )
            ->groupBy('from_email')
            ->where('type', 'received')
            ->where('is_email_read', 0)
            ->orderBy('id','DESC')
            ->pluck('from_email')
            ->toArray();

            $response['success'] = true;
            $response['data'] = $data;
            return response()->json( $response );
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );

            $response['success'] = false;
            $response['msg'] = $e->getMessage();
            return response()->json( $response );
        }
    }

    function getBetween($string, $start = "", $end = "")
    {
        if (strpos($string, $start)) {
            $startCharCount = strpos($string, $start) + strlen($start);
            $firstSubStr = substr($string, $startCharCount, strlen($string));
            $endCharCount = strpos($firstSubStr, $end);
            if ($endCharCount == 0) {
                $endCharCount = strlen($firstSubStr);
            }
            return substr($firstSubStr, 0, $endCharCount);
        } else {
            return '';
        }
    }
}
