<?php

namespace App\Http\Controllers;

use Twilio\Rest\Client;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Log;

use App\Models\Company; // Added at 10-04-2023
use App\Models\CompanyAdmin; // Added at 10-04-2023
use App\Models\SmsChatHistory; // Added at 10-04-2023
use App\Models\Driver;
use App\Models\Broker; // Added at 11-04-2023
use App\Models\Customer; // Added at 11-04-2023
use App\Models\BrokerContact; // Added at 11-04-2023


class TwilioController extends Controller
{
    public function sendSms(Request $request)
    {
        $client 	= new Client(env('TWILIO_SID'), env('TWILIO_AUTH_TOKEN'));
        $message 	= $client->messages->create(
        	// Where to send a text message (your user's phone number)
            $request->to,
            [
                'from' => env('TWILIO_NUMBER'),
                'body' => $request->message
            ]
        );
        return response()->json(['message' => 'SMS sent successfully','sid' => $message->sid]);
    }

    public function receiveSms(Request $request)
    {
        try {
            $event = $request->all();
            $company_id = $event['company_id'];
            $from = substr($event['From'], -10);

            $cell_phone = preg_replace('/(\d{3})(\d{3})(\d{4})/', '($1) $2-$3', $from);
            // dd($cell_phone);

            $sender_id = 'unknown_0';
            $table_name = '';

            // Search above number in company admin table
            $user = CompanyAdmin::where("cell_phone", $cell_phone)->first();

            if( $user ) {
                $sender_id = 'company-admin_'.$user->id;
                $table_name = 'company_admins';
            } else {
                $user = Driver::where("cell_phone", $cell_phone)->first();

                if( $user ) {
                    $sender_id = 'driver-admin_'.$user->id;
                    $table_name = 'drivers';
                }
                else{
                    $user = Broker::where("phone_number", $fromAddress)->first();
                        if( $user ) {
                        $sender_id = 'broker_'.$user->id;
                        $table_name = 'brokers';
                    }
                    else{
                            $user = BrokerContact::where("phone_number", $fromAddress)->first();
                        if( $user ) {
                            $sender_id = 'broker_contact_'.$user->id;
                            $table_name = 'broker_contacts';
                        }
                        else{
                            $user = Customer::where("phone", $fromAddress)->first();
                            if( $user ) {
                                $sender_id = 'shipper_consignee_'.$user->id;
                                $table_name = 'broker_contacts';
                            }
                        }
                    }
                }
            }

            $data = array(
                'company_id' => $company_id,
                'unique_id_sender' => $sender_id,
                'table_name' => $table_name,
                'msg_id' => $event['MessageSid'],
                'type' => 'received',
                'from_number' => $event['From'],
                'to_number' => $event['To'],
                'msg_body' => $event['Body'],
                'sms_date' => now(),
                'created_at' => now(),
                'updated_at' => now()
            );

            $storeSms = SmsChatHistory::create( $data );

            // Store the relevant information from the event payload            
            // Log::info($event);
            return response()->json(['success' => true]);
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );
        }
    }

    public function twilioFailure(Request $request)
    {
        try {
            $event = $request->all();
            Log::info($event);
            return response()->json(['success' => true]);
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );
        }
    }
}
