<?php

namespace App\Http\Requests\CompanyAdmin;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Request;

class DriverUpdateRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules(Request $request)
    {
        return [
            'first_name'    => 'required',
            'last_name'     => 'required',
            'address'       => 'required',
            'start_date'    => 'required',
            'email'         => 'required|email|unique:drivers,email,'.$request->segment(3).',id,deleted_at,NULL',
            'cell_phone'    => 'nullable|required_if:sms,1|size:14',
            'home_phone'    => 'nullable|size:14',
            'ssn'           => 'nullable|size:11',
            'ein'           => 'nullable|size:10',
        ];
    }

    /**
     * Custom message for validation
     *
     * @return array
     */
    public function messages()
    {
        return [
            'cell_phone.required_if' => 'The cell phone is required when sms is active.',
            'cell_phone.size' => 'The cell phone must be 10 digits.',
            'home_phone.size' => 'The home phone must be 10 digits.',
            'ssn.size' => 'The social security number must be 9 digits.',
            'ein.size' => 'The employer identification number must be 9 digits.',
            'ssn.numeric' => 'The social security number must be a number.',
            'ssn.digits' => 'The social security number must be 9 digits.',
            'ein.numeric' => 'The employer identification number must be a number.',
            'ein.digits' => 'The employer identification number must be 9 digits.',
        ];
    }
}
