<?php

use App\Models\Team;
use App\Models\Driver;
use App\Models\DriverFinancial;

function getTest(){
    return 'Test';
}

function getTeamsC($get_quarter,$get_year,$weekStartDate,$weekEndDate,$company_id){
    $allTeams = Team::where('teams.company_id', '=', $company_id)
        ->Join('drivers', 'drivers.team_id', '=', 'teams.id')
        ->Join('load_details', 'load_details.driver_id', '=', 'drivers.id')
        ->leftjoin('driver_financials', function ($join) use ($get_quarter, $get_year) {
            $join->on('teams.id', '=', 'driver_financials.team_id')
                ->where('driver_financials.year', $get_year)
                ->where('driver_financials.quarter', $get_quarter)
                ->where('driver_financials.team_id', '<>', 'teams.id');
        })
        ->select('teams.*', 'driver_financials.*', 'drivers.*', 'load_details.*')
        ->whereNotNull('teams.id')
        ->whereNull('driver_financials.driver_id')
        ->orWhere('driver_financials.team_id', '<>', 'teams.id')
        ->groupBy('teams.id')
        ->get();
    return $allTeams;

}

 function getDriverLoads($get_quarter,$get_year,$getTeamsdata,$company_id){
    $loadDriGet = Driver::select("teams.name as team_name", "drivers.id as driverid", "drivers.company_id as driver_company_id",
         "drivers.first_name", "drivers.last_name", "drivers.middle_name", "driver_financials.revenue_target as wgrr_seasonal",
         "driver_financials.occupancy as occupancy_commitment", "load_details.driver_id", "load_details.load_id",
         "load_details.load_type", "load_details.is_disable", "load_details.agreed_upon_rate", "load_details.detention",
         "load_details.accessorial", "load_details.fuel_surcharge_cost_per_mile", "load_details.shipper_city",
         "load_details.shipper_state", "load_details.delivery_city", "load_details.delivery_state",
         "load_details.load_number", "load_details.load_status", "load_details.actual_delivery_date",
         "load_drivers.load_detail_id")
        ->join("driver_informations", "driver_informations.driver_id", "=", "drivers.id")
        ->leftjoin("teams", "teams.id", "=", "drivers.team_id")
        ->leftjoin('driver_financials', function ($join) use ($get_quarter, $get_year) {
            $join->on('drivers.id', '=', 'driver_financials.driver_id')
                ->where('driver_financials.year', $get_year)
                ->where('driver_financials.quarter', $get_quarter);
        })
        ->leftjoin("load_details", "load_details.driver_id", "=", "drivers.id")
        ->leftjoin("load_drivers", "load_drivers.driver_id", "=", "drivers.id")
        ->leftjoin("loads", "loads.id", "=", "load_details.load_id")
        ->where('drivers.company_id', auth()->guard('company-admin')->user()->company_id)->where('drivers.id', $getTeamsdata->driver_id)
        ->where('teams.id', $getTeamsdata->team_id)
        ->groupBy('load_details.driver_id')
        ->orderByRaw('drivers.last_name ASC, drivers.first_name ASC')
        ->first();
    return $loadDriGet;
 }

function loadDetailCpmTarget($getTeamsdata,$year,$quarter){
    $loadDetail_cpm_target = DriverFinancial::where('driver_financials.driver_id', $getTeamsdata->driver_id)
        ->where('year', $year)
        ->where('quarter', $quarter)
        ->pluck('driver_financials.cpm_target')->first();
    return $loadDetail_cpm_target;
}

function dataPickupCount($getTeamsdata,$company_id,$quarter_date,$weekStartDate){
    $dataPickupCount = Driver::select("load_details.id")
        ->join("load_details", "load_details.driver_id", "=", "drivers.id")
        ->join("load_drivers", "load_drivers.load_detail_id", "=", "load_details.id")
        ->where('drivers.id', $getTeamsdata->driver_id)
        ->where('load_drivers.driver_id', $getTeamsdata->driver_id)
        ->where('drivers.company_id',$company_id)
        ->where(DB::raw('DATE_FORMAT(actual_shipper_date, "%Y-%m-%d")'), '<=', $quarter_date)
        ->where(DB::raw('DATE_FORMAT(actual_delivery_date, "%Y-%m-%d")'), '>=', $weekStartDate)
        ->where('load_details.occupied_pickup_day', 1)
        ->whereNotIn('load_details.load_type', [0, 4, 6])
        ->whereNull('load_details.deleted_at')
        ->count();
    return $dataPickupCount;
}

function dataPickupCountMonth($getTeamsdata,$company_id,$quarter_date,$weekStartDate,$monthData){
    $dataPickupCountMon = Driver::select("load_details.id")
        ->join("load_details", "load_details.driver_id", "=", "drivers.id")
        ->join("load_drivers", "load_drivers.load_detail_id", "=", "load_details.id")
        ->where('drivers.id', $getTeamsdata->driver_id)
        ->where('load_drivers.driver_id', $getTeamsdata->driver_id)
        ->where('drivers.company_id',$company_id)
        ->whereMonth('actual_delivery_date', $monthData)
        ->where(DB::raw('DATE_FORMAT(actual_shipper_date, "%Y-%m-%d")'), '<=', $quarter_date)
        ->where(DB::raw('DATE_FORMAT(actual_delivery_date, "%Y-%m-%d")'), '>=', $weekStartDate)
        ->where('load_details.occupied_pickup_day', 1)
        ->whereNotIn('load_details.load_type', [0, 4, 6])
        ->whereNull('load_details.deleted_at')
        ->count();
    return $dataPickupCountMon;
}

function dataPickupCountLastMonth($getTeamsdata,$company_id,$quarter_date,$weekStartDate,$lastMonth){
    $dataPickupCountMon = Driver::select("load_details.id")
        ->join("load_details", "load_details.driver_id", "=", "drivers.id")
        ->join("load_drivers", "load_drivers.load_detail_id", "=", "load_details.id")
        ->where('drivers.id', $getTeamsdata->driver_id)
        ->where('load_drivers.driver_id', $getTeamsdata->driver_id)
        ->where('drivers.company_id',$company_id)
        ->whereMonth('actual_delivery_date', $lastMonth)
        ->where(DB::raw('DATE_FORMAT(actual_shipper_date, "%Y-%m-%d")'), '<=', $quarter_date)
        ->where(DB::raw('DATE_FORMAT(actual_delivery_date, "%Y-%m-%d")'), '>=', $weekStartDate)
        ->where('load_details.occupied_pickup_day', 1)
        ->whereNotIn('load_details.load_type', [0, 4, 6])
        ->whereNull('load_details.deleted_at')
        ->count();
    return $dataPickupCountMon;
}

function getTwilioChatToken(){
    $user                       =  auth()->guard('company-admin')->user();
    if($user){
        $friendly_name          = $user->first_name.' '.$user->last_name;
        if( $user->type == 2 ) {
            $unique_identity    = 'dispatcher_'.$user->id;
        } else if( $user->type == 0 ) {
            $unique_identity    = 'company_admin_'.$user->id;
        } else if( $user->type == 1 ) {
            $unique_identity    = 'manager_'.$user->id;
        } else {
            $unique_identity    = '';
        }
    } else {
        $friendly_name          = '';
        $unique_identity        = '';
    }

    $baseUrl                    = env("NODE_CHAT_API_BASE_URL","http://localhost:8000");
    $data                       = array(
        'username'              => $unique_identity
    );

    $post_data                  = json_encode($data);
    // echo $post_data;
    // Prepare new cURL resource
    $crl                        = curl_init( $baseUrl.'/api/LoginParticipant');
    curl_setopt($crl, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($crl, CURLINFO_HEADER_OUT, true);
    curl_setopt($crl, CURLOPT_POST, true);
    curl_setopt($crl, CURLOPT_HEADER, true);
    curl_setopt($crl, CURLOPT_POSTFIELDS, $post_data);

    // Set HTTP Header for POST request
    curl_setopt($crl, CURLOPT_HTTPHEADER, array(
        'Content-Type: application/json' ,
        'Access-Control-Allow-Origin: * '
        // "Access-Control-Allow-Origin": "*",
    ));

    // Submit the POST request
    $result                     = curl_exec($crl);

    // handle curl error
    if ($result === false) {
        // throw new Exception('Curl error: ' . curl_error($crl));
        print_r('Curl error: ' . curl_error($crl));
        // $result_noti = 0;
        die();
    } else {
        // get cookie
        // multi-cookie variant contributed by @Combuster in comments

        // preg_match_all('/^Set-Cookie:\s*([^;]*)/mi', $result, $matches);
        // $cookies             = array();
        // foreach($matches[1] as $item) {
        //     parse_str($item, $cookie);
        //     $cookies         = array_merge($cookies, $cookie);
        // }
        // var_dump($cookies);

        $result_noti            = 1;
        // die();
        $header_size            = curl_getinfo($crl, CURLINFO_HEADER_SIZE);
        $header                 = substr($result, 0, $header_size);
        $body                   = substr($result, $header_size);
        $body                   = json_decode($body);
        $twilio_token           = '';
        if($body->success){
            $data               = $body->data;
            $twilio_token       = $data->token;
            setcookie("twilio_token", $twilio_token, time() + (86400 * 30), "/"); // 86400 = 1 day
        }
        else{
            setcookie("twilio_token", $twilio_token, time() - 36000, "/"); // expired
        }
        // dd($result,$body,json_decode($body), $twilio_token);
    }
    // dd($result,$cookies);
    // Close cURL session handle
    // setcookie("twilio_token", $cookies["connect_sid"], time() + (86400 * 30), "/"); // 86400 = 1 day
    // setcookie("twilio_token", $twilio_token, time() + (86400 * 30), "/"); // 86400 = 1 day
    curl_close($crl);
    // dd( $result,"Token generated successfully");
}

function getTwilioDriverChatToken(){
    $user                       = auth()->guard('driver-admin')->user();

    if($user) {
        $unique_identity        = 'driver_'.$user->id;
        $friendly_name          = $user->first_name.' '.$user->last_name;
    } else {
        //return $user;
    }

    $baseUrl                    = env("NODE_CHAT_API_BASE_URL","http://localhost:8000");
    $data                       = array(
        'username'              => $unique_identity
    );

    $post_data                  = json_encode($data);
    // echo $post_data;
    // Prepare new cURL resource
    $crl                        = curl_init( $baseUrl.'/api/LoginParticipant');
    curl_setopt($crl, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($crl, CURLINFO_HEADER_OUT, true);
    curl_setopt($crl, CURLOPT_POST, true);
    curl_setopt($crl, CURLOPT_HEADER, true);
    curl_setopt($crl, CURLOPT_POSTFIELDS, $post_data);

    // Set HTTP Header for POST request
    curl_setopt($crl, CURLOPT_HTTPHEADER, array(
        'Content-Type: application/json' ,
        'Access-Control-Allow-Origin: * '
    ));

    // Submit the POST request
    $result                     = curl_exec($crl);

    // handle curl error
    if ($result === false) {
        // throw new Exception('Curl error: ' . curl_error($crl));
        print_r('Curl error: ' . curl_error($crl));
        // $result_noti = 0;
        die();
    } else {
        $result_noti            = 1;
        $header_size            = curl_getinfo($crl, CURLINFO_HEADER_SIZE);
        $header                 = substr($result, 0, $header_size);
        $body                   = substr($result, $header_size);
        $body                   = json_decode($body);
        $twilio_token           = '';
        if($body->success) {
            $data               = $body->data;
            $twilio_token       = $data->token;
            setcookie("twilio_token", $twilio_token, time() + (86400 * 30), "/");
        } else {
            setcookie("twilio_token", $twilio_token, time() - 36000, "/");
        }
    }

    // dd($result,$cookies);
    // Close cURL session handle
    // setcookie("twilio_token", $cookies["connect_sid"], time() + (86400 * 30), "/"); // 86400 = 1 day
    // setcookie("twilio_token", $twilio_token, time() + (86400 * 30), "/"); // 86400 = 1 day
    curl_close($crl);

    // dd( $result,"Token generated successfully");
}

?>
