<?php

namespace App\Mail\CompanyAdmin;

use App\Models\CompanyAdmin;
use App\Models\CompanyEmailTemplate;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Mail\Mailable;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Log;

class ForgotPassword extends Mailable
{
    use Queueable, SerializesModels;

    public $data;

    /**
     * Create a new message instance.
     *
     * @return void
     */
    public function __construct($data)
    {
       $this->data = $data;
       $this->data['app_name'] = config('app.name');
    }

    /**
     * Build the message.
     *
     * @return $this
     */
    public function build()
    {
        /*
        $resetLink = route('company.admin.password.reset',$this->data['token']);

        return $this->subject('Reset Password Notification')
                    ->markdown('emails.companyAdmin.forgotPassword')
                    ->with(
                        [
                           'reset_link' => $resetLink,
                        ]
                    );
        */

        $companyAdminDetails = CompanyAdmin::where('email', $this->data['email'])->first();

        if($companyAdminDetails){
            $companyId = $companyAdminDetails->company_id;

            try {
                $resetLink = route('company.admin.password.reset', $this->data['token']);

                $getTemplate = CompanyEmailTemplate::where('company_id', $companyId)->where('title', 'Forgot Password')->first();

                if(!is_null($getTemplate)){
                    $subject = $getTemplate->subject;
                    $emailTemplate = getCompanyEmailTemplate($getTemplate);
                    $emailTemplate = str_replace(
                        [
                            '{%reset_link%}',
                            '{%app_name%}'],
                        [
                            $resetLink ?? '',
                            $this->data['app_name'] ?? ''
                        ],
                        $emailTemplate
                    );

                    return $this->subject($subject)->html($emailTemplate);
                }
            } catch (\Exception $e) {
                // Handle other exceptions
                Log::error($e->getMessage());

                return $e->getMessage();
            }
        }
    }
}
