<?php

namespace App\Mail;

use App\Models\CompanyEmailTemplate;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Mail\Mailable;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Log;

class DocumentRequestDriver extends Mailable
{
    use Queueable, SerializesModels;

    public $details;

    /**
     * Create a new message instance.
     *
     * @return void
     */
    public function __construct($details)
    {
        $this->details  = $details;
        $this->details['app_name'] = config('app.name');
    }

    /**
     * Build the message.
     *
     * @return $this
     */
    public function build()
    {
        /*
        return $this->subject('Dispatch Pro - Document Request for '.$this->details['file_name'])
            ->markdown('emails.document-request.request_driver')
            ->with(['details'   => $this->details]);
        */

        try {
            $getTemplate = CompanyEmailTemplate::where('company_id', $this->details['company_id'])->where('title', 'Document Request Driver')->first();

            if(!is_null($getTemplate)){
                $subject = str_replace('{%file_name%}', $this->details['file_name'] ?? '', $getTemplate->subject);
                $emailTemplate = getCompanyEmailTemplate($getTemplate);
                $requestNoteOrFileName = ($this->details['request_note'] != "") ? $this->details['request_note'] : 'Please upload '.$this->details['file_name'].' as soon as possible.';
                $emailTemplate = str_replace(
                    [
                        '{%file_name%}',
                        '{%driver_name%}',
                        '{%request_note_or_file_name%}',
                        '{%requested_by%}',
                        '{%app_name%}'
                    ],
                    [
                        $this->details['file_name'] ?? '',
                        $this->details['driver_name'] ?? '',
                        $requestNoteOrFileName ?? '',
                        $this->details['requested_by'] ?? '',
                        $this->details['app_name'] ?? ''
                    ],
                    $emailTemplate
                );

                return $this->subject($subject)->html($emailTemplate);
            }
        } catch (\Exception $e) {
            // Handle other exceptions
            Log::error($e->getMessage());

            return $e->getMessage();
        }
    }
}
