<?php

namespace App\Models;

use App\Mail\SendTwoFactorVerificationCodeMail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Illuminate\Support\Facades\Mail;

class Admin extends Authenticatable
{
    use HasFactory,Notifiable,SoftDeletes;

    protected $table    = 'admins';

    /**
     * The attributes that are mass assignable.
     *
     * @var string[]
     */
    protected $appends  = ['full_name'];

    protected $fillable = [
        'first_name',
        'last_name',
        'email',
        'password',
        'phone',
        'type',
        'left_drawer',
        'weekly_strat_day',
        'time_format',
        'session_lifetime',
        'timezone_id',
        'timezone_type',

        'two_factor_secret',
        'two_factor_expires_at',

        'created_at',
        'updated_at',
        'deleted_at'
    ];
    protected $dates    = ['deleted_at'];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array
     */
    protected $hidden   = [
        'password',
        'remember_token',
    ];

    // Types
    // 0 - Admin
    // 1 - Sub Admin
    // 2 - Support

    /*
     * Scopes
     */
    public function scopeAdmin($query){
        return $query->where('type',0);
    }

    public function scopeSubAdmin($query){
        return $query->where('type',1);
    }

    public function scopeSupport($query){
        return $query->where('type',2);
    }

    public function getFullNameAttribute($value): ?string {
        return $this->attributes['first_name'].' '.$this->attributes['last_name'];
    }

    public function getTimezone(){
        return $this->hasOne(Timezone::class,'id','timezone_id');
    }

    public function generateTwoFactorCode() {
        try {
            $twoFactorSettings = TwoFactorSetting::IsAdmin()->first();

            $this->timestamps = false;
            $this->two_factor_secret = rand(100000, 999999);
            $this->two_factor_expires_at = now()->addMinutes(10);
            $this->save();

            if($twoFactorSettings->enable_email_verify == '1' && !is_null($this->email)){
                $data = [
                    'name' => $this->full_name,
                    'code' => $this->two_factor_secret,
                ];

                Mail::to($this->email)->send(new SendTwoFactorVerificationCodeMail($data));
            }
            if($twoFactorSettings->enable_sms_verify == '1' && !is_null($this->phone)){
                // Twilio's credentials are fetched from env File
                sendSMS($this->phone, 'Please use this otp for 2-factor verification: '.$this->two_factor_secret);
            }
        } catch (Exception $e) {
            info("Error: ". $e->getMessage());
        }
    }
}
