<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

use Illuminate\Database\Eloquent\SoftDeletes;

class Alert extends Model
{
    use HasFactory, SoftDeletes;

    protected $table    = 'alerts';
    protected $fillable = [
        'company_id', 'source', 'action_id', 'name', 'user_id', 'user_type', 'read_at', 'created_at', 'updated_at', 'deleted_at'
    ];
    public $timestamps  = false;
    protected $dates   	= ['deleted_at'];

    public function scopeIsCompany($query)
    {
        return $query->where('company_id', auth()->guard('company-admin')->user()->company_id);
    }

    public function company()
    {
        return $this->belongsTo(Company::class);
    }

    public function getReadAtAttribute($value): ?string
    {
        return !is_null($value) ? Carbon::parse($value)->format(getTimeLayout()) : NULL;
    }
}
