<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

use Illuminate\Database\Eloquent\SoftDeletes;
use Carbon\Carbon;

class Broker extends Model
{
    use HasFactory, SoftDeletes;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'company_id',
        'name',
        'mc_number',
        'rep_name',
        'phone_number',
        'ext',
        'eight_hundred_number','ap_contact_contact_ext',
        'ap_contact_phone',
        'ap_contact_email',
        'ap_contact_name',
        'dispatch_contact_contact_ext',
        'dispatch_contact_phone',
        'dispatch_contact_email',
        'dispatch_contact_name',
        'lumper_receipts',
        'purchase_order',
        'scale_ticket',
        'delivery_receipt',
        'packing_slip',
        'bill_of_lading',
        'factored',
        'billing_terms',

        'bill_to_name',

        'bill_address_search',
        'billing_address',
        'billing_address_2',
        'billing_city',
        'billing_state',
        'billing_zip',
        'billing_latitude',
        'billing_longitude',
        'billing_timezone',
        'billing_timezone_offset',
        'billing_timezone_abbr',
        'billing_address_verified',

        'billing_phone',
        'billing_extention',
        'billing_email',
        'billing_fax',
        'billing_method',

        'logo',
        'account_type',
        'account_number',
        'scac',
        'usdot',
        'federal_id',
        'fax',
        'email',
        'phone',

        'address_search',
        'address',
        'address_2',
        'city',
        'state',
        'zip',
        'latitude',
        'longitude',
        'timezone',
        'timezone_offset',
        'timezone_abbr',
        'address_verified',

        'shipper_files',
        'consignee_files',
        'detention_price',
        'detention_time'
    ];

    /*
     * Scopes
     */
    public function scopeIsCompany($query)
    {
        return $query->where('company_id', auth()->guard('company-admin')->user()->company_id);
    }

    public function setDetentionTimeAttribute($value): ?string
    {
        return $this->attributes['detention_time'] = !is_null($value) ? Carbon::createFromFormat('H:i',$value)->format('H:i:s') : NULL;
    }

    public function getDetentionTimeAttribute($value): ?string
    {
        return !is_null($value) ? Carbon::parse($value)->format('H:i') : NULL;
    }

    public function company(){
        return $this->belongsTo(Company::class);
    }

    public function broker_accessorials()
    {
        return $this->hasMany(BrokerAccessorial::class);
    }

    public function broker_offices()
    {
        return $this->hasMany(BrokerOffice::class);
    }

    public function broker_contact()
    {
        return $this->hasMany(BrokerContact::class, 'action_id', 'id')->where('source', 'broker');
    }
}
