<?php

namespace App\Models;

use App\Mail\SendTwoFactorVerificationCodeMail;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;

class Driver extends Authenticatable
{
    use HasFactory, Notifiable, SoftDeletes;

    protected $table    = 'drivers';
    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $appends  = ['full_name'];

    protected $fillable = [
        'driver_unique_id',
        'role_id',
        'company_id',
        'team_id',
        'manager_id',
        'samsara_id',

        'first_name',
        'last_name',
        'middle_name',
        'company_name',
        'email',
        'password',
        'remember_token',

        'left_drawer',
        'weekly_strat_day',
        'time_format',
        'user_type',
        'profile_image',
        'home_phone',
        'cell_phone',
        'social',
        'start_date',

        'address',
        'address_2',
        'city',
        'state',
        'zip',
        'latitude',
        'longitude',
        'timezone',
        'timezone_offset',
        'timezone_abbr',
        'address_verified',

        'sms',
        'notify_email',
        'reminder_notify',

        'send_welcome_email',
        'allow_login',

        'dispatch_type',
        'ssn_or_ein',
        'ssn',
        'ein',

        'notes',

        'emergency_contact_name',
        'emergency_contact_number',
        'emergency_contact_relationship_to_driver',
        'emergency_address',
        'emergency_home_phone',

        'passport_expiration',
        'passport_number',

        'next_review',
        'drug_alcohol',
        'birthday',
        'medical_cert',
        'anniversary',
        'mvr_date',

        'license_number',
        'license_state',
        'license_exp_file',
        'license_exp',

        'mark_as_completed',

        'oos_date',
        'termination_date',
        'termination_reason',
        'termination_rehire',
        'termination_equipment',
        'termination_none',

        'timezone_id',
        'timezone_type',

        'two_factor_secret',
        'two_factor_expires_at',

        'status',
        'business_name',
        'business_na',
        'business_dba',
        'suffix',
        'nick_name',
        'fax',
        'other_phone',
        'years_experience',
        'gender',
        'is_1099',
        'trailer_experience',
        'truck_experience',
        'recruiter',
        'recruiter_source',
        'onboarding',
        'same_as_dispatcher',
        'load_planner',
        'billing',
        'safety',
        'fuel_card_type',
        'fuel_card_number',
        'eobr_provider',
        'eobr_id',

        'license_class',
        'license_endorsements',
        'twic_certified',
        'twic_cin_number',
        'twic_expiration_date',
        'tsa_certified',
        'tsa_expiration',
        'tanker_endorsement',
        'license_certifications',
        'smoker',

        'insurance_type',
        'insurance_provider',
        'policy_number',
        'insurance_expiration',
        'insurance_file',

        'deduction_name',
        'deduction_type',
        'deduction_amount',
        'deduction_unit',
        'starting_or_cap_amount',

        'days_per_year',
        'max_consecutive_days',
        'leave_type',
        'hire_date',
        'reset_date',
        'paid_type',
        'pto_rollover',
        'max_accumulated_pto',
        'allow_unpaid_leave',
        'allow_half_days',

        'passenger_onboard',
        'passenger_agreement_On_file',
        'passenger_expiration',
        'passenger_full_name',
        'passenger_age',
        'passenger_phone_number',
        'passenger_relationship',
        'passenger_gender',
        'passenger_allergies',

        'pet_onboard',
        'pet_type',
        'pet_name',
        'pet_deposit_amount',

        'medical_condition',
        'driving_restrictions',
        'next_doctor_visit',

        'allow_see_invoices',
        'allow_see_rate_confirmations',

        'created_at',
        'updated_at',
        'deleted_at',

        'is_report_drivers',
        'is_company_driver'
    ];

    protected $dates    = ['deleted_at'];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array
     */
    protected $hidden   = [
        'password',
        'remember_token',
    ];

    public static function boot(){
        parent::boot();

        static::deleting(function($item) {
            $item->driver_information->delete();
        });

        self::created(function($model){
            /* Uncomment the line below to enable driver to be added to general board on new driver create. */
            // chatGeneralBoardCreate($model);
        });
    }

    /*
     * Scopes
     */

    public function scopeLastDrivers($query){
        return DB::table('drivers')->first();
    }

    public function scopeIsCompany($query){
        return $query->where('company_id', auth()->guard('company-admin')->user()->company_id);
    }

    public function scopeFilter($query, $input){
        if (!is_null($input['team_id'])) {
            $query->where('teams.id',$input['team_id']);
        }

        if (!is_null($input['equipment'])) {
            $query->where(function ($query) use ($input) {
                $query->orWhere('load_details.trailer_number',$input['equipment'])
                    ->orWhere('load_details.truck_number',$input['equipment']);
            });
        }

        if (!is_null($input['dispatcher'])) {
            $query->where('load_details.booked_by',$input['dispatcher']);
        }

        return $query;
    }

    /*
     * Mutators
     */

    public function setStartDateAttribute($value): ?string {
        return $this->attributes['start_date'] = Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d H:i:s');
    }

    public function setLicenseExpAttribute($value): ?string {
        return $this->attributes['license_exp'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    public function setMvrDateAttribute($value): ?string {
        return $this->attributes['mvr_date'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    public function setAnniversaryAttribute($value): ?string {
        return $this->attributes['anniversary'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    public function setMedicalCertAttribute($value): ?string {
        return $this->attributes['medical_cert'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    public function setBirthdayAttribute($value): ?string {
        return $this->attributes['birthday'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    public function setDrugAlcoholAttribute($value): ?string {
        return $this->attributes['drug_alcohol'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }


    public function setNextReviewAttribute($value): ?string {
        return $this->attributes['next_review'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }


    public function setFaiDueDateAttribute($value): ?string {
        return $this->attributes['fai_due_date'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    public function setPassportExpirationAttribute($value): ?string {
        return $this->attributes['passport_expiration'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    public function setTwicExpirationDateAttribute($value): ?string {
        return $this->attributes['twic_expiration_date'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    public function setTsaExpirationAttribute($value): ?string {
        return $this->attributes['tsa_expiration'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    /*
     * Accessors
     */

    public function getStartDateAttribute($value): ?string {
        return Carbon::parse($value)->format(config('settings.date_format','m/d/Y'));
    }

    public function getFullNameAttribute($value): ?string {
        return $this->attributes['first_name'].' '.$this->attributes['last_name'];
    }

    public function getLicenseExpAttribute($value): ?string {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    public function getMvrDateAttribute($value): ?string {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    public function getAnniversaryAttribute($value): ?string {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    public function getMedicalCertAttribute($value): ?string {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    public function getBirthdayAttribute($value): ?string {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    public function getDrugAlcoholAttribute($value): ?string {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    public function getNextReviewAttribute($value): ?string {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    public function getPassportExpirationAttribute($value): ?string {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    public function getTwicExpirationDateAttribute($value): ?string {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }
    public function getTsaExpirationAttribute($value): ?string {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    /*
     * Relationships
     */
    public function driver_information(){
        return $this->hasOne(DriverInformation::class);
    }

    public function driver_restricted_states(){
        return $this->hasMany(DriverRestrictedState::class);
    }

    public function driver_financials(){
        return $this->hasMany(DriverFinancial::class);
    }

    public function driver_avoid_states(){
        return $this->hasMany(DriverAvoidState::class);
    }

    public function company(){
        return $this->belongsTo(Company::class);
    }

    public function team(){
        return $this->belongsTo(Team::class);
    }

    public function manager(){
        return $this->belongsTo(CompanyAdmin::class)->manager();
    }

    public function managerDetails(){
        return $this->hasOne(CompanyAdmin::class,'id','manager_id');
    }

    public function dispatcher(){
        return $this->belongsTo(CompanyAdmin::class,'manager_id','id')->dispatcher();
    }

    public function driverName(){
        return $this->hasOne(Driver::class,'id');
    }

    public function driver_hos_violations(){
        return $this->hasMany(DriverHosViolation::class);
    }

    public function driver_non_violations(){
        return $this->hasMany(DriverNonViolation::class);
    }

    public function driver_citations(){
        return $this->hasMany(DriverCitation::class);
    }

    public function driver_accidents(){
        return $this->hasMany(DriverAccident::class);
    }

    public function driver_mechanical_issues(){
        return $this->hasMany(DriverMechanicalIssue::class);
    }

    public function driver_compliance_safety(){
        return $this->hasOne(DriverComplianceSafety::class);
    }

    public function driver_onboarding(){
        return $this->hasOne(DriverOnboarding::class);
    }

    public function loads(){
        return $this->hasMany(LoadDetail::class);
    }

    public function getTimezone(){
        return $this->hasOne(Timezone::class,'id','timezone_id');
    }

    public function getLoadOccupancyCalendarMonth2(){
        return $this->hasMany(LoadDetail::class);
    }

    public function getTargetRevenueMilesByDate(){
        return $this->hasMany(DriverFinancial::class);
    }

    public function driver_offers(){
        return $this->hasMany(Offer::class, 'driver_id', 'id')->where('status', '!=', 4)->orderBy('favorite', 'ASC')->orderBy('created_at', 'DESC');
    }

    public function getCompany(){
        return $this->belongsTo(Company::class,'company_id','id');
    }

    public function loadPlanner(){
        return $this->belongsTo(CompanyAdmin::class,'load_planner','id');
    }

    public function recruiterDetails(){
        return $this->belongsTo(CompanyAdmin::class,'recruiter','id');
    }

    public function Onboarder(){
        return $this->belongsTo(CompanyAdmin::class,'onboarding','id');
    }

    public function driverBilling(){
        return $this->belongsTo(CompanyAdmin::class,'billing','id');
    }

    public function driverSafety(){
        return $this->belongsTo(CompanyAdmin::class,'safety','id');
    }

    public function scopeIsDriverCompany($query){
        return $query->where('company_id', auth()->guard('driver-admin')->user()->company_id);
    }

    public function generateTwoFactorCode() {
        try {
            $twoFactorSettings = TwoFactorSetting::IsDriverAdmin()->first();

            $this->timestamps = false;
            $this->two_factor_secret = rand(100000, 999999);
            $this->two_factor_expires_at = now()->addMinutes(10);
            $this->save();

            if($twoFactorSettings->enable_email_verify == '1' && !is_null($this->email)){
                $data = [
                    'name' => $this->full_name,
                    'code' => $this->two_factor_secret,
                ];

                Mail::to($this->email)->send(new SendTwoFactorVerificationCodeMail($data));
            }
            if($twoFactorSettings->enable_sms_verify == '1' && !is_null($this->cell_phone) && $this->sms == 1){
                // Twilio's credentials are fetched from env File
                sendSMS($this->cell_phone, 'Please use this otp for 2-factor verification: '.$this->two_factor_secret);
            }
        } catch (Exception $e) {
            info("Error: ". $e->getMessage());
        }
    }
}
