<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Models\DriverOnboardingSubStage;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Str;

class DriverOnboardingSetting extends Model
{
    use HasFactory, SoftDeletes;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'company_id', 'title', 'date', 'file', 'order', 'apply_to', 'update_profile', 'apply_to_profile', 'hired_before_stage_added_date','mark_as_completed'
    ];

    public static function boot()
    {
        parent::boot();

        static::deleting(function($item) {
            $item->sub_stages()->delete();
        });
    }

    /*
     * Scopes
     */
    public function scopeIsCompany($query)
    {
        return $query->where('company_id', auth()->guard('company-admin')->user()->company_id);
    }


    /*
     * Accessors
     */
    public function getStageNameAttribute($value): ?string
    {
        return Str::replace(' ', '_', Str::lower($this->attributes['title']));
    }


    /*
     * Relationships
     */
    public function sub_stages()
    {
        return $this->hasMany(DriverOnboardingSubStage::class);
    }
}
