<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

use Illuminate\Database\Eloquent\SoftDeletes;

use Carbon\Carbon;

class Load extends Model
{
    use HasFactory, SoftDeletes;

    protected $table        = 'loads';
    protected $fillable     = [
        'company_id', 'load_detail_id', 'is_split'
    ];

    // public $timestamps   = false;

    public static function boot(){
        parent::boot();

        static::deleting(function($item) {
            $item->load_all_drivers()->delete();
            $item->load_all_truck_owners()->delete();
            $item->load_stops()->delete();
            $item->load_all_details()->delete();
        });
    }

    /*
     * Scopes
     */
    public function scopeCompany($query){
        return $query->where('company_id', auth()->guard('company-admin')->user()->company_id);
    }

    /*
     * Relationships
     */
    public function company(){
        return $this->belongsTo(Company::class);
    }

    public function galleries(){
        return $this->hasMany(Gallery::class, 'action_id', 'id');
    }

    public function load_detail(){
        return $this->hasOne(LoadDetail::class, 'id', 'load_detail_id')->latest();
    }

    public function load_stops(){
        return $this->hasMany(LoadStop::class)->orderBy('stop_no','ASC')->orderBy('date_time','ASC');
    }

    public function load_trailers(){
        return $this->hasMany(LoadTrailer::class, 'load_id', 'id');
    }

    public function load_files(){
        return $this->hasMany(LoadFile::class, 'load_id', 'id');
    }

    public function load_notes(){
        return $this->hasMany(LoadNote::class, 'load_id', 'id');
    }

    public function load_requirements(){
        return $this->hasMany(LoadRequirement::class, 'load_id', 'id')->where('is_dummy', 0);
    }

    public function load_accessorials(){
        return $this->hasMany(LoadAccessorial::class,'load_id','id');
    }

    public function load_document_request(){
        return $this->hasOne(LoadDocumentRequest::class,'load_id','id');
    }

    public function load_rejects(){
        return $this->hasMany(LoadReject::class, 'load_id', 'id');
    }

    public function load_logs(){
        return $this->hasMany(LoadLog::class, 'load_id', 'id')->oldest();
    }

    //
    public function current_load_detail(){
        return $this->hasMany(LoadDetail::class)->latest();
    }

    public function load_details(){
        return $this->hasMany(LoadDetail::class, 'id', 'load_detail_id');
    }

    public function load_all_details(){
        return $this->hasMany(LoadDetail::class);
    }

    public function load_all_drivers(){
        return $this->hasMany(LoadDriver::class);
    }

    public function load_all_truck_owners(){
        return $this->hasMany(LoadTruckOwner::class);
    }
}