<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

use Illuminate\Database\Eloquent\SoftDeletes;

class LoadDocumentRequest extends Model
{
    use HasFactory, SoftDeletes;

    protected $table        = 'load_document_requests';
    protected $fillable     = [
    	'load_id',
        'load_detail_id',
        'broker_id',
        'instructions',
        'request_via',
        'request_send_contacts',

        'created_at',
        'created_by',
        'created_by_type',

        'updated_at',
        'updated_by',
        'updated_by_type',

        'deleted_at',
        'deleted_by',
        'deleted_by_type'
    ];

    protected $dates   	    = ['deleted_at'];
    public $timestamps   	= false;

    /*
     * Relationships
     */
    public function loads(){
    	// 'load_id' is the custom foreign key column in the load_document_requests table
    	// 'id' is the default primary key column in the loads table
        return $this->belongsTo(Load::class,'load_id','id');
    }

    public function load_detail(){
    	// 'load_detail_id' is the custom foreign key column in the load_document_requests table
        // 'id' is the default primary key column in the load_details table
        return $this->hasOne(LoadDetail::class,'id','load_detail_id');
    }

    public function broker(){
		// 'broker_id' is the custom foreign key column in the load_document_requests table
	    // 'id' is the default primary key column in the brokers table
        return $this->hasOne(Broker::class,'id','broker_id')->withTrashed();
    }

    public function items(){
    	// 'load_document_request_id' is the custom foreign key column in the load_document_request_items table
        // 'id' is the default primary key column in the load_document_requests table
        return $this->hasMany(LoadDocumentRequestItem::class, 'load_document_request_id', 'id');
    }

    public function creator(){
    	// '0' => 'company_admin', '1' => 'managers', '2' => 'dispatchers', '3' => 'drivers'
        if ($this->created_by_type === 3) {
            return $this->hasOne(Driver::class,'id','created_by')->withTrashed();
        } else {
            return $this->hasOne(CompanyAdmin::class, 'id', 'created_by')->withTrashed();
        }
    }

    public function editor(){
    	// '0' => 'company_admin', '1' => 'managers', '2' => 'dispatchers', '3' => 'drivers'
    	if ($this->updated_by_type === 3) {
    	    return $this->hasOne(Driver::class,'id','updated_by')->withTrashed();
    	} else {
    	    return $this->hasOne(CompanyAdmin::class, 'id', 'updated_by')->withTrashed();
    	}
    }

    public function deletor(){
    	// '0' => 'company_admin', '1' => 'managers', '2' => 'dispatchers', '3' => 'drivers'
    	if ($this->deleted_by_type === 3) {
    	    return $this->hasOne(Driver::class,'id','deleted_by')->withTrashed();
    	} else {
    	    return $this->hasOne(CompanyAdmin::class, 'id', 'deleted_by')->withTrashed();
    	}
    }
}
