<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

use Illuminate\Database\Eloquent\SoftDeletes;

class LoadDocumentRequestItem extends Model
{
    use HasFactory, SoftDeletes;

    protected $table        = 'load_document_request_items';
    protected $fillable     = [
    	'load_document_request_id',
        'load_id',
        'load_detail_id',
        'driver_id',
        'load_stop_id',
        'type',
        'is_stop',

        'files',

        'created_at',
        'created_by',
        'created_by_type',

        'updated_at',
        'updated_by',
        'updated_by_type',

        'deleted_at',
        'deleted_by',
        'deleted_by_type'
    ];

    protected $dates   	    = ['deleted_at'];
    public $timestamps   	= false;

    /*
     * Relationships
     */
    public function load_document_request(){
        // 'load_id' is the custom foreign key column in the load_document_request_items table
        // 'id' is the default primary key column in the load_document_requests table
        return $this->belongsTo(LoadDocumentRequest::class, 'load_document_request_id', 'id');
    }

    public function loads(){
        // 'load_id' is the custom foreign key column in the load_document_request_items table
        // 'id' is the default primary key column in the loads table
        return $this->hasOne(Load::class,'id','load_id');
    }

    public function load_detail(){
        // 'load_detail_id' is the custom foreign key column in the load_document_request_items table
        // 'id' is the default primary key column in the load_details table
        return $this->hasOne(LoadDetail::class,'id','load_detail_id');
    }

    public function driver(){
        return $this->hasOne(Driver::class,'id','driver_id')->withTrashed();
    }

    public function stop(){
        // 'load_stop_id' is the custom foreign key column in the load_document_request_items table
        // 'id' is the default primary key column in the load_stops table
        return $this->hasOne(LoadStop::class,'id','load_stop_id')->where('is_stop', 1);
    }

    public function creator(){
        // '0' => 'company_admin', '1' => 'managers', '2' => 'dispatchers', '3' => 'drivers'
        if ($this->created_by_type === 3) {
            return $this->hasOne(Driver::class,'id','created_by')->withTrashed();
        } else {
            return $this->hasOne(CompanyAdmin::class, 'id', 'created_by')->withTrashed();
        }
    }

    public function editor(){
        // '0' => 'company_admin', '1' => 'managers', '2' => 'dispatchers', '3' => 'drivers'
        if ($this->updated_by_type === 3) {
            return $this->hasOne(Driver::class,'id','updated_by')->withTrashed();
        } else {
            return $this->hasOne(CompanyAdmin::class, 'id', 'updated_by')->withTrashed();
        }
    }

    public function deletor(){
        // '0' => 'company_admin', '1' => 'managers', '2' => 'dispatchers', '3' => 'drivers'
        if ($this->deleted_by_type === 3) {
            return $this->hasOne(Driver::class,'id','deleted_by')->withTrashed();
        } else {
            return $this->hasOne(CompanyAdmin::class, 'id', 'deleted_by')->withTrashed();
        }
    }
}
