<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

use Illuminate\Database\Eloquent\SoftDeletes;

class Offer extends Model
{
    use HasFactory, SoftDeletes;

    protected $table    = 'offers';
    protected $fillable = [
        'driver_id',
        'submitted_by',
        'bound_call',
        'm_trailer_type',
        'truck_number',
        'trailer_number',
        'trailer_type',
        'carrier_id',
        'broker_id',
        'brokerage_mc',
        'terms',
        'point_of_contact',
        'phone',
        'ext',
        'email',
        'credit',
        'score_ratting',
        'score_credit',
        'score_updated_at',
        'current_location',
        'current_address_one',
        'current_address_two',
        'current_state',
        'current_city',
        'current_zip',
        'current_latitude',
        'current_longitude',
        'current_timezone',
        'current_timezone_offset',
        'current_timezone_abbr',
        'current_address_verified',
        'shipper_date_time',
        'shipper_date_time_end',
        'shipper_date',
        'shipper_open_time',
        'shipper_close_time',
        'shipper_location',
        'shipper_address_one',
        'shipper_address_two',
        'shipper_state',
        'shipper_city',
        'shipper_zip',
        'shipper_latitude',
        'shipper_longitude',
        'shipper_timezone',
        'shipper_timezone_offset',
        'shipper_timezone_abbr',
        'shipper_address_verified',
        'delivery_date_time',
        'delivery_date_time_end',
        'delivery_date',
        'delivery_open_time',
        'delivery_close_time',
        'delivery_location',
        'delivery_address_one',
        'delivery_address_two',
        'delivery_state',
        'delivery_city',
        'delivery_zip',
        'delivery_latitude',
        'delivery_longitude',
        'delivery_timezone',
        'delivery_timezone_offset',
        'delivery_timezone_abbr',
        'delivery_address_verified',
        'temp',
        'weight',
        'commodity',
        'load_value',
        'empty_miles',
        'loaded_miles',
        'total_miles',
        'tolls',
        'route_type',
        'open_border',
        'hazardous',
        'hazardous_option',
        'over_dimension',
        'length',
        'width',
        'height',
        'rate_offered',
        'is_rate_offered',
        'fuel_surcharge_cost_per_mile',
        'agreed_upon_rate',
        'is_final_rate',
        'rate_per_day',
        'rate_per_hour',
        'days',
        'hours',
        'minutes',
        'notes',
        'is_add_note_to_load',
        'favorite',
        'status',
        'status_at',
        'created_at',
        'updated_at',
        'deleted_at',
        'created_by',
        'updated_by',
        'deleted_by'
    ];
    public $timestamps  = false;
    protected $dates   	= ['deleted_at'];

    public function histories(){
        return $this->hasMany(OfferHistory::class,'offer_id','id')->orderBy('id', 'DESC');
    }

    public function stops(){
        return $this->hasMany(OfferStop::class,'offer_id','id')->orderBy('stop_no', 'ASC');
    }

    public function driver(){
        return $this->belongsTo(Driver::class)->withTrashed();
    }

    public function broker(){
        return $this->hasOne(Broker::class,'id','broker_id')->withTrashed();
    }

    public function company_admin(){
        return $this->hasOne(CompanyAdmin::class,'id','submitted_by')->withTrashed();
    }

    public function mile_trailer_type(){
        return $this->hasOne(TrailerType::class,'id','m_trailer_type')->withTrashed();
    }
}
