<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;
use App\Models\CompanyAdmin;
use App\Models\Driver;
use DB;

class Team extends Model
{
    use HasFactory, SoftDeletes;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'company_id', 'head_id', 'name', 'image'
    ];


    /*
     * Scopes
     */
    public function scopeCompany($query)
    {
        return $query->where('company_id', auth()->guard('company-admin')->user()->company_id);
    }

    public function scopeFilter($query, $input)
    {
        if (isset($input['filter']) && !is_null($input['filter'])) {
            $query->where("name","like","%{$input['filter']}%")
                ->orWhereHas('dispatcher', function ($q) use ($input) {
                    $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$input['filter']."%");
                });
        }

        return $query;
    }


    /*
     * Relationships
     */
    public function dispatcher()
    {
        return $this->hasOne(CompanyAdmin::class, 'id', 'head_id')->dispatcher();
    }

    public function drivers()
    {
        return $this->hasMany(Driver::class);
    }

    /**
     * @return HasMany
     */
    public function driverFinancials()
    {
        return $this->hasMany(DriverFinancial::class);
    }

    public function getLifeTimeRevenue()
    {
        return $this->hasMany(ReportDriver::class)->sum('actual_revenue');
    }
}
