<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Carbon\Carbon;

class Terminal extends Model
{
    use HasFactory, SoftDeletes;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'company_id',
        'name',

        'address_search',
        'address',
        'address_2',
        'city',
        'state',
        'zip',
        'latitude',
        'longitude',
        'timezone',
        'timezone_offset',
        'timezone_abbr',
        'address_verified',

        'phone',
        'email',
        'fax',

        'bill_to_name',

        'bill_address_search',
        'billing_address',
        'billing_address_2',
        'billing_city',
        'billing_state',
        'billing_zip',
        'billing_latitude',
        'billing_longitude',
        'billing_timezone',
        'billing_timezone_offset',
        'billing_timezone_abbr',
        'billing_address_verified',

        'billing_phone',
        'billing_extention',
        'billing_email',
        'billing_fax',
        'billing_cutoff',

        'terminal_code',
        'federal_id',
        'terminal_status',
        'terminal_type',
        'start_date',
        'parent_terminal',
        'carrier_id',
        'documents',
        'truck_commision',
        'brokerage_split',
        'brokerage_minimum_amount',
        'generate_1099',
        'preferred_settlement_day',
        'bank_name',
        'account_number',
        'routing_number',
        'name_on_account',
        'picture_of_voided_check',
        'bank_contact_email',
        'bank_contact_name',
        'bank_email',
        'bext',
        'bank_phone',
        'bank_contact',
        'bank_active_status',
        'created_at',
        'updated_at',
        'deleted_at'
    ];

    /*
     * Scopes
     */
    public function scopeIsCompany($query)
    {
        return $query->where('company_id', auth()->guard('company-admin')->user()->company_id);
    }

    public function brokerContact()
    {
        return $this->hasMany(BrokerContact::class, 'broker_id', 'id')->orderBy('id', 'asc');
    }

    public function setStartDateAttribute($value): ?string
    {
        return $this->attributes['start_date'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    public function getStartDateAttribute($value): ?string
    {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    public function carrier()
    {
        return $this->belongsTo(Carrier::class)->withTrashed();
    }

}
