<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Carbon\Carbon;

class Trailer extends Model
{
    use HasFactory, SoftDeletes;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'company_id',
        'trailer_id',
        'status',
        'year',
        'make',
        'model',
        'length',
        'type',
        'vin',
        'tag_state',
        'tag_number',
        'tag_expiration',
        'terminal',
        'next_service',
        'last_inspection',
        'next_inspection',
        'maintenance_date',
        'lease_exp_date',
        'axles',
        'insurance_carrier',
        'insurance_exp',
        'insurance_value',
        'leasing_company',
        'owner_id',
        'owner_name',
        'owner_address',
        'sliding','trailer_service_mileage','trailer_service_date','samsara_id','unladen_weight',
        'hubometer',
        'tire_size',
        'color',
        'width',
        'deck_height',
        'carb_id',
        'tracker_provider',
        'tracker_id',
        'tag_upload_image',
        'phys_dam_ins_carrier',
        'phys_dam_start_date',
        'physical_dam_exp_date',
        'insured_value',
        'phys_dam_attachment',
        'roof_type',
        'floor_type',
        'suspension_type',
        'spread_axie',
        'logistics_post',
        'drop_trailer_pool',
        'vented',
        'plated_interior',
        'etrack',
        'spare_tire_rank',
        'onboard_equipment',
        'carrier',
        'ownership',
        'owner_purchase_price',
        'owner_purchase_date',
        'purchased_new',
        'owner_documents',
        'leasing_co',
        'lease_expiration_date',
        'lease_documents',
        'lease_agreement_title',
        'fai_due_date',
        'fai_attachment',
        'trailer_interchange',
        'trailer_interchange_image',
        'depreciated_value',
        'current_assigned_truck',
        'current_assigned_driver',
        'federal_inspection_type',
        'federal_inspection_interval',
        'last_server_date',
        'last_inspection_location',
        'next_service_date',
        'reefer_current_hours',
        'reefer_service_due',
        'reefer_last_pm_service',
        'reefer_next_pm_service',
        'reefer_service_interval_hours',
        'reefer_model_number',
        'reefer_service_notes',
        'in_service_date',
        'equipment_comments',
        'height',
        'last_location_name',
        'last_location_load_status',
        'last_location_address',
        'last_location_address_2',
        'last_location_city',
        'last_location_state',
        'last_location_zip',
        'last_location_latitude',
        'last_location_longitude',
        'last_location_timezone',
        'last_location_timezone_offset',
        'last_location_timezone_abbr',
        'last_location_address_verified',
        'last_location_notes'
    ];

    /*
     * Scopes
     */
    public function scopeIsCompany($query)
    {
        return $query->where('company_id', auth()->guard('company-admin')->user()->company_id);
    }

    /*
     * Mutators
     */
    public function setTagExpirationAttribute($value): ?string
    {
        return $this->attributes['tag_expiration'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d H:i:s') : NULL;
    }

    public function setNextServiceAttribute($value): ?string
    {
        return $this->attributes['next_service'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d H:i:s') : NULL;
    }

    public function setLastInspectionAttribute($value): ?string
    {
        return $this->attributes['last_inspection'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d H:i:s') : NULL;
    }

    public function setNextInspectionAttribute($value): ?string
    {
        return $this->attributes['next_inspection'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d H:i:s') : NULL;
    }

    public function setMaintenanceDateAttribute($value): ?string
    {
        return $this->attributes['maintenance_date'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d H:i:s') : NULL;
    }

    public function setLeaseExpDateAttribute($value): ?string
    {
        return $this->attributes['lease_exp_date'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d H:i:s') : NULL;
    }

    public function setTrailerServiceDateAttribute($value): ?string
    {
        return $this->attributes['trailer_service_date'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }


    /*
     * Accessors
     */
    public function getTrailerServiceDateAttribute($value): ?string
    {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }
    public function getTagExpirationAttribute($value): ?string
    {
        return Carbon::parse($value)->format(config('settings.date_format','m/d/Y'));
    }

    public function getNextServiceAttribute($value): ?string
    {
        return Carbon::parse($value)->format(config('settings.date_format','m/d/Y'));
    }

    public function getLastInspectionAttribute($value): ?string
    {
        return Carbon::parse($value)->format(config('settings.date_format','m/d/Y'));
    }

    public function getNextInspectionAttribute($value): ?string
    {
        return Carbon::parse($value)->format(config('settings.date_format','m/d/Y'));
    }

    public function getMaintenanceDateAttribute($value): ?string
    {
        return Carbon::parse($value)->format(config('settings.date_format','m/d/Y'));
    }

    public function getLeaseExpDateAttribute($value): ?string
    {
        return Carbon::parse($value)->format(config('settings.date_format','m/d/Y'));
    }

    public function setPhysDamStartDateAttribute($value): ?string
    {
        return $this->attributes['phys_dam_start_date'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    public function getPhysDamStartDateAttribute($value): ?string
    {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    public function setPhysicalDamExpDateAttribute($value): ?string
    {
        return $this->attributes['physical_dam_exp_date'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    public function getPhysicalDamExpDateAttribute($value): ?string
    {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    public function setOwnerPurchaseDateAttribute($value): ?string
    {
        return $this->attributes['owner_purchase_date'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    public function getOwnerPurchaseDateAttribute($value): ?string
    {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    public function setLeaseExpirationDateAttribute($value): ?string
    {
        return $this->attributes['lease_expiration_date'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    public function getLeaseExpirationDateAttribute($value): ?string
    {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    public function setFaiDueDateAttribute($value): ?string
    {
        return $this->attributes['fai_due_date'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    public function getFaiDueDateAttribute($value): ?string
    {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    public function setLastServerDateAttribute($value): ?string
    {
        return $this->attributes['last_server_date'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    public function getLastServerDateAttribute($value): ?string
    {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    public function setNextServiceDateAttribute($value): ?string
    {
        return $this->attributes['next_service_date'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    public function getNextServiceDateAttribute($value): ?string
    {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    public function setInServiceDateAttribute($value): ?string
    {
        return $this->attributes['in_service_date'] = !is_null($value) ? Carbon::createFromFormat(config('settings.date_format','m/d/Y'),$value)->format('Y-m-d') : NULL;
    }

    public function getInServiceDateAttribute($value): ?string
    {
        return !is_null($value) ? Carbon::parse($value)->format(config('settings.date_format','m/d/Y')) : NULL;
    }

    public function load_details(){
        return $this->hasMany(LoadDetail::class, 'trailer_number', 'trailer_id')->select('id', 'load_number');
    }

    public function trailer_type(){
        return $this->hasOne(TrailerType::class,'id','type')->withTrashed();
    }

    public function truck(){
        return $this->hasOne(Truck::class,'id','current_assigned_truck')->withTrashed();
    }

    public function driver(){
        return $this->hasOne(Driver::class,'id','current_assigned_driver')->withTrashed();
    }

    public function get_carrier(){
        return $this->hasOne(Carrier::class,'id','carrier')->withTrashed();
    }
}
