<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

use Illuminate\Database\Eloquent\SoftDeletes;

class Widget extends Model
{
    use HasFactory, SoftDeletes;

    protected $table    = 'widgets';
    protected $fillable = [
        'company_id', 'company_admins_id', 'driver_id', 'widget_id', 'range', 'notes', 'properties', 'tab', 'guard_name', 'created_at', 'updated_at', 'deleted_at'
    ];
    public $timestamps  = false;
    protected $dates   	= ['deleted_at'];

    public function scopeIsCompany($query)
    {
        return $query->where('company_id', auth()->guard('company-admin')->user()->company_id);
    }

    public function scopeIsCompanyAdmin($query)
    {
        return $query->where('company_id', auth()->guard('company-admin')->user()->company_id)->where('company_admins_id', auth()->guard('company-admin')->user()->id);
    }

    public function scopeIsDriverAdmin($query)
    {
        return $query->where('company_id', auth()->guard('driver-admin')->user()->company_id)->where('driver_id', auth()->guard('driver-admin')->user()->id);
    }

    public function company()
    {
        return $this->belongsTo(Company::class);
    }

    public function companyAdmin()
    {
        return $this->belongsTo(CompanyAdmin::class,'company_admins_id','id')->withTrashed();
    }

    public function driver()
    {
        return $this->belongsTo(Driver::class,'driver_id','id')->withTrashed();
    }
}
