<?php

namespace App\Traits;

use Illuminate\Support\Facades\Log;

trait TrimbleTrait {

    // Get Trip - https://developer.trimblemaps.com/restful-apis/trip-management/api-documentation/get-trip/
    public function getTripDetails($tripId, $apiKey = null){
        $data                           = null;
        if(is_null($apiKey)){
            $apiKey                     = getTrimbleApiKey();
        }
        if(!is_null($apiKey)){
            try {
                $url                    = 'https://tripmanagement.alk.com/api/trip?tripId='.$tripId;
                $client                 = new \GuzzleHttp\Client();
                $response               = $client->request('GET', $url, [
                    'headers'           => [
                        'Accept'        => 'application/json',
                        'Content-Type'  => 'application/json',
                        'Authorization' => $apiKey
                    ],
                ]);
                // Check if response status code is OK (200)
                if ($response->getStatusCode() == 200) {
                    $body               = json_decode($response->getBody());
                    // Do something with the response body
                    if(isset($body)){
                        $data           = $body;
                    }
                }
            } catch (\GuzzleHttp\Exception\ClientException $e) {
                // Handle client-side errors (e.g. 4xx status codes)
                $response               = $e->getResponse();
                if ($response) {
                    $statusCode         = $response->getStatusCode();
                    $body               = $response->getBody()->getContents();
                    Log::error($body);
                } else {
                    Log::error($e->getMessage());
                }
            } catch (\GuzzleHttp\Exception\ServerException $e) {
                // Handle server-side errors (e.g. 5xx status codes)
                $response               = $e->getResponse();
                if ($response) {
                    $statusCode         = $response->getStatusCode();
                    $body               = $response->getBody()->getContents();
                    Log::error($body);
                } else {
                    Log::error($e->getMessage());
                }
            } catch (\Exception $e) {
                // Handle other exceptions
                Log::error($e->getMessage());
            }
        }
        return $data;
    }

    // Cancel Trip - https://developer.trimblemaps.com/restful-apis/trip-management/api-documentation/cancel-trip/
    public function cancelTrip($tripId, $apiKey = null){
        $data                           = null;
        if(is_null($apiKey)){
            $apiKey                     = getTrimbleApiKey();
        }
        if(!is_null($apiKey)){
            try {
                $url                    = 'https://tripmanagement.alk.com/api/trip/'.$tripId.'/cancel';
                $client                 = new \GuzzleHttp\Client();
                $response               = $client->request('POST', $url, [
                    'headers'           => [
                        'Accept'        => 'application/json',
                        'Content-Type'  => 'application/json',
                        'Authorization' => $apiKey
                    ],
                ]);
                // Check if response status code is OK (200)
                if ($response->getStatusCode() == 200) {
                    $body               = json_decode($response->getBody());
                    // Do something with the response body
                    if(isset($body)){
                        $data           = $body;
                    }
                }
            } catch (\GuzzleHttp\Exception\ClientException $e) {
                // Handle client-side errors (e.g. 4xx status codes)
                $response               = $e->getResponse();
                if ($response) {
                    $statusCode         = $response->getStatusCode();
                    $body               = $response->getBody()->getContents();
                    Log::error($body);
                } else {
                    Log::error($e->getMessage());
                }
            } catch (\GuzzleHttp\Exception\ServerException $e) {
                // Handle server-side errors (e.g. 5xx status codes)
                $response               = $e->getResponse();
                if ($response) {
                    $statusCode         = $response->getStatusCode();
                    $body               = $response->getBody()->getContents();
                    Log::error($body);
                } else {
                    Log::error($e->getMessage());
                }
            } catch (\Exception $e) {
                // Handle other exceptions
                Log::error($e->getMessage());
            }
        }
        return $data;
    }

    // Delete Trip - https://developer.trimblemaps.com/restful-apis/trip-management/api-documentation/delete-trip/
    public function deleteTrip($tripId, $apiKey = null){
        $data                           = null;
        if(is_null($apiKey)){
            $apiKey                     = getTrimbleApiKey();
        }
        if(!is_null($apiKey)){
            try {
                $url                    = 'https://tripmanagement.alk.com/api/trip/'.$tripId;
                $client                 = new \GuzzleHttp\Client();
                $response               = $client->request('DELETE', $url, [
                    'headers'           => [
                        'Accept'        => 'application/json',
                        'Content-Type'  => 'application/json',
                        'Authorization' => $apiKey
                    ],
                ]);
                // Check if response status code is OK (200)
                if ($response->getStatusCode() == 200) {
                    $body               = json_decode($response->getBody());
                    // Do something with the response body
                    if(isset($body)){
                        $data           = $body;
                    }
                }
            } catch (\GuzzleHttp\Exception\ClientException $e) {
                // Handle client-side errors (e.g. 4xx status codes)
                $response               = $e->getResponse();
                if ($response) {
                    $statusCode         = $response->getStatusCode();
                    $body               = $response->getBody()->getContents();
                    Log::error($body);
                } else {
                    Log::error($e->getMessage());
                }
            } catch (\GuzzleHttp\Exception\ServerException $e) {
                // Handle server-side errors (e.g. 5xx status codes)
                $response               = $e->getResponse();
                if ($response) {
                    $statusCode         = $response->getStatusCode();
                    $body               = $response->getBody()->getContents();
                    Log::error($body);
                } else {
                    Log::error($e->getMessage());
                }
            } catch (\Exception $e) {
                // Handle other exceptions
                Log::error($e->getMessage());
            }
        }
        return $data;
    }

    // Get GPS Coords - https://developer.trimblemaps.com/restful-apis/trip-management/api-documentation/get-gps-coords/
    public function getGPSCoords($tripId, $apiKey = null){
        $data                           = [];
        if(is_null($apiKey)){
            $apiKey                     = getTrimbleApiKey();
        }
        if(!is_null($apiKey)){
            try {
                $url                    = 'https://tripmanagement.alk.com/api/gpsCoords/'.$tripId;
                $client                 = new \GuzzleHttp\Client();
                $response               = $client->request('GET', $url, [
                    'headers'           => [
                        'Accept'        => 'application/json',
                        'Content-Type'  => 'application/json',
                        'Authorization' => $apiKey
                    ]
                ]);
                // Check if response status code is OK (200)
                if ($response->getStatusCode() == 200) {
                    $body               = json_decode($response->getBody());
                    // Do something with the response body
                    if(isset($body)){
                        $data           = $body;
                    }
                }
            } catch (\GuzzleHttp\Exception\ClientException $e) {
                // Handle client-side errors (e.g. 4xx status codes)
                $response               = $e->getResponse();
                if ($response) {
                    $statusCode         = $response->getStatusCode();
                    $body               = $response->getBody()->getContents();
                    Log::error($body);
                } else {
                    Log::error($e->getMessage());
                }
            } catch (\GuzzleHttp\Exception\ServerException $e) {
                // Handle server-side errors (e.g. 5xx status codes)
                $response               = $e->getResponse();
                if ($response) {
                    $statusCode         = $response->getStatusCode();
                    $body               = $response->getBody()->getContents();
                    Log::error($body);
                } else {
                    Log::error($e->getMessage());
                }
            } catch (\Exception $e) {
                // Handle other exceptions
                Log::error($e->getMessage());
            }
        }
        return $data;
    }

    // Update Positions - https://developer.trimblemaps.com/restful-apis/trip-management/api-documentation/update-positions/
    public function gpsPosition($requests, $apiKey = null){
        $data                           = null;
        if(is_null($apiKey)){
            $apiKey                     = getTrimbleApiKey();
        }
        if(!is_null($apiKey)){
            try {
                $url                    = 'https://tripmanagement.alk.com/api/trip/gpsposition';
                $client                 = new \GuzzleHttp\Client();
                $response               = $client->request('POST', $url, [
                    'headers'           => [
                        'Accept'        => 'application/json',
                        'Content-Type'  => 'application/json',
                        'Authorization' => $apiKey
                    ],
                    'json'              => $requests
                ]);
                // Check if response status code is OK (200)
                if ($response->getStatusCode() == 200) {
                    $body               = json_decode($response->getBody());
                    if(isset($body)){
                        // Log::info('Trip Id ('.$requests['tripId'].') : Update GPS Position');
                        $data           = $body;
                    }
                }
            } catch (\GuzzleHttp\Exception\ClientException $e) {
                // Handle client-side errors (e.g. 4xx status codes)
                $response               = $e->getResponse();
                if ($response) {
                    $statusCode         = $response->getStatusCode();
                    $body               = $response->getBody()->getContents();
                    Log::error($body);
                } else {
                    Log::error($e->getMessage());
                }
            } catch (\GuzzleHttp\Exception\ServerException $e) {
                // Handle server-side errors (e.g. 5xx status codes)
                $response               = $e->getResponse();
                if ($response) {
                    $statusCode         = $response->getStatusCode();
                    $body               = $response->getBody()->getContents();
                    Log::error($body);
                } else {
                    Log::error($e->getMessage());
                }
            } catch (\Exception $e) {
                // Handle other exceptions
                Log::error($e->getMessage());
            }
        }
        return $data;
    }

    // Update Trip Status - https://developer.trimblemaps.com/restful-apis/trip-management/api-documentation/update-tripstatus/
    public function updateTripStatus($requests, $apiKey = null){
        $data                           = null;
        if(is_null($apiKey)){
            $apiKey                     = getTrimbleApiKey();
        }
        if(!is_null($apiKey)){
            try {
                $url                    = 'https://tripmanagement.alk.com/api/trip/tripStatus';
                $client                 = new \GuzzleHttp\Client();
                $response               = $client->request('POST', $url, [
                    'headers'           => [
                        'Accept'        => 'application/json',
                        'Content-Type'  => 'application/json',
                        'Authorization' => $apiKey
                    ],
                    'json'              => $requests
                ]);
                // Check if response status code is OK (200)
                if ($response->getStatusCode() == 200) {
                    $body               = json_decode($response->getBody());
                    if(isset($body)){
                        // Log::info('Trip Id ('.$requests['tripId'].') : Update Trip Status');
                        $data           = $body;
                    }
                }
            } catch (\GuzzleHttp\Exception\ClientException $e) {
                // Handle client-side errors (e.g. 4xx status codes)
                $response               = $e->getResponse();
                if ($response) {
                    $statusCode         = $response->getStatusCode();
                    $body               = $response->getBody()->getContents();
                    Log::error($body);
                } else {
                    Log::error($e->getMessage());
                }
            } catch (\GuzzleHttp\Exception\ServerException $e) {
                // Handle server-side errors (e.g. 5xx status codes)
                $response               = $e->getResponse();
                if ($response) {
                    $statusCode         = $response->getStatusCode();
                    $body               = $response->getBody()->getContents();
                    Log::error($body);
                } else {
                    Log::error($e->getMessage());
                }
            } catch (\Exception $e) {
                // Handle other exceptions
                Log::error($e->getMessage());
            }
        }
        return $data;
    }

    // Update StopStatus - https://developer.trimblemaps.com/restful-apis/trip-management/api-documentation/update-stopstatus/
    public function updateStopStatus($requests, $apiKey = null){
        $data                           = null;
        if(is_null($apiKey)){
            $apiKey                     = getTrimbleApiKey();
        }
        if(!is_null($apiKey)){
            try {
                $url                    = 'https://tripmanagement.alk.com/api/trip/stopStatus';
                $client                 = new \GuzzleHttp\Client();
                $response               = $client->request('POST', $url, [
                    'headers'           => [
                        'Accept'        => 'application/json',
                        'Content-Type'  => 'application/json',
                        'Authorization' => $apiKey
                    ],
                    'json'              => $requests
                ]);
                // Check if response status code is OK (200)
                if ($response->getStatusCode() == 200) {
                    $body               = json_decode($response->getBody());
                    if(isset($body)){
                        // Log::info('Trip Id ('.$requests['tripId'].') : Update Trip Status');
                        $data           = $body;
                    }
                }
            } catch (\GuzzleHttp\Exception\ClientException $e) {
                // Handle client-side errors (e.g. 4xx status codes)
                $response               = $e->getResponse();
                if ($response) {
                    $statusCode         = $response->getStatusCode();
                    $body               = $response->getBody()->getContents();
                    Log::error($body);
                } else {
                    Log::error($e->getMessage());
                }
            } catch (\GuzzleHttp\Exception\ServerException $e) {
                // Handle server-side errors (e.g. 5xx status codes)
                $response               = $e->getResponse();
                if ($response) {
                    $statusCode         = $response->getStatusCode();
                    $body               = $response->getBody()->getContents();
                    Log::error($body);
                } else {
                    Log::error($e->getMessage());
                }
            } catch (\Exception $e) {
                // Handle other exceptions
                Log::error($e->getMessage());
            }
        }
        return $data;
    }

    public function getMilesData(){
        if(isset($this->request->latLong) && count($this->request->latLong)){
            $length                     = count($this->request->latLong)-1;
            $i                          = 1;
            $string                     = "";
            foreach($this->request->latLong as $key=>$r){
                if($key==$length){
                    $string             .= $r;
                }else{
                    $string             .= $r.';';
                }
            }

            //static parameters
            $dyanamic                   = "stops=".$string;
            $perams                     ="?reports=Mileage&vehHeight=13%276%22&vehLength=53%27&vehWidth=96%22&vehWeight=14000&".$dyanamic;

            $url                        = "https://pcmiler.alk.com/apis/rest/v1.0/Service.svc/route/routeReports".$perams;
            $client                     = new \GuzzleHttp\Client();
            $response                   = $client->request('GET', $url, [
                'headers'               => [
                    'Authorization'     => getTrimbleApiKey(), //env("TRIMBLE_MAPS_API_KEY", "83FF948F08EB3C4BB97E3AED42BEF772"),
                    'Content-Type'      => 'application/json'
                ]
            ]);
            $response                   = json_decode($response->getBody()->getContents(), true);
            $lastArr                    = \Arr::last($response[0]['ReportLines']);
            $totalMiles                 = $lastArr['TMiles'];

            $data['totalMiles']         = $totalMiles;
            $data['ReportLines']        = $response[0]['ReportLines'];
            return $data;
        }
    }

    public function geTurnByData(){
        if(isset($this->request->latLong) && count($this->request->latLong)){
            $length                     = count($this->request->latLong)-1;
            $i                          = 1;
            $string                     = "";
            foreach($this->request->latLong as $key=>$r){
                if($key==$length){
                    $string             .= $r;
                }else{
                    $string             .= $r.';';
                }
            }
            //static parameters
            $dyanamic                   = "stops=".$string;
            $perams                     = "?reports=Directions&vehHeight=13%276%22&vehLength=53%27&vehWidth=96%22&vehWeight=14000&".$dyanamic;

            $url                        = "https://pcmiler.alk.com/apis/rest/v1.0/Service.svc//route/routeReports".$perams;
            $client                     = new \GuzzleHttp\Client();
            $response                   = $client->request('GET', $url, [
                'headers'               => [
                    'Authorization'     => getTrimbleApiKey(), //env("TRIMBLE_MAPS_API_KEY", "83FF948F08EB3C4BB97E3AED42BEF772"),
                    'Content-Type'      => 'application/json'
                ]
            ]);
            $response                   = json_decode($response->getBody()->getContents(), true);
            $data['ReportLegs']         = $response[0]['ReportLegs'];
            return $data;
        }
    }
}
