<?php

namespace Database\Factories;

use App\Models\Broker;
use App\Models\Driver;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\Factory;

class LoadDetailFactory extends Factory
{
    /**
     * Define the model's default state.
     *
     * @return array
     */
    public function definition()
    {
        $randomDate = $this->faker->dateTimeThisYear()->format('m/d/Y H:i');
        $empty_miles = $this->faker->randomFloat(2, 50.00, 1000.00);
        $loaded_miles = $this->faker->randomFloat(2, 50.00, 1000.00);
        $total_miles = $empty_miles + $loaded_miles;

        $fuel_surcharge = $this->faker->randomFloat(2, 0.00, 8000.00);
        $line_haul = $this->faker->randomFloat(2, 0.00, 8000.00);
        $detention = $this->faker->randomFloat(2, 0.00, 3000.00);
        $total_bill = $fuel_surcharge + $line_haul + $detention;

        return [
            'driver_id' => Driver::all()->random()->id,
            'booked_by' => $this->faker->randomElement([5,6,7,8,9,10,11,12,13,21]),
            'submitted_by' => '5',
            'load_number' => $this->faker->randomNumber(8),
            'load_type' => '0',
            'load_status' => $this->faker->randomElement([3,4,5,6]),
            'occupied_pickup_day' => $this->faker->randomElement([0, 1]),
            'shipper_date_time' => $randomDate,
            'actual_shipper_date' => date('Y-m-d H:i:s', strtotime($randomDate)),
            'load_not_picked_up_on_time' => date('Y-m-d H:i:s', strtotime($randomDate)),
            'shipper_id' => $this->faker->randomElement([1,2,4,5,6,8,10,12,14,16,18,20,21]),
            'shipper_location' => $this->faker->address(),
            'shipper_address_one' => $this->faker->streetName(),
            'shipper_state' => $this->faker->countryCode(),
            'shipper_city' => $this->faker->city(),
            'shipper_zip' => $this->faker->postcode(),
            'shipper_is_arrived' => $this->faker->randomElement([0,1]),
            'shipper_arrived_at' => date('Y-m-d H:i:s', strtotime($randomDate)),
            'delivery_date_time' => date('m/d/Y H:i', strtotime($randomDate.' + 2 days')),
            'actual_delivery_date' => date('Y-m-d H:i:S', strtotime($randomDate.' + 2 days')),
            'delivery_location' => $this->faker->address(),
            'delivery_address_one' => $this->faker->streetName(),
            'delivery_state' => $this->faker->countryCode(),
            'delivery_city' => $this->faker->city(),
            'delivery_zip' => $this->faker->postcode(),
            'delivery_is_arrived' => date('Y-m-d H:i:s', strtotime($randomDate.' + 2 days')),
            'brokerage_firm' => $this->faker->numberBetween(0, 1000),
            'weight' => $this->faker->numberBetween(0,9999),
            'trucking_company' => $this->faker->randomElement(['Trucking Sample Company','Dawson Truck Lines', 'Forest City, NC, USA']),
            'truck_number' => $this->faker->randomElement(['9012045','DTL88', '3033']),
            'trailer_number' => $this->faker->randomElement(['22097VV','V5360', 'V5351', '86139']),
            'empty_miles' => $empty_miles,
            'loaded_miles' => $loaded_miles,
            'total_miles' => $total_miles,
            'agreed_upon_rate' => $this->faker->randomFloat(2, 0.00, 10000.00),
            'fuel_surcharge_cost_per_mile' => $this->faker->randomFloat(2, 0.00, 4000.00),
            'fuel_surcharge' => $fuel_surcharge,
            'line_haul' => $line_haul,
            'detention' => $detention,
            'total_bill' =>  $total_bill,
            'driver_revenue' =>  $total_bill,
            'default_current_time' => $this->faker->dateTimeThisYear(Carbon::now()->addDay(10))->format('m/d/Y H:i'),
            'other_files' => 'a:0:{}',
        ];
    }
}
