<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class AddRouteTypeToOffersTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::table('offers', function (Blueprint $table) {
            $table->unsignedBigInteger('m_trailer_type')->nullable()->after('bound_call');
            $table->string('trailer_number')->nullable()->after('m_trailer_type');

            $table->unsignedBigInteger('terms')->nullable()->after('brokerage_mc');

            $table->string('score_ratting')->nullable()->after('credit');
            $table->string('score_credit')->nullable()->after('score_ratting');
            $table->datetime('score_updated_at')->nullable()->after('score_credit');

            $table->string('current_location')->nullable()->after('score_updated_at');
            $table->string('current_address_one')->nullable()->after('current_location');
            $table->string('current_address_two')->nullable()->after('current_address_one');
            $table->string('current_state')->nullable()->after('current_address_two');
            $table->string('current_city')->nullable()->after('current_state');
            $table->string('current_zip')->nullable()->after('current_city');
            $table->string('current_latitude')->nullable()->after('current_zip');
            $table->string('current_longitude')->nullable()->after('current_latitude');
            $table->string('current_timezone')->nullable()->after('current_longitude');
            $table->string('current_timezone_offset')->nullable()->after('current_timezone');
            $table->string('current_timezone_abbr')->nullable()->after('current_timezone_offset');
            $table->tinyInteger('current_address_verified')->default(0)->comment('1=Yes,0=No')->after('current_timezone_abbr');

            $table->datetime('shipper_date_time_end')->nullable()->after('shipper_date_time');
            $table->datetime('delivery_date_time_end')->nullable()->after('delivery_date_time');

            $table->string('temp')->nullable()->after('delivery_address_verified');
            $table->float('weight')->nullable()->after('temp');
            $table->unsignedBigInteger('commodity')->nullable()->after('weight');
            $table->float('load_value')->nullable()->after('commodity');

            $table->tinyInteger('route_type')->default(0)->comment('0 = Practical, 1 = Shortest, 2 = Fastest')->after('total_miles');
            $table->enum('open_border', ['0', '1'])->nullable()->comment('0 = No, 1 = Yes')->after('route_type');
            $table->enum('hazardous', ['0', '1'])->default(0)->comment('0 = No, 1 = Yes')->after('open_border');
            $table->unsignedInteger('hazardous_option')->nullable()->after('hazardous');
            $table->enum('over_dimension', ['0', '1'])->default(0)->comment('0 = No, 1 = Yes')->after('hazardous_option');
            $table->string('length')->nullable()->comment('Over Dimension = Yes')->after('over_dimension');
            $table->string('width')->nullable()->comment('Over Dimension = Yes')->after('length');
            $table->string('height')->nullable()->comment('Over Dimension = Yes')->after('width');

            $table->enum('is_rate_offered', ['0', '1'])->nullable()->comment('0 = No, 1 = Yes')->after('rate_offered');
            $table->enum('is_final_rate', ['0', '1'])->nullable()->comment('0 = No, 1 = Yes')->after('agreed_upon_rate');
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::table('offers', function (Blueprint $table) {
            $table->dropColumn([
                'm_trailer_type',
                'trailer_number',
                'terms',
                'score_ratting',
                'score_credit',
                'score_updated_at',
                'current_location',
                'current_address_one',
                'current_address_two',
                'current_state',
                'current_city',
                'current_zip',
                'current_latitude',
                'current_longitude',
                'current_timezone',
                'current_timezone_offset',
                'current_timezone_abbr',
                'current_address_verified',
                'shipper_date_time_end',
                'delivery_date_time_end',
                'temp',
                'weight',
                'commodity',
                'load_value',
                'route_type',
                'open_border',
                'hazardous',
                'hazardous_option',
                'over_dimension',
                'length',
                'width',
                'height',
                'is_rate_offered',
                'is_final_rate'
            ]);
        });
    }
}
