<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;
use Illuminate\Support\Facades\DB;

class AddAndUpdateColumnsForDriverGeneralInfoTabInDriversTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::table('drivers', function (Blueprint $table) {
            /* Existing columns Update */
            $table->bigInteger('role_id')->nullable()->change();
            $table->string('password')->nullable()->change();
            DB::statement('ALTER TABLE `drivers` CHANGE `is_company_driver` `is_company_driver` TINYINT(4) NOT NULL DEFAULT "0" COMMENT "0: Owner Operator, 1: Company Driver, 2: Subcontractor"');
            DB::statement('ALTER TABLE `drivers` CHANGE `ssn_or_ein` `ssn_or_ein` TINYINT(4) NULL DEFAULT NULL COMMENT "0: Social Security, 1: Federal ID"');

            /* New columns Create */
            $table->string('business_name', 50)->nullable()->after('timezone_type');
            $table->enum('business_na', ['0', '1'])->nullable()->comment('0: No, 1: Yes')->after('business_name');
            $table->string('business_dba', 50)->nullable()->after('business_na');
            $table->string('suffix', 50)->nullable()->after('business_dba');
            $table->string('nick_name', 50)->nullable()->after('suffix');
            $table->string('fax', 50)->nullable()->after('nick_name');
            $table->enum('pro_chat_invite', ['0', '1'])->nullable()->comment('0: No, 1: Yes')->after('fax');
            $table->string('other_phone', 50)->nullable()->after('pro_chat_invite');
            $table->string('years_experience', 50)->nullable()->after('other_phone');
            $table->enum('gender', ['0', '1'])->nullable()->comment('0: Male, 1: Female')->after('years_experience');
            $table->enum('medical_condition', ['0', '1', '2', '3', '4', '5'])->nullable()->comment('0: Corrective Lenses, 1: Blood Pressure, 2: Diabetes, 3: Hearing Aid, 4: Sleep Apnea, 5: Short Physical')->after('gender');
            $table->enum('is_1099', ['0', '1'])->nullable()->comment('0: No, 1: Yes')->after('medical_condition');
            $table->string('trailer_experience', 50)->nullable()->after('is_1099');
            $table->string('recruiter', 50)->nullable()->after('trailer_experience');
            $table->string('recruiter_source', 50)->nullable()->after('recruiter');
            $table->string('onboarding', 50)->nullable()->after('recruiter_source');
            $table->enum('same_as_dispatcher', ['0', '1'])->nullable()->comment('0: No, 1: Yes')->after('onboarding');
            $table->integer('load_planner')->nullable()->comment('Dispatcher ids')->after('same_as_dispatcher');
            $table->enum('fuel_card_type', ['0', '1', '2'])->nullable()->comment('0: WEX, 1: EFS, 2: Comdata')->after('load_planner');
            $table->string('fuel_card_number', 50)->nullable()->after('fuel_card_type');
            $table->enum('eobr_provider', ['0', '1', '2'])->nullable()->comment('0: Samsara, 1: GeoTab, 2: Omnitracs')->after('fuel_card_number');
            $table->string('eobr_id')->nullable()->after('eobr_provider');
            $table->integer('pro_chat_id')->nullable()->after('eobr_id');
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::table('drivers', function (Blueprint $table) {
            /* Existing columns rollback */
            $table->bigInteger('role_id')->change();
            $table->string('password')->change();
            DB::statement('ALTER TABLE `drivers` CHANGE `is_company_driver` `is_company_driver` TINYINT(4) NOT NULL DEFAULT "0" COMMENT "0: Owner Operator, 1: Company Driver"');
            DB::statement('ALTER TABLE `drivers` CHANGE `ssn_or_ein` `ssn_or_ein` TINYINT(4) NULL DEFAULT NULL COMMENT "0: Social Security, 1: Federal ID"');

            /* Drop New columns */
            $table->dropColumn(['business_name', 'business_na', 'business_dba', 'suffix', 'nick_name', 'fax', 'proChat_invite', 'other_phone', 'years_experience', 'gender', 'medical_condition', 'is_1099', 'trailer_experience', 'recruiter', 'recruiter_source', 'onboarding', 'same_as_dispatcher', 'load_planner', 'fuel_card_type', 'fuel_card_number', 'eobr_provider', 'eobr_id', 'pro_chat_id']);
        });
    }
}
