<!DOCTYPE html>
<html>
    <head>
        <meta charset="utf-8" />
        <link rel="stylesheet" href="https://maps-sdk.trimblemaps.com/v3/trimblemaps-3.8.0.css" />
        <script src="https://maps-sdk.trimblemaps.com/v3/trimblemaps-3.8.0.js"></script>
        <style>
            body { margin: 0; padding: 0; }

            #map {
                position: absolute;
                top: 0;
                bottom: 0;
                width: 100%;
            }
        </style>
    </head>
    <body>
        <div id="map"></div>

        <script>
            TrimbleMaps.APIKey      = '{!! getTrimbleApiKey() !!}'; //'83FF948F08EB3C4BB97E3AED42BEF772';
            const map               = new TrimbleMaps.Map({
                container: 'map',
                center: new TrimbleMaps.LngLat(-85.25, 35.05),
                zoom: 8
            });

            const bounds            = map.getBounds();
            const north             = bounds.getNorth();
            const south             = bounds.getSouth();
            const east              = bounds.getEast();
            const west              = bounds.getWest();

            // Functions for generating random points and features
            function getRandomPoint() {
                const lng           = west + ((east - west) * Math.random());
                const lat           = south + ((north - south) * Math.random());
                return [lng, lat];
            }

            const categories        = ['Active Truck', 'Inactive Truck', 'Active Trailer', 'Inactive Trailer'];

            function getRandomCategory() {
                var name            = categories[Math.floor(Math.random() * categories.length)];
                return name;
            }

            function getGeoJsonFeatures() {
                const features      = [];

                for (var i = 0; i < 250; i++) {
                    var category    = getRandomCategory();
                    features.push({
                        type: 'Feature',
                        properties: {
                            name: 'Point #' + i,
                            category: category
                        },
                        geometry: {
                            type: 'Point',
                            coordinates: getRandomPoint()
                        }
                    });
                }
                return features;
            }

            // Wait for the map to load before adding layers and data sources
            map.on('load', function() {
                // Use cluster properties on datasource to group data
                map.addSource('randomPoints', {
                    type: 'geojson',
                    cluster: true,
                    clusterRadius: 40,
                    clusterMaxZoom: 14,
                    data: {
                        type: 'FeatureCollection',
                        features: getGeoJsonFeatures()
                    }
                });

                // Use filter to shot clustered points
                map.addLayer({
                    id: 'clusteredPoints',
                    type: 'symbol',
                    source: 'randomPoints',
                    filter: ['has', 'point_count'],
                    layout: {
                        'icon-image': [
                            'match',
                            ['get', 'category'],
                            'Active Truck',
                            'truck-fill-green',
                            'Inactive Truck',
                            'truck-fill-red',
                            'Active Trailer',
                            'truck-outline-orange',
                            'Inactive Trailer',
                            'truck-outline-purple',
                            'circle-fill-black',
                        ],
                        'icon-allow-overlap': true,
                    }
                });

                // Show count for clustered points
                map.addLayer({
                    id: 'clusterCount',
                    type: 'symbol',
                    source: 'randomPoints',
                    filter: ['has', 'point_count'],
                    layout: {
                        'text-field': '{point_count}',
                        'text-font': ['Roboto Regular'],
                        'text-size': 12
                    },
                    paint: {
                        'text-color': '#FFF'
                    }
                });

                // Use filter to show unclustered points
                map.addLayer({
                    id: 'unclusteredPoints',
                    type: 'symbol',
                    source: 'randomPoints',
                    filter: ['!', ['has', 'point_count']],
                    layout: {
                        'icon-image': [
                            'match',
                            ['get', 'category'],
                            'Active Truck',
                            'truck-fill-green',
                            'Inactive Truck',
                            'truck-fill-red',
                            'Active Trailer',
                            'truck-outline-orange',
                            'Inactive Trailer',
                            'truck-outline-purple',
                            'circle-fill-black',
                        ],
                        'icon-allow-overlap': true
                    }
                });
            });
        </script>
    </body>
</html>
