@extends($companyAdminTheme)

@section('title')
    Broker Create
@endsection

@section('style')
    <link rel="stylesheet" href="{{ asset('theme/css/select2.min.css') }}">
    <style type="text/css">
        .select2-container{
            width: 100% !important;
        }
        .select2-container .select2-selection--single{
            height: 40px;
        }
        .select2-container--default .select2-selection--single, .select2-container--default .select2-selection--multiple{
            border: 1px solid #707070;
            border-radius: 0;
            color: #000000 !important;
            overflow: hidden !important;
            min-height: 40px;
            height: auto !important;
        }
        .select2-container--default .select2-selection--single .select2-selection__rendered{
            line-height: 40px;
            font-size: 14px;
        }
        .select2-container--default .select2-selection--single .select2-selection__arrow{
            height: 40px;
            margin-right: 5px;
        }
        .select2-container--default .select2-selection--single .select2-selection__arrow b{
            border-color: #000 transparent transparent transparent;
        }
    </style>
@endsection

@section('content')
    @php
        $dispatchers        = getDispatcherListByCompany(auth()->guard('company-admin')->user()->company_id);
    @endphp

    {!! Form::open(array(
            'route'         => 'company.admin.brokers.store',
            'method'        => 'POST',
            'files'         => 'true',
            'autocomplete'  => 'off',
            'class'         => 'store-form'
        )
    ) !!}
        <div class="row broker-form-wrapper">
            <div class="col-lg-6">
                <div class="white-box mb-4 generalAccount">
                    <h4 class="box-title">General Information</h4>
                    <div class="box-padding">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-group">
                                    <label>Name<span>*</span></label>
                                    {!! Form::text('name', old('name'), array('class' => 'form-control', 'autocomplete' => 'new', 'required' => 'required')) !!}
                                    @error('name')
                                        <span class="text-danger" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-md-12 geocoding">
                                <input type="hidden" class="geocoding-latitude" name="latitude" value="" autocomplete="off">
                                <input type="hidden" class="geocoding-longitude" name="longitude" value="" autocomplete="off">
                                <input type="hidden" class="geocoding-abbr" name="timezone_abbr" value="" autocomplete="off" data-parsley-errors-container="#timezone_abbr-errors" data-parsley-required-message="Please verify address" required>
                                <input type="hidden" class="geocoding-verified" name="address_verified" value="0" autocomplete="off">
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Address<span>*</span></label>
                                            {!! Form::text('address', old('address'), array(
                                                    'class'         => 'form-control geocoding-address-1',
                                                    'placeholder'   => '',
                                                    'id'            => 'address',
                                                    'required'      => 'required'
                                                )
                                            ) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Address 2</label>
                                            {!! Form::text('address_2', old('address_2'), array(
                                                    'class'         => 'form-control geocoding-address-2',
                                                    'placeholder'   => '',
                                                    'id'            => 'address_2'
                                                )
                                            ) !!}
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>City</label>
                                            {!! Form::text('city', old('city'), array(
                                                    'class'         => 'form-control geocoding-city',
                                                    'placeholder'   => '',
                                                    'id'            => 'city'
                                                )
                                            ) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>State<span>*</span></label>
                                            {!! Form::text('state', old('state'), array(
                                                    'class'         => 'form-control geocoding-state',
                                                    'placeholder'   => '',
                                                    'id'            => 'state',
                                                    'required'      => 'required'
                                                )
                                            ) !!}
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Zip<span>*</span></label>
                                            {!! Form::text('zip', old('zip'), array(
                                                    'class'         => 'form-control geocoding-zip',
                                                    'placeholder'   => '',
                                                    'id'            => 'zip',
                                                    'required'      => 'required'
                                                )
                                            ) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <button type="button" class="btn btn-warning geocoding-btn" data-uid="{{ 'map-'.generateStrUniqueId() }}">Verify</button>
                                        <div id="timezone_abbr-errors"></div>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Phone</label>
                                    {!! Form::text('phone_number', old('phone_number'), array('class' => 'form-control phone')) !!}
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Email</label>
                                    {!! Form::email('email', old('email'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Fax</label>
                                    {!! Form::text('fax', old('fax'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Rep Name</label>
                                    {!! Form::text('rep_name', old('rep_name'), array('class' => 'form-control', 'autocomplete' => 'new')) !!}
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-lg-6">
                <div class="white-box mb-4 generalAccount">
                    <h4 class="box-title">Business Information</h4>
                    <div class="box-padding">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>MC Number<span>*</span></label>
                                    {!! Form::text('mc_number', old('mc_number'), array('class' => 'form-control', 'autocomplete' => 'mc_number', 'required' => 'required')) !!}
                                    @error('mc_number')
                                        <span class="text-danger" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Federal ID</label>
                                    {!! Form::text('federal_id', old('federal_id'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>USDOT</label>
                                    {!! Form::text('usdot', old('usdot'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>SCAC</label>
                                    {!! Form::text('scac', old('scac'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Account Number</label>
                                    {!! Form::text('account_number', old('account_number'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Account Type</label>
                                    {!! Form::text('account_type', old('account_type'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-12">
                                <div class="form-group">
                                    <div class="drop-zone">
                                        <span class="drop-zone__prompt">Drag and drop file here or click to browse</span>
                                        <input type="file" name="logo" class="drop-zone__input" accept="image/png,image/gif,image/jpeg" >
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-lg-6">
                <div class="white-box mb-4 generalAccount">
                    <h4 class="box-title">Billing Information</h4>
                    <div class="box-padding">
                        <div class="row">
                            <div class="col-md-12 text-right">
                                <div class="custom-control custom-checkbox">
                                    <input type="checkbox" class="custom-control-input" id="sameaddress"><label class="custom-control-label" for="sameaddress">Same as above</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-group">
                                    <label>Bill To Name</label>
                                    {!! Form::text('bill_to_name', old('bill_to_name'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-12 geocoding">
                                <input type="hidden" class="geocoding-latitude" name="billing_latitude" value="" autocomplete="off">
                                <input type="hidden" class="geocoding-longitude" name="billing_longitude" value="" autocomplete="off">
                                <input type="hidden" class="geocoding-abbr" name="billing_timezone_abbr" value="" autocomplete="off" data-parsley-errors-container="#billing_timezone_abbr-errors" data-parsley-required-message="Please verify address" required>
                                <input type="hidden" class="geocoding-verified" name="billing_address_verified" value="0" autocomplete="off">
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Billing Address<span>*</span></label>
                                            {!! Form::text('billing_address', old('billing_address'), array(
                                                    'class'         => 'form-control geocoding-address-1',
                                                    'placeholder'   => '',
                                                    'id'            => 'billing_address',
                                                    'required'      => 'required'
                                                )
                                            ) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Billing Address 2</label>
                                            {!! Form::text('billing_address_2', old('billing_address_2'), array(
                                                    'class'         => 'form-control geocoding-address-2',
                                                    'placeholder'   => '',
                                                    'id'            => 'billing_address_2'
                                                )
                                            ) !!}
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Billing City<span>*</span></label>
                                            {!! Form::text('billing_city', old('billing_city'), array(
                                                    'class'         => 'form-control geocoding-city',
                                                    'placeholder'   => '',
                                                    'id'            => 'billing_city'
                                                )
                                            ) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Billing State<span>*</span></label>
                                            {!! Form::text('billing_state', old('billing_state'), array(
                                                    'class'         => 'form-control geocoding-state',
                                                    'placeholder'   => '',
                                                    'id'            => 'billing_state',
                                                    'required'      => 'required'
                                                )
                                            ) !!}
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Billing Zip<span>*</span></label>
                                            {!! Form::text('billing_zip', old('billing_zip'), array(
                                                    'class'         => 'form-control geocoding-zip',
                                                    'placeholder'   => '',
                                                    'id'            => 'billing_zip',
                                                    'required'      => 'required'
                                                )
                                            ) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <button type="button" class="btn btn-warning geocoding-btn" data-uid="{{ 'map-'.generateStrUniqueId() }}">Verify</button>
                                        <div id="billing_timezone_abbr-errors"></div>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Billing Phone</label>
                                    {!! Form::text('billing_phone', old('billing_phone'), array('class' => 'form-control phone')) !!}
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Billing Email</label>
                                    {!! Form::email('billing_email', old('billing_email'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Billing Extention</label>
                                    {!! Form::text('billing_extention', old('billing_extention'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Billing Fax</label>
                                    {!! Form::text('billing_fax', old('billing_fax'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Billing Method</label>
                                    {!! Form::text('billing_method', old('billing_method'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Factored</label>
                                    {!! Form::text('factored', old('factored'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Terms</label>
                                    {!! Form::select('billing_terms', ['' => 'Select Terms']+getCompanyTerms(), null, ['class' => 'terms-select2 custom-select form-control']) !!}
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-lg-6">
                <div class="white-box mb-4 generalAccount">
                    <h4 class="box-title">Required Documents</h4>
                    <div class="box-padding">
                        <div class="row">
                            <div class="col-md-12 mt-2 mb-2">
                                <p>When Shipper - <span class="text-primary rep-broker-contact" data-toggle="modal" id="shipperaddRow">Add New</span></p>
                            </div>
                            <div class="col-md-12">
                                @php
                                    $newSetShi = 1001;
                                @endphp
                                @if(isset($fixed_shipper_files) && !empty($fixed_shipper_files))
                                    @foreach ($fixed_shipper_files as $key => $shipperf)
                                        <div class="row align-items-center mb-2">
                                            <div class="col-auto cheskejw">
                                                <div class="custom-control custom-checkbox">
                                                    <input type="checkbox" class="custom-control-input" id="shipper_files_is_required_{{ $newSetShi }}" name="shipper_files[is_required][{{ $newSetShi }}]">
                                                    <label class="custom-control-label" for="shipper_files_is_required_{{ $newSetShi }}"></label>
                                                </div>
                                            </div>
                                            <div class="col-md-5">
                                                <div class="form-group mt-2">
                                                    <input type="hidden" name="shipper_files[name][{{ $newSetShi }}]" value="{{ $shipperf['name'] }}">
                                                    <input type="hidden" name="shipper_files[name_id][{{ $newSetShi }}]" value="{{ $shipperf['id'] }}">
                                                    <label>{{ $shipperf['name'] }}</label>
                                                </div>
                                            </div>
                                            <div class="col-auto custom-width radio-btn-div stradibut">
                                                <div class="btn-group btn-group-toggle" data-toggle="buttons">
                                                    <label class="btn btn-secondary active">
                                                    {!! Form::radio('shipper_files[type]['.$newSetShi.']', 1, true, array('class' => 'custom-control-input')) !!} Copy
                                                    </label>
                                                    <label class="btn btn-secondary ">
                                                    {!! Form::radio('shipper_files[type]['.$newSetShi.']', 2, false, array('class' => 'custom-control-input')) !!} Original
                                                    </label>
                                                </div>
                                            </div>
                                            <div class="col-md-1">
                                                <input type="hidden" name="shipper_files[fixed][{{ $newSetShi }}]" value="yes">
                                                <input type="hidden" name="shipper_files[include_w_billing][{{ $newSetShi }}]" value="{{ $shipperf['include_w_billing'] }}">
                                            </div>
                                        </div>
                                        @php
                                            $newSetShi++;
                                        @endphp
                                    @endforeach
                                @endif
                                <div id="shippernewRow"></div>
                            </div>
                            <div class="col-md-12 mt-4 mb-2">
                                <p>When Consignee - <span class="text-primary rep-broker-contact" data-toggle="modal" id="consigneeaddRow">Add New</span></p>
                            </div>
                            <div class="col-md-12">
                                @php
                                    $newConShi = 1001;
                                @endphp
                                @if(isset($fixed_consignee_files) && !empty($fixed_consignee_files))
                                    @foreach ($fixed_consignee_files as $key => $consigneef)
                                        <div class="row align-items-center mb-2">
                                            <div class="col-auto cheskejw">
                                                <div class="custom-control custom-checkbox">
                                                    <input type="checkbox" class="custom-control-input" id="consignee_files_is_required_{{ $newConShi }}" name="consignee_files[is_required][{{ $newConShi }}]"><label class="custom-control-label" for="consignee_files_is_required_{{ $newConShi }}"></label>
                                                </div>
                                            </div>
                                            <div class="col-md-5">
                                                <div class="form-group mt-2">
                                                    <input type="hidden" name="consignee_files[name][{{ $newConShi }}]" value="{{ $consigneef['name'] }}">
                                                    <input type="hidden" name="consignee_files[name_id][{{ $newConShi }}]" value="{{ $consigneef['id'] }}">
                                                    <label>{{ $consigneef['name'] }}</label>
                                                </div>
                                            </div>
                                            <div class="col-auto custom-width radio-btn-div stradibut">
                                                <div class="btn-group btn-group-toggle" data-toggle="buttons">
                                                    <label class="btn btn-secondary active">
                                                        {!! Form::radio('consignee_files[type]['.$newConShi.']', 1, true, array('class' => 'custom-control-input')) !!} Copy
                                                    </label>
                                                    <label class="btn btn-secondary ">
                                                        {!! Form::radio('consignee_files[type]['.$newConShi.']', 2, false, array('class' => 'custom-control-input')) !!} Original
                                                    </label>
                                                </div>
                                            </div>
                                            <div class="col-md-1">
                                                <input type="hidden" name="consignee_files[fixed][{{ $newConShi }}]" value="yes">
                                                <input type="hidden" name="consignee_files[include_w_billing][{{ $newConShi }}]" value="{{ $consigneef['include_w_billing'] }}">
                                            </div>
                                        </div>
                                        @php
                                            $newConShi++;
                                        @endphp
                                    @endforeach
                                @endif
                                <div id="consigneenewRow"></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-lg-6">
                <div class="white-box mb-4 generalAccount">
                    <h4 class="box-title">Detention Configuration</h4>
                    <div class="box-padding">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Free Time</label>
                                    {!! Form::text('detention_time', old('detention_time'), array('class' => 'form-control time')) !!}
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>$/hr</label>
                                    {!! Form::number('detention_price', old('detention_price'), array('class' => 'form-control', 'step' => 'any')) !!}
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-lg-12">
                <div class="white-box mb-4 generalAccount">
                    <h4 class="box-title">Contacts</h4>
                    <div class="box-padding">
                        <div class="row">
                            <div class="col-md-3">
                                <div class="form-group">
                                    <label>Dispatch Contact Name</label>
                                    {!! Form::text('dispatch_contact_name', old('dispatch_contact_name'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-3">
                                <div class="form-group">
                                    <label>Dispatch Contact Email</label>
                                    {!! Form::text('dispatch_contact_email', old('dispatch_contact_email'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-3">
                                <div class="form-group">
                                    <label>Dispatch Contact Phone</label>
                                    {!! Form::text('dispatch_contact_phone', old('dispatch_contact_phone'), array('class' => 'form-control phone')) !!}
                                </div>
                            </div>
                            <div class="col-md-3">
                                <div class="form-group">
                                    <label>Dispatch Contact EXT</label>
                                    {!! Form::text('dispatch_contact_contact_ext', old('dispatch_contact_contact_ext'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-3">
                                <div class="form-group">
                                    <label>A/P Contact Name</label>
                                    {!! Form::text('ap_contact_name', old('ap_contact_name'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-3">
                                <div class="form-group">
                                    <label>A/P Contact Email</label>
                                    {!! Form::text('ap_contact_email', old('ap_contact_email'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                            <div class="col-md-3">
                                <div class="form-group">
                                    <label>A/P Contact Phone</label>
                                    {!! Form::text('ap_contact_phone', old('ap_contact_phone'), array('class' => 'form-control phone')) !!}
                                </div>
                            </div>
                            <div class="col-md-3">
                                <div class="form-group">
                                    <label>A/P Contact Contact EXT</label>
                                    {!! Form::text('ap_contact_contact_ext', old('ap_contact_contact_ext'), array('class' => 'form-control')) !!}
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-lg-12">
                <div class="white-box mb-4 generalAccount">
                    <h4 class="box-title">Additional Offices</h4>
                    <div class="box-padding offices-wrapper">
                        <div class="row sub-wrapper geocoding" data-last-index="0">
                            <div class="col-12 d-none">
                                <input type="hidden" class="geocoding-latitude" name="offices[0][latitude]" value="">
                                <input type="hidden" class="geocoding-longitude" name="offices[0][longitude]" value="">
                                <input type="hidden" class="geocoding-abbr" name="offices[0][timezone_abbr]" value="" data-parsley-errors-container="#offices_0_timezone_abbr-errors" data-parsley-required-message="Please verify address">
                                <input type="hidden" class="geocoding-verified" name="offices[0][address_verified]" value="0">
                            </div>
                            <div class="col-md-2">
                                <div class="form-group">
                                    <label>Name</label>
                                    <input type="text" name="offices[0][name]" value="" class="form-control">
                                </div>
                            </div>
                            <div class="col-md-2">
                                <div class="form-group">
                                    <label>Address</label>
                                    <input type="text" name="offices[0][address]" value="" class="form-control geocoding-address-1">
                                </div>
                                <div id="offices_0_timezone_abbr-errors"></div>
                            </div>
                            <div class="col-md-2">
                                <div class="form-group">
                                    <label>City</label>
                                    <input type="text" name="offices[0][city]" value="" class="form-control geocoding-city">
                                </div>
                            </div>
                            <div class="col-md-2">
                                <div class="form-group">
                                    <label>State</label>
                                    <input type="text" name="offices[0][state]" value="" class="form-control geocoding-state">
                                </div>
                            </div>
                            <div class="col-md-2">
                                <div class="form-group">
                                    <label>Zip</label>
                                    <input type="text" name="offices[0][zip]" value="" class="form-control geocoding-zip">
                                </div>
                            </div>
                            <div class="col-md-2">
                                <button type="button" class="btn btn-warning geocoding-btn mr-2" data-uid="{{ 'map-'.generateStrUniqueId() }}">Verify</button>
                                <button type="button" class="btn btn-success mt-3" id="addOffices"><i class="fa fa-plus"></i></button>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-lg-12">
                <div class="white-box mb-4 generalAccount">
                    <h4 class="box-title">Additional Contacts</h4>
                    <div class="box-padding additional-contacts-wrapper">
                        <div class="row sub-wrapper" data-last-index="0">
                            <div class="col-md-2">
                                <div class="form-group">
                                    <label>Department</label>
                                    <input type="text" name="additional_contacts[0][department]" value="" class="form-control">
                                </div>
                            </div>
                            <div class="col-md-2">
                                <div class="form-group">
                                    <label>First Name</label>
                                    <input type="text" name="additional_contacts[0][first_name]" value="" class="form-control">
                                </div>
                            </div>
                            <div class="col-md-2">
                                <div class="form-group">
                                    <label>Last Name</label>
                                    <input type="text" name="additional_contacts[0][last_name]" value="" class="form-control">
                                </div>
                            </div>
                            <div class="col-md-2">
                                <div class="form-group">
                                    <label>Phone Number</label>
                                    <input type="text" name="additional_contacts[0][phone_number]" value="" class="form-control phone">
                                </div>
                            </div>
                            <div class="col-md-2">
                                <div class="form-group">
                                    <label>Cell Number</label>
                                    <input type="text" name="additional_contacts[0][cell_number]" value="" class="form-control phone">
                                </div>
                            </div>
                            <div class="col-md-2">
                                <div class="form-group">
                                    <label class="d-block" style="visibility: hidden;">Action</label>
                                    <a href="javascript:void(0)" class="btn btn-success" id="addContacts"><i class="fa fa-plus"></i></a>
                                </div>
                            </div>
                            <div class="col-md-2">
                                <div class="form-group">
                                    <label>Ext</label>
                                    <input type="text" name="additional_contacts[0][ext]" value="" class="form-control">
                                </div>
                            </div>
                            <div class="col-md-2">
                                <div class="form-group">
                                    <label>Email</label>
                                    <input type="email" name="additional_contacts[0][email]" value="" class="form-control">
                                </div>
                            </div>
                            <div class="col-md-2">
                                <div class="form-group">
                                    <label>Preferred Connection</label>
                                    <div class="custom-checkbox-inline">
                                        <div class="custom-control custom-checkbox">
                                            <input type="checkbox" class="custom-control-input" name="additional_contacts[0][preferred_connections][]" id="additional_contacts_0_message" value="1">
                                            <label class="custom-control-label" for="additional_contacts_0_message" title="Message">
                                                <i class="fa fa-commenting" aria-hidden="true"></i>
                                            </label>
                                        </div>
                                        <div class="custom-control custom-checkbox">
                                            <input type="checkbox" class="custom-control-input" name="additional_contacts[0][preferred_connections][]" id="additional_contacts_0_email" value="2">
                                            <label class="custom-control-label" for="additional_contacts_0_email" title="Email">
                                                <i class="fa fa-envelope" aria-hidden="true"></i>
                                            </label>
                                        </div>
                                        <div class="custom-control custom-checkbox">
                                            <input type="checkbox" class="custom-control-input" name="additional_contacts[0][preferred_connections][]" id="additional_contacts_0_phone" value="3">
                                            <label class="custom-control-label" for="additional_contacts_0_phone" title="Phone">
                                                <i class="fa fa-mobile" aria-hidden="true"></i>
                                            </label>
                                        </div>
                                        <div class="custom-control custom-checkbox">
                                            <input type="checkbox" class="custom-control-input" name="additional_contacts[0][preferred_connections][]" id="additional_contacts_0_cell" value="4">
                                            <label class="custom-control-label" for="additional_contacts_0_cell" title="Cell">
                                                <i class="fa fa-phone" aria-hidden="true"></i>
                                            </label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-2">
                                <div class="form-group">
                                    <label>Primary Contact</label>
                                    <div class="d-flex align-items-center">
                                        <div class="custom-control custom-switch-blue custom-switch-small mr-2">
                                            <input type="checkbox" class="custom-control-input primary_contact" name="additional_contacts[0][primary_contact]" id="additional_contacts_0_primary_contact" value="1">
                                            <label class="custom-control-label mb-0" for="additional_contacts_0_primary_contact"></label>
                                        </div>
                                        <label class="switch-text mb-0" for="additional_contacts_0_primary_contact">Off/On</label>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-2 primary-contact-id-div d-none">
                                <div class="form-group">
                                    <label class="d-block" style="visibility: hidden;">Primary Dispatcher</label>
                                    <select name="additional_contacts[0][dispatcher_id][]" class="form-control select2" multiple>
                                        @foreach ($dispatchers as $dispatcher_id => $dispatcher_name)
                                            <option value="{{ $dispatcher_id }}">{{ $dispatcher_name }}</option>
                                        @endforeach
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-lg-12">
                <div class="white-box mb-4 load-status">
                    <h4 class="box-title clear-btn">Communications</h4>
                    <div class="box-padding">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-group mt-2 mb-5">
                                    <label><strong>Note:</strong> Notes for a broker can't be add until the create broker is saved</label>
                                    <!--a class="addmorecut" data-toggle="modal" data-target="#newFinancialModal">+ Add</a-->
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-lg-12">
                <div class="white-box mb-4 load-status">
                    <h4 class="box-title clear-btn">Customer Files</h4>
                    <div class="box-padding">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-group mt-2 mb-5">
                                    <label><strong>Note:</strong> Load Files for a broker can't be add until the create broker is saved</label>
                                    <!--a class="addmorecut" data-toggle="modal" data-target="#newFinancialModal">+ Add</a-->
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="button-bottom">
            <a href="{{ route('company.admin.brokers.index') }}" class="cancel-btn">Cancel</a>
            <button class="submit-btn">Submit</button>
        </div>
    {!! Form::close() !!}
@endsection

@section('script')
    <script src="{{ asset('theme/js/select2.full.min.js') }}"></script>
    <script type="text/javascript">
        var dispatchers_options             = '';
        var shipper_files_options           = '';
        var consignee_files_options         = '';
        $(document).ready(function() {
            var dispatchers                 = <?php echo json_encode($dispatchers); ?>;
            $.each( dispatchers, function( key, value ) {
                dispatchers_options         += '<option value="'+key+'">'+value+'</option>';
            });
            var shipper_files               = <?php echo json_encode($shipper_files); ?>;
            shipper_files_options           += '<option value="">Select File Name</option>';
            $.each( shipper_files, function( key, value ) {
                shipper_files_options       += '<option value="'+value.id+'" data-include_w_billing="'+value.include_w_billing+'">'+value.name+'</option>';
            });
            var consignee_files             = <?php echo json_encode($consignee_files); ?>;
            consignee_files_options         += '<option value="">Select File Name</option>';
            $.each( consignee_files, function( key, value ) {
                consignee_files_options     += '<option value="'+value.id+'" data-include_w_billing="'+value.include_w_billing+'">'+value.name+'</option>';
            });

            $('.store-form').parsley({
                excluded: 'input[type=button], input[type=submit], input[type=reset]',
                inputs: 'input, textarea, select, input[type=hidden], :hidden',
            });
            $('.time').datetimepicker({
                format: 'HH:mm',
                useCurrent: false,
            });
            $(".terms-select2").select2();
            $('.select2').select2({
                placeholder: 'Select options'
            });
        });
    </script>
    <script type="text/javascript">
        $("#sameaddress").click(function() {
            if ($("#sameaddress").is(":checked")) {
                $('input[name="bill_to_name"]').val($('input[name="name"]').val());
                $('input[name="billing_address"]').val($('input[name="address"]').val());
                $('input[name="billing_address_2"]').val($('input[name="address_2"]').val());
                $('input[name="billing_city"]').val($('input[name="city"]').val());
                $('input[name="billing_state"]').val($('input[name="state"]').val());
                $('input[name="billing_zip"]').val($('input[name="zip"]').val());
                $('input[name="billing_phone"]').val($('input[name="phone_number"]').val());
                $('input[name="billing_email"]').val($('input[name="email"]').val());
                $('input[name="billing_extention"]').val($('input[name="extention"]').val());
                $('input[name="billing_fax"]').val($('input[name="fax"]').val());
                // $('input[name="billing_method"]').val($('input[name="method"]').val());
                // $('input[name="factored"]').val($('input[name="factored"]').val());

                if($('input[name="billing_address"]').val()!=''){
                    $('input[name="billing_address"]').parsley().reset();
                }
                if($('input[name="billing_state"]').val()!=''){
                    $('input[name="billing_state"]').parsley().reset();
                }
                if($('input[name="billing_zip"]').val()!=''){
                    $('input[name="billing_zip"]').parsley().reset();
                }
                var address_verified    = $('input[name="address_verified"]').val();
                if(address_verified==1){
                    $('input[name="billing_latitude"]').val($('input[name="latitude"]').val());
                    $('input[name="billing_longitude"]').val($('input[name="longitude"]').val());
                    $('input[name="billing_timezone_abbr"]').val($('input[name="timezone_abbr"]').val());
                    $('input[name="billing_address_verified"]').val('1');

                    $('input[name="billing_timezone_abbr"]').parsley().reset();
                    var btn             = $('input[name="billing_latitude"]').closest('.geocoding').find('.geocoding-btn');
                    btn.text('Verified');
                    btn.removeClass("btn-warning");
                    btn.addClass("btn-success");
                }
            }else{
                $('input[name="bill_to_name"]').val('');
                $('input[name="billing_address"]').val('');
                $('input[name="billing_address_2"]').val('');
                $('input[name="billing_city"]').val('');
                $('input[name="billing_state"]').val('');
                $('input[name="billing_zip"]').val('');
                $('input[name="billing_phone"]').val('');
                $('input[name="billing_email"]').val('');
                $('input[name="billing_extention"]').val('');
                $('input[name="billing_fax"]').val('');
                // $('input[name="billing_method"]').val('');
                // $('input[name="factored"]').val('');

                $('input[name="billing_latitude"]').val('');
                $('input[name="billing_longitude"]').val('');
                $('input[name="billing_timezone_abbr"]').val('');
                $('input[name="billing_address_verified"]').val('0');

                var btn             = $('input[name="billing_latitude"]').closest('.geocoding').find('.geocoding-btn');
                btn.text('Verify');
                btn.removeClass("btn-success");
                btn.addClass("btn-warning");
            }
        });
    </script>
    <script type="text/javascript">
        var officeIndex         = 1;
        $("#addOffices").click(function () {
            var uid             = 'map-'
            uid                 += officeIndex+$.now();
            var html            = `
                <div class="row sub-wrapper geocoding" data-last-index="`+officeIndex+`">
                    <div class="col-12 d-none">
                        <input type="hidden" class="geocoding-latitude" name="offices[`+officeIndex+`][latitude]" value="">
                        <input type="hidden" class="geocoding-longitude" name="offices[`+officeIndex+`][longitude]" value="">
                        <input type="hidden" class="geocoding-abbr" name="offices[`+officeIndex+`][timezone_abbr]" value="" data-parsley-errors-container="#offices_`+officeIndex+`_timezone_abbr-errors" data-parsley-required-message="Please verify address">
                        <input type="hidden" class="geocoding-verified" name="offices[`+officeIndex+`][address_verified]" value="0">
                    </div>
                    <div class="col-md-2">
                        <div class="form-group">
                            <label>Name</label>
                            <input type="text" name="offices[`+officeIndex+`][name]" value="" class="form-control">
                        </div>
                    </div>
                    <div class="col-md-2">
                        <div class="form-group">
                            <label>Address</label>
                            <input type="text" name="offices[`+officeIndex+`][address]" value="" class="form-control geocoding-address-1">
                        </div>
                        <div id="offices_`+officeIndex+`_timezone_abbr-errors"></div>
                    </div>
                    <div class="col-md-2">
                        <div class="form-group">
                            <label>City</label>
                            <input type="text" name="offices[`+officeIndex+`][city]" value="" class="form-control geocoding-city">
                        </div>
                    </div>
                    <div class="col-md-2">
                        <div class="form-group">
                            <label>State</label>
                            <input type="text" name="offices[`+officeIndex+`][state]" value="" class="form-control geocoding-state">
                        </div>
                    </div>
                    <div class="col-md-2">
                        <div class="form-group">
                            <label>Zip</label>
                            <input type="text" name="offices[`+officeIndex+`][zip]" value="" class="form-control geocoding-zip">
                        </div>
                    </div>
                    <div class="col-md-2">
                        <button type="button" class="btn btn-warning geocoding-btn mr-2" data-uid="`+uid+`">Verify</button>
                        <button type="button" class="btn btn-danger mt-3 removeOffices"><i class="fa fa-trash"></i></button>
                    </div>
                </div>
            `;
            $('.offices-wrapper').append(html);
            officeIndex++;
        });
        // remove row
        $(document).on('click', '.removeOffices', function () {
            $(this).closest('.sub-wrapper').remove();
        });
    </script>
    <script type="text/javascript">
        var contactsIndex       = 1;
        $("#addContacts").click(function () {
            var html            = `<div class="row sub-wrapper" data-last-index="`+contactsIndex+`">
                <div class="col-md-2">
                    <div class="form-group">
                        <label>Department</label>
                        <input type="text" name="additional_contacts[`+contactsIndex+`][department]" value="" class="form-control">
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label>First Name</label>
                        <input type="text" name="additional_contacts[`+contactsIndex+`][first_name]" value="" class="form-control">
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label>Last Name</label>
                        <input type="text" name="additional_contacts[`+contactsIndex+`][last_name]" value="" class="form-control">
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label>Phone Number</label>
                        <input type="text" name="additional_contacts[`+contactsIndex+`][phone_number]" value="" class="form-control phone">
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label>Cell Number</label>
                        <input type="text" name="additional_contacts[`+contactsIndex+`][cell_number]" value="" class="form-control phone">
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label class="d-block" style="visibility: hidden;">Action</label>
                        <a href="javascript:void(0)" class="btn btn-danger removeContacts"><i class="fa fa-trash"></i></a>
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label>Ext</label>
                        <input type="text" name="additional_contacts[`+contactsIndex+`][ext]" value="" class="form-control">
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label>Email</label>
                        <input type="email" name="additional_contacts[`+contactsIndex+`][email]" value="" class="form-control">
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label>Preferred Connection</label>
                        <div class="custom-checkbox-inline">
                            <div class="custom-control custom-checkbox">
                                <input type="checkbox" class="custom-control-input" name="additional_contacts[`+contactsIndex+`][preferred_connections][]" id="additional_contacts_`+contactsIndex+`_message" value="1">
                                <label class="custom-control-label" for="additional_contacts_`+contactsIndex+`_message" title="Message">
                                    <i class="fa fa-commenting" aria-hidden="true"></i>
                                </label>
                            </div>
                            <div class="custom-control custom-checkbox">
                                <input type="checkbox" class="custom-control-input" name="additional_contacts[`+contactsIndex+`][preferred_connections][]" id="additional_contacts_`+contactsIndex+`_email" value="2">
                                <label class="custom-control-label" for="additional_contacts_`+contactsIndex+`_email" title="Email">
                                    <i class="fa fa-envelope" aria-hidden="true"></i>
                                </label>
                            </div>
                            <div class="custom-control custom-checkbox">
                                <input type="checkbox" class="custom-control-input" name="additional_contacts[`+contactsIndex+`][preferred_connections][]" id="additional_contacts_`+contactsIndex+`_phone" value="3">
                                <label class="custom-control-label" for="additional_contacts_`+contactsIndex+`_phone" title="Phone">
                                    <i class="fa fa-mobile" aria-hidden="true"></i>
                                </label>
                            </div>
                            <div class="custom-control custom-checkbox">
                                <input type="checkbox" class="custom-control-input" name="additional_contacts[`+contactsIndex+`][preferred_connections][]" id="additional_contacts_`+contactsIndex+`_cell" value="4">
                                <label class="custom-control-label" for="additional_contacts_`+contactsIndex+`_cell" title="Cell">
                                    <i class="fa fa-phone" aria-hidden="true"></i>
                                </label>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label>Primary Contact</label>
                        <div class="d-flex align-items-center">
                            <div class="custom-control custom-switch-blue custom-switch-small mr-2">
                                <input type="checkbox" class="custom-control-input primary_contact" name="additional_contacts[`+contactsIndex+`][primary_contact]" id="additional_contacts_`+contactsIndex+`_primary_contact" value="1">
                                <label class="custom-control-label mb-0" for="additional_contacts_`+contactsIndex+`_primary_contact"></label>
                            </div>
                            <label class="switch-text mb-0" for="additional_contacts_`+contactsIndex+`_primary_contact">Off/On</label>
                        </div>
                    </div>
                </div>
                <div class="col-md-2 primary-contact-id-div d-none">
                    <div class="form-group">
                        <label class="d-block" style="visibility: hidden;">Primary Dispatcher</label>
                        <select name="additional_contacts[`+contactsIndex+`][dispatcher_id][]" class="form-control select2" multiple>
                            `+dispatchers_options+`
                        </select>
                    </div>
                </div>
            </div>`;
            $('.additional-contacts-wrapper').append(html);
            contactsIndex++;
            setPhoneNumber();
            $('.select2').select2({
                placeholder: 'Select options'
            });
        });
        // remove row
        $(document).on('click', '.removeContacts', function () {
            $(this).closest('.sub-wrapper').remove();
        });
        //
        $(document).on('change', '.primary_contact', function() {
            var that    = $(this);
            var wrapper = that.closest('.sub-wrapper');
            if(this.checked) {
                wrapper.find('.primary-contact-id-div').removeClass('d-none');
            }else{
                wrapper.find('.primary-contact-id-div').addClass('d-none');
            }
        });
    </script>
    <script type="text/javascript">
        var shipperIndex        = parseInt('{{ $newSetShi }}');
        $("#shipperaddRow").click(function () {
            var html            = `<div class="row align-items-center mb-2 shipperinputFormRow">`;
            html                +=
                `<div class="col-auto cheskejw">
                    <div class="custom-control custom-checkbox">
                        <input type="checkbox" class="custom-control-input" id="shipper_files_is_required_`+shipperIndex+`" name="shipper_files[is_required][`+shipperIndex+`]">
                        <label class="custom-control-label" for="shipper_files_is_required_`+shipperIndex+`"></label>
                    </div>
                </div>
                <div class="col-md-5">
                    <div class="form-group mt-2">
                        <input type="hidden" name="shipper_files[name][`+shipperIndex+`]" value="">
                        <select name="shipper_files[name_id][`+shipperIndex+`]" class="form-control" data-parsley-errors-container="#shipper_files_name_id_`+shipperIndex+`-errors" required>
                            `+shipper_files_options+`
                        </select>
                        <div id="shipper_files_name_id_`+shipperIndex+`-errors"></div>
                    </div>
                </div>
                <div class="col-auto custom-width radio-btn-div stradibut">
                    <div class="btn-group btn-group-toggle" data-toggle="buttons">
                        <label class="btn btn-secondary">
                            <input class="custom-control-input" name="shipper_files[type][`+shipperIndex+`]" type="radio" value="1"> Copy
                        </label>
                        <label class="btn btn-secondary active">
                            <input class="custom-control-input" name="shipper_files[type][`+shipperIndex+`]" type="radio" value="2" checked="checked"> Original
                        </label>
                    </div>
                </div>
                <div class="col-md-1">
                    <input type="hidden" name="shipper_files[fixed][`+shipperIndex+`]" value="no">
                    <input type="hidden" name="shipper_files[include_w_billing][`+shipperIndex+`]" value="no">
                    <a href="javascript:void(0)" class="btn btn-danger shipperremoveRow"><i class="fa fa-trash"></i></a>
                </div>`;
            html                += `</div>`;
            $('#shippernewRow').append(html);
            $('select[name="shipper_files[name_id]['+shipperIndex+']"]').select2();
            shipperIndex++;
        });

        // remove row
        $(document).on('click', '.shipperremoveRow', function () {
            $(this).closest('.shipperinputFormRow').remove();
        });

        var consigneeIndex      = parseInt('{{ $newConShi }}');;
        $("#consigneeaddRow").click(function () {
            var html            = `<div class="row align-items-center mb-2 consigneeinputFormRow">`;
            html                +=
                `<div class="col-auto cheskejw">
                    <div class="custom-control custom-checkbox">
                        <input type="checkbox" class="custom-control-input" id="consignee_files_is_required_`+consigneeIndex+`" name="consignee_files[is_required][`+consigneeIndex+`]">
                        <label class="custom-control-label" for="consignee_files_is_required_`+consigneeIndex+`"></label>
                    </div>
                </div>
                <div class="col-md-5">
                    <div class="form-group mt-2">
                        <input type="hidden" name="consignee_files[name][`+consigneeIndex+`]" value="">
                        <select name="consignee_files[name_id][`+consigneeIndex+`]" class="form-control" data-parsley-errors-container="#consignee_files_name_id_`+consigneeIndex+`-errors" required>
                            `+consignee_files_options+`
                        </select>
                        <div id="consignee_files_name_id_`+consigneeIndex+`-errors"></div>
                    </div>
                </div>
                <div class="col-auto custom-width radio-btn-div stradibut">
                    <div class="btn-group btn-group-toggle" data-toggle="buttons">
                        <label class="btn btn-secondary">
                            <input class="custom-control-input" name="consignee_files[type][`+consigneeIndex+`]" type="radio" value="1"> Copy
                        </label>
                        <label class="btn btn-secondary active">
                            <input class="custom-control-input" name="consignee_files[type][`+consigneeIndex+`]" type="radio" value="2" checked="checked"> Original
                        </label>
                    </div>
                </div>
                <div class="col-md-1">
                    <input type="hidden" name="consignee_files[fixed][`+consigneeIndex+`]" value="no">
                    <input type="hidden" name="consignee_files[include_w_billing][`+consigneeIndex+`]" value="no">
                    <a href="javascript:void(0)" class="btn btn-danger consigneeremoveRow"><i class="fa fa-trash"></i></a>
                </div>`;
            html                += `</div>`;
            $('#consigneenewRow').append(html);
            $('select[name="consignee_files[name_id]['+consigneeIndex+']"]').select2();
            consigneeIndex++;
        });

        // remove row
        $(document).on('click', '.consigneeremoveRow', function () {
            $(this).closest('.consigneeinputFormRow').remove();
        });

        $(document).on('change', 'select[name^="shipper_files[name_id]"], select[name^="consignee_files[name_id]"]', function() {
            var optionSelected          = $("option:selected", this);
            var selectedValue           = $(this).val();
            var selectedText            = $(this).find("option:selected").text();
            if(selectedValue==''){
                selectedText            = '';
            }
            var nameId                  = $(this).attr('name').match(/\[name_id\]\[(\d+)\]/)[1];
            var nameIndex               = nameId; // Assuming nameIndex and name_id are the same

            var nameElement;
            var includeWBillingElement;
            if ($(this).attr('name').indexOf('shipper_files') !== -1) {
                nameElement             = $("input[name='shipper_files[name][" + nameIndex + "]']");
                includeWBillingElement  = $("input[name='shipper_files[include_w_billing][" + nameIndex + "]']");
                // console.log('Shipper Files Change - name_id: ' + nameId + ', shipperIndex: ' + nameIndex + ', value: ' + selectedValue+ ', text: ' + selectedText);
            } else if ($(this).attr('name').indexOf('consignee_files') !== -1) {
                nameElement             = $("input[name='consignee_files[name][" + nameIndex + "]']");
                includeWBillingElement  = $("input[name='consignee_files[include_w_billing][" + nameIndex + "]']");
                // console.log('Consignee Files Change - name_id: ' + nameId + ', consigneeIndex: ' + nameIndex + ', value: ' + selectedValue+ ', text: ' + selectedText);
            }
            if(nameElement && nameElement.length > 0){
                $(nameElement).val(selectedText);
            }
            if(includeWBillingElement && includeWBillingElement.length > 0){
                if(optionSelected.attr('data-include_w_billing') == 'yes'){
                    $(includeWBillingElement).val('yes');
                }else{
                    $(includeWBillingElement).val('no');
                }
            }
        });
    </script>
    <script type="text/javascript">
        document.querySelectorAll(".drop-zone__input").forEach((inputElement) => {
            const dropZoneElement = inputElement.closest(".drop-zone");

            dropZoneElement.addEventListener("click", (e) => {
                inputElement.click();
            });

            inputElement.addEventListener("change", (e) => {
                if (inputElement.files.length) {
                updateThumbnail(dropZoneElement, inputElement.files[0]);
                }
            });

            dropZoneElement.addEventListener("dragover", (e) => {
                e.preventDefault();
                dropZoneElement.classList.add("drop-zone--over");
            });

            ["dragleave", "dragend"].forEach((type) => {
                dropZoneElement.addEventListener(type, (e) => {
                dropZoneElement.classList.remove("drop-zone--over");
                });
            });

            dropZoneElement.addEventListener("drop", (e) => {
                e.preventDefault();

                if (e.dataTransfer.files.length) {
                inputElement.files = e.dataTransfer.files;
                updateThumbnail(dropZoneElement, e.dataTransfer.files[0]);
                }

                dropZoneElement.classList.remove("drop-zone--over");
            });
        });

        function updateThumbnail(dropZoneElement, file) {
            let thumbnailElement = dropZoneElement.querySelector(".drop-zone__thumb");

            // First time - remove the prompt
            if (dropZoneElement.querySelector(".drop-zone__prompt")) {
                dropZoneElement.querySelector(".drop-zone__prompt").remove();
            }

            // First time - there is no thumbnail element, so lets create it
            if (!thumbnailElement) {
                thumbnailElement = document.createElement("div");
                thumbnailElement.classList.add("drop-zone__thumb");
                dropZoneElement.appendChild(thumbnailElement);
            }

            thumbnailElement.dataset.label = file.name;

            // Show thumbnail for image files
            if (file.type.startsWith("image/")) {
                const reader = new FileReader();

                reader.readAsDataURL(file);
                reader.onload = () => {
                thumbnailElement.style.backgroundImage = `url('${reader.result}')`;
                };
            } else {
                thumbnailElement.style.backgroundImage = null;
            }
        }
    </script>
@endsection

@push('after-scripts')
    <script src="{{ asset('theme/js/trimble.js') }}"></script>
@endpush