@extends($companyAdminTheme)

@section('title')
    Broker Edit
@endsection

@section('style')
    <link rel="stylesheet" href="{{ asset('theme/css/select2.min.css') }}">
    <style type="text/css">
        .form-group img {position: relative;right: auto;bottom: auto;}
        .select2-container{
            width: 100% !important;
        }
        .select2-container .select2-selection--single{
            height: 40px;
        }
        .select2-container--default .select2-selection--single, .select2-container--default .select2-selection--multiple{
            border: 1px solid #707070;
            border-radius: 0;
            color: #000000 !important;
            overflow: hidden !important;
            min-height: 40px;
            height: auto !important;
        }
        .select2-container--default .select2-selection--single .select2-selection__rendered{
            line-height: 40px;
            font-size: 14px;
        }
        .select2-container--default .select2-selection--single .select2-selection__arrow{
            height: 40px;
            margin-right: 5px;
        }
        .select2-container--default .select2-selection--single .select2-selection__arrow b{
            border-color: #000 transparent transparent transparent;
        }
    </style>
@endsection

@section('content')
    @php
        $dispatchers        = getDispatcherListByCompany(auth()->guard('company-admin')->user()->company_id);
    @endphp

    <div class="row">
        {!! Form::model($broker,array(
                'route'     => ['company.admin.brokers.update',$broker->id],
                'method'    => 'PATCH',
                'files'     => 'true',
                'class'     => 'update-form'
            )
        ) !!}
            <div class="col-lg-12 broker-form-wrapper">
                <div class="row">
                    <div class="col-lg-6">
                        <div class="white-box mb-4 generalAccount">
                            <h4 class="box-title">General Information</h4>
                            <div class="box-padding">
                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="form-group">
                                            <label>Name<span>*</span></label>
                                            <input type="text" class="form-control" name="name" value="{{ isset($broker->name)?$broker->name:'' }}" data-previousValue="{{ isset($broker->name)?$broker->name:'' }}" autocomplete="new" required>
                                            @error('name')
                                                <span class="text-danger" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                            @enderror
                                        </div>
                                    </div>
                                    <div class="col-md-12 geocoding">
                                        <input type="hidden" class="geocoding-latitude" name="latitude" value="{{ isset($broker->latitude)?$broker->latitude:'' }}" autocomplete="off">
                                        <input type="hidden" class="geocoding-longitude" name="longitude" value="{{ isset($broker->longitude)?$broker->longitude:'' }}" autocomplete="off">
                                        <input type="hidden" class="geocoding-abbr" name="timezone_abbr" value="{{ isset($broker->timezone_abbr)?$broker->timezone_abbr:'' }}" autocomplete="off" data-parsley-errors-container="#timezone_abbr-errors" data-parsley-required-message="Please verify address" required>
                                        <input type="hidden" class="geocoding-verified" name="address_verified" value="{{ isset($broker->address_verified)?$broker->address_verified:'0' }}" autocomplete="off">
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label>Address<span>*</span></label>
                                                    {!! Form::text('address', old('address'), array(
                                                            'class'         => 'form-control geocoding-address-1',
                                                            'placeholder'   => '',
                                                            'id'            => 'address',
                                                            'required'      => 'required'
                                                        )
                                                    ) !!}
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label>Address 2</label>
                                                    {!! Form::text('address_2', old('address_2'), array(
                                                            'class'         => 'form-control geocoding-address-2',
                                                            'placeholder'   => '',
                                                            'id'            => 'address_2'
                                                        )
                                                    ) !!}
                                                </div>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label>City</label>
                                                    {!! Form::text('city', old('city'), array(
                                                            'class'         => 'form-control geocoding-city',
                                                            'placeholder'   => '',
                                                            'id'            => 'city'
                                                        )
                                                    ) !!}
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label>State<span>*</span></label>
                                                    {!! Form::text('state', old('state'), array(
                                                            'class'         => 'form-control geocoding-state',
                                                            'placeholder'   => '',
                                                            'id'            => 'state',
                                                            'required'      => 'required'
                                                        )
                                                    ) !!}
                                                </div>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label>Zip<span>*</span></label>
                                                    {!! Form::text('zip', old('zip'), array(
                                                            'class'         => 'form-control geocoding-zip',
                                                            'placeholder'   => '',
                                                            'id'            => 'zip',
                                                            'required'      => 'required'
                                                        )
                                                    ) !!}
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                @if(isset($broker->address_verified) && $broker->address_verified=='1')
                                                    <button type="button" class="btn btn-success geocoding-btn" data-uid="{{ 'map-'.generateStrUniqueId() }}">Verified</button>
                                                @else
                                                    <button type="button" class="btn btn-warning geocoding-btn" data-uid="{{ 'map-'.generateStrUniqueId() }}">Verify</button>
                                                @endif
                                                <div id="timezone_abbr-errors"></div>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Phone</label>
                                            {!! Form::text('phone_number', old('phone_number'), array('class' => 'form-control phone')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Email</label>
                                            {!! Form::email('email', old('email'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Fax</label>
                                            {!! Form::text('fax', old('fax'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Rep Name</label>
                                            {!! Form::text('rep_name', old('rep_name'), array('class' => 'form-control', 'autocomplete' => 'new')) !!}
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-6">
                        <div class="white-box mb-4 generalAccount">
                            <h4 class="box-title">Business Information</h4>
                            <div class="box-padding">
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>MC Number<span>*</span></label>
                                            {!! Form::text('mc_number', old('mc_number'), array('class' => 'form-control', 'autocomplete' => 'mc_number', 'required' => 'required')) !!}
                                            @error('mc_number')
                                                <span class="text-danger" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                            @enderror
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Federal ID</label>
                                            {!! Form::text('federal_id', old('federal_id'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>USDOT</label>
                                            {!! Form::text('usdot', old('usdot'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>SCAC</label>
                                            {!! Form::text('scac', old('scac'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Account Number</label>
                                            {!! Form::text('account_number', old('account_number'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Account Type</label>
                                            {!! Form::text('account_type', old('account_type'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-12">
                                        <div class="form-group">
                                            <div class="drop-zone">
                                                <span class="drop-zone__prompt">Drag and drop file here or click to browse</span>
                                                <input type="file" name="logo" class="drop-zone__input" accept="image/png,image/gif,image/jpeg" >
                                            </div>
                                        </div>
                                    </div>
                                    @if(isset($broker->logo) && $broker->logo!='' && file_exists(public_path('storage/companyAdmin/brokers/').$broker->logo))
                                        <div class="col-md-12">
                                            <div class="form-group">
                                                <a href="{{ asset('storage/companyAdmin/brokers/'.$broker->logo) }}" target="_blank">
                                                    <img src="{{ asset('storage/companyAdmin/brokers/'.$broker->logo) }}" width="150px" class="img-fluid" />
                                                </a>
                                            </div>
                                            <div class="form-group">
                                                <div class="custom-control custom-checkbox">
                                                    {!! Form::checkbox('remove_image', 1, null, array('class' => 'custom-control-input self-dispatch', 'id' => 'remove_image')) !!}
                                                    <label class="custom-control-label" for="remove_image">
                                                        <!-- Is Remove -->
                                                        <img src="{{ asset('theme/img/delete-icon.png') }}" alt="delete">
                                                    </label>
                                                </div>
                                            </div>
                                        </div>
                                    @endif
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-6">
                        <div class="white-box mb-4 generalAccount">
                            <h4 class="box-title">Billing Information</h4>
                            <div class="box-padding">
                                <div class="row">
                                    <div class="col-md-12 text-right">
                                        <div class="custom-control custom-checkbox">
                                            <input type="checkbox" class="custom-control-input" id="sameaddress"><label class="custom-control-label" for="sameaddress">Same as above</label>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="form-group">
                                            <label>Bill To Name</label>
                                            <input type="text" class="form-control" name="bill_to_name" value="{{ isset($broker->bill_to_name)?$broker->bill_to_name:'' }}" data-previousValue="{{ isset($broker->bill_to_name)?$broker->bill_to_name:'' }}">
                                        </div>
                                    </div>
                                    <div class="col-md-12 geocoding">
                                        <input type="hidden" class="geocoding-latitude" name="billing_latitude" value="{{ isset($broker->billing_latitude)?$broker->billing_latitude:'' }}" autocomplete="off">
                                        <input type="hidden" class="geocoding-longitude" name="billing_longitude" value="{{ isset($broker->billing_longitude)?$broker->billing_longitude:'' }}" autocomplete="off">
                                        <input type="hidden" class="geocoding-abbr" name="billing_timezone_abbr" value="{{ isset($broker->billing_timezone_abbr)?$broker->billing_timezone_abbr:'' }}" autocomplete="off" data-parsley-errors-container="#billing_timezone_abbr-errors" data-parsley-required-message="Please verify address" required>
                                        <input type="hidden" class="geocoding-verified" name="billing_address_verified" value="{{ isset($broker->billing_address_verified)?$broker->billing_address_verified:'0' }}" autocomplete="off">
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label>Billing Address<span>*</span></label>
                                                    {!! Form::text('billing_address', old('billing_address'), array(
                                                            'class'         => 'form-control geocoding-address-1',
                                                            'placeholder'   => '',
                                                            'id'            => 'billing_address',
                                                            'required'      => 'required'
                                                        )
                                                    ) !!}
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label>Billing Address 2</label>
                                                    {!! Form::text('billing_address_2', old('billing_address_2'), array(
                                                            'class'         => 'form-control geocoding-address-2',
                                                            'placeholder'   => '',
                                                            'id'            => 'billing_address_2'
                                                        )
                                                    ) !!}
                                                </div>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label>Billing City</label>
                                                    {!! Form::text('billing_city', old('billing_city'), array(
                                                            'class'         => 'form-control geocoding-city',
                                                            'placeholder'   => '',
                                                            'id'            => 'billing_city'
                                                        )
                                                    ) !!}
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label>Billing State<span>*</span></label>
                                                    {!! Form::text('billing_state', old('billing_state'), array(
                                                            'class'         => 'form-control geocoding-state',
                                                            'placeholder'   => '',
                                                            'id'            => 'billing_state',
                                                            'required'      => 'required'
                                                        )
                                                    ) !!}
                                                </div>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label>Billing Zip<span>*</span></label>
                                                    {!! Form::text('billing_zip', old('billing_zip'), array(
                                                            'class'         => 'form-control geocoding-zip',
                                                            'placeholder'   => '',
                                                            'id'            => 'billing_zip',
                                                            'required'      => 'required'
                                                        )
                                                    ) !!}
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                @if(isset($broker->billing_address_verified) && $broker->billing_address_verified=='1')
                                                    <button type="button" class="btn btn-success geocoding-btn" data-uid="{{ 'map-'.generateStrUniqueId() }}">Verified</button>
                                                @else
                                                    <button type="button" class="btn btn-warning geocoding-btn" data-uid="{{ 'map-'.generateStrUniqueId() }}">Verify</button>
                                                @endif
                                                <div id="billing_timezone_abbr-errors"></div>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Billing Phone</label>
                                            {!! Form::text('billing_phone', old('billing_phone'), array('class' => 'form-control phone')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Billing Email</label>
                                            {!! Form::email('billing_email', old('billing_email'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Billing Extention</label>
                                            {!! Form::text('billing_extention', old('billing_extention'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Billing Fax</label>
                                            {!! Form::text('billing_fax', old('billing_fax'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Billing Method</label>
                                            {!! Form::text('billing_method', old('billing_method'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Factored</label>
                                            {!! Form::text('factored', old('factored'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Terms</label>
                                            {!! Form::select('billing_terms', ['' => 'Select Terms']+getCompanyTerms(), null, ['class' => 'terms-select2 custom-select form-control']) !!}
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-6">
                        <div class="white-box mb-4 generalAccount">
                            <h4 class="box-title">Required Documents</h4>
                            <div class="box-padding">
                                <div class="row">
                                    <div class="col-md-12 mt-2 mb-2">
                                        <p>When Shipper - <span class="text-primary rep-broker-contact" data-toggle="modal" id="shipperaddRow">Add New</span></p>
                                    </div>
                                    <div class="col-md-12">
                                        @php
                                            $newSetShi                      = 1001;
                                            $fixed_broker_shipper_files     = array_filter($broker_shipper_files, function ($var) {
                                                return ($var['fixed'] == 'yes');
                                            });
                                            $custom_broker_shipper_files    = array_filter($broker_shipper_files, function ($var) {
                                                return ($var['fixed'] == 'no');
                                            });
                                        @endphp
                                        @if(isset($fixed_shipper_files) && !empty($fixed_shipper_files))
                                            @foreach ($fixed_shipper_files as $key => $shipperf)
                                                @php
                                                    $searchkey              = array_search($shipperf['id'], array_column($fixed_broker_shipper_files, 'name_id'));
                                                    if($searchkey!==false){
                                                        $searcharray        = $fixed_broker_shipper_files[$searchkey] ?? [];
                                                    }
                                                @endphp
                                                @if(isset($searcharray) && !empty($searcharray))
                                                    @php
                                                        $shipperf           = $searcharray;
                                                    @endphp
                                                @else
                                                    @php
                                                        $shipperf           = [
                                                            'name_id'               => $shipperf['id'],
                                                            'name'                  => $shipperf['name'],
                                                            'is_required'           => 'off',
                                                            'type'                  => 1,
                                                            'fixed'                 => $shipperf['fixed'],
                                                            'include_w_billing'     => $shipperf['include_w_billing']

                                                        ];
                                                    @endphp
                                                @endif
                                                <div class="row align-items-center mb-2">
                                                    <div class="col-auto cheskejw">
                                                        <div class="custom-control custom-checkbox">
                                                            <input type="checkbox" class="custom-control-input" id="shipper_files_is_required_{{ $newSetShi }}" name="shipper_files[is_required][{{ $newSetShi }}]" @if($shipperf['is_required'] == 'on') checked @endif>
                                                            <label class="custom-control-label" for="shipper_files_is_required_{{ $newSetShi }}"></label>
                                                        </div>
                                                    </div>
                                                    <div class="col-md-5">
                                                        <div class="form-group mt-2">
                                                            <input type="hidden" name="shipper_files[name][{{ $newSetShi }}]" value="{{ $shipperf['name'] }}">
                                                            <input type="hidden" name="shipper_files[name_id][{{ $newSetShi }}]" value="{{ $shipperf['name_id'] }}">
                                                            <label>{{ $shipperf['name'] }}</label>
                                                        </div>
                                                    </div>
                                                    <div class="col-auto custom-width radio-btn-div stradibut">
                                                        <div class="btn-group btn-group-toggle" data-toggle="buttons">
                                                            <label class="btn btn-secondary @if($shipperf['type'] == 1) active @endif">
                                                                <input type="radio" class="custom-control-input" name="shipper_files[type][{{ $newSetShi }}]" value="1" @if($shipperf['type'] == 1) checked @endif> Copy
                                                            </label>
                                                            <label class="btn btn-secondary @if($shipperf['type'] == 2) active @endif">
                                                                <input type="radio" class="custom-control-input" name="shipper_files[type][{{ $newSetShi }}]" value="2" @if($shipperf['type'] == 2) checked @endif> Original
                                                            </label>
                                                        </div>
                                                    </div>
                                                    <div class="col-md-1">
                                                        <input type="hidden" name="shipper_files[fixed][{{ $newSetShi }}]" value="yes">
                                                        <input type="hidden" name="shipper_files[include_w_billing][{{ $newSetShi }}]" value="{{ isset($shipperf['include_w_billing']) && $shipperf['include_w_billing']=='yes' ? 'yes' : 'no' }}">
                                                    </div>
                                                </div>
                                                @php
                                                    $newSetShi++;
                                                @endphp
                                            @endforeach
                                        @endif
                                        @if(isset($custom_broker_shipper_files) && !empty($custom_broker_shipper_files))
                                            @foreach ($custom_broker_shipper_files as $key => $shipperf)
                                                <div class="row align-items-center mb-2 shipperinputFormRow">
                                                    <div class="col-auto cheskejw">
                                                        <div class="custom-control custom-checkbox">
                                                            <input type="checkbox" class="custom-control-input" id="shipper_files_is_required_{{ $newSetShi }}" name="shipper_files[is_required][{{ $newSetShi }}]" @if($shipperf['is_required'] == 'on') checked @endif>
                                                            <label class="custom-control-label" for="shipper_files_is_required_{{ $newSetShi }}"></label>
                                                        </div>
                                                    </div>
                                                    <div class="col-md-5">
                                                        <div class="form-group mt-2">
                                                            <input type="hidden" name="shipper_files[name][{{ $newSetShi }}]" value="{{ $shipperf['name'] }}">
                                                            <select name="shipper_files[name_id][{{ $newSetShi }}]" class="form-control shipper_files-select2" data-parsley-errors-container="#shipper_files_name_id_{{ $newSetShi }}-errors" required>
                                                                <option value="">Select File Name</option>
                                                                @foreach ($shipper_files as $key => $node)
                                                                    <option value="{{ $node['id'] }}" data-include_w_billing="{{ $node['include_w_billing'] }}" {{ ($node['id'] == ($shipperf['name_id'] ?? '')) ? 'selected' : '' }}>{{ $node['name'] }}</option>
                                                                @endforeach
                                                            </select>
                                                            <div id="shipper_files_name_id_{{ $newSetShi }}-errors"></div>
                                                        </div>
                                                    </div>
                                                    <div class="col-auto custom-width radio-btn-div stradibut">
                                                        <div class="btn-group btn-group-toggle" data-toggle="buttons">
                                                            <label class="btn btn-secondary @if($shipperf['type'] == 1) active @endif">
                                                                <input type="radio" class="custom-control-input" name="shipper_files[type][{{ $newSetShi }}]" value="1" @if($shipperf['type'] == 1) checked @endif> Copy
                                                            </label>
                                                            <label class="btn btn-secondary @if($shipperf['type'] == 2) active @endif">
                                                                <input type="radio" class="custom-control-input" name="shipper_files[type][{{ $newSetShi }}]" value="2" @if($shipperf['type'] == 2) checked @endif> Original
                                                            </label>
                                                        </div>
                                                    </div>
                                                    <div class="col-md-1">
                                                        <input type="hidden" name="shipper_files[fixed][{{ $newSetShi }}]" value="no">
                                                        <input type="hidden" name="shipper_files[include_w_billing][{{ $newSetShi }}]" value="{{ isset($shipperf['include_w_billing']) && $shipperf['include_w_billing']=='yes' ? 'yes' : 'no' }}">
                                                        <a href="javascript:void(0)" class="btn btn-danger shipperremoveRow"><i class="fa fa-trash"></i></a>
                                                    </div>
                                                </div>
                                                @php
                                                    $newSetShi++;
                                                @endphp
                                            @endforeach
                                        @endif
                                        <div id="shippernewRow"></div>
                                    </div>
                                    <div class="col-md-12 mt-4 mb-2">
                                        <p>When Consignee - <span class="text-primary rep-broker-contact" data-toggle="modal" id="consigneeaddRow">Add New</span></p>
                                    </div>
                                    <div class="col-md-12">
                                        @php
                                            $newConShi                      = 1001;
                                            $fixed_broker_consignee_files   = array_filter($broker_consignee_files, function ($var) {
                                                return ($var['fixed'] == 'yes');
                                            });
                                            $custom_broker_consignee_files  = array_filter($broker_consignee_files, function ($var) {
                                                return ($var['fixed'] == 'no');
                                            });
                                        @endphp
                                        @if(isset($fixed_consignee_files) && !empty($fixed_consignee_files))
                                            @foreach ($fixed_consignee_files as $key => $consigneef)
                                                @php
                                                    $searchkey              = array_search($consigneef['id'], array_column($fixed_broker_consignee_files, 'name_id'));
                                                    if($searchkey!==false){
                                                        $searcharray        = $fixed_broker_consignee_files[$searchkey] ?? [];
                                                    }
                                                @endphp
                                                @if(isset($searcharray) && !empty($searcharray))
                                                    @php
                                                        $consigneef         = $searcharray;
                                                    @endphp
                                                @else
                                                    @php
                                                        $consigneef         = [
                                                            'name_id'               => $consigneef['id'],
                                                            'name'                  => $consigneef['name'],
                                                            'is_required'           => 'off',
                                                            'type'                  => 1,
                                                            'fixed'                 => $consigneef['fixed'],
                                                            'include_w_billing'     => $consigneef['include_w_billing']

                                                        ];
                                                    @endphp
                                                @endif
                                                <div class="row align-items-center mb-2">
                                                    <div class="col-auto cheskejw">
                                                        <div class="custom-control custom-checkbox">
                                                            <input type="checkbox" class="custom-control-input" id="consignee_files_is_required_{{ $newConShi }}" name="consignee_files[is_required][{{ $newConShi }}]" @if($consigneef['is_required'] == 'on') checked @endif>
                                                            <label class="custom-control-label" for="consignee_files_is_required_{{ $newConShi }}"></label>
                                                        </div>
                                                    </div>
                                                    <div class="col-md-5">
                                                        <div class="form-group mt-2">
                                                            <input type="hidden" name="consignee_files[name][{{ $newConShi }}]" value="{{ $consigneef['name'] }}">
                                                            <input type="hidden" name="consignee_files[name_id][{{ $newConShi }}]" value="{{ $consigneef['name_id'] }}">
                                                            <label>{{ $consigneef['name'] }}</label>
                                                        </div>
                                                    </div>
                                                    <div class="col-auto custom-width radio-btn-div stradibut">
                                                        <div class="btn-group btn-group-toggle" data-toggle="buttons">
                                                            <label class="btn btn-secondary @if($consigneef['type'] == 1) active @endif">
                                                                <input type="radio" class="custom-control-input" name="consignee_files[type][{{ $newConShi }}]" value="1" @if($consigneef['type'] == 1) checked @endif> Copy
                                                            </label>
                                                            <label class="btn btn-secondary @if($consigneef['type'] == 2) active @endif">
                                                                <input type="radio" class="custom-control-input" name="consignee_files[type][{{ $newConShi }}]" value="2" @if($consigneef['type'] == 2) checked @endif> Original
                                                            </label>
                                                        </div>
                                                    </div>
                                                    <div class="col-md-1">
                                                        <input type="hidden" name="consignee_files[fixed][{{ $newConShi }}]" value="yes">
                                                        <input type="hidden" name="consignee_files[include_w_billing][{{ $newConShi }}]" value="{{ isset($consigneef['include_w_billing']) && $consigneef['include_w_billing']=='yes' ? 'yes' : 'no' }}">
                                                    </div>
                                                </div>
                                                @php
                                                    $newConShi++;
                                                @endphp
                                            @endforeach
                                        @endif
                                        @if(isset($custom_broker_consignee_files) && !empty($custom_broker_consignee_files))
                                            @foreach ($custom_broker_consignee_files as $key => $consigneef)
                                                <div class="row align-items-center mb-2 consigneeinputFormRow">
                                                    <div class="col-auto cheskejw">
                                                        <div class="custom-control custom-checkbox">
                                                            <input type="checkbox" class="custom-control-input" id="consignee_files_is_required_{{ $newConShi }}" name="consignee_files[is_required][{{ $newConShi }}]" @if($consigneef['is_required'] == 'on') checked @endif>
                                                            <label class="custom-control-label" for="consignee_files_is_required_{{ $newConShi }}"></label>
                                                        </div>
                                                    </div>
                                                    <div class="col-md-5">
                                                        <div class="form-group mt-2">
                                                            <input type="hidden" name="consignee_files[name][{{ $newConShi }}]" value="{{ $consigneef['name'] }}">
                                                            <select name="consignee_files[name_id][{{ $newConShi }}]" class="form-control consignee_files-select2" data-parsley-errors-container="#consignee_files_name_id_{{ $newConShi }}-errors" required>
                                                                <option value="">Select File Name</option>
                                                                @foreach ($consignee_files as $key => $node)
                                                                    <option value="{{ $node['id'] }}" data-include_w_billing="{{ $node['include_w_billing'] }}" {{ ($node['id'] == ($consigneef['name_id'] ?? '')) ? 'selected' : '' }}>{{ $node['name'] }}</option>
                                                                @endforeach
                                                            </select>
                                                            <div id="consignee_files_name_id_{{ $newConShi }}-errors"></div>
                                                        </div>
                                                    </div>
                                                    <div class="col-auto custom-width radio-btn-div stradibut">
                                                        <div class="btn-group btn-group-toggle" data-toggle="buttons">
                                                            <label class="btn btn-secondary @if($consigneef['type'] == 1) active @endif">
                                                                <input type="radio" class="custom-control-input" name="consignee_files[type][{{ $newConShi }}]" value="1" @if($consigneef['type'] == 1) checked @endif> Copy
                                                            </label>
                                                            <label class="btn btn-secondary @if($consigneef['type'] == 2) active @endif">
                                                                <input type="radio" class="custom-control-input" name="consignee_files[type][{{ $newConShi }}]" value="2" @if($consigneef['type'] == 2) checked @endif> Original
                                                            </label>
                                                        </div>
                                                    </div>
                                                    <div class="col-md-1">
                                                        <input type="hidden" name="consignee_files[fixed][{{ $newConShi }}]" value="no">
                                                        <input type="hidden" name="consignee_files[include_w_billing][{{ $newConShi }}]" value="{{ isset($consigneef['include_w_billing']) && $consigneef['include_w_billing']=='yes' ? 'yes' : 'no' }}">
                                                        <a href="javascript:void(0)" class="btn btn-danger consigneeremoveRow"><i class="fa fa-trash"></i></a>
                                                    </div>
                                                </div>
                                                @php
                                                    $newConShi++;
                                                @endphp
                                            @endforeach
                                        @endif
                                        <div id="consigneenewRow"></div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-6">
                        <div class="white-box mb-4 generalAccount">
                            <h4 class="box-title">Detention Configuration</h4>
                            <div class="box-padding">
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Free Time</label>
                                            {!! Form::text('detention_time', old('detention_time'), array('class' => 'form-control time')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>$/hr</label>
                                            {!! Form::number('detention_price', old('detention_price'), array('class' => 'form-control', 'step' => 'any')) !!}
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-6">
                        <div class="white-box mb-4 generalAccount">
                            <h4 class="box-title">Accessorial</h4>
                            <div class="box-padding">
                                <div class="row">
                                    <div class="accessorial-table table-responsive">
                                        <table class="table table-hover">
                                            <thead>
                                                <tr>
                                                    <th scope="col">#</th>
                                                    <th scope="col">Name</th>
                                                    <th scope="col">Rate</th>
                                                    <th scope="col">
                                                        <a href="javascript:void(0);" class="btn-link-orange asdquerymetn" id="createNewAccessorial">
                                                            <i class="fa fa-plus" aria-hidden="true"></i>
                                                            Add
                                                        </a>
                                                    </th>
                                                </tr>
                                            </thead>
                                            <tbody></tbody>
                                        </table>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-12">
                        <div class="white-box mb-4 generalAccount">
                            <h4 class="box-title">Contacts</h4>
                            <div class="box-padding">
                                <div class="row">
                                    <div class="col-md-3">
                                        <div class="form-group">
                                            <label>Dispatch Contact Name</label>
                                            {!! Form::text('dispatch_contact_name', old('dispatch_contact_name'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-3">
                                        <div class="form-group">
                                            <label>Dispatch Contact Email</label>
                                            {!! Form::text('dispatch_contact_email', old('dispatch_contact_email'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-3">
                                        <div class="form-group">
                                            <label>Dispatch Contact Phone</label>
                                            {!! Form::text('dispatch_contact_phone', old('dispatch_contact_phone'), array('class' => 'form-control phone')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-3">
                                        <div class="form-group">
                                            <label>Dispatch Contact EXT</label>
                                            {!! Form::text('dispatch_contact_contact_ext', old('dispatch_contact_contact_ext'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-3">
                                        <div class="form-group">
                                            <label>A/P Contact Name</label>
                                            {!! Form::text('ap_contact_name', old('ap_contact_name'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-3">
                                        <div class="form-group">
                                            <label>A/P Contact Email</label>
                                            {!! Form::text('ap_contact_email', old('ap_contact_email'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-3">
                                        <div class="form-group">
                                            <label>A/P Contact Phone</label>
                                            {!! Form::text('ap_contact_phone', old('ap_contact_phone'), array('class' => 'form-control phone')) !!}
                                        </div>
                                    </div>
                                    <div class="col-md-3">
                                        <div class="form-group">
                                            <label>A/P Contact Contact EXT</label>
                                            {!! Form::text('ap_contact_contact_ext', old('ap_contact_contact_ext'), array('class' => 'form-control')) !!}
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-12">
                        <div class="white-box mb-4 generalAccount">
                            <h4 class="box-title">Additional Offices</h4>
                            <div class="box-padding offices-wrapper">
                                @if($broker->broker_offices->isNotEmpty())
                                    @foreach ($broker->broker_offices as $bokey => $broker_office)
                                        <div class="row sub-wrapper geocoding" data-last-index="{{ $bokey }}">
                                            <div class="col-12 d-none">
                                                <input type="hidden" class="geocoding-latitude" name="offices[{{ $bokey }}][latitude]" value="{{ isset($broker_office->latitude)?$broker_office->latitude:'' }}">
                                                <input type="hidden" class="geocoding-longitude" name="offices[{{ $bokey }}][longitude]" value="{{ isset($broker_office->longitude)?$broker_office->longitude:'' }}">
                                                <input type="hidden" class="geocoding-abbr" name="offices[{{ $bokey }}][timezone_abbr]" value="{{ isset($broker_office->timezone_abbr)?$broker_office->timezone_abbr:'' }}" data-parsley-errors-container="#offices_{{ $bokey }}_timezone_abbr-errors" data-parsley-required-message="Please verify address">
                                                <input type="hidden" class="geocoding-verified" name="offices[{{ $bokey }}][address_verified]" value="{{ isset($broker_office->address_verified)?$broker_office->address_verified:'0' }}">
                                            </div>
                                            <div class="col-md-2">
                                                <div class="form-group">
                                                    <label>Name</label>
                                                    <input type="hidden" name="offices[{{ $bokey }}][old_id]" value="{{ $broker_office->id }}">
                                                    <input type="text" name="offices[{{ $bokey }}][name]" value="{{ isset($broker_office->name)?$broker_office->name:'' }}" class="form-control" data-previousValue="{{ isset($broker_office->name)?$broker_office->name:'' }}">
                                                </div>
                                            </div>
                                            <div class="col-md-2">
                                                <div class="form-group">
                                                    <label>Address</label>
                                                    <input type="text" name="offices[{{ $bokey }}][address]" value="{{ isset($broker_office->address_one)?$broker_office->address_one:'' }}" class="form-control geocoding-address-1">
                                                </div>
                                                <div id="offices_{{ $bokey }}_timezone_abbr-errors"></div>
                                            </div>
                                            <div class="col-md-2">
                                                <div class="form-group">
                                                    <label>City</label>
                                                    <input type="text" name="offices[{{ $bokey }}][city]" value="{{ isset($broker_office->city)?$broker_office->city:'' }}" class="form-control geocoding-city">
                                                </div>
                                            </div>
                                            <div class="col-md-2">
                                                <div class="form-group">
                                                    <label>State</label>
                                                    <input type="text" name="offices[{{ $bokey }}][state]" value="{{ isset($broker_office->state)?$broker_office->state:'' }}" class="form-control geocoding-state">
                                                </div>
                                            </div>
                                            <div class="col-md-2">
                                                <div class="form-group">
                                                    <label>Zip</label>
                                                    <input type="text" name="offices[{{ $bokey }}][zip]" value="{{ isset($broker_office->zip)?$broker_office->zip:'' }}" class="form-control geocoding-zip">
                                                </div>
                                            </div>
                                            <div class="col-md-2">
                                                @if(isset($broker_office->timezone_abbr))
                                                    <button type="button" class="btn btn-success geocoding-btn mr-2" data-uid="{{ 'map-'.generateStrUniqueId() }}">Verified</button>
                                                @else
                                                    <button type="button" class="btn btn-warning geocoding-btn mr-2" data-uid="{{ 'map-'.generateStrUniqueId() }}">Verify</button>
                                                @endif
                                                @if($loop->first)
                                                    <button type="button" class="btn btn-success mt-3" id="addOffices"><i class="fa fa-plus"></i></button>
                                                @else
                                                    <button type="button" class="btn btn-danger mt-3 removeOffices"><i class="fa fa-trash"></i></button>
                                                @endif
                                            </div>
                                        </div>
                                    @endforeach
                                @else
                                    <div class="row sub-wrapper geocoding" data-last-index="0">
                                        <div class="col-12 d-none">
                                            <input type="hidden" class="geocoding-latitude" name="offices[0][latitude]" value="">
                                            <input type="hidden" class="geocoding-longitude" name="offices[0][longitude]" value="">
                                            <input type="hidden" class="geocoding-abbr" name="offices[0][timezone_abbr]" value="" data-parsley-errors-container="#offices_0_timezone_abbr-errors" data-parsley-required-message="Please verify address">
                                            <input type="hidden" class="geocoding-verified" name="offices[0][address_verified]" value="0">
                                        </div>
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                <label>Name</label>
                                                <input type="text" name="offices[0][name]" value="" class="form-control">
                                            </div>
                                        </div>
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                <label>Address</label>
                                                <input type="text" name="offices[0][address]" value="" class="form-control geocoding-address-1">
                                            </div>
                                            <div id="offices_0_timezone_abbr-errors"></div>
                                        </div>
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                <label>City</label>
                                                <input type="text" name="offices[0][city]" value="" class="form-control geocoding-city">
                                            </div>
                                        </div>
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                <label>State</label>
                                                <input type="text" name="offices[0][state]" value="" class="form-control geocoding-state">
                                            </div>
                                        </div>
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                <label>Zip</label>
                                                <input type="text" name="offices[0][zip]" value="" class="form-control geocoding-zip">
                                            </div>
                                        </div>
                                        <div class="col-md-2">
                                            <button type="button" class="btn btn-warning geocoding-btn mr-2" data-uid="{{ 'map-'.generateStrUniqueId() }}">Verify</button>
                                            <button type="button" class="btn btn-success mt-3" id="addOffices"><i class="fa fa-plus"></i></button>
                                        </div>
                                    </div>
                                @endif
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-12">
                        <div class="white-box mb-4 generalAccount">
                            <h4 class="box-title">Additional Contacts</h4>
                            <div class="box-padding additional-contacts-wrapper">
                                @if($broker->broker_contact->isNotEmpty())
                                    @foreach ($broker->broker_contact as $ackey => $broker_contact)
                                        <div class="row sub-wrapper" data-last-index="{{ $ackey }}">
                                            <div class="col-md-2">
                                                <div class="form-group">
                                                    <label>Office</label>
                                                    <select class="form-control office_id" name="additional_contacts[{{ $ackey }}][office_id]" data-id="{{ isset($broker_contact->office_id)?$broker_contact->office_id:'' }}">
                                                        <option value="">Select Office</option>
                                                    </select>
                                                </div>
                                            </div>
                                            <div class="col-md-2">
                                                <div class="form-group">
                                                    <label>Department</label>
                                                    <input type="hidden" name="additional_contacts[{{ $ackey }}][old_id]" value="{{ $broker_contact->id }}">
                                                    <input type="text" name="additional_contacts[{{ $ackey }}][department]" value="{{ isset($broker_contact->department)?$broker_contact->department:'' }}" class="form-control">
                                                </div>
                                            </div>
                                            <div class="col-md-2">
                                                <div class="form-group">
                                                    <label>First Name</label>
                                                    <input type="text" name="additional_contacts[{{ $ackey }}][first_name]" value="{{ isset($broker_contact->first_name)?$broker_contact->first_name:'' }}" class="form-control">
                                                </div>
                                            </div>
                                            <div class="col-md-2">
                                                <div class="form-group">
                                                    <label>Last Name</label>
                                                    <input type="text" name="additional_contacts[{{ $ackey }}][last_name]" value="{{ isset($broker_contact->last_name)?$broker_contact->last_name:'' }}" class="form-control">
                                                </div>
                                            </div>
                                            <div class="col-md-2">
                                                <div class="form-group">
                                                    <label>Phone Number</label>
                                                    <input type="text" name="additional_contacts[{{ $ackey }}][phone_number]" value="{{ isset($broker_contact->phone_number)?$broker_contact->phone_number:'' }}" class="form-control phone">
                                                </div>
                                            </div>
                                            <div class="col-md-2">
                                                <div class="form-group">
                                                    <label>Ext</label>
                                                    <input type="text" name="additional_contacts[{{ $ackey }}][ext]" value="{{ isset($broker_contact->ext)?$broker_contact->ext:'' }}" class="form-control">
                                                </div>
                                            </div>
                                            <div class="col-md-2">
                                                <div class="form-group">
                                                    <label>Cell Number</label>
                                                    <input type="text" name="additional_contacts[{{ $ackey }}][cell_number]" value="{{ isset($broker_contact->cell_number)?$broker_contact->cell_number:'' }}" class="form-control phone">
                                                </div>
                                            </div>
                                            <div class="col-md-2">
                                                <div class="form-group">
                                                    <label>Email</label>
                                                    <input type="email" name="additional_contacts[{{ $ackey }}][email]" value="{{ isset($broker_contact->email)?$broker_contact->email:'' }}" class="form-control">
                                                </div>
                                            </div>
                                            @php
                                                $preferred_connections          = [1,2,3,4];
                                                $broker_preferred_connections   = explode(',', $broker_contact->preferred_connections);
                                                $broker_preferred_connections   = array_map('trim', $broker_preferred_connections);
                                            @endphp
                                            <div class="col-md-2">
                                                <div class="form-group">
                                                    <label>Preferred Connection</label>
                                                    <div class="custom-checkbox-inline">
                                                        <div class="custom-control custom-checkbox">
                                                            <input type="checkbox" class="custom-control-input" name="additional_contacts[{{ $ackey }}][preferred_connections][]" id="additional_contacts_{{ $ackey }}_message" value="1" {{  (in_array('1', $broker_preferred_connections) ? ' checked' : '') }}>
                                                            <label class="custom-control-label" for="additional_contacts_{{ $ackey }}_message" title="Message">
                                                                <i class="fa fa-commenting" aria-hidden="true"></i>
                                                            </label>
                                                        </div>
                                                        <div class="custom-control custom-checkbox">
                                                            <input type="checkbox" class="custom-control-input" name="additional_contacts[{{ $ackey }}][preferred_connections][]" id="additional_contacts_{{ $ackey }}_email" value="2" {{  (in_array('2', $broker_preferred_connections) ? ' checked' : '') }}>
                                                            <label class="custom-control-label" for="additional_contacts_{{ $ackey }}_email" title="Email">
                                                                <i class="fa fa-envelope" aria-hidden="true"></i>
                                                            </label>
                                                        </div>
                                                        <div class="custom-control custom-checkbox">
                                                            <input type="checkbox" class="custom-control-input" name="additional_contacts[{{ $ackey }}][preferred_connections][]" id="additional_contacts_{{ $ackey }}_phone" value="3" {{  (in_array('3', $broker_preferred_connections) ? ' checked' : '') }}>
                                                            <label class="custom-control-label" for="additional_contacts_{{ $ackey }}_phone" title="Phone">
                                                                <i class="fa fa-mobile" aria-hidden="true"></i>
                                                            </label>
                                                        </div>
                                                        <div class="custom-control custom-checkbox">
                                                            <input type="checkbox" class="custom-control-input" name="additional_contacts[{{ $ackey }}][preferred_connections][]" id="additional_contacts_{{ $ackey }}_cell" value="4" {{  (in_array('4', $broker_preferred_connections) ? ' checked' : '') }}>
                                                            <label class="custom-control-label" for="additional_contacts_{{ $ackey }}_cell" title="Cell">
                                                                <i class="fa fa-phone" aria-hidden="true"></i>
                                                            </label>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="col-md-2">
                                                <div class="form-group">
                                                    <label>Primary Contact</label>
                                                    <div class="d-flex align-items-center">
                                                        <div class="custom-control custom-switch-blue custom-switch-small mr-2">
                                                            <input type="checkbox" class="custom-control-input primary_contact" name="additional_contacts[{{ $ackey }}][primary_contact]" id="additional_contacts_{{ $ackey }}_primary_contact" value="1" {{ ($broker_contact->primary_contact == 1 ? ' checked' : '') }}>
                                                            <label class="custom-control-label mb-0" for="additional_contacts_{{ $ackey }}_primary_contact"></label>
                                                        </div>
                                                        <label class="switch-text mb-0" for="additional_contacts_{{ $ackey }}_primary_contact">Off/On</label>
                                                    </div>
                                                </div>
                                            </div>
                                            @php
                                                $primary_contact_id   = explode(',', $broker_contact->primary_contact_id);
                                                $primary_contact_id   = array_map('trim', $primary_contact_id);
                                            @endphp
                                            <div class="col-md-2 primary-contact-id-div {{ ($broker_contact->primary_contact != 1 ? ' d-none' : '') }}">
                                                <div class="form-group">
                                                    <label class="d-block" style="visibility: hidden;">Primary Dispatcher</label>
                                                    <select name="additional_contacts[{{ $ackey }}][dispatcher_id][]" class="form-control select2" multiple>
                                                        @foreach ($dispatchers as $dispatcher_id => $dispatcher_name)
                                                            <option value="{{ $dispatcher_id }}" {{  (in_array($dispatcher_id, $primary_contact_id) ? ' selected' : '') }}>{{ $dispatcher_name }}</option>
                                                        @endforeach
                                                    </select>
                                                </div>
                                            </div>
                                            <div class="col-md-2">
                                                <div class="form-group">
                                                    <label class="d-block" style="visibility: hidden;">Action</label>
                                                    @if($loop->first)
                                                        <a href="javascript:void(0)" class="btn btn-success" id="addContacts"><i class="fa fa-plus"></i></a>
                                                    @else
                                                        <a href="javascript:void(0)" class="btn btn-danger removeContacts"><i class="fa fa-trash"></i></a>
                                                    @endif
                                                </div>
                                            </div>
                                        </div>
                                    @endforeach
                                @else
                                    <div class="row sub-wrapper" data-last-index="0">
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                <label>Office</label>
                                                <select class="form-control office_id" name="additional_contacts[0][office_id]">
                                                    <option value="">Select Office</option>
                                                </select>
                                            </div>
                                        </div>
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                <label>Department</label>
                                                <input type="text" name="additional_contacts[0][department]" value="" class="form-control">
                                            </div>
                                        </div>
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                <label>First Name</label>
                                                <input type="text" name="additional_contacts[0][first_name]" value="" class="form-control">
                                            </div>
                                        </div>
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                <label>Last Name</label>
                                                <input type="text" name="additional_contacts[0][last_name]" value="" class="form-control">
                                            </div>
                                        </div>
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                <label>Phone Number</label>
                                                <input type="text" name="additional_contacts[0][phone_number]" value="" class="form-control phone">
                                            </div>
                                        </div>
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                <label>Ext</label>
                                                <input type="text" name="additional_contacts[0][ext]" value="" class="form-control">
                                            </div>
                                        </div>
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                <label>Cell Number</label>
                                                <input type="text" name="additional_contacts[0][cell_number]" value="" class="form-control phone">
                                            </div>
                                        </div>
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                <label>Email</label>
                                                <input type="email" name="additional_contacts[0][email]" value="" class="form-control">
                                            </div>
                                        </div>
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                <label>Preferred Connection</label>
                                                <div class="custom-checkbox-inline">
                                                    <div class="custom-control custom-checkbox">
                                                        <input type="checkbox" class="custom-control-input" name="additional_contacts[0][preferred_connections][]" id="additional_contacts_0_message" value="1">
                                                        <label class="custom-control-label" for="additional_contacts_0_message" title="Message">
                                                            <i class="fa fa-commenting" aria-hidden="true"></i>
                                                        </label>
                                                    </div>
                                                    <div class="custom-control custom-checkbox">
                                                        <input type="checkbox" class="custom-control-input" name="additional_contacts[0][preferred_connections][]" id="additional_contacts_0_email" value="2">
                                                        <label class="custom-control-label" for="additional_contacts_0_email" title="Email">
                                                            <i class="fa fa-envelope" aria-hidden="true"></i>
                                                        </label>
                                                    </div>
                                                    <div class="custom-control custom-checkbox">
                                                        <input type="checkbox" class="custom-control-input" name="additional_contacts[0][preferred_connections][]" id="additional_contacts_0_phone" value="3">
                                                        <label class="custom-control-label" for="additional_contacts_0_phone" title="Phone">
                                                            <i class="fa fa-mobile" aria-hidden="true"></i>
                                                        </label>
                                                    </div>
                                                    <div class="custom-control custom-checkbox">
                                                        <input type="checkbox" class="custom-control-input" name="additional_contacts[0][preferred_connections][]" id="additional_contacts_0_cell" value="4">
                                                        <label class="custom-control-label" for="additional_contacts_0_cell" title="Cell">
                                                            <i class="fa fa-phone" aria-hidden="true"></i>
                                                        </label>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                <label>Primary Contact</label>
                                                <div class="d-flex align-items-center">
                                                    <div class="custom-control custom-switch-blue custom-switch-small mr-2">
                                                        <input type="checkbox" class="custom-control-input primary_contact" name="additional_contacts[0][primary_contact]" id="additional_contacts_0_primary_contact" value="1">
                                                        <label class="custom-control-label mb-0" for="additional_contacts_0_primary_contact"></label>
                                                    </div>
                                                    <label class="switch-text mb-0" for="additional_contacts_0_primary_contact">Off/On</label>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-md-2 primary-contact-id-div d-none">
                                            <div class="form-group">
                                                <label class="d-block" style="visibility: hidden;">Primary Dispatcher</label>
                                                <select name="additional_contacts[0][dispatcher_id][]" class="form-control select2" multiple>
                                                    @foreach ($dispatchers as $dispatcher_id => $dispatcher_name)
                                                        <option value="{{ $dispatcher_id }}">{{ $dispatcher_name }}</option>
                                                    @endforeach
                                                </select>
                                            </div>
                                        </div>
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                <label class="d-block" style="visibility: hidden;">Action</label>
                                                <a href="javascript:void(0)" class="btn btn-success" id="addContacts"><i class="fa fa-plus"></i></a>
                                            </div>
                                        </div>
                                    </div>
                                @endif
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        {!! Form::close() !!}
        <div class="col-lg-12">
            <div class="white-box mb-4 load-status generalAccount">
                <form action="{{ route('company.admin.notes.store')}}" method="post" enctype="multipart" class="notesave">
                    @csrf
                    <input type="hidden" name="action_id" value="{{$broker->id}}" />
                    <input type="hidden" name="action_type" value="brokers" />
                    <input type="hidden" name="created_by" value="{{ auth()->guard('company-admin')->user()->id }}">
                    <input type="hidden" name="created_by_type" value="{{ auth()->guard('company-admin')->user()->type }}">
                    <h4 class="box-title clear-btn">Communications</h4>
                    <div class="box-padding">
                        <div class="row align-items-center">
                            <div class="col-md-12 mt-1">
                                <div class="row">
                                    <div class="col-md-2">
                                        <div class="form-group">
                                            <select class="custom-select form-control" id="NoteType" name="type">
                                                <option value="">Select Note Type</option>
                                                @if(count(getNoteType()))
                                                    @foreach (getNoteType() as $key => $NoteType)
                                                        <option value="{{ $key }}">{{ $NoteType }}</option>
                                                    @endforeach
                                                @endif
                                            </select>
                                        </div>
                                    </div>
                                    <div class="col-md-2">
                                        <div class="form-group">
                                            <select class="custom-select form-control" id="RequestType" name="request_type">
                                                <option value="">Select Request Type</option>
                                                @if(count(getNoteRequestType()))
                                                    @foreach (getNoteRequestType() as $key => $RequestType)
                                                        <option value="{{ $key }}">{{ $RequestType }}</option>
                                                    @endforeach
                                                @endif
                                            </select>
                                        </div>
                                    </div>
                                    <div class="col-md-6"></div>
                                    <div class="col-md-2 text-right">
                                        <div class="form-group notefile">
                                            <label for="note_file" class="btn"><i class="fa fa-paperclip"></i></label>
                                            <input id="note_file" style="display: none;" type="file" name="note_file[]" multiple>
                                        </div>
                                    </div>
                                </div>
                                <div class="form-group">
                                    {!! Form::textarea('note', old('note'), array('class' => 'form-control','rows' => 5,'placeholder' => 'Enter your message','required' => 'required')) !!}
                                </div>
                            </div>
                            {{--
                            <div class="col-md-9 mb-3 enseno">
                                <div class="form-group">
                                    <div class="checkbox d-inline-block mr-2">
                                        <label class=" control-label"><strong>Notify: </strong>
                                    </div>
                                    <div class="checkbox d-inline-block mr-2">
                                      <label class=" control-label">
                                            {!! Form::checkbox('notify_my', 1, false, array('class' => 'form-control loadregucheck')) !!} Add to my notifications
                                      </label>
                                    </div>
                                    <div class="checkbox d-inline-block mr-2">
                                      <label class=" control-label">
                                            {!! Form::checkbox('notify_private', 1, false, array('class' => 'form-control loadregucheck checknondriveruser')) !!} All non drivers users
                                      </label>
                                    </div>
                                </div>
                            </div>
                            --}}
                            <div class="col-md-9 enseno">
                                <div class="d-flex flex-wrap align-items-center mb-0">
                                    <label class="mb-0 mr-3 font-weight-bold"> Notify:</label>
                                    <div class="custom-checkbox-inline mr-2">
                                        <div class="custom-control custom-checkbox" style="top: 0px;">
                                            <input type="checkbox" class="custom-control-input" name="notify_my" value="1" id="notify_my" data-parsley-multiple="notify_my">
                                            <label class="custom-control-label" for="notify_my">Add to my notifications</label>
                                        </div>
                                    </div>
                                    <div class="custom-checkbox-inline">
                                        <div class="custom-control custom-checkbox" style="top: 0px;">
                                            <input type="checkbox" class="custom-control-input checknondriveruser" name="notify_private" value="1" id="notify_private" data-parsley-multiple="notify_private">
                                            <label class="custom-control-label" for="notify_private">All non drivers users</label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-3 mb-3 text-right anabocbu">
                                <button type="submit" name="submit" class="btn btn-success">Submit</button>
                            </div>
                            <div class="col-md-3 selenondriveruser mb-4" style="display: none;">
                                <label>Select Users</label>
                                <div class="form-group">
                                    {!! Form::select('notify_private_company_admin_id', getCompanyAdminListByCompany(), null, ['class' => 'custom-select bookedby-select2 form-control','data-parsley-errors-container'=>'#booked_by_erri','id'=>'privatUser','multiple'=>'multiple','name'=>'notify_private_company_admin_id[]']) !!}
                                </div>
                            </div>
                        </div>
                    </div>
                </form>
                <div class="box-padding getnotesave"></div>
            </div>
        </div>
        <div class="col-lg-12">
            <div class="white-box mb-4 load-status">
                <h4 class="box-title clear-btn">Customer Files</h4>
                <div class="box-padding">
                    <div class="row">
                        <div class="col-md-8">
                            <div class="table-responsive" id="loadfile">
                            </div>
                        </div>
                        <div class="col-md-4 mb-3">
                            <form action="{{ route('company.admin.documents.store') }}" method="post" enctype="multipart/form-data" class="filesave">
                                @csrf
                                <input type="hidden" name="type" value="broker" />
                                <input type="hidden" name="by_id" value="<?php echo $broker->id; ?>" />
                                <div class="form-group">
                                    <label>File Name</label>
                                    <input type="text" name="filename" class="form-control" required>
                                </div>
                                <div class="form-group">
                                    <div class="drop-zone2">
                                        <span class="drop-zone2__prompt">Drag and drop file here or click to browse</span>
                                        <input type="file" name="file[]" class="drop-zone2__input" accept="image/png,image/gif,image/jpeg,application/pdf,application/vnd.ms-excel" required multiple >
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label>Note</label>
                                    <textarea class="form-control" id="filenote" name="filenote"></textarea>
                                </div>
                                <button class="green-btn notes-btn w-100" >Upload</button>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <div class="button-bottom">
        <a href="{{ route('company.admin.brokers.index') }}" class="cancel-btn">Cancel</a>
        <button class="submit-btn clickToSubmit">Submit</button>
    </div>
@endsection

@section('modal')
    <div class="modal fade" id="accessorialModal" tabindex="-1" role="dialog" aria-labelledby="accessorialModalLabel" aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="accessorialModalLabel">Accessorial</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <form class="accessorialfrm" name="accessorialfrm" id="accessorialfrm" autocomplete="off">
                    <div class="modal-body">
                        <input type="hidden" name="id" value="">
                        <input type="hidden" name="broker_id" value="{{ $broker->id }}">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Accessorial<span>*</span></label>
                                    <select class="form-control" name="company_accessorial_id" data-parsley-errors-container="#company_accessorial_id-error" required>
                                        {!! $accessorialDropDown !!}
                                    </select>
                                    <div id="company_accessorial_id-error"></div>
                                    <span class="error company_accessorial_id_error text-danger"></span>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Rate<span>*</span></label>
                                    <input type="text" class="form-control groupOfTexbox" name="rate" value="" required>
                                    <span class="error credit_available_error text-danger"></span>
                                </div>
                            </div>
                            <div class="col-md-12">
                                <div class="form-group">
                                    <label>Note</label>
                                    <textarea class="form-control" name="note" rows="3"></textarea>
                                    <span class="error note_error text-danger"></span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-themeGray cancel-btn" data-dismiss="modal">Cancel</button>
                        <button type="button" class="btn btn-orange save-btn">Save</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection

@section('script')
    <script src="{{ asset('theme/js/select2.full.min.js') }}"></script>
    <script type="text/javascript">
        var dispatchers_options             = '';
        var shipper_files_options           = '';
        var consignee_files_options         = '';
        $( document ).ready(function() {
            var dispatchers                 = <?php echo json_encode($dispatchers); ?>;
            $.each( dispatchers, function( key, value ) {
                dispatchers_options         += '<option value="'+key+'">'+value+'</option>';
            });
            var shipper_files               = <?php echo json_encode($shipper_files); ?>;
            shipper_files_options           += '<option value="">Select File Name</option>';
            $.each( shipper_files, function( key, value ) {
                shipper_files_options       += '<option value="'+value.id+'" data-include_w_billing="'+value.include_w_billing+'">'+value.name+'</option>';
            });
            var consignee_files             = <?php echo json_encode($consignee_files); ?>;
            consignee_files_options         += '<option value="">Select File Name</option>';
            $.each( consignee_files, function( key, value ) {
                consignee_files_options     += '<option value="'+value.id+'" data-include_w_billing="'+value.include_w_billing+'">'+value.name+'</option>';
            });

            $('.update-form').parsley({
                excluded: 'input[type=button], input[type=submit], input[type=reset]',
                inputs: 'input, textarea, select, input[type=hidden], :hidden',
            });
            $('.time').datetimepicker({
                format: 'HH:mm',
                useCurrent: false,
            });
            $('.terms-select2').select2();
            $('.select2').select2({
                placeholder: 'Select options'
            });

            $('.bookedby-select2').select2();
            $('.shipper_files-select2').select2();
            $('.consignee_files-select2').select2();

            $('.notesave').parsley();
            $('.filesave').parsley();

            $('.clickToSubmit').click(function(){
                $('.update-form').submit(); // Submit the form
            });

            generateOfficesDropDown();
        });
        function getOfficesOptions(){
            var array           = [];
            if($('input[name="name"]').val()){
                array.push($('input[name="name"]').val());
            }
            if($('input[name="bill_to_name"]').val()){
                array.push($('input[name="bill_to_name"]').val());
            }
            $('input[name^="offices"][name$="[name]"]').each(function() {
                var value       = $(this).val();
                if(value){
                    array.push(value);
                }
            });
            // Use $.grep() to remove blank and null array
            array               = $.grep(array, function(value) {
              return value != null && value !== "";
            });
            // Use $.unique() to get unique values
            array               = $.unique(array);

            var options         = '<option value="">Select Office</option>';
            $.each( array, function( key, value ) {
                options         += '<option value="'+value+'">'+value+'</option>';
            });
            return options;
        }
        function generateOfficesDropDown(){
            var options         = getOfficesOptions();

            $('.office_id').each(function(index, element) {
                $(element).html(options);

                setTimeout(function() {
                    var id      = $(element).attr('data-id');
                    if(id){
                        // Check if an option with value "2" exists in a dropdown list with ID "my-select"
                        if ($(element).find('option[value="'+id+'"]').length) {
                            // Select the option with value "2"
                            $(element).val(id);
                        }
                    }
                }, 100);
            });
        }
        $(document).on('keyup change', 'input[name="name"], input[name="bill_to_name"], input[name^="offices"][name$="[name]"]', function(e) {
            var previousValue   = $(this).attr('data-previousValue');
            var currentValue    = $(this).val();

            if (previousValue !== currentValue) {
                // console.log("Input value has changed! Previous value: " + previousValue + ", Current value: " + currentValue);
                $(this).attr('data-previousValue', currentValue);
                if(previousValue){
                    if($('.office_id[data-id="'+previousValue+'"]').length > 0){
                        $('.office_id[data-id="'+previousValue+'"]').each(function(index, element) {
                            $(element).attr('data-id', currentValue);
                        });
                    }
                }
            }

            setTimeout(function() {
                generateOfficesDropDown();
            }, 100);
        });
        $(document).on('change', '.office_id', function(e) {
            // Store the selected value in a data attribute
            $(this).attr('data-id', $(this).val());
        });
    </script>
    <script type="text/javascript">
        $("#sameaddress").click(function() {
            if ($("#sameaddress").is(":checked")) {
                $('input[name="bill_to_name"]').val($('input[name="name"]').val());
                $('input[name="billing_address"]').val($('input[name="address"]').val());
                $('input[name="billing_address_2"]').val($('input[name="address_2"]').val());
                $('input[name="billing_city"]').val($('input[name="city"]').val());
                $('input[name="billing_state"]').val($('input[name="state"]').val());
                $('input[name="billing_zip"]').val($('input[name="zip"]').val());
                $('input[name="billing_phone"]').val($('input[name="phone_number"]').val());
                $('input[name="billing_email"]').val($('input[name="email"]').val());
                $('input[name="billing_extention"]').val($('input[name="extention"]').val());
                $('input[name="billing_fax"]').val($('input[name="fax"]').val());
                // $('input[name="billing_method"]').val($('input[name="method"]').val());
                // $('input[name="factored"]').val($('input[name="factored"]').val());

                if($('input[name="billing_address"]').val()!=''){
                    $('input[name="billing_address"]').parsley().reset();
                }
                if($('input[name="billing_state"]').val()!=''){
                    $('input[name="billing_state"]').parsley().reset();
                }
                if($('input[name="billing_zip"]').val()!=''){
                    $('input[name="billing_zip"]').parsley().reset();
                }
                var address_verified    = $('input[name="address_verified"]').val();
                if(address_verified==1){
                    $('input[name="billing_latitude"]').val($('input[name="latitude"]').val());
                    $('input[name="billing_longitude"]').val($('input[name="longitude"]').val());
                    $('input[name="billing_timezone_abbr"]').val($('input[name="timezone_abbr"]').val());
                    $('input[name="billing_address_verified"]').val('1');

                    $('input[name="billing_timezone_abbr"]').parsley().reset();
                    var btn             = $('input[name="billing_latitude"]').closest('.geocoding').find('.geocoding-btn');
                    btn.text('Verified');
                    btn.removeClass("btn-warning");
                    btn.addClass("btn-success");
                }
            }else{
                $('input[name="bill_to_name"]').val('');
                $('input[name="billing_address"]').val('');
                $('input[name="billing_address_2"]').val('');
                $('input[name="billing_city"]').val('');
                $('input[name="billing_state"]').val('');
                $('input[name="billing_zip"]').val('');
                $('input[name="billing_phone"]').val('');
                $('input[name="billing_email"]').val('');
                $('input[name="billing_extention"]').val('');
                $('input[name="billing_fax"]').val('');
                // $('input[name="billing_method"]').val('');
                // $('input[name="factored"]').val('');

                $('input[name="billing_latitude"]').val('');
                $('input[name="billing_longitude"]').val('');
                $('input[name="billing_timezone_abbr"]').val('');
                $('input[name="billing_address_verified"]').val('0');

                var btn                 = $('input[name="billing_latitude"]').closest('.geocoding').find('.geocoding-btn');
                btn.text('Verify');
                btn.removeClass("btn-success");
                btn.addClass("btn-warning");
            }
        });
    </script>
    <script type="text/javascript">
        var officeIndex         = "{{ isset($broker->broker_offices) && $broker->broker_offices->count() > 0?$broker->broker_offices->count():'1' }}";
        $("#addOffices").click(function () {
            var uid             = 'map-'
            uid                 += officeIndex+$.now();
            var html            = `
                <div class="row sub-wrapper geocoding" data-last-index="`+officeIndex+`">
                    <div class="col-12 d-none">
                        <input type="hidden" class="geocoding-latitude" name="offices[`+officeIndex+`][latitude]" value="">
                        <input type="hidden" class="geocoding-longitude" name="offices[`+officeIndex+`][longitude]" value="">
                        <input type="hidden" class="geocoding-abbr" name="offices[`+officeIndex+`][timezone_abbr]" value="" data-parsley-errors-container="#offices_`+officeIndex+`_timezone_abbr-errors" data-parsley-required-message="Please verify address">
                        <input type="hidden" class="geocoding-verified" name="offices[`+officeIndex+`][address_verified]" value="0">
                    </div>
                    <div class="col-md-2">
                        <div class="form-group">
                            <label>Name</label>
                            <input type="text" name="offices[`+officeIndex+`][name]" value="" class="form-control">
                        </div>
                    </div>
                    <div class="col-md-2">
                        <div class="form-group">
                            <label>Address</label>
                            <input type="text" name="offices[`+officeIndex+`][address]" value="" class="form-control geocoding-address-1">
                        </div>
                        <div id="offices_`+officeIndex+`_timezone_abbr-errors"></div>
                    </div>
                    <div class="col-md-2">
                        <div class="form-group">
                            <label>City</label>
                            <input type="text" name="offices[`+officeIndex+`][city]" value="" class="form-control geocoding-city">
                        </div>
                    </div>
                    <div class="col-md-2">
                        <div class="form-group">
                            <label>State</label>
                            <input type="text" name="offices[`+officeIndex+`][state]" value="" class="form-control geocoding-state">
                        </div>
                    </div>
                    <div class="col-md-2">
                        <div class="form-group">
                            <label>Zip</label>
                            <input type="text" name="offices[`+officeIndex+`][zip]" value="" class="form-control geocoding-zip">
                        </div>
                    </div>
                    <div class="col-md-2">
                        <button type="button" class="btn btn-warning geocoding-btn mr-2" data-uid="`+uid+`">Verify</button>
                        <button type="button" class="btn btn-danger mt-3 removeOffices"><i class="fa fa-trash"></i></button>
                    </div>
                </div>
            `;
            $('.offices-wrapper').append(html);
            officeIndex++;
        });
        // remove row
        $(document).on('click', '.removeOffices', function () {
            $(this).closest('.sub-wrapper').remove();

            setTimeout(function() {
                generateOfficesDropDown();
            }, 100);
        });
    </script>
    <script type="text/javascript">
        var contactsIndex       = "{{ isset($broker->broker_contact) && $broker->broker_contact->count() > 0?$broker->broker_contact->count():'1' }}";
        $("#addContacts").click(function () {
            var options         = getOfficesOptions();
            var html            = `<div class="row sub-wrapper" data-last-index="`+contactsIndex+`">
                <div class="col-md-2">
                    <div class="form-group">
                        <label>Office</label>
                        <select class="form-control office_id" name="additional_contacts[`+contactsIndex+`][office_id]">
                            `+options+`
                        </select>
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label>Department</label>
                        <input type="text" name="additional_contacts[`+contactsIndex+`][department]" value="" class="form-control">
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label>First Name</label>
                        <input type="text" name="additional_contacts[`+contactsIndex+`][first_name]" value="" class="form-control">
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label>Last Name</label>
                        <input type="text" name="additional_contacts[`+contactsIndex+`][last_name]" value="" class="form-control">
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label>Phone Number</label>
                        <input type="text" name="additional_contacts[`+contactsIndex+`][phone_number]" value="" class="form-control phone">
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label>Cell Number</label>
                        <input type="text" name="additional_contacts[`+contactsIndex+`][cell_number]" value="" class="form-control phone">
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label>Ext</label>
                        <input type="text" name="additional_contacts[`+contactsIndex+`][ext]" value="" class="form-control">
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label>Email</label>
                        <input type="email" name="additional_contacts[`+contactsIndex+`][email]" value="" class="form-control">
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label>Preferred Connection</label>
                        <div class="custom-checkbox-inline">
                            <div class="custom-control custom-checkbox">
                                <input type="checkbox" class="custom-control-input" name="additional_contacts[`+contactsIndex+`][preferred_connections][]" id="additional_contacts_`+contactsIndex+`_message" value="1">
                                <label class="custom-control-label" for="additional_contacts_`+contactsIndex+`_message" title="Message">
                                    <i class="fa fa-commenting" aria-hidden="true"></i>
                                </label>
                            </div>
                            <div class="custom-control custom-checkbox">
                                <input type="checkbox" class="custom-control-input" name="additional_contacts[`+contactsIndex+`][preferred_connections][]" id="additional_contacts_`+contactsIndex+`_email" value="2">
                                <label class="custom-control-label" for="additional_contacts_`+contactsIndex+`_email" title="Email">
                                    <i class="fa fa-envelope" aria-hidden="true"></i>
                                </label>
                            </div>
                            <div class="custom-control custom-checkbox">
                                <input type="checkbox" class="custom-control-input" name="additional_contacts[`+contactsIndex+`][preferred_connections][]" id="additional_contacts_`+contactsIndex+`_phone" value="3">
                                <label class="custom-control-label" for="additional_contacts_`+contactsIndex+`_phone" title="Phone">
                                    <i class="fa fa-mobile" aria-hidden="true"></i>
                                </label>
                            </div>
                            <div class="custom-control custom-checkbox">
                                <input type="checkbox" class="custom-control-input" name="additional_contacts[`+contactsIndex+`][preferred_connections][]" id="additional_contacts_`+contactsIndex+`_cell" value="4">
                                <label class="custom-control-label" for="additional_contacts_`+contactsIndex+`_cell" title="Cell">
                                    <i class="fa fa-phone" aria-hidden="true"></i>
                                </label>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label>Primary Contact</label>
                        <div class="d-flex align-items-center">
                            <div class="custom-control custom-switch-blue custom-switch-small mr-2">
                                <input type="checkbox" class="custom-control-input primary_contact" name="additional_contacts[`+contactsIndex+`][primary_contact]" id="additional_contacts_`+contactsIndex+`_primary_contact" value="1">
                                <label class="custom-control-label mb-0" for="additional_contacts_`+contactsIndex+`_primary_contact"></label>
                            </div>
                            <label class="switch-text mb-0" for="additional_contacts_`+contactsIndex+`_primary_contact">Off/On</label>
                        </div>
                    </div>
                </div>
                <div class="col-md-2 primary-contact-id-div d-none">
                    <div class="form-group">
                        <label class="d-block" style="visibility: hidden;">Primary Dispatcher</label>
                        <select name="additional_contacts[`+contactsIndex+`][dispatcher_id][]" class="form-control select2" multiple>
                            `+dispatchers_options+`
                        </select>
                    </div>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <label class="d-block" style="visibility: hidden;">Action</label>
                        <a href="javascript:void(0)" class="btn btn-danger removeContacts"><i class="fa fa-trash"></i></a>
                    </div>
                </div>
            </div>`;
            $('.additional-contacts-wrapper').append(html);
            contactsIndex++;
            setPhoneNumber();
            $('.select2').select2({
                placeholder: 'Select options'
            });
        });
        // remove row
        $(document).on('click', '.removeContacts', function () {
            $(this).closest('.sub-wrapper').remove();
        });
        //
        $(document).on('change', '.primary_contact', function() {
            var that    = $(this);
            var wrapper = that.closest('.sub-wrapper');
            if(this.checked) {
                wrapper.find('.primary-contact-id-div').removeClass('d-none');
            }else{
                wrapper.find('.primary-contact-id-div').addClass('d-none');
            }
        });
    </script>
    <script type="text/javascript">
        var shipperIndex        = parseInt('{{ $newSetShi }}');;
        $("#shipperaddRow").click(function () {
            var html            = `<div class="row align-items-center mb-2 shipperinputFormRow">`;
            html                +=
                `<div class="col-auto cheskejw">
                    <div class="custom-control custom-checkbox">
                        <input type="checkbox" class="custom-control-input" id="shipper_files_is_required_`+shipperIndex+`" name="shipper_files[is_required][`+shipperIndex+`]">
                        <label class="custom-control-label" for="shipper_files_is_required_`+shipperIndex+`"></label>
                    </div>
                </div>
                <div class="col-md-5">
                    <div class="form-group mt-2">
                        <input type="hidden" name="shipper_files[name][`+shipperIndex+`]" value="">
                        <select name="shipper_files[name_id][`+shipperIndex+`]" class="form-control" data-parsley-errors-container="#shipper_files_name_id_`+shipperIndex+`-errors" required>
                            `+shipper_files_options+`
                        </select>
                        <div id="shipper_files_name_id_`+shipperIndex+`-errors"></div>
                    </div>
                </div>
                <div class="col-auto custom-width radio-btn-div stradibut">
                    <div class="btn-group btn-group-toggle" data-toggle="buttons">
                        <label class="btn btn-secondary">
                            <input class="custom-control-input" name="shipper_files[type][`+shipperIndex+`]" type="radio" value="1"> Copy
                        </label>
                        <label class="btn btn-secondary active">
                            <input class="custom-control-input" name="shipper_files[type][`+shipperIndex+`]" type="radio" value="2" checked="checked"> Original
                        </label>
                    </div>
                </div>
                <div class="col-md-1">
                    <input type="hidden" name="shipper_files[fixed][`+shipperIndex+`]" value="no">
                    <input type="hidden" name="shipper_files[include_w_billing][`+shipperIndex+`]" value="no">
                    <a href="javascript:void(0)" class="btn btn-danger shipperremoveRow"><i class="fa fa-trash"></i></a>
                </div>`;
            html                += `</div>`;
            $('#shippernewRow').append(html);
            $('select[name="shipper_files[name_id]['+shipperIndex+']"]').select2();
            shipperIndex++;
        });

        // remove row
        $(document).on('click', '.shipperremoveRow', function () {
            $(this).closest('.shipperinputFormRow').remove();
        });

        var consigneeIndex      = parseInt('{{ $newConShi }}');;
        $("#consigneeaddRow").click(function () {
            var html            = `<div class="row align-items-center mb-2 consigneeinputFormRow">`;
            html                +=
                `<div class="col-auto cheskejw">
                    <div class="custom-control custom-checkbox">
                        <input type="checkbox" class="custom-control-input" id="consignee_files_is_required_`+consigneeIndex+`" name="consignee_files[is_required][`+consigneeIndex+`]">
                        <label class="custom-control-label" for="consignee_files_is_required_`+consigneeIndex+`"></label>
                    </div>
                </div>
                <div class="col-md-5">
                    <div class="form-group mt-2">
                        <input type="hidden" name="consignee_files[name][`+consigneeIndex+`]" value="">
                        <select name="consignee_files[name_id][`+consigneeIndex+`]" class="form-control" data-parsley-errors-container="#consignee_files_name_id_`+consigneeIndex+`-errors" required>
                            `+consignee_files_options+`
                        </select>
                        <div id="consignee_files_name_id_`+consigneeIndex+`-errors"></div>
                    </div>
                </div>
                <div class="col-auto custom-width radio-btn-div stradibut">
                    <div class="btn-group btn-group-toggle" data-toggle="buttons">
                        <label class="btn btn-secondary">
                            <input class="custom-control-input" name="consignee_files[type][`+consigneeIndex+`]" type="radio" value="1"> Copy
                        </label>
                        <label class="btn btn-secondary active">
                            <input class="custom-control-input" name="consignee_files[type][`+consigneeIndex+`]" type="radio" value="2" checked="checked"> Original
                        </label>
                    </div>
                </div>
                <div class="col-md-1">
                    <input type="hidden" name="consignee_files[fixed][`+consigneeIndex+`]" value="no">
                    <input type="hidden" name="consignee_files[include_w_billing][`+consigneeIndex+`]" value="no">
                    <a href="javascript:void(0)" class="btn btn-danger consigneeremoveRow"><i class="fa fa-trash"></i></a>
                </div>`;
            html                += `</div>`;
            $('#consigneenewRow').append(html);
            $('select[name="consignee_files[name_id]['+consigneeIndex+']"]').select2();
            consigneeIndex++;
        });

        // remove row
        $(document).on('click', '.consigneeremoveRow', function () {
            $(this).closest('.consigneeinputFormRow').remove();
        });

        $(document).on('change', 'select[name^="shipper_files[name_id]"], select[name^="consignee_files[name_id]"]', function() {
            var optionSelected          = $("option:selected", this);
            var selectedValue           = $(this).val();
            var selectedText            = $(this).find("option:selected").text();
            if(selectedValue==''){
                selectedText            = '';
            }
            var nameId                  = $(this).attr('name').match(/\[name_id\]\[(\d+)\]/)[1];
            var nameIndex               = nameId; // Assuming nameIndex and name_id are the same

            var nameElement;
            var includeWBillingElement;
            if ($(this).attr('name').indexOf('shipper_files') !== -1) {
                nameElement             = $("input[name='shipper_files[name][" + nameIndex + "]']");
                includeWBillingElement  = $("input[name='shipper_files[include_w_billing][" + nameIndex + "]']");
                // console.log('Shipper Files Change - name_id: ' + nameId + ', shipperIndex: ' + nameIndex + ', value: ' + selectedValue+ ', text: ' + selectedText);
            } else if ($(this).attr('name').indexOf('consignee_files') !== -1) {
                nameElement             = $("input[name='consignee_files[name][" + nameIndex + "]']");
                includeWBillingElement  = $("input[name='consignee_files[include_w_billing][" + nameIndex + "]']");
                // console.log('Consignee Files Change - name_id: ' + nameId + ', consigneeIndex: ' + nameIndex + ', value: ' + selectedValue+ ', text: ' + selectedText);
            }
            if(nameElement && nameElement.length > 0){
                $(nameElement).val(selectedText);
            }
            if(includeWBillingElement && includeWBillingElement.length > 0){
                if(optionSelected.attr('data-include_w_billing') == 'yes'){
                    $(includeWBillingElement).val('yes');
                }else{
                    $(includeWBillingElement).val('no');
                }
            }
        });
    </script>
    <script type="text/javascript">
        document.querySelectorAll(".drop-zone__input").forEach((inputElement) => {
            const dropZoneElement = inputElement.closest(".drop-zone");

            dropZoneElement.addEventListener("click", (e) => {
                inputElement.click();
            });

            inputElement.addEventListener("change", (e) => {
                if (inputElement.files.length) {
                assupdateThumbnail(dropZoneElement, inputElement.files[0]);
                }
            });

            dropZoneElement.addEventListener("dragover", (e) => {
                e.preventDefault();
                dropZoneElement.classList.add("drop-zone--over");
            });

            ["dragleave", "dragend"].forEach((type) => {
                dropZoneElement.addEventListener(type, (e) => {
                dropZoneElement.classList.remove("drop-zone--over");
                });
            });

            dropZoneElement.addEventListener("drop", (e) => {
                e.preventDefault();

                if (e.dataTransfer.files.length) {
                inputElement.files = e.dataTransfer.files;
                assupdateThumbnail(dropZoneElement, e.dataTransfer.files[0]);
                }

                dropZoneElement.classList.remove("drop-zone--over");
            });
        });

        function assupdateThumbnail(dropZoneElement, file) {
            let thumbnailElement = dropZoneElement.querySelector(".drop-zone__thumb");

            // First time - remove the prompt
            if (dropZoneElement.querySelector(".drop-zone__prompt")) {
                dropZoneElement.querySelector(".drop-zone__prompt").remove();
            }

            // First time - there is no thumbnail element, so lets create it
            if (!thumbnailElement) {
                thumbnailElement = document.createElement("div");
                thumbnailElement.classList.add("drop-zone__thumb");
                dropZoneElement.appendChild(thumbnailElement);
            }

            thumbnailElement.dataset.label = file.name;

            // Show thumbnail for image files
            if (file.type.startsWith("image/")) {
                const reader = new FileReader();

                reader.readAsDataURL(file);
                reader.onload = () => {
                thumbnailElement.style.backgroundImage = `url('${reader.result}')`;
                };
            } else {
                thumbnailElement.style.backgroundImage = null;
            }
        }

        //drop-zone2__input
        document.querySelectorAll(".drop-zone2__input").forEach((inputElement) => {
            const dropZoneElement = inputElement.closest(".drop-zone2");

            dropZoneElement.addEventListener("click", (e) => {
                inputElement.click();
            });

            inputElement.addEventListener("change", (e) => {
                if (inputElement.files.length) {
                    var filecount = inputElement.files.length;
                updateThumbnail(dropZoneElement, inputElement.files[0], filecount);
                }
            });

            dropZoneElement.addEventListener("dragover", (e) => {
                e.preventDefault();
                dropZoneElement.classList.add("drop-zone2--over");
            });

            ["dragleave", "dragend"].forEach((type) => {
                dropZoneElement.addEventListener(type, (e) => {
                dropZoneElement.classList.remove("drop-zone2--over");
                });
            });

            dropZoneElement.addEventListener("drop", (e) => {
                e.preventDefault();

                if (e.dataTransfer.files.length) {
                inputElement.files = e.dataTransfer.files;
                var filecount = e.dataTransfer.files.length;
                updateThumbnail(dropZoneElement, e.dataTransfer.files[0], filecount);
                }

                dropZoneElement.classList.remove("drop-zone2--over");
            });
        });

        function updateThumbnail(dropZoneElement, file, filecount) {
            let thumbnailElement = dropZoneElement.querySelector(".drop-zone2__thumb");

            // First time - remove the prompt
            if (dropZoneElement.querySelector(".drop-zone2__prompt")) {
                dropZoneElement.querySelector(".drop-zone2__prompt").remove();
            }

            // First time - there is no thumbnail element, so lets create it
            if (!thumbnailElement) {
                thumbnailElement = document.createElement("div");
                thumbnailElement.classList.add("drop-zone2__thumb");
                dropZoneElement.appendChild(thumbnailElement);
            }
            //var numFiles = file[0].length;

            thumbnailElement.dataset.label = filecount+' Files Selected';

            // Show thumbnail for image files
            if (file.type.startsWith("image/")) {
                const reader = new FileReader();

                reader.readAsDataURL(file);
                reader.onload = () => {
                thumbnailElement.style.backgroundImage = `url('${reader.result}')`;
                };
            } else {
                thumbnailElement.style.backgroundImage = null;
            }
        }

        function loadFileView() {
            var token = $('meta[name="csrf-token"]').attr('content');
            $.ajax({
                url: "{{ route('company.admin.documents.index') }}",
                method: "GET",
                data: { _token : token, by_id : <?php echo $broker->id; ?>, type : 'broker'},
                success: function(response) {
                    $("#loadfile").html(response.view);
                }
            });
        }

        loadFileView();

        $(".filesave").ajaxForm({
            complete: function (response) {
                if(response.responseText == '1'){
                    toastr.success('File upload successfully', 'Success Alert', {timeOut: 5000})
                    loadFileView();
                    $('.filesave')[0].reset();
                    $('.drop-zone').prepend('<span class="drop-zone__prompt">Drag and drop file here or click to browse</span>');
                    $('.drop-zone__thumb').remove();
                }else{
                    toastr.success('Upload file not supported', 'Error Alert', {timeOut: 5000})
                    loadFileView();
                }
            },
        });
    </script>
    <script type="text/javascript">
        function getNoteSave(){
            var token   = $('meta[name="csrf-token"]').attr('content');
            var loadimg = "{{ asset('theme/img/loading.gif') }}";
            $(".getnotesave").html('<div class="loadingdiv"><img src="'+loadimg+'" /></div>');
            $.ajax({
                url: "{{ route('company.admin.notes.index') }}",
                method: "GET",
                data: { _token : token, action_id : <?php echo $broker->id; ?>, action_type : 'broker'},
                success: function(response) {
                    $(".getnotesave").html(response.view);
                }
            });
        }

        getNoteSave();

        // Add Receiver Store
        $(".notesave").ajaxForm({
            beforeSubmit:  function(formData, jqForm, options) {
                var loadimg = "{{ asset('theme/img/loading.gif') }}";
                $(".getnotesave").html('<div class="loadingdiv"><img src="'+loadimg+'" /></div>');
            },
            complete: function (response) {
                if(response.responseText == '1'){
                    getNoteSave();
                    $('.selenondriveruser').hide('200');
                    $('.notesave')[0].reset();
                    toastr.success('Note create successfully', 'Success Alert', {timeOut: 5000})
                }else{
                    toastr.error('Something went wrong try again in a few seconds', 'Error Alert', {timeOut: 5000})
                }
            },
        });

        $('.checknondriveruser').change(function() {
            if (this.checked) {
                $('.selenondriveruser').show('200');
                $('#privatUser').prop('required',true);
            } else {
                $('.selenondriveruser').hide('200');
                $('#privatUser').prop('required',false);
            }
        });
    </script>
    <script type="text/javascript">
        $( document ).ready(function() {
            getAccessorial();

            $('#accessorialModal select[name="company_accessorial_id"]').select2({
                dropdownParent: $("#accessorialModal")
            }).on('select2:select', function (e) {
                var data            = e.params.data;
                var selected        = $('#accessorialModal select[name="company_accessorial_id"] option:selected');
                var default_amount  = '';
                if(selected.attr('data-default-amount')){
                    default_amount  = selected.attr('data-default-amount')
                }
                $('#accessorialModal input[name="rate"]').val(default_amount);
            });
            $('#createNewAccessorial').click(function () {
                $('#accessorialModal input[name="id"]').val('');
                $('#accessorialModal select[name="company_accessorial_id"]').val(null).trigger('change');
                $('#accessorialModal #accessorialfrm').trigger('reset');

                $('#accessorialModal .modal-title').html('Accessorial');
                $('#accessorialModal .save-btn').html("Save");
                $('#accessorialModal').modal('show');
            });
            $('#accessorialModal').on('hidden.bs.modal', function() {
                $('#accessorialModal input[name="id"]').val('');
                $('#accessorialModal select[name="company_accessorial_id"]').val(null).trigger('change');
                $('#accessorialModal #accessorialfrm').trigger('reset');

                $('#accessorialModal #accessorialfrm').find('.error').text('');
                $('#accessorialModal #accessorialfrm').parsley().reset();
            });
            $('#accessorialfrm').on("click", ".save-btn", function(e) {
                e.preventDefault();

                var that                = $(this);
                var btnTxt              = that.text();

                var form                = $('#accessorialModal #accessorialfrm');
                var parsley             = form.parsley({
                    excluded: 'input[type=button], input[type=submit], input[type=reset]',
                    inputs: 'input, textarea, select, input[type=hidden], :hidden',
                });
                parsley.validate();
                if (parsley.isValid()){
                    var formData        = new FormData(form[0]);
                    $.ajax({
                        type: 'POST',
                        url: "{{ route('company.admin.brokers.accessorial.save') }}",
                        data: formData,
                        dataType: 'json',
                        headers: {
                            'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                        },
                        cache : false,
                        processData: false,
                        contentType: false,
                        beforeSend: function() {
                            that.prop('disabled', true).html('Please Wait...');
                        },
                        success: function(response) {
                            if(response.success){
                                getAccessorial();
                                $('#accessorialModal').modal('hide');
                                toastr.success(response.message, 'Success Alert');
                            }else{
                                toastr.error(response.message, 'Error Alert');
                            }
                        },
                        complete: function() {
                            that.prop('disabled', false).html(btnTxt);
                        },
                        error: function(jqXHR, status, exception) {
                            if (jqXHR.status === 0) {
                                error = 'Not connected.\nPlease verify your network connection.';
                            } else if (jqXHR.status == 404) {
                                error = 'The requested page not found. [404]';
                            } else if (jqXHR.status == 500) {
                                error = 'Internal Server Error [500].';
                            } else if (exception === 'parsererror') {
                                error = 'Requested JSON parse failed.';
                            } else if (exception === 'timeout') {
                                error = 'Time out error.';
                            } else if (exception === 'abort') {
                                error = 'Ajax request aborted.';
                            } else {
                                error = 'Uncaught Error.\n' + jqXHR.responseText;
                            }
                            toastr.error(error, 'Error Alert');
                        }
                    });
                    return false;
                }
            });
        });
        $( document ).on('click', '.accessorial-edit', function () {
            var that                    = $(this);
            var id                      = that.attr('data-id');
            $('#accessorialModal input[name="id"]').val(id);
            var accessorial_id          = that.attr('data-accessorial_id');
            $('#accessorialModal select[name="company_accessorial_id"]').val(accessorial_id).trigger('change');
            var rate                    = that.attr('data-rate');
            $('#accessorialModal input[name="rate"]').val(rate);
            var note                    = that.attr('data-note');
            $('#accessorialModal textarea[name="note"]').val(note);

            $('#accessorialModal .modal-title').html('Accessorial');
            $('#accessorialModal .save-btn').html("Save");
            $('#accessorialModal').modal('show');
        });
        $( document ).on('click', '.accessorial-delete', function () {
            var that            = $(this);
            Swal.fire({
                title: "Are you sure?",
                text: "You won't be able to revert this!",
                icon: "warning",
                showCancelButton: true,
                confirmButtonColor: "#3085d6",
                cancelButtonColor: "#d33",
                confirmButtonText: "Yes, delete it!",
            }).then((result) => {
                if (result.value) {
                    var action  = that.attr('data-action');
                    var id      = that.attr('data-id');
                    var token   = $("input[name='_token']").val();
                    $.ajax({
                        url: action,
                        method: "delete",
                        data: { _token : token , id : id},
                        success: function(response) {
                            getAccessorial();
                            toastr.success('deleted successfully', 'Success Alert', {
                                timeOut: 5000
                            });
                        }
                    });
                }
            });
        });
        function getAccessorial(){
            var broker_id = "{{ $broker->id }}";
            if(broker_id){
                $.ajax({
                    type: 'POST',
                    url: '{{ route("company.admin.brokers.accessorial.view") }}',
                    data: { id: broker_id },
                    dataType: 'json',
                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    },
                    beforeSend: function() {
                        //$('.accessorial-table tbody').html(`<tr><td colspan="4"><div class="loadingdiv"><img src="`+loadimg+`"></div></td></tr>`);
                    },
                    success: function(response) {
                        $('.accessorial-table tbody').html(response.html);
                    },
                    complete: function() {
                        //console.log('complete');
                    },
                    error: function(jqXHR, status, exception) {
                        if (jqXHR.status === 0) {
                            error = 'Not connected.\nPlease verify your network connection.';
                        } else if (jqXHR.status == 404) {
                            error = 'The requested page not found. [404]';
                        } else if (jqXHR.status == 500) {
                            error = 'Internal Server Error [500].';
                        } else if (exception === 'parsererror') {
                            error = 'Requested JSON parse failed.';
                        } else if (exception === 'timeout') {
                            error = 'Time out error.';
                        } else if (exception === 'abort') {
                            error = 'Ajax request aborted.';
                        } else {
                            error = 'Uncaught Error.\n' + jqXHR.responseText;
                        }
                        toastr.error(error, 'Error Alert', {
                            timeOut: 5000
                        });
                    }
                });
            }
        }
    </script>
@endsection

@push('after-scripts')
    <script src="{{ asset('theme/js/trimble.js') }}"></script>
@endpush