@extends($companyAdminTheme)

@section('title')
    Integration Settings
@endsection

@section('style')
    <style type="text/css">
        #teamsTable tr td:nth-child(3) {
            text-transform: inherit;
        }
        .fa-plus-square {
            color: #305F9C;
            border-radius: 8px;
            font-size: 35px;
        }
        .fa-minus-square {
            color: #c82333;
            border-radius: 8px;
            font-size: 35px;
        }
    </style>
@endsection

@section('content')
<div class="row">
    <div class="col-md-12 integration-detail-section">
        <div class="white-box mb-0 pb-4">
            <div class="row">
                <div class="col-md-9 pl-2">
                    <img src="{{ asset('storage/companyAdmin/app_logo'); }}/{{ $app->logo }}" altc="" class="img-fluid logo" />
                </div>
                <div class="col-md-3">
                    <div class="rulbox">
                        <a href="{{ $app->url_1 }}" target="_blank" ><img src="{{ asset('theme/img/web-icon.png'); }}" alt="" class="img-fluid" width="17" /> {{ $app->url_name_1 }}</a>
                    </div>
                    <div class="rulbox">
                        <a href="{{ $app->url_2 }}" target="_blank" ><img src="{{ asset('theme/img/web-icon.png'); }}" alt="" class="img-fluid" width="17" /> {{ $app->url_name_2 }}</a>
                    </div>
                </div>
            </div>
            <div class="row mb-3">
                <div class="col-md-12">
                    {!! $app->description !!}
                </div>
            </div>
            @if(count($integrationSettings) > 0)
                <div class="row mb-3">
                    <div class="col-md-12">
                        <ul class="d-inline-flex">
                            @if(count(array_values(array_filter(array_column($integrationSettings->toArray(), 'sync_drivers')))) > 0)
                                <li class="mr-3">
                                    <a href="javascript:void(0);" class="btn btn-primary" id="sync-drivers"> Run Sync for Drivers</a>
                                </li>
                            @endif
                            @if(count(array_values(array_filter(array_column($integrationSettings->toArray(), 'sync_vehicles')))) > 0)
                                <li class="mr-3">
                                    <a href="javascript:void(0);" class="btn btn-primary" id="sync-vehicles"> Run Sync for Vehicles</a>
                                </li>
                            @endif
                            @if(count(array_values(array_filter(array_column($integrationSettings->toArray(), 'sync_trailers')))) > 0)
                                <li class="mr-3">
                                    <a href="javascript:void(0);" class="btn btn-primary" id="sync-trailers"> Run Sync for Trailers</a>
                                </li>
                            @endif
                        </ul>
                    </div>
                </div>
            @endif
            @if(count($integrationSettings) > 0)
                @foreach($integrationSettings as $integration)
                    {!! Form::model($integration, array('route' => ['company.admin.integration.update', $integration->id], 'method'=>'PATCH', 'files'=>'true', 'class'=>'edit-form mb-3', 'autocomplete' => 'off')) !!}
                    <input type="hidden" name="app_center_id" value="{{ $app->id }}">
                    <div class="row align-items-center">
                        <div class="col-md-5">
                            <div class="form-group">
                                <label>Carrier<span>*</span></label>
                                {!! Form::select('carrier_id', ['' => 'Select Carrier']+getCarrierList(), null, ['class' => 'form-control select2', 'required' => 'required', 'data-parsley-errors-container' => '#carrier-errors']) !!}
                                <div id="carrier-errors"></div>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>API key<span>*</span></label>
                                {!! Form::text('api_key', old('api_key'), array('class' => 'form-control', 'placeholder' => 'ex. samsara_api_xxxxxxx', 'rows' => '4', 'required' => 'required')) !!}
                            </div>
                        </div>
                        <div class="col-md-1">
                            <div class="form-group mb-0">
                                @if($loop->iteration == 1)
                                    <a href="javascript:void(0);" class="add-more"><i class="fa fa-plus-square"></i></a>
                                @else
                                    <a href="javascript:void(0);" class="destroy" data-action="{{ route('company.admin.app-settings.destroy', $integration->id) }}" data-id="{{ $integration->id }}"><i class="fa fa-minus-square"></i></a>
                                @endif
                            </div>
                        </div>
                        <div class="col-md-5">
                            <div class="check-list mb-0">
                                <ul class="d-inline-flex">
                                    <li class="mr-3">
                                        <div class="form-check">
                                            {!! Form::checkbox('sync_drivers', 1, null, array('class' => 'form-check-input d-none', 'id' => 'sync_drivers_'.$loop->index)) !!}
                                            <label class="form-check-label" for="sync_drivers_{{$loop->index}}">
                                                Sync Drivers
                                            </label>
                                        </div>
                                    </li>
                                    <li class="mr-3">
                                        <div class="form-check">
                                            {!! Form::checkbox('sync_vehicles', 1, null, array('class' => 'form-check-input d-none', 'id' => 'sync_vehicles_'.$loop->index)) !!}
                                            <label class="form-check-label" for="sync_vehicles_{{$loop->index}}">
                                                Sync Vehicles
                                            </label>
                                        </div>
                                    </li>
                                    <li class="mr-3">
                                        <div class="form-check">
                                            {!! Form::checkbox('sync_trailers', 1, null, array('class' => 'form-check-input d-none', 'id' => 'sync_trailers_'.$loop->index)) !!}
                                            <label class="form-check-label" for="sync_trailers_{{$loop->index}}">
                                                Sync Trailers
                                            </label>
                                        </div>
                                    </li>
                                </ul>
                            </div>
                        </div>
                        <div class="col-md-6 text-md-right">
                            <a class="btn btn-danger mr-3 destroy" href="javascript:void(0);" data-action="{{ route('company.admin.app-settings.destroy', $integration->id) }}" data-id="{{ $integration->id }}">Cancel Integration</a>
                            <button class="btn btn-success">Update Settings</button>
                        </div>
                    </div>
                    {!! Form::close() !!}
                @endforeach
            @else
                {!! Form::open(array('route' => 'company.admin.integration.save', 'method'=>'POST', 'files'=>'true', 'class'=>'store-form', 'autocomplete' => 'off')) !!}
                <input type="hidden" name="app_center_id" value="{{ $app->id }}">
                <div class="row align-items-center">
                    <div class="col-md-5">
                        <div class="form-group">
                            <label>Carrier<span>*</span></label>
                            {!! Form::select('carrier_id', ['' => 'Select Carrier']+getCarrierList(), null, ['class' => 'form-control select2', 'required' => 'required', 'data-parsley-errors-container' => '#carrier-errors']) !!}
                            <div id="carrier-errors"></div>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="form-group">
                            <label>API key<span>*</span></label>
                            {!! Form::text('api_key', old('api_key'), array('class' => 'form-control', 'placeholder' => 'ex. samsara_api_xxxxxxx', 'rows' => '4', 'required' => 'required')) !!}
                        </div>
                    </div>
                    <div class="col-md-1">
                        <div class="form-group mb-0">
                            <a href="javascript:void(0);" class="add-more"><i class="fa fa-plus-square"></i></a>
                        </div>
                    </div>
                    <div class="col-md-5">
                        <div class="check-list mb-0">
                            <ul class="d-inline-flex">
                                <li class="mr-3">
                                    <div class="form-check">
                                        {!! Form::checkbox('sync_drivers', 1, null, array('class' => 'form-check-input d-none', 'id' => 'sync_drivers_0')) !!}
                                        <label class="form-check-label" for="sync_drivers_0">
                                            Sync Drivers
                                        </label>
                                    </div>
                                </li>
                                <li class="mr-3">
                                    <div class="form-check">
                                        {!! Form::checkbox('sync_vehicles', 1, null, array('class' => 'form-check-input d-none', 'id' => 'sync_vehicles_0')) !!}
                                        <label class="form-check-label" for="sync_vehicles_0">
                                            Sync Vehicles
                                        </label>
                                    </div>
                                </li>
                                <li class="mr-3">
                                    <div class="form-check">
                                        {!! Form::checkbox('sync_trailers', 1, null, array('class' => 'form-check-input d-none', 'id' => 'sync_trailers_0')) !!}
                                        <label class="form-check-label" for="sync_trailers_0">
                                            Sync Trailers
                                        </label>
                                    </div>
                                </li>
                            </ul>
                        </div>
                    </div>
                    <div class="col-md-6 text-md-right">
                        <button class="btn btn-success">Save Settings</button>
                    </div>
                </div>
                {!! Form::close() !!}
            @endif
            <div id="moreSamsaraIntegration"></div>
        </div>
        <div class="white-box mb-0 pt-3">
            @if(count($integrationSettings) > 0)
                <div class="row mb-3">
                    <div class="col-md-12">
                        <ul class="d-inline-flex">
                            <li class="mr-3">
                                <div class="form-group">
                                    <select name="carrier_sync" id="carrier-sync" class="form-control select2">
                                        @foreach($integrationSettings as $integrationSetting)
                                            <option value="{{ $integrationSetting->api_key }}" {{ $loop->index == 0 ? 'selected' : '' }} data-sync-drivers="{{ $integrationSetting->sync_drivers }}" data-sync-vehicles="{{ $integrationSetting->sync_vehicles }}" data-sync-trailers="{{ $integrationSetting->sync_trailers }}">{{ getCarrierList()[$integrationSetting->carrier_id] }}</option>
                                        @endforeach
                                    </select>
                                </div>
                            </li>
                            <li class="mr-3">
                                <div class="form-group py-2">
                                    <h6>Select the carrier here to view synced ELD data below</h6>
                                </div>
                            </li>
                        </ul>
                    </div>
                </div>
                <div class="row" id="listingView">
                    <div class="col-md-12">
                        <div class="employee-wrapper">
                            <ul class="nav nav-tabs" id="myTab" role="tablist">
                                <li class="nav-item" role="presentation">
                                    <a class="nav-link active" id="Drivers-tab" data-toggle="tab" href="#Drivers" role="tab" aria-controls="Drivers" aria-selected="true">Drivers</a>
                                </li>
                                <li class="nav-item" role="presentation">
                                    <a class="nav-link" id="Vehicles-tab" data-toggle="tab" href="#Vehicles" role="tab" aria-controls="Vehicles" aria-selected="false">Vehicles</a>
                                </li>
                                <li class="nav-item" role="presentation">
                                    <a class="nav-link" id="Trailers-tab" data-toggle="tab" href="#Trailers" role="tab" aria-controls="leave" aria-selected="false">Trailers</a>
                                </li>
                            </ul>
                            <div class="tab-content" id="myTabContent">
                                <div class="tab-pane fade active show" id="Drivers" role="tabpanel" aria-labelledby="Drivers-tab">
                                    <div class="row">
                                        <div class="col-md-12 pl-0 pr-0">
                                            <div class="table-view">
                                                <div class="d-flex justify-content-end">
                                                    <div class="form-group serch-txt">
                                                        <input type="text" class="form-control" id="serchboxDriver" placeholder="Search..">
                                                        <img src="{{ asset('theme/img/search-icon-grey.png'); }}" alt="" class="img-fluid" />
                                                    </div>
                                                </div>
                                                <div class="add-responsive tbl-2 table-responsive">
                                                    <table id="teamsTable" class="table dataTable">
                                                        <thead>
                                                        <tr>
                                                            <th>Account ID</th>
                                                            <th>Name</th>
                                                            <th>License Number</th>
                                                            <th>Samsara Account Number</th>
                                                            <th>Status</th>
                                                            <th>Action</th>
                                                        </tr>
                                                        </thead>
                                                        <tbody class="append-syncDriver">
                                                        </tbody>
                                                    </table>
                                                    <hr>
                                                    <div class="row mb-3">
                                                        <div class="col-md-12 text-center">
                                                            <button type="button" class="appprevnext load-more-driver" value="">Load More</button>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="tab-pane fade" id="Vehicles" role="tabpanel" aria-labelledby="Vehicles-tab">
                                    <div class="row">
                                        <div class="col-md-12 pl-0 pr-0">
                                            <div class="table-view">
                                                <div class="d-flex justify-content-end">
                                                    <div class="form-group serch-txt">

                                                        <input type="text" class="form-control" id="serchboxVihical" placeholder="Search..">
                                                        <img src="{{ asset('theme/img/search-icon-grey.png'); }}" alt="" class="img-fluid" />
                                                    </div>
                                                </div>
                                                <div class="add-responsive tbl-2 table-responsive">
                                                    <table id="teamsTablevihical" class="table dataTable">
                                                        <thead>
                                                        <tr>
                                                            <th>Account ID</th>
                                                            <th>VIN</th>
                                                            <th>Samsara Account Number</th>
                                                            <th>Status</th>
                                                            <th>Action</th>
                                                        </tr>
                                                        </thead>
                                                        <tbody class="append-syncVehicles">
                                                        </tbody>
                                                    </table>
                                                    <hr>
                                                    <div class="row mb-3">
                                                        <div class="col-md-12 text-center">
                                                            <button type="button" class="appprevnext load-more-vehicles" value="">Load More</button>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="tab-pane fade" id="Trailers" role="tabpanel" aria-labelledby="Trailers-tab">
                                    <div class="row">
                                        <div class="col-md-12 pl-0 pr-0">
                                            <div class="table-view">
                                                <div class="d-flex justify-content-end">
                                                    <div class="form-group serch-txt">

                                                        <input type="text" class="form-control" id="serchboxTrailers" placeholder="Search..">
                                                        <img src="{{ asset('theme/img/search-icon-grey.png'); }}" alt="" class="img-fluid" />
                                                    </div>
                                                </div>
                                                <div class="add-responsive tbl-2 table-responsive">
                                                    <table id="teamsTabletrailers" class="table dataTable">
                                                        <thead>
                                                        <tr>
                                                            <th>Account ID</th>
                                                            <th>Trailer ID</th>
                                                            <th>Samsara Account Number</th>
                                                            <th>Status</th>
                                                            <th>Action</th>
                                                        </tr>
                                                        </thead>
                                                        <tbody class="append-syncTrailers">
                                                        </tbody>
                                                    </table>
                                                    <hr>
                                                    <div class="row mb-3">
                                                        <div class="col-md-12 text-center">
                                                            <button type="button" class="appprevnext load-more-trailers" value="">Load More</button>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            @endif
        </div>
    </div>
</div>
@endsection

@section('script')
    <script type="text/javascript">
        @if(count($integrationSettings) > 0)
            var loadimg = "{{ asset('theme/img/loading.gif') }}";

            function loader(){
                Swal.fire({
                    title: '<h5 class="font-weight-bold">Please wait...</h5>',
                    allowEscapeKey: false,
                    allowOutsideClick: false,
                    didOpen: () => {
                        Swal.showLoading()
                    }
                });
            }

            function syncDriver(samsara_api_key, endCursor) {
                $("#teamsTable").after('<div class="loadingdiv"><img src="'+loadimg+'" /></div>');

                var token = $('meta[name="csrf-token"]').attr('content');
                $.ajax({
                    url: "{{ route('company.admin.app-settings.sync.driver') }}",
                    method: "POST",
                    data: { _token : token , samsara_api_key:samsara_api_key, endCursor:endCursor},
                    error: function (request, message) {
                        console.log(request.responseJSON.message);
                        alert("Samsara error: " + request.responseJSON.message);
                    },
                    success: function(response) {
                        if(response.endCursor){
                            $(".load-more-driver").val(response.endCursor);
                        }else{
                            $(".load-more-driver").hide();
                        }
                        $(".append-syncDriver").append(response.view);
                        $(".loadingdiv").remove();
                    }
                });
            }

            function syncVehicles(samsara_api_key, endCursorVehicles) {

                $("#teamsTablevihical").after('<div class="loadingdiv loadingvihical"><img src="'+loadimg+'" /></div>');

                var token = $('meta[name="csrf-token"]').attr('content');
                $.ajax({
                    url: "{{ route('company.admin.app-settings.sync.vehicles') }}",
                    method: "POST",
                    data: { _token : token , samsara_api_key:samsara_api_key, endCursorVehicles:endCursorVehicles},
                    error: function (request, message) {
                        console.log(request.responseJSON.message);
                        alert("Samsara error: " + request.responseJSON.message);
                    },
                    success: function(response) {
                        if(response.endCursorVehicles){
                            $(".load-more-vehicles").val(response.endCursorVehicles);
                        }else{
                            $(".load-more-vehicles").hide();
                        }
                        $(".append-syncVehicles").append(response.view);
                        $(".loadingvihical").remove();
                    }
                });
            }

            function syncTrailers(samsara_api_key, endCursorTrailers) {

                $("#teamsTabletrailers").after('<div class="loadingdiv loadingtrailer"><img src="'+loadimg+'" /></div>');

                var token = $('meta[name="csrf-token"]').attr('content');
                $.ajax({
                    url: "{{ route('company.admin.app-settings.sync.trailers') }}",
                    method: "POST",
                    data: { _token : token , samsara_api_key:samsara_api_key, endCursorTrailers:endCursorTrailers},
                    error: function (request, message) {
                        console.log(request.responseJSON.message);
                        alert("Samsara error: " + request.responseJSON.message);
                    },
                    success: function(response) {
                        if(response.endCursorTrailers){
                            $(".load-more-trailers").val(response.endCursorTrailers);
                        }else{
                            $(".load-more-trailers").hide();
                        }
                        $(".append-syncTrailers").append(response.view);
                        $(".loadingtrailer").remove();
                    }
                });
            }

            function syncListingData(samsara_api_key, endCursor, isSyncDriver, isSyncVehicles, isSyncTrailers){
                if(isSyncDriver == '0' && isSyncVehicles == '0' && isSyncTrailers == '0'){
                    $('#listingView').addClass('d-none');
                }else{
                    $('#listingView').removeClass('d-none');

                    if((isSyncDriver == '1' && isSyncVehicles == '0' && isSyncTrailers == '0') || (isSyncDriver == '1' && isSyncVehicles == '1' && isSyncTrailers == '0') || (isSyncDriver == '1' && isSyncVehicles == '0' && isSyncTrailers == '1') || (isSyncDriver == '1' && isSyncVehicles == '1' && isSyncTrailers == '1')){
                        $("#Drivers-tab").trigger("click");
                    }else if((isSyncDriver == '0' && isSyncVehicles == '1' && isSyncTrailers == '0') || (isSyncDriver == '0' && isSyncVehicles == '1' && isSyncTrailers == '1')){
                        $("#Vehicles-tab").trigger("click");
                    }else if(isSyncDriver == '0' && isSyncVehicles == '0' && isSyncTrailers == '1'){
                        $("#Trailers-tab").trigger("click");
                    }

                    if(isSyncDriver == '1'){
                        $('#Drivers-tab').removeClass('d-none');
                        syncDriver(samsara_api_key, endCursor);
                    }else{
                        $('#Drivers-tab').addClass('d-none');
                    }

                    if(isSyncVehicles == '1'){
                        $('#Vehicles-tab').removeClass('d-none');
                        syncVehicles(samsara_api_key, endCursor);
                    }else{
                        $('#Vehicles-tab').addClass('d-none');
                    }

                    if(isSyncTrailers == '1'){
                        $('#Trailers-tab').removeClass('d-none');
                        syncTrailers(samsara_api_key, endCursor);
                    }else{
                        $('#Trailers-tab').addClass('d-none');
                    }
                }
            }
        @endif

        $(function (){
            $(document).on('click', '.add-more', function (){
                let moreSamsaraIntegrationHtml = '';

                moreSamsaraIntegrationHtml += '{!! Form::open(array('route' => 'company.admin.integration.save', 'method'=>'POST', 'files'=>'true', 'class'=>'store-form mt-3', 'autocomplete' => 'off')) !!}';
                moreSamsaraIntegrationHtml += '<input type="hidden" name="app_center_id" value="{{ $app->id }}">';
                moreSamsaraIntegrationHtml += '<div class="row align-items-center">';
                moreSamsaraIntegrationHtml += '<div class="col-md-5">';
                moreSamsaraIntegrationHtml += '<div class="form-group">';
                moreSamsaraIntegrationHtml += '<label>Carrier<span>*</span></label>';
                moreSamsaraIntegrationHtml += '{!! Form::select('carrier_id', ['' => 'Select Carrier']+getCarrierList(), null, ['class' => 'form-control select2', 'required' => 'required', 'data-parsley-errors-container' => '#carrier-errors']) !!}';
                moreSamsaraIntegrationHtml += '<div id="carrier-errors"></div>';
                moreSamsaraIntegrationHtml += '</div>';
                moreSamsaraIntegrationHtml += '</div>';
                moreSamsaraIntegrationHtml += '<div class="col-md-6">';
                moreSamsaraIntegrationHtml += '<div class="form-group">';
                moreSamsaraIntegrationHtml += '<label>API key<span>*</span></label>';
                moreSamsaraIntegrationHtml += '{!! Form::text('api_key', old('api_key'), array('class' => 'form-control', 'placeholder' => 'ex. samsara_api_xxxxxxx', 'rows' => '4', 'required' => 'required')) !!}';
                moreSamsaraIntegrationHtml += '</div>';
                moreSamsaraIntegrationHtml += '</div>';
                moreSamsaraIntegrationHtml += '<div class="col-md-1">';
                moreSamsaraIntegrationHtml += '<div class="form-group mb-0">';
                moreSamsaraIntegrationHtml += '<a href="javascript:void(0);" class="remove-more"><i class="fa fa-minus-square"></i></a>';
                moreSamsaraIntegrationHtml += '</div>';
                moreSamsaraIntegrationHtml += '</div>';
                moreSamsaraIntegrationHtml += '<div class="col-md-5">';
                moreSamsaraIntegrationHtml += '<div class="check-list mb-0">';
                moreSamsaraIntegrationHtml += ' <ul class="d-inline-flex">';
                moreSamsaraIntegrationHtml += '<li class="mr-3">';
                moreSamsaraIntegrationHtml += '<div class="form-check">';
                moreSamsaraIntegrationHtml += '{!! Form::checkbox('sync_drivers', 1, null, array('class' => 'form-check-input d-none', 'id' => 'sync_drivers')) !!}';
                moreSamsaraIntegrationHtml += '<label class="form-check-label" for="sync_drivers">';
                moreSamsaraIntegrationHtml += 'Sync Drivers';
                moreSamsaraIntegrationHtml += '</label>';
                moreSamsaraIntegrationHtml += '</div>';
                moreSamsaraIntegrationHtml += '</li>';
                moreSamsaraIntegrationHtml += '<li class="mr-3">';
                moreSamsaraIntegrationHtml += '<div class="form-check">';
                moreSamsaraIntegrationHtml += '{!! Form::checkbox('sync_vehicles', 1, null, array('class' => 'form-check-input d-none', 'id' => 'sync_vehicles')) !!}';
                moreSamsaraIntegrationHtml += '<label class="form-check-label" for="sync_vehicles">';
                moreSamsaraIntegrationHtml += 'Sync Vehicles';
                moreSamsaraIntegrationHtml += '</label>';
                moreSamsaraIntegrationHtml += '</div>';
                moreSamsaraIntegrationHtml += '</li>';
                moreSamsaraIntegrationHtml += '<li class="mr-3">';
                moreSamsaraIntegrationHtml += '<div class="form-check">';
                moreSamsaraIntegrationHtml += '{!! Form::checkbox('sync_trailers', 1, null, array('class' => 'form-check-input d-none', 'id' => 'sync_trailers')) !!}';
                moreSamsaraIntegrationHtml += '<label class="form-check-label" for="sync_trailers">';
                moreSamsaraIntegrationHtml += 'Sync Trailers';
                moreSamsaraIntegrationHtml += '</label>';
                moreSamsaraIntegrationHtml += '</div>';
                moreSamsaraIntegrationHtml += '</li>';
                moreSamsaraIntegrationHtml += '</ul>';
                moreSamsaraIntegrationHtml += '</div>';
                moreSamsaraIntegrationHtml += '</div>';
                moreSamsaraIntegrationHtml += '<div class="col-md-6 text-md-right">';
                moreSamsaraIntegrationHtml += '<button class="btn btn-success">Save Settings</button>';
                moreSamsaraIntegrationHtml += '</div>';
                moreSamsaraIntegrationHtml += '</div>';
                moreSamsaraIntegrationHtml += '{!! Form::close() !!}';

                $('#moreSamsaraIntegration').append(moreSamsaraIntegrationHtml);
            });
            $(document).on('click', '.remove-more', function () {
                $(this).closest('.store-form').remove();
            });

            @if(count($integrationSettings) > 0)
                var samsara_api_key = $('#carrier-sync').val();
                var isSyncDriver = $('#carrier-sync').find(':selected').attr('data-sync-drivers');
                var isSyncVehicles = $('#carrier-sync').find(':selected').attr('data-sync-vehicles');
                var isSyncTrailers = $('#carrier-sync').find(':selected').attr('data-sync-trailers');
                var integrationSettings = $.parseJSON('{!! json_encode($integrationSettings) !!}');

                syncListingData(samsara_api_key, '', isSyncDriver, isSyncVehicles, isSyncTrailers);

                $(document).on("click",".load-more-driver",function(e){
                    var endCursor = $('.load-more-driver').val();
                    syncDriver(samsara_api_key,endCursor);
                });
                $(document).on("keyup", "#serchboxDriver", function() {
                var value = $(this).val().toLowerCase();
                $(".append-syncDriver tr").filter(function() {
                    $(this).toggle($(this).text().toLowerCase().indexOf(value) > -1)
                });
            });

                $(document).on("click",".load-more-vehicles",function(e){
                    var endCursorVehicles = $('.load-more-vehicles').val();
                    syncVehicles(samsara_api_key,endCursorVehicles);
                });
                $(document).on("keyup", "#serchboxVihical", function() {
                var value = $(this).val().toLowerCase();
                $(".append-syncVehicles tr").filter(function() {
                    $(this).toggle($(this).text().toLowerCase().indexOf(value) > -1)
                });
            });

                $(document).on("click",".load-more-trailers",function(e){
                    var endCursorTrailers = $('.load-more-trailers').val();
                    syncTrailers(samsara_api_key,endCursorTrailers);
                });
                $(document).on("keyup", "#serchboxTrailers", function() {
                    var value = $(this).val().toLowerCase();
                    $(".append-syncTrailers tr").filter(function() {
                        $(this).toggle($(this).text().toLowerCase().indexOf(value) > -1)
                    });
                });

                $(document).on('change', '#carrier-sync', function () {
                    var samsara_api_key = $(this).val();
                    var isSyncDriver = $(this).find(':selected').attr('data-sync-drivers');
                    var isSyncVehicles = $(this).find(':selected').attr('data-sync-vehicles');
                    var isSyncTrailers = $(this).find(':selected').attr('data-sync-trailers');

                    $('.append-syncDriver, .append-syncVehicles, .append-syncTrailers').html('');

                    syncListingData(samsara_api_key, '', isSyncDriver, isSyncVehicles, isSyncTrailers);
                });
                $(document).on("click", "#sync-drivers", function() {
                    let url = ''; let i = 0;

                    loader();
                    setTimeout(function(){
                        $.each(integrationSettings, function (key, val){
                            if(val.sync_drivers == '1'){
                                url = '{{ route('company.admin.samsara.sync.syncdriverbyajax', ['samsara_api_key' => ':apiKey', 'endCursor' => '0']) }}';
                                url = url.replace(':apiKey', val.api_key);

                                $.ajax({
                                    url: url,
                                    method: 'GET',
                                    dataType: 'json',
                                    async: false,
                                });
                            }
                            i++;
                        });

                        if(i == integrationSettings.length){
                            Swal.close();
                            toastr.success('Drivers synchronize successfully.', 'Success Alert', {timeOut: 5000});
                        }
                    }, 1000);
                });
                $(document).on("click", "#sync-vehicles", function() {
                    let url = ''; let i = 0;

                    loader();
                    setTimeout(function(){
                        $.each(integrationSettings, function (key, val){
                            if(val.sync_vehicles == '1'){
                                url = '{{ route('company.admin.samsara.sync.syncvehiclesbyajax', ['samsara_api_key' => ':apiKey', 'endCursor' => '0']) }}';
                                url = url.replace(':apiKey', val.api_key);

                                $.ajax({
                                    url: url,
                                    method: 'GET',
                                    dataType: 'json',
                                    async: false,
                                });
                            }
                            i++;
                        });

                        if(i == integrationSettings.length){
                            Swal.close();
                            toastr.success('Vehicles synchronize successfully.', 'Success Alert', {timeOut: 5000});
                        }
                    }, 1000);
                });
                $(document).on("click", "#sync-trailers", function() {
                    let url = ''; let i = 0;

                    loader();
                    setTimeout(function(){
                        $.each(integrationSettings, function (key, val){
                            if(val.sync_trailers == '1'){
                                url = '{{ route('company.admin.samsara.sync.synctrailersbyajax', ['samsara_api_key' => ':apiKey', 'endCursor' => '0']) }}';
                                url = url.replace(':apiKey', val.api_key);

                                $.ajax({
                                    url: url,
                                    method: 'GET',
                                    dataType: 'json',
                                    async: false,
                                });
                            }
                            i++;
                        });

                        if(i == integrationSettings.length){
                            Swal.close();
                            toastr.success('Trailers synchronize successfully.', 'Success Alert', {timeOut: 5000});
                        }
                    }, 1000);
                });
            @endif
        });
    </script>
@endsection
