<!DOCTYPE html>
<html lang="en">
    <head>
        <title>Map Demo</title>
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <meta name="csrf-token" content="{{ csrf_token() }}">
        <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@4.6.2/dist/css/bootstrap.min.css">
        <link rel="stylesheet" href="https://maps-sdk.trimblemaps.com/v3/trimblemaps-3.10.0.css" />
        <link rel="stylesheet" href="https://maps-sdk.trimblemaps.com/addon/trimblemaps-mapmenus-1.0.4.css" />
        <style type="text/css">
            .map-box {
                position: relative;
            }
            #map {
                position: absolute;
                top: 0;
                bottom: 0;
                width: 100%;
                height: 600px;
            }
        </style>
        <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.6.4/jquery.min.js"></script>
        <!-- <script src="https://cdn.jsdelivr.net/npm/jquery@3.6.4/dist/jquery.slim.min.js"></script> -->
        <script src="https://cdn.jsdelivr.net/npm/popper.js@1.16.1/dist/umd/popper.min.js"></script>
        <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.2/dist/js/bootstrap.bundle.min.js"></script>
        <script src="https://maps-sdk.trimblemaps.com/v3/trimblemaps-3.10.0.js"></script>
        <script src="https://maps-sdk.trimblemaps.com/addon/trimblemaps-mapmenus-1.0.4.js"></script>
    </head>
    <body>
        <div class="jumbotron text-center">
            <h1>Live Feature Update</h1>
            <p>Shows the progression of a GPS track by adding new GPS points to a feature in a line layer. This feature could be used for visualizing real-time data sources.</p>
        </div>
        <div class="container-fluid">
            <div class="row">
                <div class="col-md-12">
                    <div class="map-box">
                        <div id="map"></div>
                    </div>
                </div>
            </div>
        </div>
        <!-- <script>
            TrimbleMaps.APIKey          = '83FF948F08EB3C4BB97E3AED42BEF772';
            const map                   = new TrimbleMaps.Map({
                container: 'map',
                style: TrimbleMaps.Common.Style.DATADARK,
                center: [-81.030593, 35.252706], // starting position
                zoom: 6
            });

            mapMenusOptions             = {
                showContentLayers: true,
                showBaseStyles: true,
                showCustomStyles: false,
                showMobileStyles: false,
                hideStyles: ['Accessible Dark', 'Accessible Light', 'Basic'],
                hideLayers: ['3D Buildings','Weather Cloud'],
            };

            var ctrl                    = new TrimbleMapsControl.MapMenus(mapMenusOptions);

            // Map#addControl takes an optional second argument to set the position of the control.
            // If no position is specified the control defaults to `top-right`.
            map.addControl(ctrl, "top-right");

            map.addControl(new TrimbleMaps.NavigationControl({
                showCompass : false
            }));

            // If false, custom stop icons can be used, if other values, default icons and styles are used.
            const showDefaultStops      = true;

            const myRoute               = new TrimbleMaps.Route({
                routeId: 'myRoute',
                stops: [
                    new TrimbleMaps.LngLat(-81.030593, 35.252706),
                    new TrimbleMaps.LngLat(-95.567230, 29.634249),
                    new TrimbleMaps.LngLat(-93.225996, 44.083804),
                    new TrimbleMaps.LngLat(-77.657781, 39.944360),
                    new TrimbleMaps.LngLat(-78.942824, 38.357312)
                ],
                routeColor: '#888888',
                showStops: showDefaultStops
            });

            map.on('load', async () => {
                myRoute.addTo(map);

                const gpsTracksData = {
                    type: 'FeatureCollection',
                    features: [{
                        type: 'Feature',
                        properties: {},
                        geometry: {
                            type: 'Point',
                            coordinates: [
                                [-88.98068128, 42.5979444]
                            ]
                        }
                    }]
                };
                // Add GeoJSON data source to the map
                map.addSource('gpsTrack', { type: 'geojson', data: gpsTracksData });
                // Add a layer to draw line for each point in the data source
                map.addLayer({
                    'id': 'gpsTrack',
                    'type': 'line',
                    'source': 'gpsTrack',
                    'layout': {
                        'line-cap': 'round'
                    },
                    'paint': {
                        'line-color': '#005F9E',
                        'line-opacity': 0.6,
                        'line-width': 8
                    }
                });
                map.jumpTo({ 'center': [-88.98068128, 42.5979444], 'zoom': 10 });
                map.setPitch(40);

                // draw green truck at the start
                const point = {
                    'type': 'FeatureCollection',
                    'features': [{
                        'type': 'Feature',
                        'properties': {},
                        'geometry': {
                            'type': 'Point',
                            'coordinates': [-88.98068128, 42.5979444]
                        }
                    }]
                };
                map.addSource('point', {
                    type: 'geojson',
                    data: point
                });
                map.addLayer({
                    'id': 'point',
                    'source': 'point',
                    'type': 'symbol',
                    'layout': {
                        'icon-image': 'truck-outline-green',
                        'icon-size': 1,
                        'icon-allow-overlap' : true
                    },
                    'paint': {
                        'icon-opacity': 1
                    }
                });

                // draw gps track
                let i       = 0;
                const timer = setInterval(() => {
                    $.ajax({
                        type: 'POST',
                        url: "{{ route('company.admin.truck.get.current.location') }}",
                        data: {
                            id: 2
                        },
                        dataType: 'json',
                        headers: {
                            'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                        },
                        // async: false,
                        success: function(response) {
                            if(response.success){
                                if(response.location && !$.isEmptyObject(response.location)){
                                    gpsTracksData.features[0].geometry.coordinates.push([response.location.longitude, response.location.latitude]);
                                    map.getSource('gpsTrack').setData(gpsTracksData);
                                    map.panTo([response.location.longitude, response.location.latitude]);
                                }
                            }
                        }
                    });
                    i++;
                }, 15000);
            });
        </script> -->
        <script>
            TrimbleMaps.APIKey          = '83FF948F08EB3C4BB97E3AED42BEF772';
            const map                   = new TrimbleMaps.Map({
                container: 'map',
                style: TrimbleMaps.Common.Style.DATADARK,
                center: [-117.918511, 33.799693], // starting position
                zoom: 6
            });

            const coordinates           = [
              [-117.91851166666666,33.79969333333333],
              [-117.91834,33.799685],
              [-117.91813166666667,33.79972166666667],
              [-117.91802166666666,33.799746666666664],
              [-117.917905,33.79976166666667],
              [-117.91769,33.799775],
              [-117.91748166666666,33.79980166666667],
              [-117.917245,33.79980333333334],
              [-117.91701833333333,33.79980666666667],
              [-117.91682333333333,33.79978666666667],
              [-117.91670333333333,33.799745],
              [-117.916655,33.79972333333333],
              [-117.91645833333334,33.79967666666667],
              [-117.91612666666667,33.79967333333333],
              [-117.91576166666667,33.79967166666667],
              [-117.91557,33.79967666666667],
              [-117.91546166666667,33.79967666666667],
              [-117.91528,33.79970333333333],
              [-117.91512,33.79983166666667],
              [-117.91511166666666,33.800065000000004],
              [-117.91512333333333,33.80038666666667],
              [-117.915125,33.800776666666664],
              [-117.91513666666667,33.80119333333333],
              [-117.91515166666667,33.801588333333335],
              [-117.91514666666667,33.801986666666664],
              [-117.915105,33.80225],
              [-117.91510333333333,33.80243166666666],
              [-117.91511,33.802503333333334],
              [-117.91509,33.802573333333335],
              [-117.915105,33.80264833333333],
              [-117.91511,33.80273833333333],
              [-117.91511666666666,33.80285],
              [-117.91513833333333,33.802995],
              [-117.91514333333333,33.803065],
              [-117.91510833333334,33.80313833333334],
              [-117.91487166666667,33.803216666666664],
              [-117.91448666666666,33.80323333333333],
              [-117.91397666666667,33.80325833333333],
              [-117.91342333333333,33.803265],
              [-117.91291333333334,33.803268333333335],
              [-117.91242666666666,33.803263333333334],
              [-117.91198833333333,33.80325],
              [-117.91152666666666,33.803248333333336],
              [-117.91113333333334,33.803246666666666],
              [-117.91084,33.80325166666667],
              [-117.91064666666666,33.803255],
              [-117.91050333333334,33.803255],
              [-117.91036166666666,33.803268333333335],
              [-117.91011333333333,33.80328166666666],
              [-117.90972,33.803275],
              [-117.90919166666667,33.803285],
              [-117.90864666666667,33.803308333333334],
              [-117.90811166666667,33.803313333333335],
              [-117.90757333333333,33.80331833333334],
              [-117.90719,33.803335],
              [-117.90702166666667,33.803335],
              [-117.906945,33.80331666666667],
              [-117.906725,33.80334],
              [-117.906545,33.803518333333336],
              [-117.90650833333333,33.80383],
              [-117.90645333333333,33.804228333333334],
              [-117.90639333333333,33.80466666666667],
              [-117.90634,33.805033333333334],
              [-117.90631833333333,33.80528],
              [-117.90630666666667,33.80557],
              [-117.90627666666667,33.80584666666667],
              [-117.90624333333334,33.80622],
              [-117.90623333333333,33.806345],
              [-117.90612166666666,33.80701333333333],
              [-117.90614833333333,33.80721],
              [-117.90634166666666,33.80746],
              [-117.90668,33.80775166666667],
              [-117.90706166666666,33.80807],
              [-117.90751333333333,33.808416666666666],
              [-117.90799166666666,33.80881],
              [-117.90846833333333,33.80926],
              [-117.90893833333334,33.809685],
              [-117.90940833333333,33.81010333333333],
              [-117.90988833333333,33.810541666666666],
              [-117.91041,33.81102166666667],
              [-117.91094166666667,33.81154166666666],
              [-117.91149,33.81207333333333],
              [-117.91205,33.81261666666666],
              [-117.91262666666667,33.81317833333333],
              [-117.9132,33.813735],
              [-117.91377833333334,33.814283333333336],
              [-117.914385,33.814838333333334],
              [-117.91501666666667,33.81543833333333],
              [-117.91563333333333,33.81604333333333],
              [-117.91633333333333,33.816695],
              [-117.91700833333333,33.81735666666667],
              [-117.91767333333334,33.818],
              [-117.91833,33.81863833333333],
              [-117.91896666666666,33.819253333333336],
              [-117.91957,33.819855],
              [-117.92011666666667,33.82037666666667],
              [-117.92068333333333,33.82091666666667],
              [-117.92131833333333,33.821513333333336],
              [-117.92199166666667,33.82217166666667],
              [-117.922695,33.82286666666667],
              [-117.92336833333333,33.82358833333333],
              [-117.92397166666666,33.82434166666667],
              [-117.92458,33.82510166666667],
              [-117.92516833333333,33.82584833333333],
              [-117.92576333333334,33.82657],
              [-117.92642666666667,33.827261666666665],
              [-117.92711833333334,33.827931666666665],
              [-117.92780333333333,33.828585],
              [-117.928505,33.829231666666665],
              [-117.92915833333333,33.82985],
              [-117.92982,33.830463333333334],
              [-117.93046,33.83107],
              [-117.93109666666666,33.83166333333333],
              [-117.93176166666667,33.832278333333335],
              [-117.93249,33.83282166666667],
              [-117.93326,33.833305],
              [-117.934115,33.833731666666665],
              [-117.93500166666666,33.834088333333334],
              [-117.93596333333333,33.83437],
              [-117.936895,33.834588333333336],
              [-117.93781666666666,33.83479833333333],
              [-117.93869666666667,33.835013333333336],
              [-117.93958333333333,33.83523],
              [-117.94042,33.835496666666664],
              [-117.94124333333333,33.835838333333335],
              [-117.94207333333334,33.83621333333333],
              [-117.94284999999999,33.836666666666666],
              [-117.94365666666667,33.83707833333333],
              [-117.94445333333333,33.83752166666667],
              [-117.94528166666667,33.837985],
              [-117.94613,33.83843666666667],
              [-117.94691333333333,33.83886],
              [-117.94766333333334,33.83928],
              [-117.94838166666666,33.839661666666665],
              [-117.94908166666667,33.840046666666666],
              [-117.949805,33.84043666666667],
              [-117.95054833333333,33.840848333333334],
              [-117.95135166666667,33.841298333333334],
              [-117.952195,33.84175333333334],
              [-117.95302,33.842195],
              [-117.95384166666666,33.84264833333334],
              [-117.95465333333334,33.84310166666667],
              [-117.95541166666666,33.84357166666667],
              [-117.95616166666667,33.84406333333333],
              [-117.95687,33.844543333333334],
              [-117.95761,33.845011666666664],
              [-117.95838833333333,33.845455],
              [-117.959185,33.845866666666666],
              [-117.96000666666667,33.84625333333334],
              [-117.96079833333333,33.84663166666667],
              [-117.96166,33.84706333333333],
              [-117.96249,33.84749166666667],
              [-117.96325666666667,33.84793666666667],
              [-117.96405,33.84833833333333],
              [-117.96483166666667,33.84871166666667],
              [-117.96558166666667,33.84908166666666],
              [-117.966335,33.84945333333334],
              [-117.96704166666666,33.84981166666667],
              [-117.96770166666667,33.850163333333334],
              [-117.96837666666667,33.85051833333333],
              [-117.96905,33.850881666666666],
              [-117.96973166666666,33.851245],
              [-117.97047166666667,33.85161],
              [-117.97123833333333,33.851995],
              [-117.97201333333334,33.8524],
              [-117.97279166666667,33.85284],
              [-117.97354333333334,33.8533],
              [-117.97423,33.853785],
              [-117.97486,33.854231666666664],
              [-117.975485,33.85465333333333],
              [-117.976135,33.85510166666667],
              [-117.97677666666667,33.85559],
              [-117.97745666666667,33.85608],
              [-117.978115,33.856535],
              [-117.97880666666667,33.856968333333334],
              [-117.97963166666666,33.857245],
              [-117.98045,33.85738666666666],
              [-117.981285,33.857441666666666],
              [-117.98213666666666,33.85736833333333],
              [-117.98297666666667,33.85717666666667],
              [-117.98380833333333,33.856903333333335],
              [-117.98463166666667,33.85663],
              [-117.985505,33.856406666666665],
              [-117.98644333333333,33.856255],
              [-117.98742666666666,33.85617333333333],
              [-117.988445,33.856155],
              [-117.98942666666667,33.856145],
              [-117.99038666666667,33.856136666666664],
              [-117.99135666666666,33.856141666666666],
              [-117.99229666666666,33.856141666666666],
              [-117.993265,33.856138333333334],
              [-117.994225,33.85612833333333],
              [-117.99516666666666,33.856118333333335],
              [-117.99613166666667,33.85611333333333],
              [-117.99709833333333,33.85611333333333],
              [-117.99803166666666,33.856115],
              [-117.99896333333334,33.856105],
              [-117.99984333333333,33.856095],
              [-118.00068,33.856093333333334],
              [-118.001545,33.85608833333333],
              [-118.002405,33.85608],
              [-118.00332166666666,33.85607],
              [-118.00425,33.85605833333334],
              [-118.00517833333333,33.85603666666667],
              [-118.00608833333334,33.856035],
              [-118.00700333333333,33.85604166666667],
              [-118.00793166666666,33.85603833333333],
              [-118.00889166666667,33.85603],
              [-118.009795,33.856025],
              [-118.010635,33.85601666666667],
              [-118.011425,33.85601666666667],
              [-118.01222166666666,33.856015],
              [-118.01302333333334,33.85601333333334],
              [-118.013785,33.856003333333334],
              [-118.014625,33.856003333333334],
              [-118.015515,33.856006666666666],
              [-118.01641,33.856005],
              [-118.01728166666666,33.85599833333333],
              [-118.01814166666666,33.856003333333334],
              [-118.01904,33.85599833333333],
              [-118.019935,33.85597666666666],
              [-118.020835,33.855965],
              [-118.021735,33.85596],
              [-118.02264333333333,33.85596],
              [-118.02357,33.855956666666664],
              [-118.02453666666666,33.85599833333333],
              [-118.02549166666667,33.85608333333333],
              [-118.02639833333333,33.85621],
              [-118.02720833333333,33.856361666666665],
              [-118.02794833333333,33.856535],
              [-118.02866666666667,33.85673833333333],
              [-118.02940333333333,33.856985],
              [-118.03009333333334,33.85724333333334],
              [-118.03080833333334,33.85753833333333],
              [-118.03151,33.857825],
              [-118.03218833333334,33.858115],
              [-118.03284166666667,33.858396666666664],
              [-118.03348666666666,33.858670000000004],
              [-118.03413166666667,33.85893333333333],
              [-118.03474,33.859181666666665],
              [-118.035305,33.859408333333334],
              [-118.03590666666666,33.859645],
              [-118.03654833333333,33.859901666666666],
              [-118.03718833333333,33.86017833333333],
              [-118.03788666666667,33.86047],
              [-118.03860833333333,33.86076],
              [-118.03931,33.861055],
              [-118.03999333333333,33.86132333333333],
              [-118.04068,33.861608333333336],
              [-118.041365,33.86189],
              [-118.04207833333334,33.86219166666667],
              [-118.04282833333333,33.86248833333333],
              [-118.04358,33.86280333333333],
              [-118.04429,33.86309333333333],
              [-118.04491,33.863365],
              [-118.04545,33.86362166666667],
              [-118.04597833333334,33.86388],
              [-118.04650666666667,33.864158333333336],
              [-118.04703166666667,33.86445666666667],
              [-118.04755166666666,33.86477],
              [-118.04807333333333,33.86507833333334],
              [-118.04860333333333,33.86541833333333],
              [-118.04914333333333,33.86577833333333],
              [-118.049645,33.86611666666667],
              [-118.05013166666667,33.86643333333333],
              [-118.05057666666667,33.86674166666667],
              [-118.05102,33.867023333333336],
              [-118.05143833333334,33.86732666666666],
              [-118.05187666666667,33.86761],
              [-118.05234166666666,33.867914999999996],
              [-118.052855,33.868246666666664],
              [-118.05340833333334,33.868626666666664],
              [-118.05398,33.86901666666667],
              [-118.05456666666667,33.86941],
              [-118.05513833333333,33.869805],
              [-118.05569333333334,33.870196666666665],
              [-118.05624333333333,33.87055333333333],
              [-118.05679166666667,33.87092],
              [-118.057335,33.87128],
              [-118.057885,33.871651666666665],
              [-118.05840833333333,33.872013333333335],
              [-118.05896,33.87237833333333],
              [-118.05955166666666,33.87277666666667],
              [-118.060155,33.87318166666667],
              [-118.06074,33.87356666666667],
              [-118.0613,33.873938333333335],
              [-118.06186166666667,33.874295000000004],
              [-118.06242,33.874658333333336],
              [-118.062955,33.87496333333333],
              [-118.063485,33.875235],
              [-118.06399333333333,33.87548],
              [-118.064505,33.87568],
              [-118.06504,33.875885],
              [-118.06550333333334,33.876025],
              [-118.06597666666667,33.876131666666666],
              [-118.06655166666667,33.87625833333333],
              [-118.06712333333333,33.876351666666665],
              [-118.06767833333333,33.87642833333334],
              [-118.06824333333333,33.87649833333333],
              [-118.06884166666667,33.876533333333334],
              [-118.069415,33.87653666666667],
              [-118.06995666666667,33.87652666666666],
              [-118.07048833333333,33.87652666666666],
              [-118.07105,33.87653],
              [-118.07157166666667,33.87652833333333],
              [-118.07206333333333,33.87653],
              [-118.072535,33.876515],
              [-118.07299666666667,33.876513333333335],
              [-118.07350833333334,33.87651833333334],
              [-118.07405833333334,33.87651666666667],
              [-118.07469333333333,33.87651833333334],
              [-118.075455,33.87652333333333],
              [-118.07626333333333,33.87651],
              [-118.07716,33.87649666666667],
              [-118.07806333333333,33.876486666666665],
              [-118.07897833333334,33.87647333333334],
              [-118.079885,33.87647666666667],
              [-118.08077833333333,33.87648],
              [-118.081705,33.87647833333333],
              [-118.08263833333334,33.87647166666667],
              [-118.08357,33.876465],
              [-118.08450666666667,33.876463333333334],
              [-118.08549166666667,33.876465],
              [-118.08652333333333,33.87646],
              [-118.08756166666667,33.876461666666664],
              [-118.088585,33.876461666666664],
              [-118.08960166666667,33.87645833333333],
              [-118.090615,33.87645],
              [-118.09163833333334,33.876446666666666],
              [-118.09268666666667,33.876445],
              [-118.09372666666667,33.87643833333333],
              [-118.094775,33.876441666666665],
              [-118.095825,33.87642833333334],
              [-118.09685666666667,33.87642666666667],
              [-118.09790833333334,33.8764],
              [-118.09893,33.87641833333333],
              [-118.09994,33.876423333333335],
              [-118.10091666666666,33.87641166666667],
              [-118.10186833333333,33.876405],
              [-118.10281833333333,33.87640666666667],
              [-118.10375666666667,33.87641166666667],
              [-118.104705,33.87641333333333],
              [-118.105635,33.87645333333333],
              [-118.1065,33.87654666666667],
              [-118.10732166666666,33.87666],
              [-118.10815166666667,33.876776666666665],
              [-118.108955,33.876893333333335],
              [-118.10972,33.876981666666666],
              [-118.11049,33.877021666666664],
              [-118.11131666666667,33.87703666666667],
              [-118.11221,33.87701666666667],
              [-118.11313333333334,33.87692],
              [-118.11407666666666,33.87679333333333],
              [-118.11502166666666,33.87665],
              [-118.115955,33.87651],
              [-118.116885,33.87636833333333],
              [-118.11781166666667,33.87628333333333],
              [-118.11872666666666,33.87624],
              [-118.11962833333334,33.876235],
              [-118.12049833333333,33.876235],
              [-118.121345,33.87623166666667],
              [-118.12222333333334,33.87622666666667],
              [-118.12310166666667,33.87622],
              [-118.12398666666667,33.876216666666664],
              [-118.12482,33.87622833333333],
              [-118.12562,33.876223333333336],
              [-118.126485,33.876223333333336],
              [-118.127345,33.876225],
              [-118.12816833333333,33.876223333333336],
              [-118.12895166666667,33.876203333333336],
              [-118.12975333333333,33.876245],
              [-118.13057333333333,33.876331666666665],
              [-118.13137,33.876488333333334],
              [-118.13214333333333,33.876705],
              [-118.13293,33.87693],
              [-118.13377166666666,33.877111666666664],
              [-118.13460666666667,33.87721],
              [-118.13547666666666,33.877235],
              [-118.13634666666667,33.87723],
              [-118.13718,33.877226666666665],
              [-118.13801166666667,33.87721],
              [-118.138815,33.877183333333335],
              [-118.139665,33.87717166666667],
              [-118.14041,33.877203333333334],
              [-118.14121333333334,33.877176666666664],
              [-118.14206,33.877175],
              [-118.14295666666666,33.87716],
              [-118.14382166666667,33.87716],
              [-118.14473,33.87713],
              [-118.14564333333334,33.87712166666667],
              [-118.14651333333333,33.87712333333333],
              [-118.14735333333333,33.87710666666667],
              [-118.14815833333333,33.87708333333333],
              [-118.14901333333333,33.87708666666666],
              [-118.14986666666667,33.877085],
              [-118.150705,33.87707833333333],
              [-118.15154166666666,33.877065],
              [-118.15243166666667,33.877068333333334],
              [-118.15335333333333,33.877065],
              [-118.15426666666667,33.877055],
              [-118.15521333333334,33.877026666666666],
              [-118.15618333333333,33.87693],
              [-118.15716833333333,33.87674833333333],
              [-118.15813166666666,33.876525],
              [-118.15907333333334,33.87630166666667],
              [-118.16005333333334,33.87614333333333],
              [-118.16104666666666,33.87605833333333],
              [-118.16204833333333,33.87604833333333],
              [-118.16303666666667,33.876041666666666],
              [-118.16404333333334,33.87603166666667],
              [-118.16499333333333,33.87602],
              [-118.16596666666666,33.87601333333333],
              [-118.166945,33.876015],
              [-118.16792,33.87602166666667],
              [-118.16890666666667,33.876105],
              [-118.16988666666667,33.876263333333334],
              [-118.17086333333333,33.87647],
              [-118.17183666666666,33.876685],
              [-118.17280833333334,33.87683666666667],
              [-118.17375166666666,33.876918333333336],
              [-118.17468,33.87692333333333],
              [-118.17559166666666,33.87692666666667],
              [-118.17656333333333,33.87694833333333],
              [-118.17751333333334,33.876945],
              [-118.17844833333334,33.87694833333333],
              [-118.17930666666666,33.87696],
              [-118.18012333333333,33.876961666666666],
              [-118.180955,33.87697166666667],
              [-118.18181166666666,33.876978333333334],
              [-118.18256333333333,33.87699166666667],
              [-118.18333166666666,33.877008333333336],
              [-118.18411666666667,33.87703166666667],
              [-118.18491333333333,33.87703166666667],
              [-118.18564666666667,33.87703666666667],
              [-118.18631333333333,33.87705166666667],
              [-118.18702,33.877093333333335],
              [-118.18777666666666,33.87713166666666],
              [-118.18840166666666,33.87715166666667],
              [-118.18904166666667,33.877195],
              [-118.18974666666666,33.87726],
              [-118.19037166666666,33.87735833333333],
              [-118.1909,33.87758],
              [-118.191335,33.87791333333333],
              [-118.191655,33.87835333333334],
              [-118.19181333333333,33.87885],
              [-118.19175,33.87941166666667],
              [-118.19164,33.880066666666664],
              [-118.19151833333333,33.880775],
              [-118.191385,33.8815],
              [-118.19123166666667,33.88223],
              [-118.19106833333333,33.88291666666667],
              [-118.190915,33.883633333333336],
              [-118.19067166666666,33.88433],
              [-118.19038166666667,33.88501333333333],
              [-118.190065,33.88572666666666],
              [-118.18972166666667,33.886448333333334],
              [-118.18940166666667,33.88716],
              [-118.18916333333334,33.887885],
              [-118.18894,33.88860666666667],
              [-118.188665,33.88942333333333],
              [-118.18845833333333,33.89022333333333],
              [-118.18827,33.89100666666667],
              [-118.18811,33.891801666666666],
              [-118.18797666666667,33.89263666666667],
              [-118.18784166666667,33.89346666666667],
              [-118.187725,33.89429],
              [-118.18759666666666,33.895118333333336],
              [-118.18747166666667,33.89595833333333],
              [-118.18734666666667,33.89675166666667],
              [-118.18723166666666,33.8975],
              [-118.18710333333334,33.89830333333333],
              [-118.18697833333333,33.899103333333336],
              [-118.186835,33.89989833333333],
              [-118.186625,33.90069333333334],
              [-118.18638,33.901473333333335],
              [-118.18607166666666,33.902265],
              [-118.18570166666666,33.90300666666667],
              [-118.18526666666666,33.90371666666667],
              [-118.18469666666667,33.904363333333336],
              [-118.18408666666667,33.90501166666667],
              [-118.183465,33.90563],
              [-118.18281833333333,33.906295],
              [-118.18221833333334,33.90696],
              [-118.18167833333334,33.90767],
              [-118.18120333333333,33.908433333333335],
              [-118.18083666666666,33.909213333333334],
              [-118.18053833333333,33.91003],
              [-118.18034333333334,33.91084],
              [-118.18018000000001,33.91164333333333],
              [-118.18000666666667,33.912441666666666],
              [-118.17985333333333,33.91323333333333],
              [-118.17967666666667,33.91397333333333],
              [-118.17952,33.91475833333333],
              [-118.179345,33.915501666666664],
              [-118.17919499999999,33.91630166666667],
              [-118.17903,33.917073333333335],
              [-118.17888333333333,33.917811666666665],
              [-118.17874333333333,33.91858],
              [-118.178595,33.91938666666667],
              [-118.17842166666667,33.92022166666667],
              [-118.17825166666667,33.92108],
              [-118.178085,33.921905],
              [-118.177915,33.92272833333333],
              [-118.17776,33.92351333333333],
              [-118.177665,33.92427333333333],
              [-118.17765833333333,33.925023333333336],
              [-118.17773166666667,33.925761666666666],
              [-118.17790333333333,33.92648833333333],
              [-118.17813,33.92724],
              [-118.178415,33.927978333333336],
              [-118.17865,33.92875333333333],
              [-118.17877166666666,33.929536666666664],
              [-118.17879166666667,33.93029666666666],
              [-118.17871,33.93105333333333],
              [-118.17849,33.93181333333333],
              [-118.17818166666666,33.93256],
              [-118.17778666666666,33.93327166666667],
              [-118.177295,33.93392166666667],
              [-118.17671333333334,33.934538333333336],
              [-118.17606166666667,33.935085],
              [-118.175365,33.935583333333334],
              [-118.17468333333333,33.936055],
              [-118.17399666666667,33.936525],
              [-118.173335,33.93704833333334],
              [-118.17277333333334,33.93760833333333],
              [-118.17229333333333,33.938203333333334],
              [-118.17186333333333,33.93883833333334],
              [-118.171555,33.939483333333335],
              [-118.17129833333334,33.940245],
              [-118.171165,33.941026666666666],
              [-118.17107166666666,33.94180333333333],
              [-118.17095666666667,33.942598333333336],
              [-118.17086666666667,33.943395],
              [-118.170775,33.944181666666665],
              [-118.17066666666666,33.94497166666667],
              [-118.17056166666667,33.94576333333333],
              [-118.17043833333334,33.946558333333336],
              [-118.17035,33.94734833333333],
              [-118.17027833333333,33.948115],
              [-118.170275,33.94893166666667],
              [-118.170325,33.94972166666667],
              [-118.17037666666667,33.95048833333333],
              [-118.17047166666667,33.95128],
              [-118.17052,33.952043333333336],
              [-118.17056333333333,33.95281333333333],
              [-118.17057,33.953601666666664],
              [-118.17056666666667,33.95435333333333],
              [-118.17054,33.95512],
              [-118.170515,33.955843333333334],
              [-118.17046166666667,33.95650833333333],
              [-118.17040666666666,33.95721666666667],
              [-118.170335,33.95795833333333],
              [-118.170245,33.958708333333334],
              [-118.17014666666667,33.959473333333335],
              [-118.17002166666667,33.96027333333333],
              [-118.1699,33.961075],
              [-118.169785,33.961845],
              [-118.16966,33.96259833333333],
              [-118.16947833333333,33.96335166666667],
              [-118.16919666666666,33.964085],
              [-118.16885,33.96478833333333],
              [-118.16847833333334,33.965515],
              [-118.16815,33.966258333333336],
              [-118.16789666666666,33.96697666666667],
              [-118.16773,33.967715],
              [-118.16756166666667,33.96909333333333],
              [-118.16755,33.96968],
              [-118.16756333333333,33.97013666666667],
              [-118.16758833333333,33.97047833333333],
              [-118.16761833333334,33.97075666666667],
              [-118.16766,33.97101333333333],
              [-118.16769666666667,33.97131],
              [-118.16774166666667,33.971653333333336],
              [-118.16778333333333,33.972075],
              [-118.16781666666667,33.972456666666666],
              [-118.16783333333333,33.972831666666664],
              [-118.16781666666667,33.973243333333336],
              [-118.16777833333333,33.97361333333333],
              [-118.16772666666667,33.973975],
              [-118.16767333333334,33.97434],
              [-118.16761333333334,33.974713333333334],
              [-118.16754833333333,33.97513333333333],
              [-118.16749166666666,33.97558],
              [-118.167435,33.97602166666667],
              [-118.16737833333333,33.976411666666664],
              [-118.16733833333333,33.976778333333336],
              [-118.16731,33.97712],
              [-118.1673,33.977466666666665],
              [-118.16728166666667,33.97783166666667],
              [-118.16727166666666,33.97820166666666],
              [-118.16728,33.978561666666664],
              [-118.167285,33.978876666666665],
              [-118.1673,33.97918333333333],
              [-118.16732666666667,33.97947],
              [-118.16735,33.979753333333335],
              [-118.16738833333334,33.98007166666667],
              [-118.16743333333334,33.98040833333334],
              [-118.16749333333334,33.980785],
              [-118.16757666666666,33.981184999999996],
              [-118.16764,33.98157833333333],
              [-118.16773833333333,33.98200833333333],
              [-118.16785166666666,33.982413333333334],
              [-118.16796333333333,33.98278666666667],
              [-118.16808666666667,33.983126666666664],
              [-118.168205,33.98345],
              [-118.16829833333334,33.983785],
              [-118.168435,33.984156666666664],
              [-118.168575,33.98453],
              [-118.168725,33.98491833333333],
              [-118.16890833333333,33.98534],
              [-118.16912666666667,33.985785],
              [-118.16937,33.986225],
              [-118.169615,33.986648333333335],
              [-118.169815,33.98695166666667],
              [-118.16998333333333,33.98722166666667],
              [-118.17011166666667,33.98741166666667],
              [-118.17025166666667,33.98762],
              [-118.170395,33.98781666666667],
              [-118.170545,33.98802833333333],
              [-118.17068333333333,33.98822666666667],
              [-118.17083833333334,33.98843333333333],
              [-118.17101666666667,33.98865333333333],
              [-118.17121833333333,33.988895],
              [-118.17143333333334,33.98914],
              [-118.171615,33.98934833333333],
              [-118.17180666666667,33.98957166666667],
              [-118.171995,33.989781666666666],
              [-118.17221166666667,33.98999166666667],
              [-118.17239833333333,33.990183333333334],
              [-118.172585,33.990345],
              [-118.17276,33.99050666666667],
              [-118.17297333333333,33.99071333333333],
              [-118.17320833333333,33.99093333333333],
              [-118.17341166666667,33.991095],
              [-118.17361333333334,33.991235],
              [-118.17382666666667,33.9914],
              [-118.173995,33.99153],
              [-118.17412833333333,33.991641666666666],
              [-118.17427666666667,33.99177666666667],
              [-118.17445333333333,33.99192333333333],
              [-118.17466333333333,33.99209166666667],
              [-118.1749,33.99227166666667],
              [-118.17515166666666,33.99247666666667],
              [-118.17542333333333,33.99274],
              [-118.17565833333333,33.99299833333333],
              [-118.175875,33.99328],
              [-118.17607166666667,33.99355666666666],
              [-118.17623166666667,33.993831666666665],
              [-118.176385,33.99411666666666],
              [-118.17651166666667,33.994398333333336],
              [-118.17660833333333,33.99467166666667],
              [-118.17671,33.99498166666667],
              [-118.176765,33.995215],
              [-118.176785,33.99539333333333],
              [-118.17681833333333,33.99559],
              [-118.17684166666666,33.995805],
              [-118.17685333333333,33.99607666666667],
              [-118.17682833333333,33.99641],
              [-118.17679333333334,33.99677166666667],
              [-118.17672333333333,33.997155],
              [-118.17664166666667,33.997458333333334],
              [-118.17657166666666,33.99766833333334],
              [-118.176515,33.99783333333333],
              [-118.176465,33.99794333333333],
              [-118.17642,33.998035],
              [-118.17636666666667,33.998153333333335],
              [-118.17629166666667,33.998311666666666],
              [-118.17620833333334,33.99847333333334],
              [-118.17609166666666,33.99864],
              [-118.175975,33.99878],
              [-118.17585666666666,33.99894833333333],
              [-118.17573166666666,33.99912666666667],
              [-118.17564666666667,33.999255],
              [-118.17557666666667,33.999356666666664],
              [-118.17549666666666,33.999473333333334],
              [-118.17541666666666,33.999583333333334],
              [-118.175375,33.99970166666667],
              [-118.17532333333334,33.99987],
              [-118.17525333333333,33.99998333333333],
              [-118.175205,34.00006666666667],
              [-118.17515,34.000098333333334],
              [-118.1751,34.00015833333333],
              [-118.17499333333333,34.00030833333334],
              [-118.174875,34.000476666666664],
              [-118.17481,34.000605],
              [-118.17474166666666,34.00069333333333],
              [-118.17460666666666,34.00089],
              [-118.17452333333334,34.00104],
              [-118.17445833333333,34.00116333333333],
              [-118.174255,34.00152833333333],
              [-118.17410833333334,34.00180666666667],
              [-118.17397,34.001963333333336],
              [-118.17386166666667,34.002185],
              [-118.17374,34.00237666666666],
              [-118.17367833333333,34.002525],
              [-118.17364666666667,34.002608333333335],
              [-118.17361833333334,34.00268166666667],
              [-118.17357166666666,34.002775],
              [-118.17350333333333,34.00292],
              [-118.17344333333334,34.003065],
              [-118.17338666666667,34.00319833333333],
              [-118.173305,34.003371666666666],
              [-118.17325166666667,34.00351833333333],
              [-118.17321166666666,34.00360333333333],
              [-118.17316333333333,34.003726666666665],
              [-118.17311333333333,34.00386666666667],
              [-118.17308833333334,34.003953333333335],
              [-118.17306666666667,34.00404833333333],
              [-118.17304333333334,34.004115],
              [-118.17302166666667,34.00419333333333],
              [-118.17298166666667,34.00432333333333],
              [-118.172935,34.00445666666667],
              [-118.17289166666667,34.00456833333333],
              [-118.172845,34.004706666666664],
              [-118.17279,34.004893333333335],
              [-118.17276166666667,34.00501833333333],
              [-118.17274666666667,34.00509],
              [-118.17270833333333,34.00521333333333],
              [-118.17266833333333,34.005381666666665],
              [-118.17262333333333,34.00557166666667],
              [-118.17258333333334,34.005736666666664],
              [-118.17257166666667,34.005903333333336],
              [-118.17255166666666,34.005995],
              [-118.17254166666666,34.006075],
              [-118.17254333333334,34.00615],
              [-118.17253666666667,34.00622],
              [-118.17252166666667,34.00630833333334],
              [-118.17249666666666,34.006436666666666],
              [-118.17246333333334,34.00658333333333],
              [-118.17244166666667,34.00675666666667],
              [-118.17242,34.00693166666667],
              [-118.17239166666667,34.007128333333334],
              [-118.17236166666666,34.00736166666667],
              [-118.17233666666667,34.00757],
              [-118.17231166666667,34.007785],
              [-118.17229833333333,34.00805833333333],
              [-118.17227833333334,34.008358333333334],
              [-118.17226833333334,34.00865833333334],
              [-118.17228,34.00897],
              [-118.17228333333334,34.00927333333333],
              [-118.172305,34.009566666666665],
              [-118.17229666666667,34.009861666666666],
              [-118.1723,34.010135],
              [-118.172295,34.01044666666667],
              [-118.17228333333334,34.01075],
              [-118.17229666666667,34.011035],
              [-118.1723,34.01132333333333],
              [-118.1723,34.011601666666664],
              [-118.172295,34.01184333333333],
              [-118.172305,34.0121],
              [-118.1723,34.012365],
              [-118.1723,34.01262166666667],
              [-118.172305,34.012816666666666],
              [-118.172295,34.01300666666667],
              [-118.17228166666666,34.013196666666666],
              [-118.17228833333333,34.01331],
              [-118.17230333333333,34.01343333333333],
              [-118.172325,34.013565],
              [-118.17233333333333,34.013695],
              [-118.17234166666667,34.013821666666665],
              [-118.17234166666667,34.013935],
              [-118.17234166666667,34.01403],
              [-118.17234166666667,34.01413],
              [-118.172345,34.01422],
              [-118.17237666666666,34.01436833333333],
              [-118.172385,34.014453333333336],
              [-118.17239666666667,34.01455166666667],
              [-118.17240833333334,34.01466833333333],
              [-118.17241833333334,34.014785],
              [-118.17243333333333,34.01493166666667],
              [-118.17245,34.01508],
              [-118.17247166666667,34.015195],
              [-118.17249666666666,34.015305],
              [-118.17251833333333,34.015385],
              [-118.17255166666666,34.01547166666667],
              [-118.17258333333334,34.01556166666666],
              [-118.17261333333333,34.01564166666667],
              [-118.17264666666667,34.015715],
              [-118.17269166666667,34.01580166666667],
              [-118.172745,34.01589166666667],
              [-118.17279666666667,34.015973333333335],
              [-118.17283833333333,34.016025],
              [-118.17296833333333,34.016185],
              [-118.173005,34.01623166666667],
              [-118.17305333333333,34.01628],
              [-118.17311,34.016333333333336],
              [-118.17315333333333,34.01638166666667],
              [-118.1732,34.01642],
              [-118.173265,34.01645333333333],
              [-118.173335,34.01648],
              [-118.17356333333333,34.01658333333334],
              [-118.17366666666666,34.016643333333334],
              [-118.17378666666667,34.016715],
              [-118.173925,34.01679],
              [-118.17408833333333,34.01689666666667],
              [-118.17426666666667,34.01701],
              [-118.17447166666666,34.01712],
              [-118.174745,34.01728333333333],
              [-118.17503833333333,34.01746333333333],
              [-118.17539666666667,34.017645],
              [-118.17572166666666,34.01779166666667],
              [-118.17604166666666,34.01793833333333],
              [-118.17644166666666,34.018121666666666],
              [-118.17690833333333,34.018328333333336],
              [-118.17745166666667,34.018566666666665],
              [-118.17797166666666,34.01880333333333],
              [-118.17848,34.01904666666667],
              [-118.17902166666667,34.019286666666666],
              [-118.179525,34.019465],
              [-118.18000166666667,34.01965166666667],
              [-118.18047833333334,34.01983],
              [-118.18086166666667,34.019888333333334],
              [-118.18115666666667,34.019965],
              [-118.18140166666667,34.020001666666666],
              [-118.18162166666667,34.020026666666666],
              [-118.18187333333333,34.02006166666666],
              [-118.18209166666666,34.020091666666666],
              [-118.18228,34.02012],
              [-118.18242833333333,34.02014166666667],
              [-118.182515,34.02015],
              [-118.18264833333333,34.02016],
              [-118.18281,34.020176666666664],
              [-118.18307333333334,34.02019333333333],
              [-118.18340666666667,34.020205],
              [-118.18377,34.02021166666667],
              [-118.18417333333333,34.020205],
              [-118.18456333333333,34.02020666666667],
              [-118.18492666666667,34.02021],
              [-118.185325,34.0202],
              [-118.185755,34.02019],
              [-118.186155,34.020195],
              [-118.18657666666667,34.02018],
              [-118.18701833333333,34.02018],
              [-118.18746333333333,34.020176666666664],
              [-118.187905,34.02018],
              [-118.18820166666667,34.02018],
              [-118.18846833333333,34.020178333333334],
              [-118.18877166666667,34.020176666666664],
              [-118.18909333333333,34.020176666666664],
              [-118.18938166666666,34.02018],
              [-118.1896,34.020176666666664],
              [-118.18985166666667,34.020178333333334],
              [-118.19019166666666,34.020176666666664],
              [-118.19050333333334,34.02017],
              [-118.19083666666667,34.020163333333336],
              [-118.19123,34.02017],
              [-118.19171666666666,34.020183333333335],
              [-118.19220166666666,34.020226666666666],
              [-118.19258333333333,34.02028833333333],
              [-118.192875,34.02033],
              [-118.19314833333334,34.020381666666665],
              [-118.19344,34.02044166666666],
              [-118.19378666666667,34.02053],
              [-118.19417333333334,34.020628333333335],
              [-118.19452333333334,34.020735],
              [-118.194815,34.02083833333333],
              [-118.19506666666666,34.02093166666667],
              [-118.19529166666666,34.02102333333333],
              [-118.195565,34.021135],
              [-118.19591333333334,34.02129],
              [-118.196285,34.02145333333333],
              [-118.19674166666667,34.02166],
              [-118.19725833333334,34.021881666666665],
              [-118.19784666666666,34.02213833333333],
              [-118.198425,34.022395],
              [-118.198985,34.02263],
              [-118.19954,34.022861666666664],
              [-118.20007333333334,34.023095],
              [-118.20064333333333,34.02334166666667],
              [-118.20115166666666,34.02356],
              [-118.201585,34.023743333333336],
              [-118.20199333333333,34.02393166666667],
              [-118.20240666666666,34.02411],
              [-118.20285333333334,34.024298333333334],
              [-118.20332333333333,34.024503333333335],
              [-118.20380833333333,34.024708333333336],
              [-118.20426666666667,34.02491333333333],
              [-118.204645,34.025088333333336],
              [-118.20492333333334,34.02520333333333],
              [-118.20515833333333,34.025295],
              [-118.20532333333334,34.025351666666666],
              [-118.20543166666667,34.025396666666666],
              [-118.20559666666666,34.02544],
              [-118.20573166666667,34.025481666666664],
              [-118.20588166666667,34.025528333333334],
              [-118.20610166666667,34.025596666666665],
              [-118.20635166666666,34.02568333333333],
              [-118.20657333333334,34.025756666666666],
              [-118.20673333333333,34.02581166666667],
              [-118.20685166666667,34.02585166666667],
              [-118.20695,34.02589],
              [-118.20711166666666,34.02594666666667],
              [-118.20725333333333,34.02599166666667],
              [-118.20733166666666,34.026035],
              [-118.20757333333333,34.02612333333333],
              [-118.20768833333334,34.02617166666667],
              [-118.2078,34.02621666666667],
              [-118.207895,34.026255],
              [-118.20798,34.02628833333333],
              [-118.20807833333333,34.02633],
              [-118.20823333333334,34.026401666666665],
              [-118.20833166666667,34.026453333333336],
              [-118.20839833333334,34.026471666666666],
              [-118.208505,34.02652],
              [-118.20863333333334,34.02657833333333],
              [-118.208765,34.026635],
              [-118.20888,34.026685],
              [-118.20896666666667,34.026718333333335],
              [-118.20916666666666,34.02681666666667],
              [-118.209265,34.02686333333333],
              [-118.20934166666666,34.026898333333335],
              [-118.20940333333333,34.02692166666667],
              [-118.209475,34.02695333333333],
              [-118.20957833333334,34.027],
              [-118.20971333333334,34.02706],
              [-118.20983,34.02711166666667],
              [-118.20992333333334,34.02715333333333],
              [-118.21001333333334,34.02719333333334],
              [-118.21013333333333,34.02724833333333],
              [-118.21027333333333,34.027316666666664],
              [-118.21043333333333,34.02738166666666],
              [-118.210585,34.02744833333333],
              [-118.21069,34.02749166666667],
              [-118.21080666666667,34.02753833333333],
              [-118.21092833333333,34.027595],
              [-118.21105833333333,34.027651666666664],
              [-118.21120333333333,34.027723333333334],
              [-118.21135666666666,34.0278],
              [-118.21154833333334,34.02789666666666],
              [-118.21172666666666,34.02797666666667],
              [-118.21186,34.02803333333333],
              [-118.211945,34.02807166666667],
              [-118.21203,34.02811333333333],
              [-118.21212166666666,34.028155],
              [-118.21222333333333,34.02820166666667],
              [-118.21233333333333,34.02825166666667],
              [-118.21246666666667,34.02831166666667],
              [-118.21261666666666,34.028373333333334],
              [-118.21274333333334,34.028423333333336],
              [-118.21286333333333,34.02847333333333],
              [-118.213155,34.028596666666665],
              [-118.21328166666666,34.02865166666667],
              [-118.21343166666666,34.02872166666667],
              [-118.21359833333334,34.028796666666665],
              [-118.21374666666667,34.028863333333334],
              [-118.21388833333333,34.02892333333333],
              [-118.214045,34.02899333333333],
              [-118.21423166666666,34.02907833333333],
              [-118.21440666666666,34.02915],
              [-118.21458166666666,34.0292],
              [-118.21487833333333,34.029315],
              [-118.21510333333333,34.029421666666664],
              [-118.21532666666667,34.02952166666667],
              [-118.21550333333333,34.02959333333333],
              [-118.21571333333333,34.029693333333334],
              [-118.21594333333333,34.0298],
              [-118.21611333333334,34.029875],
              [-118.21621,34.02992166666667],
              [-118.216345,34.02999],
              [-118.21641833333334,34.030028333333334],
              [-118.21655666666666,34.0301],
              [-118.216715,34.030175],
              [-118.21688666666667,34.030273333333334],
              [-118.21699333333333,34.03033],
              [-118.217155,34.03042166666667],
              [-118.217355,34.030545],
              [-118.21749,34.03062666666667],
              [-118.21756833333333,34.030696666666664],
              [-118.21768666666667,34.03075833333333],
              [-118.21777333333333,34.030815],
              [-118.21785333333334,34.030865],
              [-118.21798,34.030946666666665],
              [-118.21817,34.03107166666667],
              [-118.21839333333334,34.031225],
              [-118.218595,34.03136833333333],
              [-118.21880666666667,34.03152],
              [-118.21902166666666,34.03169333333334],
              [-118.21921166666667,34.031843333333335],
              [-118.21942166666666,34.032016666666664],
              [-118.21962,34.032203333333335],
              [-118.21980166666667,34.03236833333333],
              [-118.21994166666667,34.03251],
              [-118.22002666666667,34.03261],
              [-118.22005333333334,34.03269],
              [-118.22015333333333,34.032765],
              [-118.220235,34.032846666666664],
              [-118.22032,34.03294666666667],
              [-118.22040166666666,34.033031666666666],
              [-118.220455,34.033091666666664],
              [-118.220495,34.03315666666666],
              [-118.22067833333334,34.03337833333333],
              [-118.22074833333333,34.03346333333333],
              [-118.220825,34.03356333333333],
              [-118.22093666666666,34.03371],
              [-118.22106666666667,34.033921666666664],
              [-118.22120833333334,34.034155],
              [-118.22128333333333,34.034288333333336],
              [-118.22133166666667,34.03436166666667],
              [-118.22134833333334,34.03444833333333],
              [-118.22138166666667,34.034546666666664],
              [-118.22142,34.03460166666667],
              [-118.22144333333334,34.034635],
              [-118.22153,34.03509666666667],
              [-118.22153333333333,34.035293333333335],
              [-118.221555,34.03543166666667],
              [-118.221575,34.035563333333336],
              [-118.22158833333333,34.03573333333333],
              [-118.22160666666667,34.035916666666665],
              [-118.22162833333333,34.0361],
              [-118.22161333333334,34.036265],
              [-118.22159333333333,34.036413333333336],
              [-118.22157833333333,34.036555],
              [-118.22156,34.03668166666667],
              [-118.22154333333333,34.03680833333333],
              [-118.221545,34.03697666666667],
              [-118.22148166666666,34.03712],
              [-118.22146166666667,34.03727],
              [-118.22143166666666,34.03743166666667],
              [-118.22141333333333,34.037593333333334],
              [-118.221405,34.037745],
              [-118.22138833333334,34.0379],
              [-118.22138666666666,34.03801166666667],
              [-118.22140833333333,34.038111666666666],
              [-118.221405,34.03821],
              [-118.22141333333333,34.038335],
              [-118.22144,34.038471666666666],
              [-118.22145333333333,34.03861833333333],
              [-118.22148166666666,34.03882333333333],
              [-118.22151333333333,34.039001666666664],
              [-118.22150666666667,34.039213333333336],
              [-118.22154166666667,34.03944],
              [-118.22152833333334,34.039675],
              [-118.22151333333333,34.03991166666667],
              [-118.22148166666666,34.04020833333333],
              [-118.22141166666667,34.040525],
              [-118.22129833333334,34.040881666666664],
              [-118.22114333333333,34.04138833333333],
              [-118.22099,34.041785],
              [-118.22088,34.042206666666665],
              [-118.22078166666667,34.04253666666666],
              [-118.220735,34.04284],
              [-118.220825,34.043031666666664],
              [-118.22109333333333,34.04304166666667],
              [-118.22144833333333,34.04302166666667],
              [-118.22171166666666,34.04298],
              [-118.22196833333334,34.04296166666666],
              [-118.22215333333334,34.042995],
              [-118.22226333333333,34.042986666666664],
              [-118.22237333333334,34.042965],
              [-118.22255166666666,34.04295],
              [-118.222785,34.042941666666664],
              [-118.22314166666666,34.04289333333333],
              [-118.22349833333334,34.042788333333334],
              [-118.2239,34.042656666666666],
              [-118.22438333333334,34.042458333333336],
              [-118.22496166666667,34.04231166666667],
              [-118.22556666666667,34.042135],
              [-118.22616333333333,34.041955],
              [-118.22672166666666,34.041783333333335],
              [-118.22725333333334,34.041668333333334],
              [-118.227855,34.04161],
              [-118.22849166666667,34.04159],
              [-118.229135,34.041583333333335],
              [-118.22978833333333,34.04157],
              [-118.23043833333334,34.041563333333336],
              [-118.23106333333334,34.04155166666666],
              [-118.23166333333333,34.041648333333335],
              [-118.23221166666667,34.041898333333336],
              [-118.23271833333334,34.04218],
              [-118.23317166666666,34.042456666666666],
              [-118.233475,34.04265],
              [-118.233695,34.042773333333336],
              [-118.23380666666667,34.042858333333335],
              [-118.23408166666667,34.043033333333334],
              [-118.23436666666667,34.043205],
              [-118.23469833333333,34.043396666666666],
              [-118.23505666666667,34.04360833333333],
              [-118.23540333333334,34.043823333333336],
              [-118.23576333333334,34.044021666666666],
              [-118.23612833333334,34.044243333333334],
              [-118.23653833333333,34.04449],
              [-118.236865,34.044716666666666],
              [-118.23719,34.044975],
              [-118.23747833333333,34.04525666666667],
              [-118.23780166666667,34.045478333333335],
              [-118.23812666666667,34.045615],
              [-118.23846166666667,34.045745],
              [-118.23879,34.045878333333334],
              [-118.23916,34.046025],
              [-118.23948166666666,34.046166666666664],
              [-118.23981666666667,34.046256666666665],
              [-118.24014166666667,34.04638166666667],
              [-118.24051166666666,34.046503333333334],
              [-118.24089833333333,34.04664666666667],
              [-118.241285,34.04680666666667],
              [-118.24166166666667,34.046953333333335],
              [-118.242105,34.04716833333333],
              [-118.24256166666666,34.04741333333333],
              [-118.24299666666667,34.04761833333333],
              [-118.24341833333334,34.04784],
              [-118.24387333333334,34.04808833333333],
              [-118.24430166666667,34.04834666666667],
              [-118.24471833333334,34.048595],
              [-118.2451,34.048835],
              [-118.24543333333334,34.049035],
              [-118.24569333333334,34.04923333333333],
              [-118.24582833333334,34.04951666666667],
              [-118.24607666666667,34.049746666666664],
              [-118.24636833333334,34.04994333333333],
              [-118.24670166666667,34.0501],
              [-118.24699833333334,34.050285],
              [-118.247285,34.050491666666666],
              [-118.247545,34.050675],
              [-118.24777333333333,34.050835],
              [-118.24802,34.05103833333333],
              [-118.24829666666666,34.05119],
              [-118.24852666666666,34.051335],
              [-118.24888166666666,34.05159333333334],
              [-118.24919,34.05179],
              [-118.24957666666667,34.051966666666665],
              [-118.25242833333333,34.05381833333333],
              [-118.25261,34.053931666666664],
              [-118.25279833333333,34.054051666666666],
              [-118.25298833333333,34.05417333333333],
              [-118.25318,34.054293333333334],
              [-118.25330833333334,34.054375],
              [-118.25373166666667,34.05463833333334],
              [-118.25393,34.05477333333333],
              [-118.25411166666666,34.054896666666664],
              [-118.254315,34.05504833333333],
              [-118.25454833333333,34.055218333333336],
              [-118.25481833333333,34.055416666666666],
              [-118.25509,34.055681666666665],
              [-118.25519166666666,34.05599333333333],
              [-118.25518166666667,34.056325],
              [-118.25504833333333,34.05661333333333],
              [-118.25488333333334,34.05690166666667],
              [-118.254675,34.05715],
              [-118.25448833333333,34.057345],
              [-118.25434,34.057498333333335],
              [-118.25415,34.05768833333333],
              [-118.25397833333334,34.057876666666665],
              [-118.25383333333333,34.058031666666665],
              [-118.25367,34.058185],
              [-118.25345666666666,34.05837666666667],
              [-118.25334333333333,34.058483333333335],
              [-118.25326,34.058575],
              [-118.25311,34.058725],
              [-118.25301333333333,34.05882166666667],
              [-118.25290166666667,34.058933333333336],
              [-118.25272333333334,34.059081666666664],
              [-118.25256,34.05921333333333],
              [-118.25234666666667,34.05939333333333],
              [-118.25215833333333,34.05956],
              [-118.25205166666667,34.05963],
              [-118.25175333333334,34.05988],
              [-118.25161,34.06],
              [-118.25153166666666,34.060066666666664],
              [-118.251465,34.06012166666667],
              [-118.2513,34.06024],
              [-118.25119666666667,34.060325],
              [-118.25107,34.06042166666667],
              [-118.250865,34.06057166666667],
              [-118.25057,34.06077833333333],
              [-118.25036833333333,34.06093666666667],
              [-118.25019333333333,34.061078333333334],
              [-118.25013333333334,34.06112666666667],
              [-118.25007333333333,34.06117666666667],
              [-118.25001666666667,34.06121666666667],
              [-118.24993333333333,34.061278333333334],
              [-118.249825,34.06135166666667],
              [-118.24967666666667,34.061456666666665],
              [-118.249555,34.06156],
              [-118.24949666666667,34.061615],
              [-118.24942666666666,34.06167],
              [-118.24932333333334,34.06174333333333],
              [-118.24924166666666,34.06180833333333],
              [-118.24916666666667,34.061881666666665],
              [-118.24909333333333,34.06196666666666],
              [-118.24902333333333,34.06205666666666],
              [-118.24898666666667,34.06211833333333],
              [-118.248955,34.062171666666664],
              [-118.24892,34.06225333333333],
              [-118.24888833333333,34.06233666666667],
              [-118.24888166666666,34.062376666666665],
              [-118.24887,34.062423333333335],
              [-118.24886,34.062465],
              [-118.248865,34.062575],
              [-118.24886333333333,34.062731666666664],
              [-118.24884166666666,34.06307666666667],
              [-118.248875,34.063251666666666],
              [-118.248895,34.063395],
              [-118.248935,34.06346333333333],
              [-118.24899,34.06354],
              [-118.24904666666667,34.063628333333334],
              [-118.24912166666667,34.06371166666667],
              [-118.24923166666666,34.06380166666667],
              [-118.24932166666666,34.06386166666667],
              [-118.24938666666667,34.063905],
              [-118.249515,34.063986666666665],
              [-118.24962666666667,34.06404333333333],
              [-118.24970666666667,34.06409166666667],
              [-118.24982666666666,34.064165],
              [-118.24992333333333,34.06422],
              [-118.25003166666667,34.064283333333336],
              [-118.250155,34.06435166666667],
              [-118.25028,34.064415],
              [-118.250395,34.064478333333334],
              [-118.250555,34.06457833333333],
              [-118.25075166666667,34.06471],
              [-118.25087166666667,34.064791666666665],
              [-118.25102833333334,34.06489333333333],
              [-118.25124333333333,34.065041666666666],
              [-118.251465,34.065196666666665],
              [-118.25165333333334,34.06532166666667],
              [-118.25190333333333,34.06550166666667],
              [-118.252205,34.06571],
              [-118.252505,34.065945],
              [-118.25284666666667,34.06619166666667],
              [-118.25322666666666,34.06646166666667],
              [-118.253645,34.066741666666665],
              [-118.254105,34.06706833333333],
              [-118.25468166666667,34.06738166666667],
              [-118.25527166666667,34.06765],
              [-118.255865,34.06792],
              [-118.25652,34.068178333333336],
              [-118.25719,34.06840833333333],
              [-118.2579,34.068645],
              [-118.25867166666667,34.06890333333333],
              [-118.25943833333334,34.06918666666667],
              [-118.260245,34.069471666666665],
              [-118.26103333333333,34.06975166666667],
              [-118.26167166666667,34.06998166666666],
              [-118.26221166666667,34.07017],
              [-118.26272166666666,34.070365],
              [-118.26325666666666,34.070566666666664],
              [-118.263805,34.070798333333336],
              [-118.26437333333334,34.07104],
              [-118.264975,34.07132166666667],
              [-118.265565,34.07158833333333],
              [-118.26616666666666,34.07185333333334],
              [-118.26679,34.072131666666664],
              [-118.267405,34.07239333333333],
              [-118.26805833333333,34.07266],
              [-118.268745,34.07293333333333],
              [-118.26943166666666,34.07322],
              [-118.27016,34.07351666666667],
              [-118.27082333333334,34.07384166666667],
              [-118.27144,34.074155],
              [-118.27213166666667,34.07449],
              [-118.27289666666667,34.07481],
              [-118.27369333333333,34.07510333333333],
              [-118.27448666666666,34.075365],
              [-118.27528666666667,34.07557333333333],
              [-118.27609333333334,34.07581666666667],
              [-118.27692666666667,34.076058333333336],
              [-118.27778166666667,34.076303333333335],
              [-118.278605,34.076546666666665],
              [-118.27942666666667,34.07677666666667],
              [-118.28020166666667,34.07697833333334],
              [-118.28097166666667,34.077148333333334],
              [-118.28168,34.077308333333335],
              [-118.28241833333334,34.077463333333334],
              [-118.28317,34.077635],
              [-118.28392666666667,34.0778],
              [-118.28468833333334,34.07798],
              [-118.285415,34.07814],
              [-118.28613166666666,34.07827666666667],
              [-118.286835,34.078406666666666],
              [-118.28754666666667,34.078543333333336],
              [-118.28828833333333,34.078736666666664],
              [-118.28905,34.07897666666667],
              [-118.289785,34.07926166666667],
              [-118.29054833333333,34.07962],
              [-118.291305,34.080016666666666],
              [-118.29205666666667,34.08043833333333],
              [-118.29284666666666,34.08081833333333],
              [-118.29364333333334,34.08119666666666],
              [-118.29442333333333,34.08157333333333],
              [-118.29517666666666,34.081921666666666],
              [-118.29590666666667,34.082275],
              [-118.29661333333334,34.082605],
              [-118.29730333333333,34.082945],
              [-118.29800166666666,34.08331],
              [-118.29868666666667,34.083726666666664],
              [-118.29935,34.084156666666665],
              [-118.299995,34.084601666666664],
              [-118.30063166666666,34.08504166666667],
              [-118.30121,34.08544666666667],
              [-118.30179,34.08585],
              [-118.30239,34.086261666666665],
              [-118.30302166666667,34.08670333333333],
              [-118.30365,34.087201666666665],
              [-118.30424,34.087741666666666],
              [-118.30479166666667,34.088348333333336],
              [-118.30526,34.088985],
              [-118.30567166666667,34.089648333333336],
              [-118.30605833333334,34.090305],
              [-118.30646,34.09097],
              [-118.30685166666666,34.09162666666667],
              [-118.30728166666667,34.09222666666667],
              [-118.30777166666667,34.09278333333334],
              [-118.30837166666667,34.0933],
              [-118.30907,34.093775],
              [-118.309835,34.09424666666666],
              [-118.31051166666667,34.094696666666664],
              [-118.311105,34.095065],
              [-118.31167333333333,34.09541333333333],
              [-118.31225,34.09580166666667],
              [-118.31268,34.096156666666666],
              [-118.31303833333334,34.096505],
              [-118.31338333333333,34.096851666666666],
              [-118.31370166666666,34.09720333333333],
              [-118.31402,34.09763],
              [-118.31434166666666,34.098095],
              [-118.31463166666667,34.09865666666666],
              [-118.31490333333333,34.09919],
              [-118.31513333333334,34.099693333333335],
              [-118.31536333333334,34.100208333333335],
              [-118.31558333333334,34.100665],
              [-118.315775,34.10102333333333],
              [-118.31590833333334,34.10124833333333],
              [-118.31599166666666,34.10138833333333],
              [-118.31602333333333,34.101441666666666],
              [-118.31611666666667,34.101548333333334],
              [-118.31628666666667,34.101686666666666],
              [-118.31660166666667,34.10172],
              [-118.31692333333334,34.101725],
              [-118.31723666666667,34.101728333333334],
              [-118.317535,34.101713333333336],
              [-118.31773666666666,34.10167833333333],
              [-118.31799333333333,34.10167833333333],
              [-118.318325,34.10167],
              [-118.31871,34.10166],
              [-118.3191,34.101663333333335],
              [-118.31952833333334,34.101665],
              [-118.31996833333334,34.10165333333333],
              [-118.32042166666666,34.101661666666665],
              [-118.32088666666667,34.10166666666667],
              [-118.32131666666666,34.101661666666665],
              [-118.32169666666667,34.101665],
              [-118.322005,34.101668333333336],
              [-118.322175,34.101661666666665],
              [-118.32238833333334,34.10165166666667],
              [-118.32269833333334,34.10165333333333],
              [-118.32310833333334,34.10165666666666],
              [-118.32356,34.10165],
              [-118.32403833333333,34.101643333333335],
              [-118.32453833333334,34.10164],
              [-118.32501833333333,34.10164666666667],
              [-118.32545833333333,34.10165166666667],
              [-118.32583833333334,34.101643333333335],
              [-118.32617333333333,34.10165333333333],
              [-118.32652333333333,34.101663333333335],
              [-118.326865,34.101661666666665],
              [-118.32728833333333,34.101655],
              [-118.327685,34.101681666666664],
              [-118.32808833333333,34.10169166666667],
              [-118.32839833333334,34.101686666666666],
              [-118.328695,34.101665],
              [-118.32896666666667,34.10167],
              [-118.329155,34.101655],
              [-118.32926833333333,34.10166666666667],
              [-118.32962166666667,34.101668333333336],
              [-118.32984166666667,34.10164],
              [-118.33015833333333,34.101641666666666],
              [-118.33047833333333,34.10162],
              [-118.33082166666667,34.10162166666667],
              [-118.33117166666666,34.101615],
              [-118.33155333333333,34.101593333333334],
              [-118.33190166666667,34.101618333333334],
              [-118.33232333333333,34.10161],
              [-118.332745,34.101618333333334],
              [-118.33316166666667,34.101638333333334],
              [-118.33358,34.10163],
              [-118.33401333333333,34.10164],
              [-118.33444333333334,34.101638333333334],
              [-118.33486166666667,34.10165166666667],
              [-118.335295,34.10162666666667],
              [-118.33567166666667,34.10160666666667],
              [-118.33596166666666,34.101598333333335],
              [-118.33621,34.101565],
              [-118.336375,34.101585],
              [-118.336525,34.101593333333334],
              [-118.33664166666667,34.10160333333334],
              [-118.33692333333333,34.101585],
              [-118.33717333333334,34.101573333333334],
              [-118.33738666666666,34.101565],
              [-118.33761,34.101565],
              [-118.33779666666666,34.10158666666667],
              [-118.33792,34.10158666666667],
              [-118.338005,34.10158166666667],
              [-118.3381,34.10163333333333],
              [-118.33818333333333,34.10161],
              [-118.33824,34.10158333333333],
              [-118.33838333333334,34.10159],
              [-118.33852666666667,34.10158833333333],
              [-118.33867333333333,34.10158166666667],
              [-118.33893833333333,34.10158833333333],
              [-118.33916666666667,34.10161333333333],
              [-118.33942166666667,34.101596666666666],
              [-118.33966666666667,34.10159],
              [-118.33991833333333,34.10160833333333],
              [-118.34012166666666,34.1016],
              [-118.34032333333333,34.10160166666667],
              [-118.340505,34.10158166666667],
              [-118.34063833333333,34.101593333333334],
              [-118.34076,34.10156833333333],
              [-118.34087333333333,34.10154166666667],
              [-118.34098166666666,34.10153666666667],
              [-118.341115,34.101531666666666],
              [-118.34123666666666,34.101528333333334],
              [-118.34134,34.101528333333334],
              [-118.34146833333334,34.10154333333333],
              [-118.34154166666667,34.10158833333333],
              [-118.34174,34.101875],
              [-118.341735,34.10196833333333],
              [-118.34169166666666,34.10243166666667],
              [-118.34161833333333,34.102465],
              [-118.34146666666666,34.102448333333335]
            ]

            const gpsTracksData         = {
                type: 'FeatureCollection',
                features: [{
                    type: 'Feature',
                    properties: {},
                    geometry: {
                        type: 'LineString',
                        coordinates: [coordinates[0]]
                    }
                }]
            };

            var gpsTracksDataLive       = {
                type: 'FeatureCollection',
                features:[
                    {
                        type: 'Feature',
                        properties: {},
                        geometry: {
                            type: 'Point',
                            coordinates: coordinates[0]
                        }
                    }
                ]
            };

            // Wait for the map to load before adding layers and data sources
            map.on('load', function() {
                // Add GeoJSON data source to the map
                map.addSource('gpsTrack', { type: 'geojson', data: gpsTracksData });
                // Add a layer to draw line for each point in the data source
                map.addLayer({
                    'id': 'gpsTrack',
                    'source': 'gpsTrack',
                    'type': 'line',
                    'layout': {
                        'line-cap': 'round'
                    },
                    'paint': {
                        'line-color': '#005F9E',
                        'line-opacity': 0.6,
                        'line-width': 8
                    }
                });
                map.jumpTo({ 'center': coordinates[0], 'zoom': 10 });
                map.setPitch(40);

                // Add GeoJSON data source to the map
                map.addSource('hqSource', { type: 'geojson', data: gpsTracksDataLive });
                // Add a layer to draw circles for each point in the data source
                map.addLayer({
                    'id': 'hqPoints',
                    'source': 'hqSource',
                    'type': 'symbol',
                    'layout': {
                        'icon-image': 'truck-fill-green',
                        'icon-size': 1,
                        'icon-allow-overlap' : true,
                        'icon-ignore-placement': true
                    },
                    'paint': {
                        'icon-opacity': 1
                    }
                });

                // draw green truck at the start
                const point = {
                    'type': 'FeatureCollection',
                    'features': [{
                        'type': 'Feature',
                        'properties': {
                            'pointType': 'start'
                        },
                        'geometry': {
                            'type': 'Point',
                            'coordinates': coordinates[0]
                        }
                    },
                    {
                        'type': 'Feature',
                        'properties': {
                            'pointType': 'end'
                        },
                        'geometry': {
                            'type': 'Point',
                            'coordinates': coordinates[0]
                        }
                    }]
                };
                map.addSource('point', {
                    type: 'geojson',
                    data: point
                });
                map.addLayer({
                    'id': 'point',
                    'source': 'point',
                    'type': 'symbol',
                    'layout': {
                        'icon-image': [
                            'match',
                            ['get', 'pointType'],
                            'start',
                            'truck-outline-green',
                            'truck-outline-red'
                        ],
                        'icon-size': 1
                    },
                    'paint': {
                        'icon-opacity': 1
                    }
                });

                // draw gps track
                let i = 0;
                const timer = setInterval(() => {
                    if (i < coordinates.length) {
                        gpsTracksData.features[0].geometry.coordinates.push(coordinates[i]);
                        map.getSource('gpsTrack').setData(gpsTracksData);
                        map.panTo(coordinates[i]);
                        point.features[1].geometry.coordinates = coordinates[i];

                        gpsTracksDataLive.features[0].geometry.coordinates = coordinates[i];
                        map.getSource('hqSource').setData(gpsTracksDataLive);
                        i++;
                    } else {
                        window.clearInterval(timer);
                        // draw red truck at the end
                        map.getSource('point').setData(point);
                    }
                }, 20);
            });
        </script>
    </body>
</html>
