<?php

use App\Http\Controllers\Auth\DriverAdmin\LoginController;
use App\Http\Controllers\DriverAdmin\TwoFactorSettingController;
use App\Http\Controllers\DriverAdmin\TwoFactorAuthenticationController;

use App\Http\Controllers\Auth\DriverAdmin\ResetPasswordController;
use App\Http\Controllers\Auth\DriverAdmin\ForgotPasswordController;

use App\Http\Controllers\DriverAdmin\LoadController;
use App\Http\Controllers\DriverAdmin\MyTripController;

use App\Http\Controllers\DriverAdmin\AnnouncementController;
use App\Http\Controllers\DriverAdmin\CompelAnnouncementController;

use App\Http\Controllers\DriverAdmin\HomeController;
use App\Http\Controllers\DriverAdmin\ProfileController;
use App\Http\Controllers\DriverAdmin\BookmarkController;
use App\Http\Controllers\DriverAdmin\AccountSettingController;

use App\Http\Controllers\ChatController;
use App\Http\Controllers\SendGridController; // Added at 14-04-2023

// LoginController
Route::get('login', [LoginController::class, 'showLoginForm'])->name('login.view');
Route::post('login', [LoginController::class, 'login'])->name('login');
Route::post('logout', [LoginController::class, 'logout'])->name('logout');

// ForgotPasswordController
Route::get('password/reset', [ForgotPasswordController::class, 'showLinkRequestForm'])->name('password.request');
Route::post('password/email', [ForgotPasswordController::class, 'sendResetLinkEmail'])->name('password.email');

// ResetPasswordController
Route::get('password/reset/{token}', [ResetPasswordController::class, 'showResetForm'])->name('password.reset');
Route::post('password/reset', [ResetPasswordController::class, 'reset'])->name('password.update');

// Driver Admin 2-Factor Authentication - START
Route::group(['middleware' => 'driver.admin.auth'],function () {
    Route::group(['middleware' => '2fa'],function () {
        Route::get('two-factor-settings', [TwoFactorSettingController::class, 'index'])->name('two-factor.index');
        Route::post('two-factor-settings/update-settings', [TwoFactorSettingController::class, 'updateSettings'])->name('two-factor.update.setting');
    });
    Route::get('two-factor-authentication', [TwoFactorAuthenticationController::class, 'index'])->name('two-factor-authentication.index');
    Route::post('two-factor-authentication/verify-code', [TwoFactorAuthenticationController::class, 'verifyCode'])->name('two-factor-authentication.verify');
    Route::get('two-factor-authentication/resend-code', [TwoFactorAuthenticationController::class, 'resendCode'])->name('two-factor-authentication.resend');
});
// Driver Admin 2-Factor Authentication - END

Route::group(['middleware' => ['driver.admin.auth', '2fa']],function () {
    // HomeController
    Route::get('home', [HomeController::class, 'home'])->name('home');
    Route::get('targetRevenue', [HomeController::class, 'getTargetRevenue'])->name('targetRevenue');
    Route::get('actualRevenue', [HomeController::class, 'getActualRevenue'])->name('actualRevenue');
    Route::get('inTransitLoads', [HomeController::class, 'inTransitLoads'])->name('inTransitLoads');
    Route::post('chart-data', [HomeController::class, 'chartData'])->name('chart.data');
    Route::post('widget/data', [HomeController::class, 'widgetData'])->name('widget.data');
    Route::post('widget/delete', [HomeController::class, 'widgetDestroy'])->name('widget.delete');
    Route::post('widget/restore', [HomeController::class, 'widgetRestore'])->name('widget.restore');
    Route::post('widget/notes/store', [HomeController::class, 'widgetNotesStore'])->name('widget.notes.store');
    Route::post('scrollData',[HomeController::class,'scrollDataInsert'])->name('scrollInsertData');

    Route::resource('bookmarks', BookmarkController::class);

    // mytrips
    Route::get('/mytrips', [MyTripController::class, 'index'])->name('mytrips.index');
    Route::post('/mytrips/upcoming-dispatch', [MyTripController::class, 'upcomingDispatch'])->name('mytrips.upcoming.dispatch');
    Route::post('/mytrips/upcoming-dispatch-read', [MyTripController::class, 'upcomingDispatchRead'])->name('mytrips.upcoming.dispatch.read');
    Route::post('/mytrips/upcoming-dispatch-detail', [MyTripController::class, 'upcomingDispatchDetail'])->name('mytrips.upcoming.dispatch.detail');
    Route::post('/mytrips/dispatch-now-detail', [MyTripController::class, 'dispatchNowDetail'])->name('mytrips.dispatch.now.detail');
    Route::post('/mytrips/dispatch-requirements-detail', [MyTripController::class, 'dispatchRequirementsDetail'])->name('mytrips.dispatch.requirements.detail');
    Route::post('/mytrips/change-status', [MyTripController::class, 'changeStatus'])->name('mytrips.change.status');

    Route::post('/mytrips/current-dispatch-detail', [MyTripController::class, 'currentDispatchDetail'])->name('mytrips.current.dispatch.detail');
    Route::post('/mytrips/current-dispatch-completed-miles', [MyTripController::class, 'currentDispatchCompletedMiles'])->name('mytrips.current.dispatch.completed.miles');
    Route::post('/mytrips/carousel-content', [MyTripController::class, 'carouselContent'])->name('mytrips.carousel.content');

    Route::post('/mytrips/arrive-depart-request', [MyTripController::class, 'arriveDepartRequest'])->name('mytrips.arrive.depart.request');
    Route::post('/mytrips/review-save', [MyTripController::class, 'reviewSave'])->name('mytrips.review.save');

    Route::post('/mytrips/detention-request', [MyTripController::class, 'detentionRequest'])->name('mytrips.detention.request');
    Route::post('/mytrips/detention-save', [MyTripController::class, 'detentionSave'])->name('mytrips.detention.save');

    Route::post('/mytrips/depart-detail', [MyTripController::class, 'departDetail'])->name('mytrips.depart.detail');

    Route::post('/mytrips/drop-hook-save', [MyTripController::class, 'dropHookSave'])->name('mytrips.drop.hook.save');
    Route::post('/mytrips/current-file-save', [MyTripController::class, 'currentFileSave'])->name('mytrips.current.file.save');
    Route::post('/mytrips/current-file-remove', [MyTripController::class, 'currentFileRemove'])->name('mytrips.current.file.remove');
    Route::post('/mytrips/additional-file-save', [MyTripController::class, 'additionalFileSave'])->name('mytrips.additional.file.save');

    Route::post('/mytrips/historic-dispatch', [MyTripController::class, 'historicDispatch'])->name('mytrips.historic.dispatch');
    Route::post('/mytrips/historic-dispatch-status', [MyTripController::class, 'historicDispatchStatus'])->name('mytrips.historic.dispatch.status');
    Route::post('/mytrips/historic-dispatch-detail', [MyTripController::class, 'historicDispatchDetail'])->name('mytrips.historic.dispatch.detail');
    Route::post('/mytrips/historic-file-save', [MyTripController::class, 'historicFileSave'])->name('mytrips.historic.file.save');
    Route::post('/mytrips/historic-file-remove', [MyTripController::class, 'historicFileRemove'])->name('mytrips.historic.file.remove');
    // loads
    Route::get('/loads', [LoadController::class, 'index'])->name('loads.index');
    Route::get('/loads/{load}', [LoadController::class, 'show'])->name('loads.show');
    Route::get('loads-pending', [LoadController::class, 'pending'])->name('loads.pending');
    Route::get('loads-accepted', [LoadController::class, 'accepted'])->name('loads.accepted');
    Route::get('loads-in-transit', [LoadController::class, 'inTransit'])->name('loads.in.transit');
    Route::get('loads-rejected', [LoadController::class, 'rejected'])->name('loads.rejected');
    Route::get('loads-complete', [LoadController::class, 'complete'])->name('loads.complete');
    Route::get('loads-cancelled', [LoadController::class, 'cancelled'])->name('loads.cancelled');
    Route::get('loads-unoccupied', [LoadController::class, 'unoccupied'])->name('loads.unoccupied');
    Route::get('loads-all', [LoadController::class, 'all'])->name('loads.all');
    Route::post('loads-file-view', [LoadController::class, 'loadFileView']);
    Route::post('loads-file-save', [LoadController::class, 'loadFileSave'])->name('loads.file.view.save');
    Route::delete('loads-file-view/delete/{id}', [LoadController::class, 'destroyFile'])->name('loads.file.view.delete');
    Route::post('loads-required-file-save', [LoadController::class, 'requiredFileSave'])->name('loads.required.file.save');
    Route::post('loads-change-status', [LoadController::class, 'changeStatus'])->name('loads.change.status');
    Route::post('loads-arrived-request', [LoadController::class, 'arrivedRequest'])->name('loads.arrived.request');
    Route::post('loads-detention-request', [LoadController::class, 'detentionRequest'])->name('loads.detention.request');
    Route::post('loads-detention-save', [LoadController::class, 'detentionSave'])->name('loads.detention.save');

    // Announcement
    Route::get('/dispatch-pro-announcement', [CompelAnnouncementController::class, 'index'])->name('compel.announcement.index');
    Route::get('/dispatch-pro-announcement/{compel_announcement}', [CompelAnnouncementController::class, 'show'])->name('compel.announcement.show');
    Route::post('/announcement-clear', [CompelAnnouncementController::class, 'announcementClear'])->name('announcement.clear');

    // Announcement
    Route::get('/announcement', [AnnouncementController::class, 'index'])->name('announcement.index');
    Route::get('/announcement/{announcement}', [AnnouncementController::class, 'show'])->name('announcement.show');

    Route::get('account-settings', [AccountSettingController::class, 'index'])->name('account.index');
    Route::patch('account-settings/update/{id}', [AccountSettingController::class, 'update'])->name('account.update');

    Route::get('/change-password', [ProfileController::class, 'changePassword'])->name('changePassword');
    Route::post('/update-password', [ProfileController::class, 'updatePassword'])->name('updatePassword');

    Route::get('chat',[ChatController::class, 'index'])->name('chat.index');
    Route::get('chat/load-detail',[ChatController::class, 'loadDetail'])->name('chat.load.detail');
    Route::get('chat/load-internal-detail',[ChatController::class, 'loadInternalDetail'])->name('chat.load.internal.detail');
    Route::post('chat/load-truck-location-update',[ChatController::class, 'loadTruckLocationUpdate'])->name('chat.load.truck.location.update');
    Route::post('chat/get-chat-history',[ChatController::class, 'getChatHistory'])->name('chat.get.chat.history');

    // Developed at - 10-04-2023
    Route::post('chat/send-sms-twilio',[ChatController::class, 'sendSmsTwilio'])->name('chat.send.sms.twilio');
    // Developed at - 11-04-2023
    Route::post('chat/load-more-sms-history',[ChatController::class, 'loadMoreSmsHistory'])->name('chat.load.more.sms.history');
    Route::post('chat/search-sms-history',[ChatController::class, 'searchSmsHistory'])->name('chat.search.sms.history');
    Route::post('chat/get-email-for-external-use',[ChatController::class, 'getEmailForExternalUse'])->name('get.email.for.external.use');
    // Developed at 14-04-2023
    Route::post('chat/get-unread-emails',[SendGridController::class, 'getUnreadEmails'])->name('chat.get.unread.emails');
    Route::post('chat/checknew-unread-emails',[SendGridController::class, 'checkUnreadEmails'])->name('chat.checknew.unread.emails');
    // Developed at 18-04-2023
    Route::post('chat/get-unread-message',[ChatController::class, 'getUnreadMessage'])->name('chat.get.unread.message');
    // Developed at 19-04-2023
    Route::post('chat/get-unread-sms-count',[ChatController::class, 'getUnreadMessageCount'])->name('chat.get.unread.smscount');
    Route::post('chat/get-user-phones',[ChatController::class, 'getUserPhones'])->name('chat.get.user.phones');
    Route::post('chat/get-unread-message-details',[ChatController::class, 'getUnreadMessageDetails'])->name('chat.get.unread.message.details');
});
