<?php

use App\Http\Controllers\HomeController;

use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Mail;

use App\Models\Bookmark;

use Carbon\Carbon;

/*
|--------------------------------------------------------------------------
| Command Routes
|--------------------------------------------------------------------------
*/

Route::get('cache', function() {
	Artisan::call('cache:clear');
    Artisan::call('config:cache');
    Artisan::call('config:clear');
    Artisan::call('view:clear');
    Artisan::call('route:clear');
    Bookmark::truncate();
    return "Bookmark & Cache are cleared";
});

Route::group(['prefix' => 'commands'], function () {
    Route::get('/php-info', function() {
        phpinfo();
    });

    Route::get('/check-imagick-extension', function() {
        // Check if Imagick extension is loaded
        if (extension_loaded('imagick')) {
            echo 'Imagick extension is installed.';
        } else {
            echo 'Imagick extension is NOT installed.';
        }
    });

    Route::get('/optimize-clear', function() {
        Artisan::call('optimize:clear');
        echo '<pre>'.str_replace('\n', "\n", Artisan::output()).'</pre>';
    });

    Route::get('/migrate', function() {
        Artisan::call('migrate');
        echo '<pre>'.str_replace('\n', "\n", Artisan::output()).'</pre>';
    });

    Route::get('/clear-compiled', function() {
        Artisan::call('clear-compiled');
        echo '<pre>'.str_replace('\n', "\n", Artisan::output()).'</pre>';
    });

    Route::get('/migrate-fresh', function() {
        Artisan::call('migrate:fresh');
        echo '<pre>'.str_replace('\n', "\n", Artisan::output()).'</pre>';
    });

    Route::get('/seed', function() {
        Artisan::call('db:seed');
        echo '<pre>'.str_replace('\n', "\n", Artisan::output()).'</pre>';
    });

    Route::get('/db-wipe', function() {
        Artisan::call('db:wipe');
        echo '<pre>'.str_replace('\n', "\n", Artisan::output()).'</pre>';
    });

    Route::get('/migrate-rollback', function() {
        Artisan::call('migrate:rollback');
        echo '<pre>'.str_replace('\n', "\n", Artisan::output()).'</pre>';
    });
});

/*
|--------------------------------------------------------------------------
| Front Routes
|--------------------------------------------------------------------------
*/

Route::view('/', 'welcome');

Auth::routes();

Route::get('/state-list', [HomeController::class, 'stateList'])->name('state.list');

Route::post('/trimble-location', [HomeController::class, 'getTrimbleLocation'])->name('trimble.location');

Route::get('/add-load-status-order', [HomeController::class, 'updateSortOrderLoadStatus']);

// Route::post('sms-status', 'WebhookController@receiveSMS')->name('sms-status');
// Route::post('status-callback', 'WebhookController@statusCallback')->name('status-callback');

Route::post('/sendgrid/send-email', [\App\Http\Controllers\SendGridController::class, 'sendEmail']);
Route::post('/sendgrid/webhook', [\App\Http\Controllers\SendGridController::class, 'handle']);

// DEVELOPED AT 29-03-2023
Route::post('/sendgrid/send-chat-email', [\App\Http\Controllers\SendGridController::class, 'sendChatEmail']);
Route::post('/receive-email-response', [\App\Http\Controllers\SendGridController::class, 'receiveEmailResponse']);
Route::post('/sendgrid/chat-email-history', [\App\Http\Controllers\SendGridController::class, 'getChatEmailHistory']);
Route::post('/chat-load-more-email-history', [\App\Http\Controllers\SendGridController::class, 'loadMoreChatEmailHistory']);
Route::post('/chat-search-email-history', [\App\Http\Controllers\SendGridController::class, 'searchChatEmailHistory']);

Route::post('/twilio/send-sms', [\App\Http\Controllers\TwilioController::class, 'sendSms']);
Route::post('/twilio/receive-sms', [\App\Http\Controllers\TwilioController::class, 'receiveSms']);
// DEVELOPED at 13-04-2023
Route::post('/incoming-email-sendgrid', [\App\Http\Controllers\SendGridController::class, 'incomingEmail']);

/*
|--------------------------------------------------------------------------
| Extra Routes
|--------------------------------------------------------------------------
*/

Route::get('update-manager-role', function() {
	\App\Models\CompanyAdmin::where('type', 1)->update(['role_id' => 0]);
	\App\Models\CompanyAdminRole::where('guard_name', 'manager')->delete();
	return 'update';
});

Route::get('delete-load-appointment', function() {
    // \App\Models\LoadAppointment::query()->forceDelete();
    \App\Models\LoadAppointment::whereNull('customer_id')->forceDelete();
    return 'delete';
});

Route::get('test-job', function(){
    dispatch(new App\Jobs\TestJob());
    dd('done');
});

Route::get('test-email', function(){
    try {
        $details = [
            "full_name"         => "Sam Driver",
            "load_id"           => 10392,
            "load_detail_id"    => 10374,
            "load_number"       => "DEF-12",
            "documents"         => [
                "Stop 1 - AP Form",
                "Stop 1 - Bill of Lading"
            ]
        ];
        \Illuminate\Support\Facades\Mail::to('web.dhaval@spaculus.info')->queue(new \App\Mail\LoadDocumentRequestDriver($details));
    } catch (\Swift_TransportException $e) {
        dd('Email sending failed: ' . $e->getMessage());
    } catch (\Exception $e) {
        dd('An error occurred while sending the email: ' . $e->getMessage());
    }
});