import cors from "cors";
import createError from "http-errors";
import express, { json, urlencoded, request } from "express";
import logger from "morgan";
import session from "express-session";
import store from "connect-mongo";
import cookieParser from "cookie-parser";
import { Router } from "express";
import axios, { Axios } from "axios";
import { asyncWrapper } from "./utils/controller.js";

import { twilioConfig } from "./config/index.js";
import { LaravelApiBaseURL } from "./config/index.js";
import { createToken } from "./utils/token.js";
import twilio from "twilio";
import jwt from "jsonwebtoken";
import { twilioServiceSid } from "./config/index.js";
import * as fs from "fs";

import { corsClient, port, sessionDB } from "./config/index.js";
console.log("***************************************");
console.log(process.env.NODE_ENV);
console.log("***************************************");
var app = express();

import http from "http";
import https from "https";

let server;
if (process.env.NODE_ENV === "production") {
    server = https.createServer(
        {
            key: fs.readFileSync("key.pem"),
            cert: fs.readFileSync("cert.pem")
        },
        app
    );
} else {
    server = http.createServer(app);
}

var router = Router();

// import { createServer } from "http";
import { Server } from "socket.io";

/*const options = {
    key: fs.readFileSync('/etc/ssl/private/ssl-cert-snakeoil.key'),
    cert: fs.readFileSync('/etc/ssl/certs/ssl-cert-snakeoil.pem')
}*/
// const server = createServer(options, app);
const io = new Server(server, { cors: { origin: "*" } });

//Whenever someone connects this gets executed
io.on("connection", function(socket) {
    socket.on("hello", arg => {
        console.log(arg); // world
    });
    console.log("A user connected");

    //Whenever someone disconnects this piece of code executed
    socket.on("disconnect", function() {
        console.log("A user disconnected");
    });
});

app.use(logger("dev"));
app.use(json());
app.use(urlencoded({ extended: false }));

// app.use(cors({
//     origin: corsClient.domain,
//     credentials: true,
//     methods: ['GET', 'POST', 'DELETE'],
//     maxAge: 3600 * 1000,
//     allowedHeaders: ['Content-Type', 'Range','myToken'],
//     exposedHeaders: ['Accept-Ranges', 'Content-Encoding', 'Content-Length', 'Content-Range']
// }));
app.use(cors());
app.options("*", cors());

app.use(cookieParser());

await app.use(
    session({
        secret: "anything",
        resave: true,
        saveUninitialized: false,
        cookie: {
            maxAge: 24 * 60 * 60 * 365 * 1000
        }
    })
);

await app.get("/me", function(req, res, next) {
    req.session.asd = "123";
    // req.cookies.asdf = 12345;
    console.log("request demo", req.cookies.asdf);
    res.send({ msg: "hello world" });
});

await app.get("/you", function(req, res, next) {
    console.log("request you session", req.session);
    // console.log('request you', req.cookies.asdf);
    res.send({ msg: "You world" });
});

async function GetToken(req, res, next) {
    try {
        let token = req.headers.authorization.split(" ")[1];
        if (!token) {
            res.json({
                success: false,
                message: "Error! Token was not provided."
            });
        } else {
            const decodedToken = jwt.verify(token, "secretkeyappearshere");
            res.status(200).json({
                success: true,
                data: {
                    token: decodedToken.token,
                    username: decodedToken.username
                }
            });
        }
        io.emit("demo", "12345");
    } catch (error) {
        res.json({
            success: false,
            message: "Error! There was a problem with the token."
        });
    }
}

async function DeleteToken(req, res, _next) {
    delete req.session.token;
    delete req.session.username;

    res.send({ message: "Session destroyed" });
}

async function DeleteConversation(req, res, next) {
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { conversationSid } = req.body;
    try {
        if (conversationSid) {
            await client.conversations.conversations(conversationSid).remove();

            res.json({
                success: true,
                message: "Conversation deleted successfully"
            });
        } else {
            res.json({
                success: false,
                message: "Missing direct conversationSid"
            });
        }
    } catch (error) {
        next({
            error,
            message: "There was a problem deleting your conversation"
        });
    }
}

async function CreateDirectConversation(req, res, next) {
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const {
        conversationTitle,
        username1,
        username2,
        friendlyName1,
        friendlyName2,
        profilePic1,
        profilePic2
    } = req.body;

    try {
        console.log("*****request body*******");
        console.log(req.body);

        console.log("************");
        if (conversationTitle && username1 && username2) {
            var conversation = await client.conversations.conversations.create({
                friendlyName: conversationTitle
            });

            let convAttr = JSON.stringify({
                convType: "one_to_one",
                username1: username1,
                username2: username2,
                friendlyName1: friendlyName1,
                friendlyName2: friendlyName2,
                profilePic1: profilePic1,
                profilePic2: profilePic2,
                username1_visibility: 1,
                username2_visibility: 1
            });
            if (req.body.user2EldId) {
                convAttr = JSON.stringify({
                    convType: "one_to_one",
                    username1: username1,
                    username2: username2,
                    friendlyName1: friendlyName1,
                    friendlyName2: friendlyName2,
                    profilePic1: profilePic1,
                    profilePic2: profilePic2,
                    username1_visibility: 1,
                    username2_visibility: 1,
                    user2EldId: req.body.user2EldId
                });
            }

            await client.conversations
                .conversations(conversation.sid)
                .update({ attributes: convAttr })
                .then(conv => {
                    console.log(conv);
                    conversation = conv;
                });

            let attr1 = JSON.stringify({
                friendlyName: friendlyName1,
                profilePic: profilePic1
            });
            let attr2 = JSON.stringify({
                friendlyName: friendlyName2,
                profilePic: profilePic2
            });
            let participant1 = await client.conversations
                .conversations(conversation.sid)
                .participants.create({ identity: username1 });

            await client.conversations
                .conversations(conversation.sid)
                .participants(participant1.sid)
                .update({ attributes: attr1 })
                .then(participant => {
                    console.log(participant);
                    participant1 = participant;
                });

            let participant2 = await client.conversations
                .conversations(conversation.sid)
                .participants.create({ identity: username2 });

            await client.conversations
                .conversations(conversation.sid)
                .participants(participant2.sid)
                .update({ attributes: attr2 })
                .then(participant => {
                    console.log(participant);
                    participant2 = participant;
                });

            res.send({ conversation, participant1, participant2 });
        } else {
            next({ message: "Missing direct conversation parameters" });
        }
    } catch (error) {
        next({
            error,
            message: "There was a problem creating your conversation"
        });
    }
}

async function CreateGroupConversation(req, res, next) {
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { conversationTitle, participant_details } = await req.body;

    try {
        console.log("*****request body*******");
        console.log(req.body);

        console.log("************");
        if (conversationTitle) {
            var conversation = await client.conversations.conversations.create({
                friendlyName: conversationTitle
            });

            let replacerFunc = async obj => {
                let cache = [];
                let str = JSON.stringify(obj, function(key, value) {
                    if (typeof value === "object" && value !== null) {
                        if (cache.indexOf(value) !== -1) {
                            // Circular reference found, discard key
                            return;
                        }
                        // Store value in our collection
                        cache.push(value);
                    }
                    return value;
                });
                cache = null; // reset the cache
                return str;
            };
            let pd = await participant_details;
            let convAttr = await replacerFunc({
                convType: "group",
                participant_details: await pd
            });

            await client.conversations
                .conversations(conversation.sid)
                .update({ attributes: convAttr })
                .then(conv => {
                    console.log(conv);
                    conversation = conv;
                });

            for (let i = 0; i < pd.length; i++) {
                let fn = await pd[i].friendlyName;
                let pp = await pd[i].profilePic;
                let un = await pd[i].username;
                let attr1 = await replacerFunc({
                    friendlyName: await fn,
                    profilePic: await pp
                });
                setTimeout(async function() {
                    let participant = await client.conversations
                        .conversations(conversation.sid)
                        .participants.create({ identity: await un });
                    if (participant.hasOwnProperty("sid")) {
                        await client.conversations
                            .conversations(conversation.sid)
                            .participants(participant.sid)
                            .update({ attributes: attr1 })
                            .then(participant1 => {
                                console.log(
                                    "Prtcpnt1 ********************",
                                    participant1
                                );
                            });
                    } else {
                        console.log("no participant to be updated");
                    }
                }, 0);
            }
            res.send({ conversation });
        } else {
            next({ message: "Missing group conversation parameters" });
        }
    } catch (error) {
        next({
            error,
            message: "There was a problem creating your conversation"
        });
    }
}

async function CreateLoadConversation(req, res, next) {
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { load_number, ttl, load_id } = req.body;

    try {
        console.log("*****request body*******");
        console.log(req.body);

        console.log("************");
        if (load_number) {
            var conversation = await client.conversations.conversations.create({
                friendlyName: load_number
            });

            let convAttr = JSON.stringify({
                convType: "load",
                load_id: await load_id
            });

            await client.conversations
                .conversations(conversation.sid)
                .update({
                    attributes: convAttr,
                    "timers.closed": "P" + ttl + "D"
                })
                .then(conv => {
                    console.log(conv);
                    conversation = conv;
                });
            res.send({ conversation });
        } else {
            next({ message: "Missing load conversation parameters" });
        }
    } catch (error) {
        next({
            error,
            message: "There was a problem creating your load conversation"
        });
    }
}

async function CreateLoadInternalConversation(req, res, next) {
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { load_number, ttl } = req.body;

    try {
        console.log("*****request body*******");
        console.log(req.body);

        console.log("************");
        if (load_number) {
            var conversation = await client.conversations.conversations.create({
                friendlyName: load_number
            });

            let convAttr = JSON.stringify({ convType: "load_internal" });

            await client.conversations
                .conversations(conversation.sid)
                .update({
                    attributes: convAttr,
                    "timers.closed": "P" + ttl + "D"
                })
                .then(conv => {
                    console.log(conv);
                    conversation = conv;
                });

            res.send({ conversation });
        } else {
            next({ message: "Missing load conversation parameters" });
        }
    } catch (error) {
        next({
            error,
            message: "There was a problem creating your load conversation"
        });
    }
}

async function addLoadParticipant(req, res, next) {
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { load_sid, participant_details } = req.body;

    try {
        console.log("*****request body*******");
        console.log(await req.body);

        console.log("************");
        let replacerFunc = async obj => {
            let cache = [];
            let str = JSON.stringify(obj, function(key, value) {
                if (typeof value === "object" && value !== null) {
                    if (cache.indexOf(value) !== -1) {
                        // Circular reference found, discard key
                        return;
                    }
                    // Store value in our collection
                    cache.push(value);
                }
                return value;
            });
            cache = null; // reset the cache
            return str;
        };

        let loadParticipant = {};
        setTimeout(async function() {
            for (let i = 0; i < (await participant_details.length); i++) {
                let attr1 = await replacerFunc({
                    friendlyName: await participant_details[i].friendlyName,
                    profilePic: await participant_details[i].profilePic
                });
                console.log("attr1,participant_details[i].username");
                console.log(await attr1, await participant_details[i].username);
                let participant = await client.conversations
                    .conversations(await load_sid)
                    .participants.create({
                        identity: await participant_details[i].username
                    });

                await client.conversations
                    .conversations(load_sid)
                    .participants(await participant.sid)
                    .update({ attributes: attr1 })
                    .then(p => {
                        console.log(p);
                        loadParticipant = p;
                    });
            }

            res.send({ loadParticipant });
        }, 0);
    } catch (error) {
        next({
            error,
            message: "There was a problem creating your conversation"
        });
    }
}

async function removeConversationParticipant(req, res, next) {
    var client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    var { conversationSid, old_participants } = req.body;

    try {
        console.log("*****request body*******");
        console.log(await req.body);

        console.log("************");

        let loadParticipant = {};
        for (let i = 0; i < (await old_participants.length); i++) {
            setTimeout(async function() {
                await client.conversations
                    .conversations(await conversationSid)
                    .participants(await old_participants[i])
                    .remove();

                console.log(i);
            }, 0);
        }

        res.json({
            success: true,
            message: "Conversation participants deleted successfully"
        });
    } catch (error) {
        next({
            error,
            message: "There was a problem deleting conversation participants"
        });
    }
}

async function CreateGenelarBoardConversation(req, res, next) {
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { participant_details } = req.body;

    try {
        console.log("*****request body*******");
        console.log(req.body);

        console.log("************");

        var conversation = await client.conversations.conversations.create({
            friendlyName: "General"
        });

        let convAttr = JSON.stringify({
            convType: "general_board",
            participant_details: participant_details
        });

        await client.conversations
            .conversations(conversation.sid)
            .update({ attributes: convAttr })
            .then(conv => {
                console.log(conv);
                conversation = conv;
            });

        for (let i = 0; i < participant_details.length; i++) {
            let attr1 = JSON.stringify({
                friendlyName: participant_details[i].friendlyName,
                profilePic: participant_details[i].profilePic
            });
            console.log("attr1,participant_details[i].username");
            console.log(attr1, participant_details[i].username);
            let participant = await client.conversations
                .conversations(conversation.sid)
                .participants.create({
                    identity: participant_details[i].username
                });

            await client.conversations
                .conversations(conversation.sid)
                .participants(participant.sid)
                .update({ attributes: attr1 })
                .then(participant => {
                    console.log(participant);
                });
        }

        res.send({ conversation });
    } catch (error) {
        next({
            error,
            message: "There was a problem creating your conversation"
        });
    }
}

async function UpdateGroupConversation(req, res, next) {
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { conversationTitle, participant_details, groupSid } = req.body;

    try {
        console.log("*****request body*******");
        console.log(req.body);

        console.log("************");
        if (conversationTitle) {
            let convAttr = JSON.stringify({
                convType: "group",
                participant_details: participant_details
            });
            let old_participants = [];
            await client.conversations.v1
                .conversations(groupSid)
                .participants.list()
                .then(participants =>
                    participants.forEach(p => {
                        old_participants[p.identity] = p.sid;
                    })
                );

            console.log(old_participants);
            for (let i = 0; i < participant_details.length; i++) {
                if (participant_details[i].username in old_participants) {
                    delete old_participants[participant_details[i].username];
                    delete participant_details[i];
                }
            }
            for (var key in old_participants) {
                console.log(key, old_participants[key]);
                client.conversations
                    .conversations(groupSid)
                    .participants(old_participants[key])
                    .remove();
            }

            for (var i in participant_details) {
                console.log(
                    "*********************************",
                    participant_details[i]
                );
                let attr1 = JSON.stringify({
                    friendlyName: participant_details[i].friendlyName,
                    profilePic: participant_details[i].profilePic
                });
                console.log("attr1,participant_details[i].username");
                console.log(attr1, participant_details[i].username);
                let participant = await client.conversations
                    .conversations(groupSid)
                    .participants.create({
                        identity: participant_details[i].username
                    });

                await client.conversations
                    .conversations(groupSid)
                    .participants(participant.sid)
                    .update({ attributes: attr1 })
                    .then(participant => {
                        console.log(participant);
                    });
            }
            let conversation = await client.conversations.v1
                .conversations(groupSid)
                .update({ friendlyName: conversationTitle })
                .then(conversation => console.log(conversation.friendlyName));
            res.send({ conversation });
        } else {
            next({ message: "Missing group conversation parameters" });
        }
    } catch (error) {
        next({
            error,
            message: "There was a problem creating your conversation"
        });
    }
}

async function StartConversation(req, res, next) {
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { conversationTitle, username } = req.body;

    try {
        if (conversationTitle && username) {
            var conversation = await client.conversations.conversations.create({
                friendlyName: conversationTitle
            });

            await client.conversations
                .conversations(conversation.sid)
                .update({ attributes: '{convType: "one_to_one1"}' })
                .then(conversation => console.log(conversation));

            req.session.token = await createToken(
                username,
                conversation.chatServiceSid
            );

            req.session.username = username;
            const participant = await client.conversations
                .conversations(conversation.sid)
                .participants.create({ identity: username });

            res.send({ conversation, participant });
        } else {
            next({ message: "Missing conversation title or username" });
        }
    } catch (error) {
        next({
            error,
            message: "There was a problem creating your conversation"
        });
    }
}

async function AddParticipant(req, res, next) {
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);
    const { username } = req.body;
    const conversationSid = req.params.id;

    try {
        const conversation = await client.conversations.conversations
            .get(conversationSid)
            .fetch();

        if (username && conversationSid) {
            req.session.token = await createToken(
                username,
                conversation.chatServiceSid
            );
            req.session.username = username;

            const participant = await client.conversations
                .conversations(conversationSid)
                .participants.create({ identity: username });

            res.send({ conversation, participant });
        } else {
            next({ message: "Missing username or conversation Sid" });
        }
    } catch (error) {
        next({ error, message: "There was a problem adding a participant" });
    }
}

async function LoginParticipant(req, res, next) {
    const client = await twilio(
        twilioConfig.accountSid,
        twilioConfig.authToken
    );
    const { username } = req.body;
    console.log(req.body);

    try {
        const conversation = await client.conversations.conversations.get();
        let token = {};
        if (username) {
            let tempToken = await createToken(username, twilioServiceSid);
            req.session.token = await tempToken;

            //Creating jwt token
            token = await jwt.sign(
                { token: tempToken, username: username },
                "secretkeyappearshere",
                { expiresIn: "24h" }
            );

            // req.session.token = await createToken(username, conversation.chatServiceSid);
            req.session.username = username;

            res.json({
                success: true,
                data: { conversation, token, username: username }
            }); // res.send({ conversation,token});
        } else {
            res.json({ success: false, message: "Missing username" });
            // next({ message: 'Missing username or conversation Sid' });
        }
    } catch (error) {
        res.json({
            success: false,
            message: "There was a problem adding a participant",
            error: error
        });
        // next({ error, message: 'There was a problem adding a participant' });
    }
}

async function UpdateConversationVisibilityStatus(req, res, next) {
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { conversationSid, name, visibilityStatus } = req.body;

    let attrbutes = {};
    let cnv = {};
    try {
        // await client.conversations.v1.conversations(conversationSid)
        await client.conversations
            .conversations(conversationSid)
            .fetch()
            .then(conv => (attrbutes = conv.attributes));
        attrbutes = await JSON.parse(await attrbutes);
        if (
            (await attrbutes.username1) == name ||
            (await attrbutes.friendlyName1) == name
        ) {
            attrbutes.username2_visibility = visibilityStatus;
        } else {
            attrbutes.username1_visibility = visibilityStatus;
        }
        let UpdatedAtteibutes = await JSON.stringify(attrbutes);
        const conversation = await client.conversations.conversations
            .get(conversationSid)
            .update({ attributes: UpdatedAtteibutes })
            .then(conversation => {
                console.log(conversation.attributes);
                cnv = conversation;
            });
        res.json({ success: true, data: { cnv } });
    } catch (error) {
        res.json({
            success: false,
            message: "There was a problem getting conversation details",
            error: error
        });
        // next({ error, message: 'There was a problem getting conversation details' });
    }
}

async function UpdateConversation(req, res, next) {
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { conversationSid, convType, uid1, uid2, name1, name2 } = req.body;

    let attr = JSON.stringify({
        convType: convType,
        participants: [uid1, uid2, name1, name2]
    });
    var cnv = {};
    try {
        const conversation = await client.conversations.conversations
            .get(conversationSid)
            .update({ attributes: attr })
            .then(conversation => {
                console.log(conversation.friendlyName);
                cnv = conversation;
            });

        res.send({ cnv });
    } catch (error) {
        next({ error, message: "There was a problem adding a participant" });
    }
}

async function UpdateConversationStatus(req, res, next) {
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { conversationSid, conversationState } = req.body;
    console.log(conversationSid, conversationState);

    var cnv = {};
    let attr = { state: conversationState };
    console.log(attr);
    try {
        const conversation = await client.conversations.conversations
            .get(conversationSid)
            .update(attr)
            .then(conversation => {
                console.log(conversation.state);
                cnv = conversation;
            });

        res.send({ cnv });
    } catch (error) {
        next({ error, message: "There was a problem adding a participant" });
    }
}

async function getConversation(req, res, next) {
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { conversationSid } = req.body;
    console.log(conversationSid);

    var cnv = {};
    try {
        let conversation = await client.conversations.conversations
            .get(conversationSid)
            .fetch();

        res.send({ conversation });
    } catch (error) {
        next({ error, message: "There was a problem getting conversation" });
    }
}

async function closeCurrentLoadForNewLoad(req, res, next) {
    // console.log("req");
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { conversationSid, load_number, ttl } = req.body;
    console.log(req.body);
    var cnv = {};
    let attr = { state: "closed" };
    console.log(attr);
    try {
        if (load_number) {
            attr = JSON.stringify({
                isLoadCloseMsg: true,
                newLoadNumber: load_number
            });
            let create = { attributes: attr };
            await client.conversations
                .conversations(conversationSid)
                .messages.create(create)
                .then(msg => console.log("new message ", msg));

            attr = { state: "closed" };
            const conversation1 = await client.conversations.conversations
                .get(conversationSid)
                .update(attr)
                .then(conversation => {
                    console.log(conversation.state);
                    cnv = conversation;
                });

            var conversation = await client.conversations.conversations.create({
                friendlyName: load_number
            });

            let convAttr = JSON.stringify({ convType: "load" });

            await client.conversations
                .conversations(conversation.sid)
                .update({
                    attributes: convAttr,
                    "timers.closed": "P" + ttl + "D"
                })
                .then(conv => {
                    console.log(conv);
                    conversation = conv;
                });

            res.send({ conversation });
        } else {
            next({ message: "Missing load conversation parameters" });
        }
    } catch (error) {
        next({
            error,
            message:
                "There was a problem closing load conversation for new load"
        });
    }
}

async function addMessageTochatLoadInternal(req, res, next) {
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);
    console.log(req.body);
    console.log(req.files);
}

async function getConversationMessage(req, res, next) {
    console.log("req");
    console.log(req.body);
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { conversationSid, messageSid } = req.body;

    var message = {};
    try {
        await client.conversations
            .conversations(conversationSid)
            .messages(messageSid)
            .fetch()
            .then(msg => (message = msg));

        res.send(message);
    } catch (error) {
        next({ error, message: "There was a problem adding a participant" });
    }
}

async function getConversationMessages(req, res, next) {
    console.log("req");
    console.log(req.body);
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { conversationSid } = req.body;

    var message = {};
    try {
        await client.conversations
            .conversations(conversationSid)
            .messages.list()
            .then(msg => {
                console.log(msg);
                message = msg;
            });

        res.send(message);
    } catch (error) {
        next({ error, message: "There was a problem adding a participant" });
    }
}

async function forwardMessage(req, res, next) {
    console.log("req");
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);
    console.log(req.body);

    const {
        author,
        isForwarded,
        forwardTo,
        msgType,
        body,
        msgIndex,
        mediaSID,
        fromConversationSid,
        profilePic,
        friendlyName,
        initials
    } = req.body;
    if (typeof forwardTo !== "undefined" && forwardTo.length > 0) {
        let forwardToArray = forwardTo.split(",");

        for (let conversationSid of forwardToArray) {
            let attr = {};
            console.log("conversationSid = " + conversationSid);
            let create = { author: author, body: body };
            if (msgType == "text") {
                attr = JSON.stringify({
                    isForwarded: isForwarded,
                    msgType: msgType,
                    msgIndex: msgIndex,
                    fromConversationSid: fromConversationSid,
                    profilePic: profilePic,
                    friendlyName: friendlyName,
                    initials: initials
                });
                create = { author: author, body: body, attributes: attr };
            } else {
                attr = JSON.stringify({
                    isForwarded: isForwarded,
                    msgType: msgType,
                    msgIndex: msgIndex,
                    mediaSID: mediaSID,
                    fromConversationSid: fromConversationSid,
                    profilePic: profilePic,
                    friendlyName: friendlyName,
                    initials: initials
                });
                create = { author: author, attributes: attr };
            }
            console.log(attr);
            try {
                await client.conversations
                    .conversations(conversationSid)
                    .messages.create(create)
                    .then(msg => console.log("new message ", msg));
            } catch (error) {
                console.log(error);
                next({
                    error,
                    message: "There was a problem forworking message"
                });
            }
        }
        res.send({ message: "Message forwarded successfully" });
    } else {
        next({ message: "Message forwarding required atleast 1 receiver" });
    }
}

async function BoardMsgPropagation(req, res, next) {
    console.log("req");
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);
    console.log(await req.body, LaravelApiBaseURL);

    const {
        author,
        isForwarded,
        msgType,
        body,
        msgIndex,
        mediaSID,
        fromConversationSid,
        profilePic,
        friendlyName,
        initials
    } = req.body;
    console.log("yep1");

    let replacerFunc = async obj => {
        let cache = [];
        let str = JSON.stringify(obj, function(key, value) {
            if (typeof value === "object" && value !== null) {
                if (cache.indexOf(value) !== -1) {
                    // Circular reference found, discard key
                    return;
                }
                // Store value in our collection
                cache.push(value);
            }
            return value;
        });
        cache = null; // reset the cache
        return str;
    };

    let sid = { sid: await fromConversationSid };
    console.log("yep2");
    var data = {};
    let url = LaravelApiBaseURL + "/chat/get_general_boards";
    // let url = `https://mcs.us1.twilio.com/v1/Services/${chatServiceSid}/Media/${mediaSID}`;
    try {
        console.log("yep3");
        const resp = await axios
            .post(url, sid)
            .then(async function(response) {
                console.log(await response.data);
                data = await response.data;
            })
            .catch(async function(error) {
                console.log({
                    error,
                    message:
                        "There was a problem getting media details for given sid"
                });
                next({
                    error,
                    message:
                        "There was a problem getting media details for given sid"
                });
            });
    } catch (err) {
        console.log(err);
        next(err);
    }
    console.log("FrowardTo = ", await data);
    console.log(await data.status, await data.data.length);

    if (data.status && data.data.length > 0) {
        let forwardToArray = await data.data;
        console.log("yep4");

        for (let i in await forwardToArray) {
            let conversationSid = await forwardToArray[i];
            console.log("yep5", await conversationSid);
            let attr = {};
            console.log("conversationSid = " + (await conversationSid));
            let create = { author: await author, body: await body };
            if ((await msgType) == "text") {
                if ((await req.body.replyTo) != undefined) {
                    let rpt = await req.body.replyTo;
                    attr = await replacerFunc({
                        isForwarded: await isForwarded,
                        msgType: await msgType,
                        msgIndex: await msgIndex,
                        fromConversationSid: await fromConversationSid,
                        profilePic: await profilePic,
                        friendlyName: await friendlyName,
                        initials: await initials,
                        isBoardForwarded: false,
                        replyTo: await rpt
                    });
                } else {
                    attr = await replacerFunc({
                        isForwarded: isForwarded,
                        msgType: msgType,
                        msgIndex: msgIndex,
                        fromConversationSid: fromConversationSid,
                        profilePic: profilePic,
                        friendlyName: friendlyName,
                        initials: initials,
                        isBoardForwarded: false
                    });
                }
                create = { author: author, body: body, attributes: attr };
            } else {
                if ((await req.body.replyTo) != undefined) {
                    let rpt = await req.body.replyTo;
                    attr = await replacerFunc({
                        isForwarded: await isForwarded,
                        msgType: await msgType,
                        msgIndex: await msgIndex,
                        mediaSID: await mediaSID,
                        fromConversationSid: await fromConversationSid,
                        profilePic: await profilePic,
                        friendlyName: await friendlyName,
                        initials: await initials,
                        isBoardForwarded: false,
                        replyTo: await rpt
                    });
                } else {
                    attr = await replacerFunc({
                        isForwarded: await isForwarded,
                        msgType: await msgType,
                        msgIndex: await msgIndex,
                        mediaSID: await mediaSID,
                        fromConversationSid: await fromConversationSid,
                        profilePic: await profilePic,
                        friendlyName: await friendlyName,
                        initials: await initials,
                        isBoardForwarded: false
                    });
                }
                create = { author: await author, attributes: attr };
            }
            try {
                setTimeout(async function() {
                    await client.conversations
                        .conversations(await conversationSid)
                        .messages.create(create)
                        .then(msg => {});
                }, i * 10);
            } catch (error) {
                console.log(error);
                next({
                    error,
                    message: "There was a problem forworking message"
                });
            }
        }
        res.send({ message: "Message forwarded successfully" });
    } else {
        next({ message: "Message forwarding required atleast 1 receiver" });
    }
}

async function getMediaMessageDetails(req, res, next) {
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { conversationSid, mediaSID } = req.body;
    console.log(req.body);

    const conversation = await client.conversations.conversations
        .get(conversationSid)
        .fetch();
    await client.conversations
        .services(conversation.chatServiceSid)
        .configuration()
        .update({ reachabilityEnabled: true })
        .then(configuration => console.log(configuration.chatServiceSid));

    let chatServiceSid = conversation.chatServiceSid;
    let buff = new Buffer.from(
        twilioConfig.accountSid + ":" + twilioConfig.authToken
    );
    let token = buff.toString("base64");
    var data = {};
    var config = {
        headers: {
            Authorization: "Basic " + token
        }
    };
    let url = `https://mcs.us1.twilio.com/v1/Services/${chatServiceSid}/Media/${mediaSID}`;
    try {
        const resp = await axios
            .get(url, config)
            .then(function(response) {
                data = response.data;
            })
            .catch(function(error) {
                next({
                    error,
                    message:
                        "There was a problem getting media details for given sid"
                });
            });
    } catch (err) {
        console.log(err);
        next(err);
    }
    res.send(data);
}

async function conversationMessageSearch(req, res, next) {
    console.log("req");
    console.log(req.body);
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { conversationSid, searchText, page_size, page_number } = req.body;

    var messagesData = {};
    try {
        await client.conversations
            .conversations(conversationSid)
            .messages.list({ order: "desc" })
            .then(msg => (messagesData = msg));

        let searchResult = [];
        // Loop through the messages in the first page and log the ones that match the search query
        await messagesData.forEach(async message => {
            if (message.body != null) {
                if (
                    message.body
                        .trim()
                        .toLowerCase()
                        .includes(searchText.trim().toLowerCase())
                ) {
                    let t1 = {
                        attributes: JSON.parse(message.attributes),
                        author: message.author
                    };
                    message.state = t1;
                    message.dateCreated = new Date(message.dateCreated);
                    searchResult.push(await message);
                }
            } else {
            }
        });
        let msgCount = await searchResult.length;
        let messagesData1 = searchResult.slice(
            (page_number - 1) * page_size,
            page_number * page_size
        );
        //console.log(messagesData1);
        let result = {
            count: msgCount,
            page_number: page_number,
            page_size: page_size,
            data: messagesData1
        };

        res.send(result);
    } catch (error) {
        next({ error, message: "There was a problem in message search" });
    }
}

async function getClosedconversationMessages(req, res, next) {
    console.log("req");
    console.log(req.body);
    const client = twilio(twilioConfig.accountSid, twilioConfig.authToken);

    const { conversationSid, page_size, page_number } = req.body;

    var messagesData = {};
    try {
        await client.conversations
            .conversations(conversationSid)
            .messages.list({ order: "desc" })
            .then(msg => (messagesData = msg));

        let searchResult = [];
        // Loop through the messages in the first page and log the ones that match the search query
        await messagesData.forEach(async message => {
            let msgType = "text";
            let t1 = {
                attributes: JSON.parse(message.attributes),
                author: message.author,
                type: "text"
            };
            if (message.media != null) {
                t1 = {
                    attributes: JSON.parse(message.attributes),
                    author: message.author,
                    filename: message.media[0].filename,
                    contentType: message.media[0].content_type,
                    mediaSID: message.media[0].sid
                };
                let t2 = {
                    state: {
                        filename: message.media[0].filename,
                        contentType: message.media[0].content_type,
                        mediaSID: message.media[0].sid
                    }
                };
                msgType = "media";
                message.media = t2;
            }
            message.state = t1;
            message.type = msgType;
            message.dateCreated = new Date(message.dateCreated);
            searchResult.push(await message);
        });
        let msgCount = await searchResult.length;
        let messagesData1 = searchResult.slice(
            (page_number - 1) * page_size,
            page_number * page_size
        );
        let result = {
            count: msgCount,
            page_number: page_number,
            page_size: page_size,
            data: messagesData1
        };
        res.send(result);
    } catch (error) {
        next({
            error,
            message: "There was a problem fetching closed conversation messages"
        });
    }
}

await app.post("/api/conversations", asyncWrapper(StartConversation));

await app.post(
    "/api/conversations/:id/participants",
    asyncWrapper(AddParticipant)
);

await app.delete("/auth/token", DeleteToken);

await app.get("/auth/token", GetToken);

await app.post("/api/loginParticipant", asyncWrapper(LoginParticipant));

await app.post("/api/updateConversation", asyncWrapper(UpdateConversation));

await app.post(
    "/api/getConversationMessage",
    asyncWrapper(getConversationMessage)
);

await app.post(
    "/api/getMediaMessageDetails",
    asyncWrapper(getMediaMessageDetails)
);

await app.post("/api/forwardMessage", asyncWrapper(forwardMessage));

await app.post(
    "/api/createDirectConversation",
    asyncWrapper(CreateDirectConversation)
);

await app.post("/api/deleteConversation", asyncWrapper(DeleteConversation));

await app.post(
    "/api/updateConversationVisibilityStatus",
    asyncWrapper(UpdateConversationVisibilityStatus)
);

await app.post(
    "/api/CreateGroupConversation",
    asyncWrapper(CreateGroupConversation)
);

await app.post(
    "/api/updateGroupConversation",
    asyncWrapper(UpdateGroupConversation)
);

await app.post(
    "/api/CreateGenelarBoardConversation",
    asyncWrapper(CreateGenelarBoardConversation)
);

await app.post("/api/BoardMsgPropagation", asyncWrapper(BoardMsgPropagation));

await app.post(
    "/api/UpdateConversationStatus",
    asyncWrapper(UpdateConversationStatus)
);

await app.post(
    "/api/getConversationMessages",
    asyncWrapper(getConversationMessages)
);

await app.post(
    "/api/CreateLoadConversation",
    asyncWrapper(CreateLoadConversation)
);

await app.post("/api/addLoadParticipant", asyncWrapper(addLoadParticipant));

await app.post(
    "/api/conversationMessageSearch",
    asyncWrapper(conversationMessageSearch)
);

await app.post(
    "/api/closeCurrentLoadForNewLoad",
    asyncWrapper(closeCurrentLoadForNewLoad)
);

await app.post("/api/getConversation", asyncWrapper(getConversation));

await app.post(
    "/api/getClosedconversationMessages",
    asyncWrapper(getClosedconversationMessages)
);

await app.post(
    "/api/removeConversationParticipant",
    asyncWrapper(removeConversationParticipant)
);

await app.post(
    "/api/CreateLoadInternalConversation",
    asyncWrapper(CreateLoadInternalConversation)
);

await app.post(
    "/api/addMessageTochatLoadInternal",
    asyncWrapper(addMessageTochatLoadInternal)
);

app.use(function(_req, _res, next) {
    next(createError(404, "Route does not exist."));
});

app.use(function(err, _req, res, _next) {
    res.status(err.status || 500).send(err);
});

server.listen(port);
