<?php

namespace App\Http\Controllers\CompanyAdmin;

use App\Http\Controllers\CompanyAdmin\CompanyAdminController;

use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Illuminate\Support\Arr;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;

use App\Http\Requests\CompanyAdmin\LoadStoreRequest;
use App\Http\Requests\CompanyAdmin\LoadUpdateRequest;
use App\Http\Requests\CompanyAdmin\SplitLoadStoreRequest;

use App\Mail\DetentionRequestBroker;
use App\Mail\CompanyAdmin\LoadNoteCreate;
use App\Mail\CompanyAdmin\LoadAssignMailToDriver;
use App\Mail\CompanyAdmin\LoadUpdateMailToDriver;

use App\Mail\LoadDocumentRequestDriver;
use App\Mail\CompanyAdmin\LoadDroppedFromDropTrailer;
use App\Mail\CompanyAdmin\LoadOnHoldFromDropTrailer;

use App\Models\Load;
use App\Models\LoadStop;
use App\Models\LoadNote;
use App\Models\LoadDriver;
use App\Models\LoadReject;
use App\Models\LoadDetail;
use App\Models\LoadTrailer;
use App\Models\LoadDetention;
use App\Models\LoadTruckOwner;

use App\Models\LoadStopReview;
use App\Models\LoadAppointment;
use App\Models\LoadAppointmentLog;
use App\Models\LoadDocumentRequest;
use App\Models\LoadDocumentRequestItem;

use App\Models\LoadFile;
use App\Models\LoadFileType;

use App\Models\Accessorial;
use App\Models\CompanyAccessorial;

use App\Models\LoadAccessorial;
use App\Models\LoadAccessorialTemp;

use App\Models\LoadRequirement;
use App\Models\CompanyLoadRequirement;

use App\Models\LoadLog;
use App\Models\LoadAudit;

use App\Models\Driver;
use App\Models\DriverAvoidState;
use App\Models\DriverInformation;
use App\Models\DriverRestrictedState;

use App\Models\Vendor;
use App\Models\Carrier;
use App\Models\Terminal;
use App\Models\TruckOwner;

use App\Models\Broker;
use App\Models\BrokerOffice;
use App\Models\BrokerContact;

use App\Models\Trailer;
use App\Models\TrailerType;
use App\Models\DropTrailer;

use App\Models\Offer;
use App\Models\State;
use App\Models\Shipper;
use App\Models\Customer;

use App\Models\Gallery;
use App\Models\FileUpload;

use App\Models\CompanyAdmin;

use App\Models\Bookmark;
use App\Models\IntegrationSetting;
use App\Models\WeeklyFuelSurcharge;
use App\Models\VehicleHistoricalStats;

use App\Traits\TrimbleTrait;
use App\Traits\AuditLoagTrait;

use Mail;
use File;
use DateTime;
use DataTables;
use Carbon\Carbon;
use App\Helpers\Common;

class LoadController extends CompanyAdminController{

    use TrimbleTrait,AuditLoagTrait;

    public $timeZone;
    public $timeZoneId;
    public $offset;

    public function __construct(){
        parent::__construct();

        // Set the maximum execution time to 3600 seconds
        ini_set('max_execution_time', 0);

        // Set the maximum memory limit to 2048 megabytes
        ini_set('memory_limit', '1024M');

        $this->middleware(function ($request, $next) {
            $this->timeZone     = getTimeZone();
            $this->timeZoneId   = getTimeZoneId();
            $this->offset       = getTimeZoneOffset();

            return $next($request);
        });
    }

    public function clusterPoints($id=''){
        // return view('liveMap');
        // return view('load_view');
        //
        if($id==2){
            return view('clusterPoints.demo_second');
        }else{
            return view('clusterPoints.demo');
        }
    }

    /**
     * Display a listing of active loads.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request){
        try {
            $getCompanyAdmin            = auth()->guard('company-admin')->user();

            $getField                   = '';
            $isCheck                    = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','loads_active')->first();
            if( !empty( $isCheck->id ) ) {
                //$getField             = unserialize($isCheck->config);
                $getField               = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_loads_active_first'));
            } else {
                $getField               = config('settings.table_loads_active_first');
            }

            if( $request->ajax() ) {
                $data                   = LoadDetail::select('load_details.*', DB::raw('CONCAT(drivers.first_name," ",drivers.last_name) as driver'), 'drivers.cell_phone as phone_number', 'brokers.name as broker_name')
                    ->leftJoin('drivers', 'load_details.driver_id', '=', 'drivers.id')
                    ->leftJoin('brokers', 'load_details.brokerage_firm', '=', 'brokers.id')
                    //->leftJoin('company_admins', 'load_details.booked_by', '=', 'company_admins.id')
                    ->where('load_details.is_disable', 0)
                    ->where( function($query) {
                        $query->whereNotIn('load_details.load_status',[5,6,7,8,9,10])
                        ->orWhere(function($q) {
                            $q->whereNull('load_details.driver_id')->orWhere('load_details.driver_id', 0);
                        });
                    })
                    ->where(function($q) {
                        $q->whereNull('load_details.is_on_hold')->orWhere('load_details.is_on_hold', 0);
                    })
                    ->whereNull('load_details.deleted_at')
                    ->whereHas('loads', function($q){
                        $q->where('loads.company_id', auth()->guard('company-admin')->user()->company_id)->whereNull('loads.deleted_at');
                    });
                // General filter code - start
                foreach( $getField as $key => $value ) {
                    $conditionReq       = 'search_string_condition_'.$key;
                    $sortReq            = 'search_string_sort_'.$key;
                    $conditionDateReq   = 'search_date_condition_'.$key;
                    $sortDateReq        = 'search_date_sort_'.$key;
                    $conditionStatusReq = 'search_status_condition_'.$key;
                    $sortStatusReq      = 'search_status_sort_'.$key;

                    // String filter
                    if( isset( request()->$conditionReq ) ) {
                        $typeReq        = 'search_string_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'string' ) {
                            Common::getStringFilterResult( $data, $key );
                        }
                    }

                    // Status filter
                    if( isset( request()->$conditionStatusReq ) && request()->$conditionStatusReq == 1 ) {
                        Common::getStatusFilterResult( $data, $key );
                    }

                    // Date filter
                    if( isset( request()->$conditionDateReq ) ) {
                        $typeReq        = 'search_date_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'date' ) {
                            Common::getDateFilterResult( $data, $key );
                        }
                    }

                    // String sort only
                    if( isset( request()->$sortReq ) ) {
                        Common::sortStringFilter( $data, $key );
                    }

                    // Date sort only
                    if( isset( request()->$sortDateReq ) ) {
                        Common::sortDateFilter( $data, $key );
                    }

                    // Status sort only
                    if( isset( request()->$sortStatusReq ) ) {
                        Common::sortStatusFilter( $data, $key );
                    }
                }
                // General filter code - end
                $data->get();
                return Datatables::of($data)
                    ->addIndexColumn()
                    ->editColumn('load_number', function($row){
                        if ($row->is_disable == 0) {
                            if(in_array($row->load_type, ['0', '6'])) {
                                if ($row->load_type == 0) {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                                } else {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                                }
                            } else {
                                return '<a href="'.route('company.admin.loads.edit', base64Encode($row->load_id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        } else {
                            if ($row->load_type == 0) {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                            } else {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        }
                    })
                    /*
                    ->addColumn('driver', function($row){
                        return isset($row->driver->full_name) ? $row->driver->full_name : '';
                    })
                    */
                    ->filterColumn('driver', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(drivers.first_name, ' ', drivers.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('phone_number', function($row){
                        return isset($row->driver->cell_phone) ? $row->driver->cell_phone : '';
                    })
                    */
                    ->filterColumn('phone_number', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where("drivers.cell_phone", 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('broker_name', function($row){
                        return isset($row->broker->name) ? $row->broker->name : '';
                    })
                    */
                    ->filterColumn('broker_name', function ($query, $keyword) {
                        $query->whereHas('broker', function ($q) use ($keyword) {
                            $q->where("brokers.name", 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('actual_delivery_date', function($row){
                        return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date." ".$row->delivery_timezone_abbr : '';
                    })
                    ->editColumn('created_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('updated_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('booked_by', function($row){
                        if($row->booked_by == 0){
                            return 'Self Dispatch';
                        }else{
                            return $row->dispatcher->full_name;
                        }
                    })
                    ->filterColumn('booked_by', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('trailer_type', function($row){
                        return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                    })
                    ->addColumn('dispatcher', function($row){
                        return getLoadDispatcherName($row->booked_by);
                    })
                    ->filterColumn('dispatcher', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->addColumn('status', function($row){
                        return getLoadStatus($row->load_status,$row->is_on_hold);
                    })
                    ->filterColumn('status', function ($query, $keyword) {
                        if (Str::contains('pending' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 0);
                        }
                        if (Str::contains('accepted' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 1);
                        }
                        if (Str::contains('preplaned' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 2);
                        }
                        if (Str::contains('confirmed' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 3);
                        }
                        if (Str::contains('in transit' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 4);
                        }
                        if (Str::contains('delivered' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 5);
                        }
                        if (Str::contains('ready to bill' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 6);
                        }
                        if (Str::contains('on hold' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 7);
                        }
                        if (Str::contains('complete' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 8);
                        }
                        if (Str::contains('cancelled' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 9);
                        }
                        return $query;
                    })
                    ->addColumn('last_location', function($row){
                        return 'Seattle, WA, USA';
                    })
                    ->editColumn('total_bill', function($row){
                        return getPrice($row->total_bill);
                    })
                    ->editColumn('shipper_location', function($row){
                        $html = [];
                        if($row->shipper_address_one){
                            $html[0]    = $row->shipper_address_one;
                        }
                        if($row->shipper_address_two){
                            $html[1]    = $row->shipper_address_two;
                        }
                        if($row->shipper_city){
                            $html[2]    = $row->shipper_city;
                        }
                        if($row->shipper_state){
                            $html[3]    = $row->shipper_state;
                        }
                        if($row->shipper_zip){
                            $html[4]    = $row->shipper_zip;
                        }
                        if(count($html) == 0){
                            return $row->shipper_location;
                        }else{
                            return implode(', ', $html);
                        }
                    })
                    ->editColumn('delivery_location', function($row){
                        $html           = [];
                        if($row->delivery_address_one){
                            $html[0]    = $row->delivery_address_one;
                        }
                        if($row->delivery_address_two){
                            $html[1]    = $row->delivery_address_two;
                        }
                        if($row->delivery_city){
                            $html[2]    = $row->delivery_city;
                        }
                        if($row->delivery_state){
                            $html[3]    = $row->delivery_state;
                        }
                        if($row->delivery_zip){
                            $html[4]    = $row->delivery_zip;
                        }
                        if(count($html) == 0){
                            return $row->delivery_location;
                        }else{
                            return implode(', ', $html);
                        }
                    })
                    ->addColumn('action', function($row){
                        $btn            = '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1"><img src="'.asset('theme/img/eye.png').'" alt=""></a>';
                        if ($row->is_disable == 0) {
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-2.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-3.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="javascript:" class="destroy" data-action="'.route('company.admin.loads.destroy',$row->load_id).'" data-id="'.$row->load_id.'"><img src="'.asset('theme/img/tbl--icon-4.png').'" alt=""></a>';
                        }
                        return $btn;
                    })
                    ->rawColumns(['action','load_number'])
                    ->make(true);
            }

            $tableName                  = 'settings.table_loads_active';
            $tables                     = Common::getStaticLoadTables();
            $isMulitpleTable            = 1;
            //return view('companyAdmin.load.index', compact('getField'));
            //return view('companyAdmin.load.indextemp', compact('getField','tableName'));
            return view('companyAdmin.load.tempindex', compact( 'getField', 'tableName', 'tables', 'isMulitpleTable' ));
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );
        }
    }

    /**
     * Display a listing of the ready to bill loads.
     *
     * @return \Illuminate\Http\Response
     */
    public function newLoadsIndex(Request $request){
        try {
            $getCompanyAdmin            = auth()->guard('company-admin')->user();

            $getField                   = '';
            $isCheck                    = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','loads_active')->first();
            if(!empty($isCheck->id)) {
                //$getField             = unserialize($isCheck->config);
                $getField               = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_loads_active_first'));
            } else {
                $getField               = config('settings.table_loads_active_first');
            }

            if ($request->ajax()) {
                $data                   = LoadDetail::select('load_details.*', DB::raw('CONCAT(drivers.first_name," ",drivers.last_name) as driver'), 'drivers.cell_phone as phone_number', 'brokers.name as broker_name')
                    ->leftJoin('drivers', 'load_details.driver_id', '=', 'drivers.id')
                    ->leftJoin('brokers', 'load_details.brokerage_firm', '=', 'brokers.id')
                    ->where('load_details.is_disable', 0)
                    ->where(function($query) {
                        $query->whereIn('load_details.load_status',[6,10])
                        ->where(function($q) {
                            $q->whereNotNull('load_details.driver_id')->where('load_details.driver_id', '!=', 0);
                        });
                    })
                    ->whereIn('load_details.load_status', [6,10])
                    ->where(function($q) {
                        $q->whereNull('load_details.is_on_hold')->orWhere('load_details.is_on_hold', 0);
                    })
                    ->whereHas('loads', function($q){
                        $q->where('company_id', auth()->guard('company-admin')->user()->company_id);
                    });
                // General filter code - start
                foreach( $getField as $key => $value ) {
                    $conditionReq       = 'search_string_condition_'.$key;
                    $sortReq            = 'search_string_sort_'.$key;
                    $conditionDateReq   = 'search_date_condition_'.$key;
                    $sortDateReq        = 'search_date_sort_'.$key;
                    $conditionStatusReq = 'search_status_condition_'.$key;
                    $sortStatusReq      = 'search_status_sort_'.$key;

                    // String filter
                    if( isset( request()->$conditionReq ) ) {
                        $typeReq        = 'search_string_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'string' ) {
                            Common::getStringFilterResult( $data, $key );
                        }
                    }

                    // Status filter
                    if( isset( request()->$conditionStatusReq ) && request()->$conditionStatusReq == 1 ) {
                        Common::getStatusFilterResult( $data, $key );
                    }

                    // Date filter
                    if( isset( request()->$conditionDateReq ) ) {
                        $typeReq        = 'search_date_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'date' ) {
                            Common::getDateFilterResult( $data, $key );
                        }
                    }

                    // String sort only
                    if( isset( request()->$sortReq ) ) {
                        Common::sortStringFilter( $data, $key );
                    }

                    // Date sort only
                    if( isset( request()->$sortDateReq ) ) {
                        Common::sortDateFilter( $data, $key );
                    }

                    // Status sort only
                    if( isset( request()->$sortStatusReq ) ) {
                        Common::sortStatusFilter( $data, $key );
                    }
                }
                // General filter code - end
                $data->get();
                return Datatables::of($data)
                    ->addIndexColumn()
                    ->editColumn('load_number', function($row){
                        if ($row->is_disable == 0) {
                            if(in_array($row->load_type, ['0', '6'])) {
                                if ($row->load_type == 0) {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                                } else {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                                }
                            } else {
                                return '<a href="'.route('company.admin.loads.edit', base64Encode($row->load_id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        } else {
                            if ($row->load_type == 0) {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                            } else {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        }
                    })
                    /*
                    ->addColumn('driver', function($row){
                        return isset($row->driver->full_name) ? $row->driver->full_name : '';
                    })
                    */
                    ->filterColumn('driver', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(drivers.first_name, ' ', drivers.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('phone_number', function($row){
                        return isset($row->driver->cell_phone) ? $row->driver->cell_phone : '';
                    })
                    */
                    ->filterColumn('phone_number', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where("drivers.cell_phone", 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('broker_name', function($row){
                        return isset($row->broker->name) ? $row->broker->name : '';
                    })
                    */
                    ->filterColumn('broker_name', function ($query, $keyword) {
                        $query->whereHas('broker', function ($q) use ($keyword) {
                            $q->where("brokers.name", 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('actual_delivery_date', function($row){
                        return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date." ".$row->delivery_timezone_abbr : '';
                    })
                    ->editColumn('created_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('updated_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('booked_by', function($row){
                        if($row->booked_by == 0){
                            return 'Self Dispatch';
                        }else{
                            return $row->dispatcher->full_name;
                        }
                    })
                    ->filterColumn('booked_by', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('trailer_type', function($row){
                        return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                    })
                    ->addColumn('dispatcher', function($row){
                        return getLoadDispatcherName($row->booked_by);
                    })
                    ->filterColumn('dispatcher', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->addColumn('status', function($row){
                        return getLoadStatus($row->load_status,$row->is_on_hold);
                    })
                    ->filterColumn('status', function ($query, $keyword) {
                        if (Str::contains('pending' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 0);
                        }
                        if (Str::contains('accepted' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 1);
                        }
                        if (Str::contains('preplaned' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 2);
                        }
                        if (Str::contains('confirmed' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 3);
                        }
                        if (Str::contains('in transit' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 4);
                        }
                        if (Str::contains('delivered' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 5);
                        }
                        if (Str::contains('ready to bill' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 6);
                        }
                        if (Str::contains('on hold' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 7);
                        }
                        if (Str::contains('complete' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 8);
                        }
                        if (Str::contains('cancelled' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 9);
                        }
                        return $query;
                    })
                    ->addColumn('last_location', function($row){
                        return 'Seattle, WA, USA';
                    })
                    ->editColumn('total_bill', function($row){
                        return getPrice($row->total_bill);
                    })
                    ->editColumn('shipper_location', function($row){
                        $html           = [];
                        if($row->shipper_address_one){
                            $html[0]    = $row->shipper_address_one;
                        }
                        if($row->shipper_address_two){
                            $html[1]    = $row->shipper_address_two;
                        }
                        if($row->shipper_city){
                            $html[2]    = $row->shipper_city;
                        }
                        if($row->shipper_state){
                            $html[3]    = $row->shipper_state;
                        }
                        if($row->shipper_zip){
                            $html[4]    = $row->shipper_zip;
                        }
                        if(count($html) == 0){
                            return $row->shipper_location;
                        }else{
                            return implode(', ', $html);
                        }
                    })
                    ->editColumn('delivery_location', function($row){
                        $html           = [];
                        if($row->delivery_address_one){
                            $html[0]    = $row->delivery_address_one;
                        }
                        if($row->delivery_address_two){
                            $html[1]    = $row->delivery_address_two;
                        }
                        if($row->delivery_city){
                            $html[2]    = $row->delivery_city;
                        }
                        if($row->delivery_state){
                            $html[3]    = $row->delivery_state;
                        }
                        if($row->delivery_zip){
                            $html[4]    = $row->delivery_zip;
                        }
                        if(count($html) == 0){
                            return $row->delivery_location;
                        }else{
                            return implode(', ', $html);
                        }
                    })
                    ->addColumn('action', function($row){
                        $btn            = '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1"><img src="'.asset('theme/img/eye.png').'" alt=""></a>';
                        if ($row->is_disable == 0) {
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-2.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-3.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="javascript:" class="destroy" data-action="'.route('company.admin.loads.destroy',$row->load_id).'" data-id="'.$row->load_id.'"><img src="'.asset('theme/img/tbl--icon-4.png').'" alt=""></a>';
                        }
                        return $btn;
                    })
                    ->rawColumns(['action','load_number'])
                    ->make(true);
            }
            // return view('companyAdmin.load.index');
            // return view('companyAdmin.load.indextemp');
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );
        }
    }

    /**
     * Display a listing of the ready to bill loads.
     *
     * @return \Illuminate\Http\Response
     */
    public function deliveredLoadsIndex(Request $request){
        try {
            $getCompanyAdmin            = auth()->guard('company-admin')->user();

            $getField                   = '';
            $isCheck                    = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','loads_active')->first();
            if(!empty($isCheck->id)) {
                //$getField             = unserialize($isCheck->config);
                $getField               = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_loads_active_first'));
            } else {
                $getField               = config('settings.table_loads_active_first');
            }

            if ($request->ajax()) {
                $data                   = LoadDetail::select('load_details.*', DB::raw('CONCAT(drivers.first_name," ",drivers.last_name) as driver'), 'drivers.cell_phone as phone_number', 'brokers.name as broker_name')
                    ->leftJoin('drivers', 'load_details.driver_id', '=', 'drivers.id')
                    ->leftJoin('brokers', 'load_details.brokerage_firm', '=', 'brokers.id')
                    ->where('load_details.is_disable', 0)
                    ->where(function($query) {
                        $query->where('load_details.load_status', 5)
                        ->where(function($q) {
                            $q->whereNotNull('load_details.driver_id')->where('load_details.driver_id', '!=', 0);
                        });
                    })
                    ->where(function($q) {
                        $q->whereNull('load_details.is_on_hold')->orWhere('load_details.is_on_hold', 0);
                    })
                    ->whereHas('loads', function($q){
                        $q->where('company_id', auth()->guard('company-admin')->user()->company_id);
                    });
                // General filter code - start
                foreach( $getField as $key => $value ) {
                    $conditionReq       = 'search_string_condition_'.$key;
                    $sortReq            = 'search_string_sort_'.$key;
                    $conditionDateReq   = 'search_date_condition_'.$key;
                    $sortDateReq        = 'search_date_sort_'.$key;
                    $conditionStatusReq = 'search_status_condition_'.$key;
                    $sortStatusReq      = 'search_status_sort_'.$key;

                    // String filter
                    if( isset( request()->$conditionReq ) ) {
                        $typeReq        = 'search_string_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'string' ) {
                            Common::getStringFilterResult( $data, $key );
                        }
                    }

                    // Status filter
                    if( isset( request()->$conditionStatusReq ) && request()->$conditionStatusReq == 1 ) {
                        Common::getStatusFilterResult( $data, $key );
                    }

                    // Date filter
                    if( isset( request()->$conditionDateReq ) ) {
                        $typeReq        = 'search_date_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'date' ) {
                            Common::getDateFilterResult( $data, $key );
                        }
                    }

                    // String sort only
                    if( isset( request()->$sortReq ) ) {
                        Common::sortStringFilter( $data, $key );
                    }

                    // Date sort only
                    if( isset( request()->$sortDateReq ) ) {
                        Common::sortDateFilter( $data, $key );
                    }

                    // Status sort only
                    if( isset( request()->$sortStatusReq ) ) {
                        Common::sortStatusFilter( $data, $key );
                    }
                }
                // General filter code - end
                $data->get();
                return Datatables::of($data)
                    ->addIndexColumn()
                    ->editColumn('load_number', function($row){
                        if ($row->is_disable == 0) {
                            if(in_array($row->load_type, ['0', '6'])) {
                                if ($row->load_type == 0) {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                                } else {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                                }
                            } else {
                                return '<a href="'.route('company.admin.loads.edit', base64Encode($row->load_id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        } else {
                            if ($row->load_type == 0) {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                            } else {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        }
                    })
                    /*
                    ->addColumn('driver', function($row){
                        return isset($row->driver->full_name) ? $row->driver->full_name : '';
                    })
                    */
                    ->filterColumn('driver', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(drivers.first_name, ' ', drivers.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('phone_number', function($row){
                        return isset($row->driver->cell_phone) ? $row->driver->cell_phone : '';
                    })
                    */
                    ->filterColumn('phone_number', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where("drivers.cell_phone", 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('broker_name', function($row){
                        return isset($row->broker->name) ? $row->broker->name : '';
                    })
                    */
                    ->filterColumn('broker_name', function ($query, $keyword) {
                        $query->whereHas('broker', function ($q) use ($keyword) {
                            $q->where("brokers.name", 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('actual_delivery_date', function($row){
                        return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date." ".$row->delivery_timezone_abbr : '';
                    })
                    ->editColumn('created_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('updated_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('booked_by', function($row){
                        if($row->booked_by == 0){
                            return 'Self Dispatch';
                        }else{
                            return $row->dispatcher->full_name;
                        }
                    })
                    ->filterColumn('booked_by', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('trailer_type', function($row){
                        return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                    })
                    ->addColumn('dispatcher', function($row){
                        return getLoadDispatcherName($row->booked_by);
                    })
                    ->filterColumn('dispatcher', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->addColumn('status', function($row){
                        return getLoadStatus($row->load_status,$row->is_on_hold);
                    })
                    ->filterColumn('status', function ($query, $keyword) {
                        if (Str::contains('pending' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 0);
                        }
                        if (Str::contains('accepted' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 1);
                        }
                        if (Str::contains('preplaned' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 2);
                        }
                        if (Str::contains('confirmed' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 3);
                        }
                        if (Str::contains('in transit' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 4);
                        }
                        if (Str::contains('delivered' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 5);
                        }
                        if (Str::contains('ready to bill' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 6);
                        }
                        if (Str::contains('on hold' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 7);
                        }
                        if (Str::contains('complete' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 8);
                        }
                        if (Str::contains('cancelled' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 9);
                        }
                        return $query;
                    })
                    ->addColumn('last_location', function($row){
                        return 'Seattle, WA, USA';
                    })
                    ->editColumn('total_bill', function($row){
                        return getPrice($row->total_bill);
                    })
                    ->editColumn('shipper_location', function($row){
                        $html           = [];
                        if($row->shipper_address_one){
                            $html[0]    = $row->shipper_address_one;
                        }
                        if($row->shipper_address_two){
                            $html[1]    = $row->shipper_address_two;
                        }
                        if($row->shipper_city){
                            $html[2]    = $row->shipper_city;
                        }
                        if($row->shipper_state){
                            $html[3]    = $row->shipper_state;
                        }
                        if($row->shipper_zip){
                            $html[4]    = $row->shipper_zip;
                        }
                        if(count($html) == 0){
                            return $row->shipper_location;
                        }else{
                            return implode(', ', $html);
                        }
                    })
                    ->editColumn('delivery_location', function($row){
                        $html           = [];
                        if($row->delivery_address_one){
                            $html[0]    = $row->delivery_address_one;
                        }
                        if($row->delivery_address_two){
                            $html[1]    = $row->delivery_address_two;
                        }
                        if($row->delivery_city){
                            $html[2]    = $row->delivery_city;
                        }
                        if($row->delivery_state){
                            $html[3]    = $row->delivery_state;
                        }
                        if($row->delivery_zip){
                            $html[4]    = $row->delivery_zip;
                        }
                        if(count($html) == 0){
                            return $row->delivery_location;
                        }else{
                            return implode(', ', $html);
                        }
                    })
                    ->addColumn('action', function($row){
                        $btn            = '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1"><img src="'.asset('theme/img/eye.png').'" alt=""></a>';
                        if ($row->is_disable == 0) {
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-2.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-3.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="javascript:" class="destroy" data-action="'.route('company.admin.loads.destroy',$row->load_id).'" data-id="'.$row->load_id.'"><img src="'.asset('theme/img/tbl--icon-4.png').'" alt=""></a>';
                        }
                        return $btn;
                    })
                    ->rawColumns(['action','load_number'])
                    ->make(true);
            }
            // return view('companyAdmin.load.index');
            // return view('companyAdmin.load.indextemp');
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );
        }
    }

    /**
     * Display a listing of the complete loads.
     *
     * @return \Illuminate\Http\Response
     */
    public function completeLoadsIndex(Request $request){
        try {
            $getCompanyAdmin            = auth()->guard('company-admin')->user();

            $getField                   = '';
            $isCheck                    = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','loads_active')->first();
            if(!empty($isCheck->id)) {
                //$getField             = unserialize($isCheck->config);
                $getField               = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_loads_active_first'));
            } else {
                $getField               = config('settings.table_loads_active_first');
            }

            if ($request->ajax()) {
                $data                   = LoadDetail::select('load_details.*', DB::raw('CONCAT(drivers.first_name," ",drivers.last_name) as driver'), 'drivers.cell_phone as phone_number', 'brokers.name as broker_name')
                    ->leftJoin('drivers', 'load_details.driver_id', '=', 'drivers.id')
                    ->leftJoin('brokers', 'load_details.brokerage_firm', '=', 'brokers.id')
                    ->where('load_details.is_disable', 0)
                    ->where('load_details.load_type', 0) //->whereIn('load_type', [0,6,4])
                    ->where(function($query) {
                        $query->where('load_details.load_status', 8)
                        ->where(function($q) {
                            $q->whereNotNull('load_details.driver_id')->where('load_details.driver_id', '!=', 0);
                        });
                    })
                    ->where(function($q) {
                        $q->whereNull('load_details.is_on_hold')->orWhere('load_details.is_on_hold', 0);
                    })
                    ->whereHas('loads', function($q) {
                        $q->where('company_id', auth()->guard('company-admin')->user()->company_id);
                    });
                // General filter code - start
                foreach( $getField as $key => $value ) {
                    $conditionReq       = 'search_string_condition_'.$key;
                    $sortReq            = 'search_string_sort_'.$key;
                    $conditionDateReq   = 'search_date_condition_'.$key;
                    $sortDateReq        = 'search_date_sort_'.$key;
                    $conditionStatusReq = 'search_status_condition_'.$key;
                    $sortStatusReq      = 'search_status_sort_'.$key;

                    // String filter
                    if( isset( request()->$conditionReq ) ) {
                        $typeReq        = 'search_string_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'string' ) {
                            Common::getStringFilterResult( $data, $key );
                        }
                    }

                    // Status filter
                    if( isset( request()->$conditionStatusReq ) && request()->$conditionStatusReq == 1 ) {
                        Common::getStatusFilterResult( $data, $key );
                    }

                    // Date filter
                    if( isset( request()->$conditionDateReq ) ) {
                        $typeReq        = 'search_date_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'date' ) {
                            Common::getDateFilterResult( $data, $key );
                        }
                    }

                    // String sort only
                    if( isset( request()->$sortReq ) ) {
                        Common::sortStringFilter( $data, $key );
                    }

                    // Date sort only
                    if( isset( request()->$sortDateReq ) ) {
                        Common::sortDateFilter( $data, $key );
                    }

                    // Status sort only
                    if( isset( request()->$sortStatusReq ) ) {
                        Common::sortStatusFilter( $data, $key );
                    }
                }
                // General filter code - end
                $data->get();
                return Datatables::of($data)
                    ->addIndexColumn()
                    ->editColumn('load_number', function($row){
                        if ($row->is_disable == 0) {
                            if(in_array($row->load_type, ['0', '6'])) {
                                if ($row->load_type == 0) {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                                } else {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                                }
                            } else {
                                return '<a href="'.route('company.admin.loads.edit', base64Encode($row->load_id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        } else {
                            if ($row->load_type == 0) {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                            } else {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        }
                    })
                    /*
                    ->addColumn('driver', function($row){
                        return isset($row->driver->full_name) ? $row->driver->full_name : '';
                    })
                    */
                    ->filterColumn('driver', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(drivers.first_name, ' ', drivers.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('phone_number', function($row){
                        return isset($row->driver->cell_phone) ? $row->driver->cell_phone : '';
                    })
                    */
                    ->filterColumn('phone_number', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where("drivers.cell_phone", 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('broker_name', function($row){
                        return isset($row->broker->name) ? $row->broker->name : '';
                    })
                    */
                    ->filterColumn('broker_name', function ($query, $keyword) {
                        $query->whereHas('broker', function ($q) use ($keyword) {
                            $q->where("brokers.name", 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('actual_delivery_date', function($row){
                        return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date." ".$row->delivery_timezone_abbr : '';
                    })
                    ->editColumn('created_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('updated_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('booked_by', function($row){
                        if($row->booked_by == 0){
                            return 'Self Dispatch';
                        }else{
                            return $row->dispatcher->full_name;
                        }
                    })
                    ->filterColumn('booked_by', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('trailer_type', function($row){
                        return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                    })
                    ->addColumn('dispatcher', function($row){
                        return getLoadDispatcherName($row->booked_by);
                    })
                    ->filterColumn('dispatcher', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->addColumn('status', function($row){
                        return getLoadStatus($row->load_status,$row->is_on_hold);
                    })
                    ->filterColumn('status', function ($query, $keyword) {
                        if (Str::contains('pending' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 0);
                        }
                        if (Str::contains('accepted' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 1);
                        }
                        if (Str::contains('preplaned' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 2);
                        }
                        if (Str::contains('confirmed' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 3);
                        }
                        if (Str::contains('in transit' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 4);
                        }
                        if (Str::contains('delivered' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 5);
                        }
                        if (Str::contains('ready to bill' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 6);
                        }
                        if (Str::contains('on hold' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 7);
                        }
                        if (Str::contains('complete' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 8);
                        }
                        if (Str::contains('cancelled' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 9);
                        }
                        return $query;
                    })
                    ->addColumn('last_location', function($row){
                        return 'Seattle, WA, USA';
                    })
                    ->editColumn('total_bill', function($row){
                        return getPrice($row->total_bill);
                    })
                    ->editColumn('shipper_location', function($row){
                        $html           = [];
                        if($row->shipper_address_one){
                            $html[0]    = $row->shipper_address_one;
                        }
                        if($row->shipper_address_two){
                            $html[1]    = $row->shipper_address_two;
                        }
                        if($row->shipper_city){
                            $html[2]    = $row->shipper_city;
                        }
                        if($row->shipper_state){
                            $html[3]    = $row->shipper_state;
                        }
                        if($row->shipper_zip){
                            $html[4]    = $row->shipper_zip;
                        }
                        if(count($html) == 0){
                            return $row->shipper_location;
                        }else{
                            return implode(', ', $html);
                        }
                    })
                    ->editColumn('delivery_location', function($row){
                        $html           = [];
                        if($row->delivery_address_one){
                            $html[0]    = $row->delivery_address_one;
                        }
                        if($row->delivery_address_two){
                            $html[1]    = $row->delivery_address_two;
                        }
                        if($row->delivery_city){
                            $html[2]    = $row->delivery_city;
                        }
                        if($row->delivery_state){
                            $html[3]    = $row->delivery_state;
                        }
                        if($row->delivery_zip){
                            $html[4]    = $row->delivery_zip;
                        }
                        if(count($html) == 0){
                            return $row->delivery_location;
                        }else{
                            return implode(', ', $html);
                        }
                    })
                    ->addColumn('action', function($row){
                        $btn            = '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1"><img src="'.asset('theme/img/eye.png').'" alt=""></a>';
                        if ($row->is_disable == 0) {
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-2.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-3.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="javascript:" class="destroy" data-action="'.route('company.admin.loads.destroy',$row->load_id).'" data-id="'.$row->load_id.'"><img src="'.asset('theme/img/tbl--icon-4.png').'" alt=""></a>';
                        }
                        return $btn;
                    })
                    ->rawColumns(['action','load_number'])
                    ->make(true);
            }
            // return view('companyAdmin.load.index');
            // return view('companyAdmin.load.indextemp');
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );
        }
    }

    /**
     * Display a listing of the complete loads.
     *
     * @return \Illuminate\Http\Response
     */
    public function onholdLoadsIndex(Request $request){
        try {
            $getCompanyAdmin            = auth()->guard('company-admin')->user();

            $getField                   = '';
            $isCheck                    = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','loads_active')->first();
            if(!empty($isCheck->id)) {
                //$getField             = unserialize($isCheck->config);
                $getField               = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_loads_active_first'));
            } else {
                $getField               = config('settings.table_loads_active_first');
            }

            if ($request->ajax()) {
                $data                   = LoadDetail::select('load_details.*', DB::raw('CONCAT(drivers.first_name," ",drivers.last_name) as driver'), 'drivers.cell_phone as phone_number', 'brokers.name as broker_name')
                    ->leftJoin('drivers', 'load_details.driver_id', '=', 'drivers.id')
                    ->leftJoin('brokers', 'load_details.brokerage_firm', '=', 'brokers.id')
                    ->where(function($query) {
                        $query->where(function($q) {
                            $q->where('load_details.load_status', 7)->orWhere('load_details.is_on_hold', 1);
                        })
                        ->where(function($q) {
                            $q->whereNotNull('load_details.driver_id')->where('load_details.driver_id', '!=', 0);
                        });
                    })
                    ->whereHas('loads', function($q){
                        $q->where('company_id', auth()->guard('company-admin')->user()->company_id);
                    });
                // General filter code - start
                foreach( $getField as $key => $value ) {
                    $conditionReq       = 'search_string_condition_'.$key;
                    $sortReq            = 'search_string_sort_'.$key;
                    $conditionDateReq   = 'search_date_condition_'.$key;
                    $sortDateReq        = 'search_date_sort_'.$key;
                    $conditionStatusReq = 'search_status_condition_'.$key;
                    $sortStatusReq      = 'search_status_sort_'.$key;

                    // String filter
                    if( isset( request()->$conditionReq ) ) {
                        $typeReq        = 'search_string_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'string' ) {
                            Common::getStringFilterResult( $data, $key );
                        }
                    }

                    // Status filter
                    if( isset( request()->$conditionStatusReq ) && request()->$conditionStatusReq == 1 ) {
                        Common::getStatusFilterResult( $data, $key );
                    }

                    // Date filter
                    if( isset( request()->$conditionDateReq ) ) {
                        $typeReq        = 'search_date_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'date' ) {
                            Common::getDateFilterResult( $data, $key );
                        }
                    }

                    // String sort only
                    if( isset( request()->$sortReq ) ) {
                        Common::sortStringFilter( $data, $key );
                    }

                    // Date sort only
                    if( isset( request()->$sortDateReq ) ) {
                        Common::sortDateFilter( $data, $key );
                    }

                    // Status sort only
                    if( isset( request()->$sortStatusReq ) ) {
                        Common::sortStatusFilter( $data, $key );
                    }
                }
                // General filter code - end
                $data->get();
                return Datatables::of($data)
                    ->addIndexColumn()
                    ->editColumn('load_number', function($row){
                        if ($row->is_disable == 0) {
                            if(in_array($row->load_type, ['0', '6'])) {
                                if ($row->load_type == 0) {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                                } else {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                                }
                            } else {
                                return '<a href="'.route('company.admin.loads.edit', base64Encode($row->load_id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        } else {
                            if ($row->load_type == 0) {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                            } else {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        }
                    })
                    /*
                    ->addColumn('driver', function($row){
                        return isset($row->driver->full_name) ? $row->driver->full_name : '';
                    })
                    */
                    ->filterColumn('driver', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(drivers.first_name, ' ', drivers.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('phone_number', function($row){
                        return isset($row->driver->cell_phone) ? $row->driver->cell_phone : '';
                    })
                    */
                    ->filterColumn('phone_number', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where("drivers.cell_phone", 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('broker_name', function($row){
                        return isset($row->broker->name) ? $row->broker->name : '';
                    })
                    */
                    ->filterColumn('broker_name', function ($query, $keyword) {
                        $query->whereHas('broker', function ($q) use ($keyword) {
                            $q->where("brokers.name", 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('actual_delivery_date', function($row){
                        return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date." ".$row->delivery_timezone_abbr : '';
                    })
                    ->editColumn('created_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('updated_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('booked_by', function($row){
                        if($row->booked_by == 0){
                            return 'Self Dispatch';
                        }else{
                            return $row->dispatcher->full_name;
                        }
                    })
                    ->filterColumn('booked_by', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('trailer_type', function($row){
                        return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                    })
                    ->addColumn('dispatcher', function($row){
                        return getLoadDispatcherName($row->booked_by);
                    })
                    ->filterColumn('dispatcher', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->addColumn('status', function($row){
                        return getLoadStatus($row->load_status,$row->is_on_hold);
                    })
                    ->filterColumn('status', function ($query, $keyword) {
                        if (Str::contains('pending' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 0);
                        }
                        if (Str::contains('accepted' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 1);
                        }
                        if (Str::contains('preplaned' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 2);
                        }
                        if (Str::contains('confirmed' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 3);
                        }
                        if (Str::contains('in transit' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 4);
                        }
                        if (Str::contains('delivered' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 5);
                        }
                        if (Str::contains('ready to bill' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 6);
                        }
                        if (Str::contains('on hold' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 7);
                        }
                        if (Str::contains('complete' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 8);
                        }
                        if (Str::contains('cancelled' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 9);
                        }
                        return $query;
                    })
                    ->addColumn('last_location', function($row){
                        return 'Seattle, WA, USA';
                    })
                    ->editColumn('total_bill', function($row){
                        return getPrice($row->total_bill);
                    })
                    ->editColumn('shipper_location', function($row){
                        $html           = [];
                        if($row->shipper_address_one){
                            $html[0]    = $row->shipper_address_one;
                        }
                        if($row->shipper_address_two){
                            $html[1]    = $row->shipper_address_two;
                        }
                        if($row->shipper_city){
                            $html[2]    = $row->shipper_city;
                        }
                        if($row->shipper_state){
                            $html[3]    = $row->shipper_state;
                        }
                        if($row->shipper_zip){
                            $html[4]    = $row->shipper_zip;
                        }
                        if(count($html) == 0){
                            return $row->shipper_location;
                        }else{
                            return implode(', ', $html);
                        }
                    })
                    ->editColumn('delivery_location', function($row){
                        $html           = [];
                        if($row->delivery_address_one){
                            $html[0]    = $row->delivery_address_one;
                        }
                        if($row->delivery_address_two){
                            $html[1]    = $row->delivery_address_two;
                        }
                        if($row->delivery_city){
                            $html[2]    = $row->delivery_city;
                        }
                        if($row->delivery_state){
                            $html[3]    = $row->delivery_state;
                        }
                        if($row->delivery_zip){
                            $html[4]    = $row->delivery_zip;
                        }
                        if(count($html) == 0){
                            return $row->delivery_location;
                        }else{
                            return implode(', ', $html);
                        }
                    })
                    ->addColumn('action', function($row){
                        $btn            = '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1"><img src="'.asset('theme/img/eye.png').'" alt=""></a>';
                        if ($row->is_disable == 0) {
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-2.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-3.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="javascript:" class="destroy" data-action="'.route('company.admin.loads.destroy',$row->load_id).'" data-id="'.$row->load_id.'"><img src="'.asset('theme/img/tbl--icon-4.png').'" alt=""></a>';
                        }
                        return $btn;
                    })
                    ->rawColumns(['action','load_number'])
                    ->make(true);
            }
            // return view('companyAdmin.load.index');
            // return view('companyAdmin.load.indextemp');
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );
        }
    }

    /**
     * Display a listing of the cancelled loads.
     *
     * @return \Illuminate\Http\Response
     */
    public function cancelLoadIndex(Request $request){
        try {
            $getCompanyAdmin            = auth()->guard('company-admin')->user();

            $getField                   = '';
            $isCheck                    = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','loads_active')->first();
            if(!empty($isCheck->id)) {
                //$getField             = unserialize($isCheck->config);
                $getField               = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_loads_active_first'));
            } else {
                $getField               = config('settings.table_loads_active_first');
            }

            if ($request->ajax()) {
                $data                   = LoadDetail::select('load_details.*', DB::raw('CONCAT(drivers.first_name," ",drivers.last_name) as driver'), 'drivers.cell_phone as phone_number', 'brokers.name as broker_name')
                    ->leftJoin('drivers', 'load_details.driver_id', '=', 'drivers.id')
                    ->leftJoin('brokers', 'load_details.brokerage_firm', '=', 'brokers.id')
                    ->where('load_details.load_type', 0)
                    ->where(function($query) {
                        $query->where(function($q) {
                            $q->where('load_details.load_status', 9)->orWhere('load_details.is_on_hold', 2);
                        })
                        ->where(function($q) {
                            $q->whereNotNull('load_details.driver_id')->where('load_details.driver_id', '!=', 0);
                        });
                    })
                    ->whereHas('loads', function($q){
                        $q->where('company_id', auth()->guard('company-admin')->user()->company_id);
                    });
                // General filter code - start
                foreach( $getField as $key => $value ) {
                    $conditionReq       = 'search_string_condition_'.$key;
                    $sortReq            = 'search_string_sort_'.$key;
                    $conditionDateReq   = 'search_date_condition_'.$key;
                    $sortDateReq        = 'search_date_sort_'.$key;
                    $conditionStatusReq = 'search_status_condition_'.$key;
                    $sortStatusReq      = 'search_status_sort_'.$key;

                    // String filter
                    if( isset( request()->$conditionReq ) ) {
                        $typeReq        = 'search_string_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'string' ) {
                            Common::getStringFilterResult( $data, $key );
                        }
                    }

                    // Status filter
                    if( isset( request()->$conditionStatusReq ) && request()->$conditionStatusReq == 1 ) {
                        Common::getStatusFilterResult( $data, $key );
                    }

                    // Date filter
                    if( isset( request()->$conditionDateReq ) ) {
                        $typeReq        = 'search_date_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'date' ) {
                            Common::getDateFilterResult( $data, $key );
                        }
                    }

                    // String sort only
                    if( isset( request()->$sortReq ) ) {
                        Common::sortStringFilter( $data, $key );
                    }

                    // Date sort only
                    if( isset( request()->$sortDateReq ) ) {
                        Common::sortDateFilter( $data, $key );
                    }

                    // Status sort only
                    if( isset( request()->$sortStatusReq ) ) {
                        Common::sortStatusFilter( $data, $key );
                    }
                }
                // General filter code - end
                $data->get();
                return Datatables::of($data)
                    ->addIndexColumn()
                    ->editColumn('load_number', function($row){
                        if ($row->is_disable == 0) {
                            if(in_array($row->load_type, ['0', '6'])) {
                                if ($row->load_type == 0) {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                                } else {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                                }
                            } else {
                                return '<a href="'.route('company.admin.loads.edit', base64Encode($row->load_id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        } else {
                            if ($row->load_type == 0) {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                            } else {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        }
                    })
                    /*
                    ->addColumn('driver', function($row){
                        return isset($row->driver->full_name) ? $row->driver->full_name : '';
                    })
                    */
                    ->filterColumn('driver', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(drivers.first_name, ' ', drivers.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('phone_number', function($row){
                        return isset($row->driver->cell_phone) ? $row->driver->cell_phone : '';
                    })
                    */
                    ->filterColumn('phone_number', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where("drivers.cell_phone", 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('broker_name', function($row){
                        return isset($row->broker->name) ? $row->broker->name : '';
                    })
                    */
                    ->filterColumn('broker_name', function ($query, $keyword) {
                        $query->whereHas('broker', function ($q) use ($keyword) {
                            $q->where("brokers.name", 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('actual_delivery_date', function($row){
                        return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date." ".$row->delivery_timezone_abbr : '';
                    })
                    ->editColumn('created_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('updated_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('booked_by', function($row){
                        if($row->booked_by == 0){
                            return 'Self Dispatch';
                        }else{
                            return $row->dispatcher->full_name;
                        }
                    })
                    ->filterColumn('booked_by', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('trailer_type', function($row){
                        return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                    })
                    ->addColumn('dispatcher', function($row){
                        return getLoadDispatcherName($row->booked_by);
                    })
                    ->filterColumn('dispatcher', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->addColumn('status', function($row){
                        return getLoadStatus($row->load_status,$row->is_on_hold);
                    })
                    ->filterColumn('status', function ($query, $keyword) {
                        if (Str::contains('pending' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 0);
                        }
                        if (Str::contains('accepted' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 1);
                        }
                        if (Str::contains('preplaned' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 2);
                        }
                        if (Str::contains('confirmed' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 3);
                        }
                        if (Str::contains('in transit' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 4);
                        }
                        if (Str::contains('delivered' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 5);
                        }
                        if (Str::contains('ready to bill' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 6);
                        }
                        if (Str::contains('on hold' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 7);
                        }
                        if (Str::contains('complete' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 8);
                        }
                        if (Str::contains('cancelled' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 9);
                        }
                        return $query;
                    })
                    ->addColumn('last_location', function($row){
                        return 'Seattle, WA, USA';
                    })
                    ->editColumn('total_bill', function($row){
                        return getPrice($row->total_bill);
                    })
                    ->editColumn('shipper_location', function($row){
                        $html           = [];
                        if($row->shipper_address_one){
                            $html[0]    = $row->shipper_address_one;
                        }
                        if($row->shipper_address_two){
                            $html[1]    = $row->shipper_address_two;
                        }
                        if($row->shipper_city){
                            $html[2]    = $row->shipper_city;
                        }
                        if($row->shipper_state){
                            $html[3]    = $row->shipper_state;
                        }
                        if($row->shipper_zip){
                            $html[4]    = $row->shipper_zip;
                        }
                        if(count($html) == 0){
                            return $row->shipper_location;
                        }else{
                            return implode(', ', $html);
                        }
                    })
                    ->editColumn('delivery_location', function($row){
                        $html           = [];
                        if($row->delivery_address_one){
                            $html[0]    = $row->delivery_address_one;
                        }
                        if($row->delivery_address_two){
                            $html[1]    = $row->delivery_address_two;
                        }
                        if($row->delivery_city){
                            $html[2]    = $row->delivery_city;
                        }
                        if($row->delivery_state){
                            $html[3]    = $row->delivery_state;
                        }
                        if($row->delivery_zip){
                            $html[4]    = $row->delivery_zip;
                        }
                        if(count($html) == 0){
                            return $row->delivery_location;
                        }else{
                            return implode(', ', $html);
                        }
                    })
                    ->addColumn('action', function($row){
                        $btn            = '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1"><img src="'.asset('theme/img/eye.png').'" alt=""></a>';
                        if ($row->is_disable == 0) {
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-2.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-3.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="javascript:" class="destroy" data-action="'.route('company.admin.loads.destroy',$row->load_id).'" data-id="'.$row->load_id.'"><img src="'.asset('theme/img/tbl--icon-4.png').'" alt=""></a>';
                        }
                        return $btn;
                    })
                    ->rawColumns(['action','load_number'])
                    ->make(true);
            }
            // return view('companyAdmin.load.index');
            // return view('companyAdmin.load.indextemp');
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );
        }
    }

    /**
     * Display a listing of the cancelled loads.
     *
     * @return \Illuminate\Http\Response
     */
    public function unoccupiedLoadIndex(Request $request){
        try {
            $getCompanyAdmin            = auth()->guard('company-admin')->user();

            $getField                   = '';
            $isCheck                    = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','loads_active')->first();
            if(!empty($isCheck->id)) {
                //$getField             = unserialize($isCheck->config);
                $getField               = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_loads_active_first'));
            } else {
                $getField               = config('settings.table_loads_active_first');
            }

            if ($request->ajax()) {
                $data                   = LoadDetail::select('load_details.*', DB::raw('CONCAT(drivers.first_name," ",drivers.last_name) as driver'), 'drivers.cell_phone as phone_number', 'brokers.name as broker_name')
                    ->leftJoin('drivers', 'load_details.driver_id', '=', 'drivers.id')
                    ->leftJoin('brokers', 'load_details.brokerage_firm', '=', 'brokers.id')
                    ->whereIn('load_details.load_type', [1,2,3,4,5,6])
                    ->whereHas('loads', function($q){
                        $q->where('company_id', auth()->guard('company-admin')->user()->company_id);
                    })
                    ->where(function($q) {
                        $q->whereNotNull('load_details.driver_id')->where('load_details.driver_id', '!=', 0);
                    });
                // General filter code - start
                foreach( $getField as $key => $value ) {
                    $conditionReq       = 'search_string_condition_'.$key;
                    $sortReq            = 'search_string_sort_'.$key;
                    $conditionDateReq   = 'search_date_condition_'.$key;
                    $sortDateReq        = 'search_date_sort_'.$key;
                    $conditionStatusReq = 'search_status_condition_'.$key;
                    $sortStatusReq      = 'search_status_sort_'.$key;

                    // String filter
                    if( isset( request()->$conditionReq ) ) {
                        $typeReq        = 'search_string_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'string' ) {
                            Common::getStringFilterResult( $data, $key );
                        }
                    }

                    // Status filter
                    if( isset( request()->$conditionStatusReq ) && request()->$conditionStatusReq == 1 ) {
                        Common::getStatusFilterResult( $data, $key );
                    }

                    // Date filter
                    if( isset( request()->$conditionDateReq ) ) {
                        $typeReq        = 'search_date_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'date' ) {
                            Common::getDateFilterResult( $data, $key );
                        }
                    }

                    // String sort only
                    if( isset( request()->$sortReq ) ) {
                        Common::sortStringFilter( $data, $key );
                    }

                    // Date sort only
                    if( isset( request()->$sortDateReq ) ) {
                        Common::sortDateFilter( $data, $key );
                    }

                    // Status sort only
                    if( isset( request()->$sortStatusReq ) ) {
                        Common::sortStatusFilter( $data, $key );
                    }
                }
                // General filter code - end
                $data->get();
                return Datatables::of($data)
                    ->addIndexColumn()
                    ->editColumn('load_number', function($row){
                        if ($row->is_disable == 0) {
                            if(in_array($row->load_type, ['0', '6'])) {
                                if ($row->load_type == 0) {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                                } else {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                                }
                            } else {
                                return '<a href="'.route('company.admin.loads.edit', base64Encode($row->load_id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        } else {
                            if ($row->load_type == 0) {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                            } else {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        }
                    })
                    /*
                    ->addColumn('driver', function($row){
                        return isset($row->driver->full_name) ? $row->driver->full_name : '';
                    })
                    */
                    ->filterColumn('driver', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(drivers.first_name, ' ', drivers.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('phone_number', function($row){
                        return isset($row->driver->cell_phone) ? $row->driver->cell_phone : '';
                    })
                    */
                    ->filterColumn('phone_number', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where("drivers.cell_phone", 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('broker_name', function($row){
                        return isset($row->broker->name) ? $row->broker->name : '';
                    })
                    */
                    ->filterColumn('broker_name', function ($query, $keyword) {
                        $query->whereHas('broker', function ($q) use ($keyword) {
                            $q->where("brokers.name", 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('actual_delivery_date', function($row){
                        return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date." ".$row->delivery_timezone_abbr : '';
                    })
                    ->editColumn('created_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('updated_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('booked_by', function($row){
                        if($row->booked_by == 0){
                            return 'Self Dispatch';
                        }else{
                            return $row->dispatcher->full_name;
                        }
                    })
                    ->filterColumn('booked_by', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('trailer_type', function($row){
                        return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                    })
                    ->addColumn('dispatcher', function($row){
                        return getLoadDispatcherName($row->booked_by);
                    })
                    ->filterColumn('dispatcher', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->addColumn('status', function($row){
                        return getLoadStatus($row->load_status,$row->is_on_hold);
                    })
                    ->filterColumn('status', function ($query, $keyword) {
                        if (Str::contains('pending' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 0);
                        }
                        if (Str::contains('accepted' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 1);
                        }
                        if (Str::contains('preplaned' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 2);
                        }
                        if (Str::contains('confirmed' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 3);
                        }
                        if (Str::contains('in transit' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 4);
                        }
                        if (Str::contains('delivered' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 5);
                        }
                        if (Str::contains('ready to bill' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 6);
                        }
                        if (Str::contains('on hold' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 7);
                        }
                        if (Str::contains('complete' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 8);
                        }
                        if (Str::contains('cancelled' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 9);
                        }
                        return $query;
                    })
                    ->addColumn('last_location', function($row){
                        return 'Seattle, WA, USA';
                    })
                    ->editColumn('total_bill', function($row){
                        return getPrice($row->total_bill);
                    })
                    ->editColumn('shipper_location', function($row){
                        $html           = [];
                        if($row->shipper_address_one){
                            $html[0]    = $row->shipper_address_one;
                        }
                        if($row->shipper_address_two){
                            $html[1]    = $row->shipper_address_two;
                        }
                        if($row->shipper_city){
                            $html[2]    = $row->shipper_city;
                        }
                        if($row->shipper_state){
                            $html[3]    = $row->shipper_state;
                        }
                        if($row->shipper_zip){
                            $html[4]    = $row->shipper_zip;
                        }
                        if(count($html) == 0){
                            return $row->shipper_location;
                        }else{
                            return implode(', ', $html);
                        }
                    })
                    ->editColumn('delivery_location', function($row){
                        $html           = [];
                        if($row->delivery_address_one){
                            $html[0]    = $row->delivery_address_one;
                        }
                        if($row->delivery_address_two){
                            $html[1]    = $row->delivery_address_two;
                        }
                        if($row->delivery_city){
                            $html[2]    = $row->delivery_city;
                        }
                        if($row->delivery_state){
                            $html[3]    = $row->delivery_state;
                        }
                        if($row->delivery_zip){
                            $html[4]    = $row->delivery_zip;
                        }
                        if(count($html) == 0){
                            return $row->delivery_location;
                        }else{
                            return implode(', ', $html);
                        }
                    })
                    ->addColumn('action', function($row){
                        $btn            = '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1"><img src="'.asset('theme/img/eye.png').'" alt=""></a>';
                        if ($row->is_disable == 0) {
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-2.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-3.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="javascript:" class="destroy" data-action="'.route('company.admin.loads.destroy',$row->load_id).'" data-id="'.$row->load_id.'"><img src="'.asset('theme/img/tbl--icon-4.png').'" alt=""></a>';
                        }
                        return $btn;
                    })
                    ->rawColumns(['action','load_number'])
                    ->make(true);
            }
            // return view('companyAdmin.load.index');
            // return view('companyAdmin.load.indextemp');
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );
        }
    }

    /**
     * Display a listing of the all loads.
     *
     * @return \Illuminate\Http\Response
     */
    public function allLoadIndex(Request $request){
        try {
            $getCompanyAdmin            = auth()->guard('company-admin')->user();

            $getField                   = '';
            $isCheck                    = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','loads_active')->first();

            if(!empty($isCheck->id)) {
                //$getField             = unserialize($isCheck->config);
                $getField               = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_loads_active_first'));
            } else {
                $getField               = config('settings.table_loads_active_first');
            }

            if ($request->ajax()) {
                $data                   = LoadDetail::select('load_details.*', DB::raw('CONCAT(drivers.first_name," ",drivers.last_name) as driver'), 'drivers.cell_phone as phone_number', 'brokers.name as broker_name')
                    ->leftJoin('drivers', 'load_details.driver_id', '=', 'drivers.id')
                    ->leftJoin('brokers', 'load_details.brokerage_firm', '=', 'brokers.id')
                    //->orderBy('load_id','DESC')
                    //->orderBy('id','ASC')
                    ->whereHas('loads', function($q){
                        $q->where('company_id', auth()->guard('company-admin')->user()->company_id);
                    })
                    ->where('load_details.is_disable', 0);
                // General filter code - start
                foreach( $getField as $key => $value ) {
                    $conditionReq       = 'search_string_condition_'.$key;
                    $sortReq            = 'search_string_sort_'.$key;
                    $conditionDateReq   = 'search_date_condition_'.$key;
                    $sortDateReq        = 'search_date_sort_'.$key;
                    $conditionStatusReq = 'search_status_condition_'.$key;
                    $sortStatusReq      = 'search_status_sort_'.$key;

                    // String filter
                    if( isset( request()->$conditionReq ) ) {
                        $typeReq        = 'search_string_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'string' ) {
                            Common::getStringFilterResult( $data, $key );
                        }
                    }

                    // Status filter
                    if( isset( request()->$conditionStatusReq ) && request()->$conditionStatusReq == 1 ) {
                        Common::getStatusFilterResult( $data, $key );
                    }

                    // Date filter
                    if( isset( request()->$conditionDateReq ) ) {
                        $typeReq        = 'search_date_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'date' ) {
                            Common::getDateFilterResult( $data, $key );
                        }
                    }

                    // String sort only
                    if( isset( request()->$sortReq ) ) {
                        Common::sortStringFilter( $data, $key );
                    }

                    // Date sort only
                    if( isset( request()->$sortDateReq ) ) {
                        Common::sortDateFilter( $data, $key );
                    }

                    // Status sort only
                    if( isset( request()->$sortStatusReq ) ) {
                        Common::sortStatusFilter( $data, $key );
                    }
                }
                // General filter code - end
                $data->get();
                return Datatables::of($data)
                    ->addIndexColumn()
                    ->editColumn('load_number', function($row){
                        if ($row->is_disable == 0) {
                            if(in_array($row->load_type, ['0', '6'])) {
                                if ($row->load_type == 0) {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                                } else {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                                }
                            } else {
                                return '<a href="'.route('company.admin.loads.edit', base64Encode($row->load_id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        } else {
                            if ($row->load_type == 0) {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                            } else {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        }
                    })
                    /*
                    ->addColumn('driver', function($row){
                        return isset($row->driver->full_name) ? $row->driver->full_name : '';
                    })
                    */
                    ->filterColumn('driver', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(drivers.first_name, ' ', drivers.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('phone_number', function($row){
                        return isset($row->driver->cell_phone) ? $row->driver->cell_phone : '';
                    })
                    */
                    ->filterColumn('phone_number', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where("drivers.cell_phone", 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('broker_name', function($row){
                        return isset($row->broker->name) ? $row->broker->name : '';
                    })
                    */
                    ->filterColumn('broker_name', function ($query, $keyword) {
                        $query->whereHas('broker', function ($q) use ($keyword) {
                            $q->where("brokers.name", 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('actual_delivery_date', function($row){
                        return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date." ".$row->delivery_timezone_abbr : '';
                    })
                    ->editColumn('created_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('updated_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('booked_by', function($row){
                        if($row->booked_by == 0){
                            return 'Self Dispatch';
                        }else{
                            return $row->dispatcher->full_name;
                        }
                    })
                    ->filterColumn('booked_by', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('trailer_type', function($row){
                        return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                    })
                    ->addColumn('dispatcher', function($row){
                        return getLoadDispatcherName($row->booked_by);
                    })
                    ->filterColumn('dispatcher', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->addColumn('status', function($row){
                        return getLoadStatus($row->load_status,$row->is_on_hold);
                    })
                    ->filterColumn('status', function ($query, $keyword) {
                        if (Str::contains('pending' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 0);
                        }
                        if (Str::contains('accepted' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 1);
                        }
                        if (Str::contains('preplaned' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 2);
                        }
                        if (Str::contains('confirmed' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 3);
                        }
                        if (Str::contains('in transit' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 4);
                        }
                        if (Str::contains('delivered' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 5);
                        }
                        if (Str::contains('ready to bill' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 6);
                        }
                        if (Str::contains('on hold' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 7);
                        }
                        if (Str::contains('complete' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 8);
                        }
                        if (Str::contains('cancelled' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 9);
                        }
                        return $query;
                    })
                    ->addColumn('last_location', function($row){
                        return 'Seattle, WA, USA';
                    })
                    ->editColumn('total_bill', function($row){
                        return getPrice($row->total_bill);
                    })
                    ->editColumn('shipper_location', function($row){
                        $html           = [];
                        if($row->shipper_address_one){
                            $html[0]    = $row->shipper_address_one;
                        }
                        if($row->shipper_address_two){
                            $html[1]    = $row->shipper_address_two;
                        }
                        if($row->shipper_city){
                            $html[2]    = $row->shipper_city;
                        }
                        if($row->shipper_state){
                            $html[3]    = $row->shipper_state;
                        }
                        if($row->shipper_zip){
                            $html[4]    = $row->shipper_zip;
                        }
                        if(count($html) == 0){
                            return $row->shipper_location;
                        }else{
                            return implode(', ', $html);
                        }
                    })
                    ->editColumn('delivery_location', function($row){
                        $html           = [];
                        if($row->delivery_address_one){
                            $html[0]    = $row->delivery_address_one;
                        }
                        if($row->delivery_address_two){
                            $html[1]    = $row->delivery_address_two;
                        }
                        if($row->delivery_city){
                            $html[2]    = $row->delivery_city;
                        }
                        if($row->delivery_state){
                            $html[3]    = $row->delivery_state;
                        }
                        if($row->delivery_zip){
                            $html[4]    = $row->delivery_zip;
                        }
                        if(count($html) == 0){
                            return $row->delivery_location;
                        }else{
                            return implode(', ', $html);
                        }
                    })
                    ->addColumn('action', function($row){
                        $btn            = '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1"><img src="'.asset('theme/img/eye.png').'" alt=""></a>';
                        if ($row->is_disable == 0) {
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-2.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-3.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="javascript:" class="destroy" data-action="'.route('company.admin.loads.destroy',$row->load_id).'" data-id="'.$row->load_id.'"><img src="'.asset('theme/img/tbl--icon-4.png').'" alt=""></a>';
                        }
                        return $btn;
                    })
                    ->rawColumns(['action','load_number'])
                    ->make(true);
            }
            // return view('companyAdmin.load.index');
            // return view('companyAdmin.load.indextemp');
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );
        }
    }

    /**
     * Display a listing of the Oos pending loads.
     *
     * @return \Illuminate\Http\Response
     */
    public function OosPendingLoadsIndex(Request $request){
        try {
            $getCompanyAdmin            = auth()->guard('company-admin')->user();

            $getField                   = '';
            $isCheck                    = Bookmark::where('company_id',getUserCompnayId())->where('user_id',$getCompanyAdmin->id)->where('user_type',$getCompanyAdmin->type)->where('table_id','loads_active')->first();
            if(!empty($isCheck->id)) {
                //$getField             = unserialize($isCheck->config);
                $getField               = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_loads_active_first'));
            } else {
                $getField               = config('settings.table_loads_active_first');
            }

            if ($request->ajax()) {
                $data                   = LoadDetail::select('load_details.*', DB::raw('CONCAT(drivers.first_name," ",drivers.last_name) as driver'), 'drivers.cell_phone as phone_number', 'brokers.name as broker_name')
                    ->leftJoin('drivers', 'load_details.driver_id', '=', 'drivers.id')
                    ->leftJoin('brokers', 'load_details.brokerage_firm', '=', 'brokers.id')
                    //->orderBy('load_id','DESC')
                    //->orderBy('id','ASC')
                    ->where('load_details.oos_pending', 1)
                    ->whereHas('loads', function($q){
                        $q->where('company_id', auth()->guard('company-admin')->user()->company_id);
                    })
                    ->where(function($q) {
                        $q->whereNotNull('load_details.driver_id')->where('load_details.driver_id', '!=', 0);
                    });
                // General filter code - start
                foreach( $getField as $key => $value ) {
                    $conditionReq       = 'search_string_condition_'.$key;
                    $sortReq            = 'search_string_sort_'.$key;
                    $conditionDateReq   = 'search_date_condition_'.$key;
                    $sortDateReq        = 'search_date_sort_'.$key;
                    $conditionStatusReq = 'search_status_condition_'.$key;
                    $sortStatusReq      = 'search_status_sort_'.$key;

                    // String filter
                    if( isset( request()->$conditionReq ) ) {
                        $typeReq        = 'search_string_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'string' ) {
                            Common::getStringFilterResult( $data, $key );
                        }
                    }

                    // Status filter
                    if( isset( request()->$conditionStatusReq ) && request()->$conditionStatusReq == 1 ) {
                        Common::getStatusFilterResult( $data, $key );
                    }

                    // Date filter
                    if( isset( request()->$conditionDateReq ) ) {
                        $typeReq        = 'search_date_type_'.$key;
                        $type           = request()->$typeReq;

                        if( $type == 'date' ) {
                            Common::getDateFilterResult( $data, $key );
                        }
                    }

                    // String sort only
                    if( isset( request()->$sortReq ) ) {
                        Common::sortStringFilter( $data, $key );
                    }

                    // Date sort only
                    if( isset( request()->$sortDateReq ) ) {
                        Common::sortDateFilter( $data, $key );
                    }

                    // Status sort only
                    if( isset( request()->$sortStatusReq ) ) {
                        Common::sortStatusFilter( $data, $key );
                    }
                }
                // General filter code - end
                $data->get();
                return Datatables::of($data)
                    ->addIndexColumn()
                    ->editColumn('load_number', function($row){
                        if ($row->is_disable == 0) {
                            if(in_array($row->load_type, ['0', '6'])) {
                                if ($row->load_type == 0) {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                                } else {
                                    return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                                }
                            } else {
                                return '<a href="'.route('company.admin.loads.edit', base64Encode($row->load_id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        } else {
                            if ($row->load_type == 0) {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.$row->load_number.'</a>';
                            } else {
                                return '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1 load-edit-link">'.getLoadTypeList()[$row->load_type].'</a>';
                            }
                        }
                    })
                    /*
                    ->addColumn('driver', function($row){
                        return $row->driver->full_name;
                    })
                    */
                    ->filterColumn('driver', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(drivers.first_name, ' ', drivers.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('phone_number', function($row){
                        return isset($row->driver->cell_phone) ? $row->driver->cell_phone : '';
                    })
                    */
                    ->filterColumn('phone_number', function ($query, $keyword) {
                        $query->whereHas('driver', function ($q) use ($keyword) {
                            $q->where("drivers.cell_phone", 'LIKE', "%".$keyword."%");
                        });
                    })
                    /*
                    ->addColumn('broker_name', function($row){
                        return isset($row->broker->name) ? $row->broker->name : '';
                    })
                    */
                    ->filterColumn('broker_name', function ($query, $keyword) {
                        $query->whereHas('broker', function ($q) use ($keyword) {
                            $q->where("brokers.name", 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('actual_delivery_date', function($row){
                        return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date." ".$row->delivery_timezone_abbr : '';
                    })
                    ->editColumn('created_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('updated_at', function($row){
                        if(auth()->guard('company-admin')->user()->time_format=='12'){
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                        }else{
                            return !is_null($row->updated_at) ? Carbon::parse($row->updated_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                        }
                    })
                    ->editColumn('booked_by', function($row){
                        if($row->booked_by == 0){
                            return 'Self Dispatch';
                        }else{
                            return $row->dispatcher->full_name;
                        }
                    })
                    ->filterColumn('booked_by', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->editColumn('trailer_type', function($row){
                        return isset(getTrailerTypeList()[$row->trailer_type]) ? getTrailerTypeList()[$row->trailer_type] : '';
                    })
                    ->addColumn('dispatcher', function($row){
                        return getLoadDispatcherName($row->booked_by);
                    })
                    ->filterColumn('dispatcher', function ($query, $keyword) {
                        $query->whereHas('dispatcher', function ($q) use ($keyword) {
                            $q->where(DB::raw("CONCAT(company_admins.first_name, ' ', company_admins.last_name)"), 'LIKE', "%".$keyword."%");
                        });
                    })
                    ->addColumn('status', function($row){
                        return getLoadStatus($row->load_status,$row->is_on_hold);
                    })
                    ->filterColumn('status', function ($query, $keyword) {
                        if (Str::contains('pending' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 0);
                        }
                        if (Str::contains('accepted' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 1);
                        }
                        if (Str::contains('preplaned' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 2);
                        }
                        if (Str::contains('confirmed' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 3);
                        }
                        if (Str::contains('in transit' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 4);
                        }
                        if (Str::contains('delivered' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 5);
                        }
                        if (Str::contains('ready to bill' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 6);
                        }
                        if (Str::contains('on hold' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 7);
                        }
                        if (Str::contains('complete' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 8);
                        }
                        if (Str::contains('cancelled' , Str::lower($keyword))) {
                            $query      = $query->where('load_status', 9);
                        }
                        return $query;
                    })
                    ->addColumn('last_location', function($row){
                        return 'Seattle, WA, USA';
                    })
                    ->editColumn('total_bill', function($row){
                        return getPrice($row->total_bill);
                    })
                    ->editColumn('shipper_location', function($row){
                        $html           = [];
                        if($row->shipper_address_one){
                            $html[0]    = $row->shipper_address_one;
                        }
                        if($row->shipper_address_two){
                            $html[1]    = $row->shipper_address_two;
                        }
                        if($row->shipper_city){
                            $html[2]    = $row->shipper_city;
                        }
                        if($row->shipper_state){
                            $html[3]    = $row->shipper_state;
                        }
                        if($row->shipper_zip){
                            $html[4]    = $row->shipper_zip;
                        }
                        if(count($html) == 0){
                            return $row->shipper_location;
                        }else{
                            return implode(', ', $html);
                        }

                    })
                    ->editColumn('delivery_location', function($row){
                        $html           = [];
                        if($row->delivery_address_one){
                            $html[0]    = $row->delivery_address_one;
                        }
                        if($row->delivery_address_two){
                            $html[1]    = $row->delivery_address_two;
                        }
                        if($row->delivery_city){
                            $html[2]    = $row->delivery_city;
                        }
                        if($row->delivery_state){
                            $html[3]    = $row->delivery_state;
                        }
                        if($row->delivery_zip){
                            $html[4]    = $row->delivery_zip;
                        }
                        if(count($html) == 0){
                            return $row->delivery_location;
                        }else{
                            return implode(', ', $html);
                        }
                    })
                    ->addColumn('action', function($row){
                        $btn            = '<a href="'.route('company.admin.loads.show', base64Encode($row->id)).'" class="mr-1"><img src="'.asset('theme/img/eye.png').'" alt=""></a>';
                        if ($row->is_disable == 0) {
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-2.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="#" class="mr-1"><img src="'.asset('theme/img/tbl--icon-3.png').'" alt=""></a>';
                            $btn        = $btn.'<a href="javascript:" class="destroy" data-action="'.route('company.admin.loads.destroy',$row->load_id).'" data-id="'.$row->load_id.'"><img src="'.asset('theme/img/tbl--icon-4.png').'" alt=""></a>';
                        }
                        return $btn;
                    })
                    ->rawColumns(['action','load_number'])
                    ->make(true);
            }
            // return view('companyAdmin.load.index');
            // return view('companyAdmin.load.indextemp');
        } catch( \Exception $e ) {
            \Log::emergency( "File: ".$e->getFile() );
            \Log::emergency( "Line: ".$e->getLine() );
            \Log::emergency( "Message: ".$e->getMessage() );
        }
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request){
        $load_assign_trailers                   = getLoadAssignTrailers();
        $load_available_trailers                = getLoadAvailableTrailers($load_assign_trailers);
        $this->data['load_available_trailers']  = $load_available_trailers;
        $load_pickup_trailers                   = getLoadPickUpTrailers($load_assign_trailers, $load_available_trailers);
        $this->data['load_pickup_trailers']     = $load_pickup_trailers;

        $accessorialList                        = CompanyAccessorial::isCompany()->get(['id', 'name', 'default_amount', 'gl_code']);
        $accessorialDropDown                    = "";
        if($accessorialList->count() > 0){
            $accessorialDropDown                .= '<option value="">Select accessorial</option>';
            foreach ($accessorialList as $accessorial){
                $accessorialDropDown            .= '<option value="'.$accessorial->id.'" data-default-amount="'.$accessorial->default_amount.'">'.$accessorial->name.'</option>';
            }
        }else{
            $accessorialDropDown                .= '<option value="" data-default-amount="">Select accessorial</option>';
        }
        $this->data['accessorialDropDown']      = $accessorialDropDown;

        $this->data['offer']                    = Offer::where('id', $request->offer_id)->first();
        return view('companyAdmin.load.create', $this->data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request){
        try {
            // dd('Create New Load', $request->all());

            /*------------------------------------------
            --------------------------------------------
            Start DB Transaction
            --------------------------------------------
            --------------------------------------------*/
            // DB::beginTransaction();

            /* Create New Load */
            $setting                = auth()->guard('company-admin')->user()->getCompany;
            $company_id             = auth()->guard('company-admin')->user()->company_id;
            $load                   = Load::create(['company_id' => $company_id]);

            $formdata               = $request->all();
            $dummy_load_id          = $formdata['load_id'];
            $accessorial_unique_id  = $formdata['accessorial_unique_id'];

            $load_type              = $formdata['load_type'];
            $load_occupied          = false;
            // 1 = MAINTENANCE, 2 = UNAUTHORIZED, 3 = HOS, 4 = NO DISPATCH, 5 = TIME OFF
            if(in_array($load_type, ['0', '6'])){
                // 0 = OCCUPIED, 6 = TONU
                $load_occupied      = true;
            }

            $input                                                      = [];
            $input['load_id']                                           = $load->id;

            // Created Load number base on 'desired_option' added by Dhaval Thakor - 23-12-2022 - Start
            $load_number                                                = null;
            if(isset($formdata['carrier_id'])){
                $carrier                                                = Carrier::find($formdata['carrier_id']);
                if(!is_null($carrier)){
                    if(trim($carrier->desired_option) != ""){
                        if($carrier->desired_option == "0"){
                            $desired_load_number                        = $carrier->desired_load_number + 1;
                            $carrier->desired_load_number               = $desired_load_number;
                            if($carrier->save()){
                                if(trim($carrier->identifier) != ""){
                                    $load_number                       .= $carrier->identifier."-";
                                }
                                $load_number                           .= $desired_load_number;
                            }
                        }else if($carrier->desired_option == "1"){
                            if(!is_null($formdata['load_number'])){
                                if(trim($carrier->identifier) != ""){
                                    $load_number                        .= $carrier->identifier."-";
                                }
                                $load_number                            .= $formdata['load_number'];
                            }
                        }else{
                            if(!is_null($formdata['load_number'])){
                                if(trim($formdata['identifier']) != ""){
                                    $load_number                        .= $formdata['identifier'];
                                }
                                $load_number                            .= $formdata['load_number'];
                            }
                        }
                    }else{
                        if(!is_null($formdata['load_number'])){
                            if(trim($formdata['identifier']) != ""){
                                $load_number                            .= $formdata['identifier'];
                            }
                            $load_number                                .= $formdata['load_number'];
                        }
                    }
                }else{
                    if(!is_null($formdata['load_number'])){
                        if(trim($formdata['identifier']) != ""){
                            $load_number                                .= $formdata['identifier'];
                        }
                        $load_number                                    .= $formdata['load_number'];
                    }
                }
            }else{
                if(!is_null($formdata['load_number'])){
                    if(trim($formdata['identifier']) != ""){
                        $load_number                                    .= $formdata['identifier'];
                    }
                    $load_number                                        .= $formdata['load_number'];
                }
            }
            $input['load_number']                                       = $load_number;
            // Created Load number base on 'desired_option' added by Dhaval Thakor - 23-12-2022 - End

            $input['submitted_by']                                      = auth()->guard('company-admin')->user()->id;
            $input['booked_by']                                         = $formdata['booked_by'];
            $input['self_dispatch']                                     = $formdata['self_dispatch'] ?? 0;
            if (isset($formdata['self_dispatch'])) {
                $input['booked_by']                                     = 0;
            } elseif (!isset($formdata['self_dispatch']) && !isset($formdata['booked_by'])) {
                $manager                                                = Driver::whereId($formdata['driver_id'])->first();
                if(!is_null($manager)){
                    $input['booked_by']                                 = $manager->manager_id;
                }else{
                    $input['booked_by']                                 = 0;
                }
            }
            $input['load_type']                                         = $formdata['load_type'];
            $input['load_status']                                       = $formdata['load_status'];
            // NEW CODE TO STORE STATUS SORT ORDER - START
            $input['load_status_order']                                 = Common::getLoadStatusOrderById( $formdata['load_status'] );
            // NEW CODE TO STORE STATUS SORT ORDER - END
            $input['is_on_hold']                                        = $formdata['is_on_hold'] ?? 0;
            $input['notification_reason']                               = $load_occupied ? $formdata['notification_reason'] : null;
            $input['reason_on_hold']                                    = $load_occupied ? $formdata['reason_on_hold'] : null;
            if ($input['is_on_hold']=='1') {
                $input['load_on_hold_datetime']                         = Carbon::now()->format('Y-m-d H:i:s');
            }

            $input['driver_id']                                         = $formdata['driver_id'];
            $input['co_driver_id']                                      = $formdata['co_driver_id'] ?? null;
            $input['trucking_company']                                  = $formdata['truck_company'];
            $input['truck_number']                                      = $formdata['truck_number'];
            $input['trailer_number']                                    = $formdata['trailer_number'];
            $input['trailer_type']                                      = $formdata['trailer_type'];
            $input['carrier_id']                                        = $formdata['carrier_id'];
            $input['terminal_id']                                       = $formdata['terminal_id'];

            $driver_oos_pending             = 0;
            $equipment_oos_pending          = 0;
            $input['oos_pending']           = 0;
            if($setting->oos_driver == 3){
                if(checkOosDriver($formdata['driver_id'])){
                    $driver_oos_pending     = 1;
                    $input['oos_pending']   = 1;
                }
            }
            if($setting->oos_equipment == 3){
                if(checkOosTrailer($formdata['trailer_number'])){
                    $equipment_oos_pending  = 1;
                    $input['oos_pending']   = 1;
                }
                if(checkOosTruck($formdata['truck_number'])){
                    $equipment_oos_pending  = 1;
                    $input['oos_pending']   = 1;
                }
            }
            if($driver_oos_pending==1 || $equipment_oos_pending==1){
                if(!empty(getManagerList())){
                    foreach(getManagerList() as $key => $manager){
                        if($driver_oos_pending==1){
                            $description    = 'Load created with OOS Driver - '.$load->id;
                            createNotification(
                                15, // source
                                'OOS Driver', // name
                                $key, // user_id
                                1, // user_type
                                1, // type
                                $load->id, // action_id
                                $description // description
                            );
                        }
                        if($equipment_oos_pending==1){
                            $description    = 'Load created with OOS Equipment - '.$load->id;
                            createNotification(
                                15, // source
                                'OOS Equipment', // name
                                $key, // user_id
                                1, // user_type
                                1, // type
                                $load->id, // action_id
                                $description // description
                            );
                        }
                    }
                }
            }

            if($load_occupied){
                // 0 = OCCUPIED, 6 = TONU

                $input['brokerage_firm']                                = $formdata['brokerage_firm'];
                $input['brokerage_mc']                                  = $formdata['brokerage_mc'];
                $input['terms']                                         = $formdata['terms'];
                $input['rep']                                           = $formdata['rep'];
                $input['phone']                                         = $formdata['phone'];
                $input['broker_email']                                  = $formdata['broker_email'];
                $input['ext']                                           = $formdata['ext'];

                $is_cod                                                 = $formdata['is_cod'] ?? '0';
                $input['is_cod']                                        = $is_cod;
                if($is_cod == '1'){
                    $input['up_front_amount']                           = $formdata['up_front_amount'];
                    $input['up_front_payment_type']                     = $formdata['up_front_payment_type'];
                    $input['up_front_ref_number']                       = $formdata['up_front_ref_number'];
                    $input['up_front_is_paid']                          = $formdata['up_front_is_paid'] ?? '0';

                    $input['at_pickup_amount']                          = $formdata['at_pickup_amount'];
                    $input['at_pickup_payment_type']                    = $formdata['at_pickup_payment_type'];
                    $input['at_pickup_ref_number']                      = $formdata['at_pickup_ref_number'];
                    $input['at_pickup_is_paid']                         = $formdata['at_pickup_is_paid'] ?? '0';

                    $input['at_delivery_amount']                        = $formdata['at_delivery_amount'];
                    $input['at_delivery_payment_type']                  = $formdata['at_delivery_payment_type'];
                    $input['at_delivery_ref_number']                    = $formdata['at_delivery_ref_number'];
                    $input['at_delivery_is_paid']                       = $formdata['at_delivery_is_paid'] ?? '0';
                }else{
                    $input['score_ratting']                             = $formdata['score_ratting'];
                    $input['score_credit']                              = $formdata['score_credit'];
                    $input['score_updated_at']                          = $formdata['score_updated_at'];
                }

                $itemize                                                = $formdata['itemize'] ?? 0;
                $input['itemize']                                       = $itemize;
                $input['load_type_2']                                   = $formdata['load_type_2'];
                if($itemize == 0){
                    $input['temp_type']                                 = $formdata['reefer_temp_type'] ?? 0;
                    $input['temp']                                      = $formdata['reefer_temp'];
                    $input['commodity']                                 = $formdata['commodity'];
                    $input['weight']                                    = $formdata['weight'];
                    $input['load_value']                                = $formdata['load_value'];
                    $input['pickup_number']                             = $formdata['pickup_number'];
                }
                $input['hazardous_load']                                = $formdata['hazardous_load'];
                if($formdata['hazardous_load'] == '1'){
                    $input['hazardous_options']                         = $formdata['hazardous_options'];
                }
                $input['overdimensional']                               = $formdata['overdimensional'];

                $input['broker_load_number']                            = $formdata['broker_load_number'];
                $input['bol_number']                                    = $formdata['bol_number'];
                $input['delivery_number']                               = $formdata['delivery_number'];
                $input['po_Number']                                     = $formdata['po_Number'];
                $input['sku_number']                                    = $formdata['sku_number'];

                $other_number                                           = $formdata['other_number'] ?? [];
                $other_number_arry                                      = [];
                if(!empty($other_number)){
                    if(array_key_exists('name', $other_number)){
                        $other_number_names                             = $other_number['name'];
                        foreach ($other_number_names as $key => $value) {
                            $arry                                       = [];
                            $arry['other_name']                         = $value;
                            $arry['other_number']                       = $other_number['number'][$key] ?? null;
                            $other_number_arry[]                        = $arry;
                        }
                    }
                }
                if(!empty($other_number_arry)){
                    $input['other_number']                              = serialize($other_number_arry);
                }

                if(isset($formdata['deadhead_mileage_options'])){
                    $deadhead_mileage_options                           = json_decode($formdata['deadhead_mileage_options'], true);
                    if(!empty($deadhead_mileage_options)){
                        // $deadhead_mileage_options['type']            = 0;
                        $input['deadhead_mileage_options']              = json_encode($deadhead_mileage_options);
                    }
                }
                $input['occupied_pickup_day']                           = $formdata['occupied_pickup_day'] ?? 0;

                $shipping_time_range                                    = $formdata['shipping_time_range'];

                $input['shipper_id']                                    = $formdata['shipper_id'];
                $input['shipper_address_one']                           = $formdata['shipper_address_one'];
                $input['shipper_address_two']                           = $formdata['shipper_address_two'];
                $input['shipper_state']                                 = $formdata['shipper_state'];
                $input['shipper_city']                                  = $formdata['shipper_city'];
                $input['shipper_zip']                                   = $formdata['shipper_zip'];

                if($formdata['shipper_address_verified']==0){
                    $input['shipper_latitude']                          = null;
                    $input['shipper_longitude']                         = null;
                    $input['shipper_timezone']                          = null;
                    $input['shipper_timezone_offset']                   = null;
                    $input['shipper_timezone_abbr']                     = null;
                }else{
                    $shipper_timezone                                   = null;
                    $shipper_timezone_offset                            = null;
                    if(!is_null($formdata['shipper_timezone_abbr'])){
                        $shipper_timezone                               = timezone_name_from_abbr($formdata['shipper_timezone_abbr']);
                        $shipper_timezone_offset                        = Carbon::createFromTimestamp(time(), $shipper_timezone)->getOffsetString();
                    }
                    $input['shipper_latitude']                          = $formdata['shipper_latitude'];
                    $input['shipper_longitude']                         = $formdata['shipper_longitude'];
                    $input['shipper_timezone']                          = $shipper_timezone;
                    $input['shipper_timezone_offset']                   = $shipper_timezone_offset;
                    $input['shipper_timezone_abbr']                     = $formdata['shipper_timezone_abbr'];
                    $input['shipper_address_verified']                  = 1;
                }

                $input['shipper_note']                                  = $formdata['shipper_note'];

                if($itemize == 1){
                    $input['shipper_commodity']                         = $formdata['shipper_commodity'];
                    $input['shipper_stop_value']                        = $formdata['shipper_stop_value'];
                    $input['shipper_stop_weight']                       = $formdata['shipper_stop_weight'];
                    $input['shipper_reefer_mode']                       = $formdata['shipper_reefer_mode'];
                    $input['shipper_reefer_temp_type']                  = $formdata['shipper_reefer_temp_type'] ?? 0;
                    $input['shipper_reefer_temp']                       = $formdata['shipper_reefer_temp'];
                    $input['shipper_pickup_number']                     = $formdata['shipper_pickup_number'];
                }
                if(isset($formdata['shipper_dimension']) && !empty($formdata['shipper_dimension'])){
                    $input['shipper_dimension']                         = serialize($formdata['shipper_dimension']);
                }

                $input['shipper_drop_trailer_schedule']                 = $formdata['shipper_drop_trailer_schedule'] ?? 0;
                if($input['shipper_drop_trailer_schedule'] == 1){
                    $input['shipper_drop_trailer_id']                   = $formdata['shipper_drop_trailer_id'] ?? null;
                } else if($input['shipper_drop_trailer_schedule'] == 2){
                    $input['shipper_drop_trailer_id']                   = $formdata['shipper_drop_trailer_id'] ?? null;
                    $input['shipper_pickup_trailer_id']                 = $formdata['shipper_pickup_trailer_id'] ?? null; // isset($formdata['shipper_pickup_trailer_id']) ? str_replace('TRAILERDROP', '', $formdata['shipper_pickup_trailer_id']) : null;
                }

                $shipper_files                                          = $formdata['shipper_files'] ?? [];
                if(!empty($shipper_files)){
                    if (array_key_exists('name_id', $shipper_files)) {
                        $shipper_files_array                            = [];
                        $shipper_files_name_ids                         = array_filter($shipper_files['name_id'], function ($var) {
                            return $var !== null && $var !== '';
                        });
                        foreach($shipper_files_name_ids as $sfkey => $shipper_files_name_id){
                            $arry                                       = [];
                            $arry['name_id']                            = $shipper_files_name_id;
                            $arry['name']                               = isset($shipper_files['name'][$sfkey]) ? $shipper_files['name'][$sfkey] : '';
                            $arry['is_required']                        = isset($shipper_files['is_required'][$sfkey]) ? $shipper_files['is_required'][$sfkey] : 'off';
                            $arry['type']                               = $shipper_files['type'][$sfkey];
                            $arry['fixed']                              = $shipper_files['fixed'][$sfkey];
                            $arry['include_w_billing']                  = isset($shipper_files['include_w_billing'][$sfkey]) && $shipper_files['include_w_billing'][$sfkey]=='yes' ? 'yes' : 'no';
                            $arry['custom']                             = isset($shipper_files['custom'][$sfkey]) && $shipper_files['custom'][$sfkey]=='yes' ? 'yes' : 'no';
                            $shipper_files_array[]                      = $arry;
                        }
                        $input['shipper_files']                         = serialize($shipper_files_array);
                    }
                }

                $shipper_files_upload                                   = $formdata['shipper_files_upload'] ?? [];
                if(!empty($shipper_files_upload)){
                    if (array_key_exists('name_id', $shipper_files_upload)) {
                        $shipper_files_upload_array                     = [];
                        $shipper_files_upload_name_ids                  = array_filter($shipper_files_upload['name_id'], function ($var) {
                            return $var !== null && $var !== '';
                        });
                        foreach($shipper_files_upload_name_ids as $sfkey => $shipper_files_upload_name_id){
                            $arry                                       = [];
                            $arry['name_id']                            = $shipper_files_upload_name_id;
                            $arry['name']                               = isset($shipper_files_upload['name'][$sfkey]) ? $shipper_files_upload['name'][$sfkey] : '';
                            $arry['is_required']                        = isset($shipper_files_upload['is_required'][$sfkey]) ? $shipper_files_upload['is_required'][$sfkey] : 'off';
                            $arry['type']                               = $shipper_files_upload['type'][$sfkey];
                            $arry['fixed']                              = $shipper_files_upload['fixed'][$sfkey];
                            $arry['include_w_billing']                  = isset($shipper_files_upload['include_w_billing'][$sfkey]) && $shipper_files_upload['include_w_billing'][$sfkey]=='yes' ? 'yes' : 'no';
                            $arry['custom']                             = isset($shipper_files_upload['custom'][$sfkey]) && $shipper_files_upload['custom'][$sfkey]=='yes' ? 'yes' : 'no';

                            $arry['is_received']                        = isset($shipper_files_upload['is_received'][$sfkey]) ? $shipper_files_upload['is_received'][$sfkey] : 'off';
                            $arry['hide_from_driver']                   = isset($shipper_files_upload['hide_from_driver'][$sfkey]) && $shipper_files_upload['hide_from_driver'][$sfkey]=='yes' ? 'yes' : 'no';
                            $arry['file_not_provided']                  = isset($shipper_files_upload['file_not_provided'][$sfkey]) ? $shipper_files_upload['file_not_provided'][$sfkey] : 'off';
                            if(isset($shipper_files_upload['file'][$sfkey])){
                                $arry['is_received']                    = 'on';
                                $arry['file']                           = UploadImagePdf($shipper_files_upload['file'][$sfkey], 'companyAdmin/load_detail_document');
                            }else{
                                $arry['file']                           = null;
                            }
                            if($arry['is_received'] == 'on'){
                                $arry['upload_user_type']               = auth()->guard('company-admin')->user()->type;
                                $arry['upload_by']                      = auth()->guard('company-admin')->user()->id;
                                $arry['uploaded_at']                    = Carbon::now();
                            }
                            $shipper_files_upload_array[]               = $arry;
                        }
                        $input['shipper_files_upload']                  = serialize($shipper_files_upload_array);
                    }
                }

                $delivery_time_range                                    = $formdata['delivery_time_range'];

                $input['receiver_id']                                   = $formdata['receiver_id'];
                $input['delivery_address_one']                          = $formdata['delivery_address_one'];
                $input['delivery_address_two']                          = $formdata['delivery_address_two'];
                $input['delivery_state']                                = $formdata['delivery_state'];
                $input['delivery_city']                                 = $formdata['delivery_city'];
                $input['delivery_zip']                                  = $formdata['delivery_zip'];

                if($formdata['delivery_address_verified']==0){
                    $input['delivery_latitude']                         = null;
                    $input['delivery_longitude']                        = null;
                    $input['delivery_timezone']                         = null;
                    $input['delivery_timezone_offset']                  = null;
                    $input['delivery_timezone_abbr']                    = null;
                }else{
                    $delivery_timezone                                  = null;
                    $delivery_timezone_offset                           = null;
                    if(!is_null($formdata['delivery_timezone_abbr'])){
                        $delivery_timezone                              = timezone_name_from_abbr($formdata['delivery_timezone_abbr']);
                        $delivery_timezone_offset                       = Carbon::createFromTimestamp(time(), $delivery_timezone)->getOffsetString();
                    }
                    $input['delivery_latitude']                         = $formdata['delivery_latitude'];
                    $input['delivery_longitude']                        = $formdata['delivery_longitude'];
                    $input['delivery_timezone']                         = $delivery_timezone;
                    $input['delivery_timezone_offset']                  = $delivery_timezone_offset;
                    $input['delivery_timezone_abbr']                    = $formdata['delivery_timezone_abbr'];
                    $input['delivery_address_verified']                 = 1;
                }

                $input['delivery_note']                                 = $formdata['delivery_note'];

                if($itemize == 1){
                    $input['delivery_commodity']                        = $formdata['delivery_commodity'];
                    $input['delivery_stop_value']                       = $formdata['delivery_stop_value'];
                    $input['delivery_stop_weight']                      = $formdata['delivery_stop_weight'];
                    $input['delivery_reefer_mode']                      = $formdata['delivery_reefer_mode'];
                    $input['delivery_reefer_temp_type']                 = $formdata['delivery_reefer_temp_type'] ?? 0;
                    $input['delivery_reefer_temp']                      = $formdata['delivery_reefer_temp'];
                    $input['delivery_pickup_number']                    = $formdata['delivery_pickup_number'];
                }
                if(isset($formdata['delivery_dimension']) && !empty($formdata['delivery_dimension'])){
                    $input['delivery_dimension']                        = serialize($formdata['delivery_dimension']);
                }

                $input['delivery_drop_trailer_schedule']                = $formdata['delivery_drop_trailer_schedule'] ?? 0;
                if($input['delivery_drop_trailer_schedule'] == 1){
                    $input['delivery_drop_trailer_id']                  = $formdata['delivery_drop_trailer_id'] ?? null;
                } else if($input['delivery_drop_trailer_schedule'] == 2){
                    $input['delivery_drop_trailer_id']                  = $formdata['delivery_drop_trailer_id'] ?? null;
                    $input['delivery_pickup_trailer_id']                = $formdata['delivery_pickup_trailer_id'] ?? null; // isset($formdata['delivery_pickup_trailer_id']) ? str_replace('TRAILERDROP', '', $formdata['delivery_pickup_trailer_id']) : null;
                }

                $consignee_files                                        = $formdata['consignee_files'] ?? [];
                if(!empty($consignee_files)){
                    if (array_key_exists('name_id', $consignee_files)) {
                        $consignee_files_array                          = [];
                        $consignee_files_name_ids                       = array_filter($consignee_files['name_id'], function ($var) {
                            return $var !== null && $var !== '';
                        });
                        foreach($consignee_files_name_ids as $cfkey => $consignee_files_name_id){
                            $arry                                       = [];
                            $arry['name_id']                            = $consignee_files_name_id;
                            $arry['name']                               = isset($consignee_files['name'][$cfkey]) ? $consignee_files['name'][$cfkey] : '';
                            $arry['is_required']                        = isset($consignee_files['is_required'][$cfkey]) ? $consignee_files['is_required'][$cfkey] : 'off';
                            $arry['type']                               = $consignee_files['type'][$cfkey];
                            $arry['fixed']                              = $consignee_files['fixed'][$cfkey];
                            $arry['include_w_billing']                  = isset($consignee_files['include_w_billing'][$cfkey]) && $consignee_files['include_w_billing'][$cfkey]=='yes' ? 'yes' : 'no';
                            $arry['custom']                             = isset($consignee_files['custom'][$cfkey]) && $consignee_files['custom'][$cfkey]=='yes' ? 'yes' : 'no';
                            $consignee_files_array[]                    = $arry;
                        }
                        $input['consignee_files']                       = serialize($consignee_files_array);
                    }
                }

                $consignee_files_upload                                 = $formdata['consignee_files_upload'] ?? [];
                if(!empty($consignee_files_upload)){
                    if (array_key_exists('name_id', $consignee_files_upload)) {
                        $consignee_files_upload_array                   = [];
                        $consignee_files_upload_name_ids                = array_filter($consignee_files_upload['name_id'], function ($var) {
                            return $var !== null && $var !== '';
                        });
                        foreach($consignee_files_upload_name_ids as $cfkey => $consignee_files_upload_name_id){
                            $arry                                       = [];
                            $arry['name_id']                            = $consignee_files_upload_name_id;
                            $arry['name']                               = isset($consignee_files_upload['name'][$cfkey]) ? $consignee_files_upload['name'][$cfkey] : '';
                            $arry['is_required']                        = isset($consignee_files_upload['is_required'][$cfkey]) ? $consignee_files_upload['is_required'][$cfkey] : 'off';
                            $arry['type']                               = $consignee_files_upload['type'][$cfkey];
                            $arry['fixed']                              = $consignee_files_upload['fixed'][$cfkey];
                            $arry['include_w_billing']                  = isset($consignee_files_upload['include_w_billing'][$cfkey]) && $consignee_files_upload['include_w_billing'][$cfkey]=='yes' ? 'yes' : 'no';
                            $arry['custom']                             = isset($consignee_files_upload['custom'][$cfkey]) && $consignee_files_upload['custom'][$cfkey]=='yes' ? 'yes' : 'no';

                            $arry['is_received']                        = isset($consignee_files_upload['is_received'][$cfkey]) ? $consignee_files_upload['is_received'][$cfkey] : 'off';
                            $arry['hide_from_driver']                   = isset($consignee_files_upload['hide_from_driver'][$cfkey]) && $consignee_files_upload['hide_from_driver'][$cfkey]=='yes' ? 'yes' : 'no';
                            $arry['file_not_provided']                  = isset($consignee_files_upload['file_not_provided'][$cfkey]) ? $consignee_files_upload['file_not_provided'][$cfkey] : 'off';
                            if(isset($consignee_files_upload['file'][$cfkey])){
                                $arry['is_received']                    = 'on';
                                $arry['file']                           = UploadImagePdf($consignee_files_upload['file'][$cfkey], 'companyAdmin/load_detail_document');
                            }else{
                                $arry['file']                           = null;
                            }
                            if($arry['is_received'] == 'on'){
                                $arry['upload_user_type']               = auth()->guard('company-admin')->user()->type;
                                $arry['upload_by']                      = auth()->guard('company-admin')->user()->id;
                                $arry['uploaded_at']                    = Carbon::now();
                            }
                            $consignee_files_upload_array[]             = $arry;
                        }
                        $input['consignee_files_upload']                = serialize($consignee_files_upload_array);
                    }
                }

                $input['empty_miles']                                   = $formdata['empty_miles'];
                $input['loaded_miles']                                  = $formdata['loaded_miles'];
                $input['total_miles']                                   = $formdata['total_miles'];
                $input['agreed_upon_rate']                              = $formdata['agreed_upon_rate'];
                $input['fuel_surcharge_cost_per_mile']                  = $formdata['fuel_surcharge_cost_per_mile'];
                $input['fuel_surcharge']                                = $formdata['fuel_surcharge'];
                $input['line_haul']                                     = $formdata['line_haul'];

                $input['total_bill']                                    = $formdata['total_bill'];
                $driver_revenue                                         = 0;
                if(isset($formdata['total_bill']) && $formdata['total_bill'] > 0){
                    $driver_revenue                                     += (float) str_replace(',', '', $formdata['total_bill']);
                }
                // if(isset($formdata['lumper']) && $formdata['lumper'] > 0){
                //     $driver_revenue                                  -= $formdata['lumper'];
                // }
                $input['driver_revenue']                                = $driver_revenue;

                $input['map_toll_roads']                                = $formdata['map_toll_roads'];
                $input['map_max_elevation']                             = $formdata['map_max_elevation'];
                $input['map_close_borders']                             = $formdata['map_close_borders'];
                $input['load_trip_id']                                  = $formdata['load_trip_id'];
                $input['load_tms_trip_id']                              = $formdata['load_tms_trip_id'];
            }else{
                // 1 = MAINTENANCE, 2 = UNAUTHORIZED, 3 = HOS, 4 = NO DISPATCH, 5 = TIME OFF
                $input['start_date']                                    = date('Y-m-d', strtotime($formdata['start_date']));
                $input['end_date']                                      = date('Y-m-d', strtotime($formdata['end_date']));

                $shipping_time_range                                    = 0;
                $delivery_time_range                                    = 0;

                //
                $formdata['shipper_date_time']                          = Carbon::parse(date('Y-m-d h:i A', strtotime($input['start_date'])))->format(getTimeLayout());
                // $formdata['shipper_date_time_end']                   = null;

                $formdata['intransit_driver_acknowledgement']           = 0;
                $formdata['intransit_shipping_information']             = 0;
                $formdata['intransit_date_time']                        = Carbon::parse(date('Y-m-d h:i A', strtotime($input['start_date'])))->format(getTimeLayout());

                $formdata['delivery_date_time']                         = Carbon::parse(date('Y-m-d h:i A', strtotime($input['end_date'].' 12:00 PM')))->format(getTimeLayout());
                // $formdata['delivery_date_time_end']                  = null;

                $formdata['delivered_driver_acknowledgement']           = 0;
                $formdata['delivered_delivery_information']             = 0;
                $formdata['delivered_date_time']                        = Carbon::parse(date('Y-m-d h:i A', strtotime($input['end_date'].' 12:00 PM')))->format(getTimeLayout());
                //

                $input['notes']                                         = $formdata['notes'];
            }

            $input['shipping_time_range']                               = $shipping_time_range;
            $input['shipper_date_time']                                 = $formdata['shipper_date_time'];
            if ($shipping_time_range == 0) {
                $input['shipper_date_time_end']                         = null;
            }else{
                $input['shipper_date_time_end']                         = $formdata['shipper_date_time_end'];
            }

            if (!is_null($input['shipper_date_time_end'])) {
                $input['actual_shipper_date']                           = !is_null($input['shipper_date_time_end']) ? Carbon::createFromFormat(getTimeLayout(),$input['shipper_date_time_end'])->format('Y-m-d H:i:s') : null;
            }else{
                $input['actual_shipper_date']                           = !is_null($input['shipper_date_time']) ? Carbon::createFromFormat(getTimeLayout(),$input['shipper_date_time'])->format('Y-m-d H:i:s') : null;
            }

            $input['delivery_time_range']                               = $delivery_time_range;
            $input['delivery_date_time']                                = $formdata['delivery_date_time'];
            if ($delivery_time_range == 0) {
                $input['delivery_date_time_end']                        = null;
            }else{
                $input['delivery_date_time_end']                        = $formdata['delivery_date_time_end'];
            }

            if (!is_null($input['delivery_date_time_end'])) {
                $input['actual_delivery_date']                          = !is_null($input['delivery_date_time_end']) ? Carbon::createFromFormat(getTimeLayout(),$input['delivery_date_time_end'])->format('Y-m-d H:i:s') : null;
            }else{
                $input['actual_delivery_date']                          = !is_null($input['delivery_date_time']) ? Carbon::createFromFormat(getTimeLayout(),$input['delivery_date_time'])->format('Y-m-d H:i:s') : null;
            }

            $input['send_notification']                                 = $formdata['send_notification'] ?? 0;
            $input['preplaned_driver_acknowledgement']                  = $formdata['preplaned_driver_acknowledgement'] ?? 0;
            $input['sent_to_driver']                                    = $formdata['sent_to_driver'] ?? 0;
            $input['default_current_time']                              = $formdata['default_current_time'];

            $input['confirmed_driver_acknowledgement']                  = $formdata['confirmed_driver_acknowledgement'] ?? 0;

            $input['intransit_driver_acknowledgement']                  = $formdata['intransit_driver_acknowledgement'] ?? 0;
            $input['intransit_shipping_information']                    = $formdata['intransit_shipping_information'] ?? 0;
            $input['intransit_date_time']                               = $formdata['intransit_date_time'];
            if(in_array($input['load_status'], [4,5,6,10,8])){
                if(!empty($input['intransit_date_time'])){
                    $input['actual_shipper_date']                       = !is_null($input['intransit_date_time']) ? Carbon::createFromFormat(getTimeLayout(),$input['intransit_date_time'])->format('Y-m-d H:i:s') : null;
                }else{
                    if($input['intransit_shipping_information'] == 0){
                        $input['actual_shipper_date']                   = !is_null($input['shipper_date_time']) ? Carbon::createFromFormat(getTimeLayout(),$input['shipper_date_time'])->format('Y-m-d H:i:s') : null;
                    }elseif($input['intransit_shipping_information'] == 1){
                        $input['actual_shipper_date']                   = Carbon::now()->format('Y-m-d H:i:s');
                    }else{
                        $input['actual_shipper_date']                   = Carbon::now()->format('Y-m-d H:i:s');
                    }
                }
            }else{
                $input['intransit_shipping_information']                = 0;
                $input['intransit_date_time']                           = null;
            }

            $input['delivered_driver_acknowledgement']                  = $formdata['delivered_driver_acknowledgement'] ?? 0;
            $input['delivered_delivery_information']                    = $formdata['delivered_delivery_information'] ?? 0;
            $input['delivered_date_time']                               = $formdata['delivered_date_time'];
            if(in_array($input['load_status'], [5,6,10,8])){
                if(!empty($input['delivered_date_time'])){
                    $input['actual_delivery_date']                      = !is_null($input['delivered_date_time']) ? Carbon::createFromFormat(getTimeLayout(),$input['delivered_date_time'])->format('Y-m-d H:i:s') : null;
                }else{
                    if($input['delivered_delivery_information'] == 0){
                        $input['actual_delivery_date']                  = !is_null($input['delivery_date_time']) ? Carbon::createFromFormat(getTimeLayout(),$input['delivery_date_time'])->format('Y-m-d H:i:s') : null;
                    }elseif($input['delivered_delivery_information'] == 1){
                        $input['actual_delivery_date']                  = Carbon::now()->format('Y-m-d H:i:s');
                    }else{
                        $input['actual_delivery_date']                  = Carbon::now()->format('Y-m-d H:i:s');
                    }
                }
            }else{
                $input['delivered_delivery_information']                = 0;
                $input['delivered_date_time']                           = null;
            }

            $input['created_at']                                        = Carbon::now()->format('Y-m-d H:i:s');
            // Add New Load Detail
            $loadDetail                                                 = LoadDetail::create($input);
            if($loadDetail){
                createLoadLog($loadDetail->getChanges(), $loadDetail, 'create');

                // update load
                $load->update(['load_detail_id' => $loadDetail->id]);

                $addtrauier                                             = isset($formdata['addtrauier'])?$formdata['addtrauier']:[];
                if(!empty($addtrauier)){
                    foreach($addtrauier as $value){
                        $load_trailer                                   = [];
                        $load_trailer['company_id']                     = auth()->guard('company-admin')->user()->company_id;
                        $load_trailer['load_id']                        = $load->id;
                        $load_trailer['trailer_number']                 = $value['trailer_number'];
                        $load_trailer['trailer_type']                   = $value['trailer_type'];
                        LoadTrailer::create($load_trailer);
                    }
                }

                $trailerOther                                           = isset($formdata['trailerOther'])?$formdata['trailerOther']:[];
                if(!empty($trailerOther)){
                    foreach($trailerOther as $value){
                        if($value['trailer_number'] != "" && $value['trailer_type'] != ""){
                            $load_trailer                               = [];
                            $load_trailer['company_id']                 = auth()->guard('company-admin')->user()->company_id;
                            $load_trailer['load_id']                    = $load->id;
                            $load_trailer['trailer_number']             = $value['trailer_number'];
                            $load_trailer['trailer_type']               = $value['trailer_type'];
                            LoadTrailer::create($load_trailer);
                        }
                    }
                }

                if(!is_null($dummy_load_id)){
                    LoadNote::where('load_id', $dummy_load_id)
                        ->where('is_dummy', 1)
                        ->update(['load_id' => $load->id, 'is_dummy'=> 0]);

                    if($load_occupied){
                        LoadRequirement::where('load_id', $dummy_load_id)
                            ->where('is_dummy', 1)
                            ->update(['load_id' => $load->id, 'is_dummy'=> 0]);

                        Gallery::IsCompany()
                            ->where('action_id', $dummy_load_id)
                            ->where('source', 'load')
                            ->whereIn('field_name', ['up_front_file','at_pickup_file','at_delivery_file'])
                            ->update(['action_id' => $load->id]);

                        $load_accessorials                              = LoadAccessorialTemp::where('unique_id', $accessorial_unique_id)
                            ->where('load_id', $dummy_load_id)
                            ->whereNotIn('type', [3]) // not add stop
                            ->where('is_stop', 0)
                            ->get();
                        if($load_accessorials->isNotEmpty()){
                            foreach ($load_accessorials as $latkey => $load_accessorial_temp) {
                                // load_accessorial_temp
                                $load_accessorial                       = LoadAccessorial::create([
                                    'load_id'                           => $load->id,
                                    'load_detail_id'                    => $loadDetail->id,
                                    'type'                              => $load_accessorial_temp->type, // not add stop
                                    'is_stop'                           => 0,

                                    'company_accessorial_id'            => $load_accessorial_temp->company_accessorial_id,
                                    'paid_by'                           => $load_accessorial_temp->paid_by,
                                    'charge_deduct'                     => $load_accessorial_temp->charge_deduct,
                                    'paid_type'                         => $load_accessorial_temp->paid_type,
                                    'reference'                         => $load_accessorial_temp->reference,

                                    'doc_required'                      => $load_accessorial_temp->doc_required,
                                    'qty'                               => $load_accessorial_temp->qty,
                                    'rate'                              => $load_accessorial_temp->rate,
                                    'total'                             => $load_accessorial_temp->total,

                                    'owner_liable'                      => $load_accessorial_temp->owner_liable,
                                    'owner_id'                          => $load_accessorial_temp->owner_id,
                                    'owner_type'                        => $load_accessorial_temp->owner_type,
                                    'owner_pay_deduct'                  => $load_accessorial_temp->owner_pay_deduct,
                                    'owner_qty'                         => $load_accessorial_temp->owner_qty,
                                    'owner_rate'                        => $load_accessorial_temp->owner_rate,
                                    'owner_total'                       => $load_accessorial_temp->owner_total,

                                    'driver_liable'                     => $load_accessorial_temp->driver_liable,
                                    'driver_id'                         => $load_accessorial_temp->driver_id,
                                    'pay_deduct'                        => $load_accessorial_temp->pay_deduct,
                                    'driver_qty'                        => $load_accessorial_temp->driver_qty,
                                    'driver_rate'                       => $load_accessorial_temp->driver_rate,
                                    'driver_total'                      => $load_accessorial_temp->driver_total,

                                    'notes'                             => $load_accessorial_temp->notes,
                                    'is_received'                       => $load_accessorial_temp->is_received,
                                    'is_deduction'                      => $load_accessorial_temp->is_deduction,
                                    'status'                            => $load_accessorial_temp->status,
                                    'created_at'                        => $load_accessorial_temp->created_at,
                                    'created_by'                        => $load_accessorial_temp->created_by
                                ]);
                                if($load_accessorial){
                                    Gallery::IsCompany()
                                        ->where('action_id', $load_accessorial_temp->id)
                                        ->where('source', 'load_accessorial_temps')
                                        ->where('field_name', 'accessorial_files')
                                        ->update(['action_id' => $load_accessorial->id, 'source' => 'load_accessorials']);
                                    $load_accessorial_temp->forceDelete();
                                }
                            }
                        }
                    }else{
                        LoadRequirement::where('load_id', $dummy_load_id)
                            ->where('is_dummy', 1)
                            ->delete();

                        $galleries                                      = Gallery::IsCompany()
                            ->where('action_id', $dummy_load_id)
                            ->where('source', 'load')
                            ->whereIn('field_name', ['up_front_file','at_pickup_file','at_delivery_file'])
                            ->get();
                        if($galleries->isNotEmpty()){
                            foreach ($galleries as $key => $gallery) {
                                if (File::exists('storage/companyAdmin/gallery/'.$gallery->image)) {
                                    File::delete('storage/companyAdmin/gallery/'.$gallery->image);
                                }
                                $gallery->delete();
                            }
                        }

                        $load_accessorials                              = LoadAccessorialTemp::where('unique_id', $accessorial_unique_id)
                            ->where('load_id', $dummy_load_id)
                            // ->whereNotIn('type', [3]) // not add stop
                            // ->where('is_stop', 0)
                            ->get();
                        if($load_accessorials->isNotEmpty()){
                            foreach ($load_accessorials as $latkey => $load_accessorial_temp) {
                                $galleries                              = Gallery::IsCompany()
                                    ->where('action_id', $load_accessorial_temp->id)
                                    ->where('source', 'load_accessorial_temps')
                                    ->where('field_name', 'accessorial_files')
                                    ->get();
                                if($galleries->isNotEmpty()){
                                    foreach ($galleries as $key => $gallery) {
                                        if (File::exists('storage/companyAdmin/gallery/'.$gallery->image)) {
                                            File::delete('storage/companyAdmin/gallery/'.$gallery->image);
                                        }
                                        $gallery->delete();
                                    }
                                }
                                $load_accessorial_temp->forceDelete();
                            }
                        }
                    }
                }

                if($load_occupied){
                    $shipper_appointment                                = $formdata['shipper_appointment'];
                    if($loadDetail->shipping_time_range == 0 && !is_null($shipper_appointment)){
                        $shipper_appointment                            = json_decode($shipper_appointment, true);
                        if(!empty($shipper_appointment)){
                            $appointment                                = [];
                            $appointment['broker_id']                   = $shipper_appointment['req_brokerage_id'];
                            $appointment['customer_id']                 = $shipper_appointment['req_customer_id'];
                            $appointment['load_detail_id']              = $loadDetail->id;
                            $appointment['type']                        = 1;
                            $appointment['is_stop']                     = 0;

                            $appointment['request_date']                = date('Y-m-d', strtotime($shipper_appointment['req_date']));
                            $appointment['request_time']                = date('H:i:s', strtotime($shipper_appointment['req_time']));

                            $emails                                     = [];
                            $appointment_emails                         = $shipper_appointment['req_email[]'] ?? null;
                            if (is_array($appointment_emails)) {
                                foreach ($appointment_emails as $key => $appointment_email) {
                                    $appointment_email_array            = explode('|', $appointment_email);
                                    $emails[]                           = [
                                        'table'                         => $appointment_email_array[0],
                                        'field_name'                    => $appointment_email_array[1],
                                        'email'                         => $appointment_email_array[2]
                                    ];
                                }
                            }else{
                                if(!is_null($appointment_emails)){
                                    $appointment_email_array            = explode('|', $appointment_emails);
                                    $emails[]                           = [
                                        'table'                         => $appointment_email_array[0],
                                        'field_name'                    => $appointment_email_array[1],
                                        'email'                         => $appointment_email_array[2]
                                    ];
                                }
                            }
                            $appointment['emails']                      = !empty($emails) ? serialize($emails) : null;

                            $phones                                     = [];
                            $appointment_phones                         = $shipper_appointment['req_phone[]'] ?? null;
                            if (is_array($appointment_phones)) {
                                foreach ($appointment_phones as $key => $appointment_phone) {
                                    $appointment_phone_array            = explode('|', $appointment_phone);
                                    $phones[]                           = [
                                        'table'                         => $appointment_phone_array[0],
                                        'field_name'                    => $appointment_phone_array[1],
                                        'phone'                         => $appointment_phone_array[2]
                                    ];
                                }
                            }else{
                                if(!is_null($appointment_phones)){
                                    $appointment_phone_array            = explode('|', $appointment_phones);
                                    $phones[]                           = [
                                        'table'                         => $appointment_phone_array[0],
                                        'field_name'                    => $appointment_phone_array[1],
                                        'phone'                         => $appointment_phone_array[2]
                                    ];
                                }
                            }
                            $appointment['phones']                      = !empty($phones) ? serialize($phones) : null;

                            $confirmation_numbers                       = $shipper_appointment['req_confirmation_number[]'] ?? null;
                            if (is_array($confirmation_numbers)) {
                                $confirmation_numbers                   = !empty($confirmation_numbers) ? implode(', ', $confirmation_numbers) : null;
                            }
                            $appointment['confirmation_numbers']        = $confirmation_numbers;

                            $reminder_on                                = $shipper_appointment['req_reminder_on[]'] ?? null;
                            if (is_array($reminder_on)) {
                                $reminder_on                            = !empty($reminder_on) ? implode(',', $reminder_on) : null;
                            }
                            $appointment['reminder_on']                 = $reminder_on;
                            $appointment['reminder_type']               = $shipper_appointment['req_reminder_type'] ?? null;
                            if($appointment['reminder_type']=='Custom'){
                                $appointment['reminder_repeat_every']   = $shipper_appointment['req_reminder_repeat_every'] ?? 0;
                                $appointment['reminder_custom_hours']   = $shipper_appointment['req_reminder_custom_hours'];
                            }
                            $appointment['reminder_status']             = $shipper_appointment['req_reminder_status'] ?? 0;

                            $appointment['status']                      = 0;
                            $appointment['status_at']                   = Carbon::now()->format('Y-m-d H:i:s');
                            $appointment['created_at']                  = Carbon::now()->format('Y-m-d H:i:s');
                            $load_appointment                           = LoadAppointment::create($appointment);
                            if($load_appointment){
                                $load_appointment_log                   = LoadAppointmentLog::create([
                                    'load_appointment_id'               => $load_appointment->id,
                                    'date'                              => date('Y-m-d', strtotime($shipper_appointment['req_date'])),
                                    'time'                              => date('H:i:s', strtotime($shipper_appointment['req_time'])),
                                    'note'                              => $shipper_appointment['req_note'] ?? null,
                                    'sender_id'                         => auth()->guard('company-admin')->user()->id,
                                    'sent_at'                           => Carbon::now()->format('Y-m-d H:i:s'),
                                    'source'                            => 1, // 1=Email, 2=SMS
                                    'reply_from'                        => auth()->guard('company-admin')->user()->email,
                                    'reply_at'                          => Carbon::now()->format('Y-m-d H:i:s'),
                                    'ip_address'                        => $request->ip(),
                                    'review_user_type'                  => 'Company Admin',
                                    'review_by'                         => auth()->guard('company-admin')->user()->id,
                                    'review_status'                     => 0,
                                    'review_at'                         => Carbon::now()->format('Y-m-d H:i:s'),
                                    'created_at'                        => Carbon::now()->format('Y-m-d H:i:s'),
                                ]);
                                if($load_appointment_log){
                                    // appointmentRequestSend($load_appointment);
                                }
                            }
                        }
                    }

                    $delivery_appointment                               = $formdata['delivery_appointment'];
                    if($loadDetail->delivery_time_range == 0 && !is_null($delivery_appointment)){
                        $delivery_appointment                           = json_decode($delivery_appointment, true);
                        if(!empty($delivery_appointment)){
                            $appointment                                = [];
                            $appointment['broker_id']                   = $delivery_appointment['req_brokerage_id'];
                            $appointment['customer_id']                 = $delivery_appointment['req_customer_id'];
                            $appointment['load_detail_id']              = $loadDetail->id;
                            $appointment['type']                        = 2;
                            $appointment['is_stop']                     = 0;

                            $appointment['request_date']                = date('Y-m-d', strtotime($delivery_appointment['req_date']));
                            $appointment['request_time']                = date('H:i:s', strtotime($delivery_appointment['req_time']));

                            $emails                                     = [];
                            $appointment_emails                         = $delivery_appointment['req_email[]'] ?? null;
                            if (is_array($appointment_emails)) {
                                foreach ($appointment_emails as $key => $appointment_email) {
                                    $appointment_email_array            = explode('|', $appointment_email);
                                    $emails[]                           = [
                                        'table'                         => $appointment_email_array[0],
                                        'field_name'                    => $appointment_email_array[1],
                                        'email'                         => $appointment_email_array[2]
                                    ];
                                }
                            }else{
                                if(!is_null($appointment_emails)){
                                    $appointment_email_array            = explode('|', $appointment_emails);
                                    $emails[]                           = [
                                        'table'                         => $appointment_email_array[0],
                                        'field_name'                    => $appointment_email_array[1],
                                        'email'                         => $appointment_email_array[2]
                                    ];
                                }
                            }
                            $appointment['emails']                      = !empty($emails) ? serialize($emails) : null;

                            $phones                                     = [];
                            $appointment_phones                         = $delivery_appointment['req_phone[]'] ?? null;
                            if (is_array($appointment_phones)) {
                                foreach ($appointment_phones as $key => $appointment_phone) {
                                    $appointment_phone_array            = explode('|', $appointment_phone);
                                    $phones[]                           = [
                                        'table'                         => $appointment_phone_array[0],
                                        'field_name'                    => $appointment_phone_array[1],
                                        'phone'                         => $appointment_phone_array[2]
                                    ];
                                }
                            }else{
                                if(!is_null($appointment_phones)){
                                    $appointment_phone_array            = explode('|', $appointment_phones);
                                    $phones[]                           = [
                                        'table'                         => $appointment_phone_array[0],
                                        'field_name'                    => $appointment_phone_array[1],
                                        'phone'                         => $appointment_phone_array[2]
                                    ];
                                }
                            }
                            $appointment['phones']                      = !empty($phones) ? serialize($phones) : null;

                            $confirmation_numbers                       = $delivery_appointment['req_confirmation_number[]'] ?? null;
                            if (is_array($confirmation_numbers)) {
                                $confirmation_numbers                   = !empty($confirmation_numbers) ? implode(', ', $confirmation_numbers) : null;
                            }
                            $appointment['confirmation_numbers']        = $confirmation_numbers;

                            $reminder_on                                = $delivery_appointment['req_reminder_on[]'] ?? null;
                            if (is_array($reminder_on)) {
                                $reminder_on                            = !empty($reminder_on) ? implode(',', $reminder_on) : null;
                            }
                            $appointment['reminder_on']                 = $reminder_on;
                            $appointment['reminder_type']               = $delivery_appointment['req_reminder_type'] ?? null;
                            if($appointment['reminder_type']=='Custom'){
                                $appointment['reminder_repeat_every']   = $delivery_appointment['req_reminder_repeat_every'] ?? 0;
                                $appointment['reminder_custom_hours']   = $delivery_appointment['req_reminder_custom_hours'];
                            }
                            $appointment['reminder_status']             = $delivery_appointment['req_reminder_status'] ?? 0;

                            $appointment['status']                      = 0;
                            $appointment['status_at']                   = Carbon::now()->format('Y-m-d H:i:s');
                            $appointment['created_at']                  = Carbon::now()->format('Y-m-d H:i:s');
                            $load_appointment                           = LoadAppointment::create($appointment);
                            if($load_appointment){
                                $load_appointment_log                   = LoadAppointmentLog::create([
                                    'load_appointment_id'               => $load_appointment->id,
                                    'date'                              => date('Y-m-d', strtotime($delivery_appointment['req_date'])),
                                    'time'                              => date('H:i:s', strtotime($delivery_appointment['req_time'])),
                                    'note'                              => $delivery_appointment['req_note'] ?? null,
                                    'sender_id'                         => auth()->guard('company-admin')->user()->id,
                                    'sent_at'                           => Carbon::now()->format('Y-m-d H:i:s'),
                                    'source'                            => 1, // 1=Email, 2=SMS
                                    'reply_from'                        => auth()->guard('company-admin')->user()->email,
                                    'reply_at'                          => Carbon::now()->format('Y-m-d H:i:s'),
                                    'ip_address'                        => $request->ip(),
                                    'review_user_type'                  => 'Company Admin',
                                    'review_by'                         => auth()->guard('company-admin')->user()->id,
                                    'review_status'                     => 0,
                                    'review_at'                         => Carbon::now()->format('Y-m-d H:i:s'),
                                    'created_at'                        => Carbon::now()->format('Y-m-d H:i:s'),
                                ]);
                                if($load_appointment_log){
                                    // appointmentRequestSend($load_appointment);
                                }
                            }
                        }
                    }

                    $stops                                              = isset($formdata['stop'])?$formdata['stop']:[];
                    if(!empty($stops)){
                        foreach ($stops as $stkey => $stop) {
                            $stop_random_id                                         = $stop['random_id'] ?? null;

                            $customer_type                                          = $stop['customer_type'];

                            $stop_array                                             = [];
                            $stop_array['stop_no']                                  = $stop['stop_no'] ?? null;
                            $stop_array['company_id']                               = auth()->guard('company-admin')->user()->company_id;
                            $stop_array['load_id']                                  = $load->id;
                            $stop_array['date_time_range']                          = $stop['date_time_range'];
                            $stop_array['date_time']                                = $stop['date_time'];
                            $stop_array['date_time_end']                            = $stop['date_time_range']!=0?$stop['date_time_end']:null;
                            $stop_array['customer_type']                            = $customer_type;
                            $stop_array['customer_id']                              = $stop['customer_id'];
                            $stop_array['address_one']                              = $stop['address_one'];
                            $stop_array['address_two']                              = $stop['address_two'];
                            $stop_array['city']                                     = $stop['city'];
                            $stop_array['state']                                    = $stop['state'];
                            $stop_array['zip']                                      = $stop['zip'];

                            $address_verified                                       = $stop['address_verified'] ?? 0;
                            if($address_verified==0){
                                $stop_array['latitude']                             = null;
                                $stop_array['longitude']                            = null;
                                $stop_array['timezone']                             = null;
                                $stop_array['timezone_offset']                      = null;
                                $stop_array['timezone_abbr']                        = null;
                                $stop_array['address_verified']                     = 0;
                            }else{
                                $stop_timezone                                      = null;
                                $stop_timezone_offset                               = null;
                                $stop_timezone_abbr                                 = $stop['timezone_abbr'] ?? null;
                                if(!is_null($stop_timezone_abbr)){
                                    $stop_timezone                                  = timezone_name_from_abbr($stop_timezone_abbr);
                                    $stop_timezone_offset                           = Carbon::createFromTimestamp(time(), $stop_timezone)->getOffsetString();
                                }

                                $stop_array['latitude']                             = $stop['latitude'] ?? null;
                                $stop_array['longitude']                            = $stop['longitude'] ?? null;
                                $stop_array['timezone']                             = $stop_timezone;
                                $stop_array['timezone_offset']                      = $stop_timezone_offset;
                                $stop_array['timezone_abbr']                        = $stop_timezone_abbr;
                                $stop_array['address_verified']                     = 1;
                            }

                            $stop_array['stop_note']                                = $stop['stop_note'];

                            if($itemize == 1){
                                $stop_array['commodity']                            = $stop['commodity'];
                                $stop_array['stop_value']                           = $stop['stop_value'];
                                $stop_array['stop_weight']                          = $stop['stop_weight'];
                                $stop_array['reefer_mode']                          = $stop['reefer_mode'];
                                $stop_array['reefer_temp_type']                     = $stop['reefer_temp_type'] ?? 0;
                                $stop_array['reefer_temp']                          = $stop['reefer_temp'] ?? null;
                                $stop_array['pickup_number']                        = $stop['pickup_number'];
                            }
                            if(isset($stop['dimension']) && !empty($stop['dimension'])){
                                $stop_array['dimension']                            = serialize($stop['dimension']);
                            }

                            $stop_array['drop_trailer_schedule']                    = $stop['drop_trailer_schedule'] ?? 0;
                            if($stop_array['drop_trailer_schedule'] == 1){
                                $stop_array['drop_trailer_id']                      = $stop['drop_trailer_id'] ?? null;
                            } else if($stop_array['drop_trailer_schedule'] == 2){
                                $stop_array['drop_trailer_id']                      = $stop['drop_trailer_id'] ?? null;
                                $stop_array['pickup_trailer_id']                    = $stop['pickup_trailer_id'] ?? null; // isset($stop['pickup_trailer_id']) ? str_replace('TRAILERDROP', '', $stop['pickup_trailer_id']) : null;
                            }

                            $stop_files                                             = isset($formdata['stop_files'][$stkey])?$formdata['stop_files'][$stkey]:[];
                            $stop_files_array                                       = [];
                            if(!empty($stop_files)){
                                if (array_key_exists('name_id', $stop_files)) {
                                    $stop_files_name_ids                            = array_filter($stop_files['name_id'], function ($var) {
                                        return $var !== null && $var !== '';
                                    });
                                    foreach($stop_files_name_ids as $stfkey => $stop_files_name_id){
                                        $arry                                       = [];
                                        $arry['name_id']                            = $stop_files_name_id;
                                        $arry['name']                               = isset($stop_files['name'][$stfkey]) ? $stop_files['name'][$stfkey] : '';
                                        $arry['is_required']                        = isset($stop_files['is_required'][$stfkey]) ? $stop_files['is_required'][$stfkey] : 'off';
                                        $arry['type']                               = $stop_files['type'][$stfkey];
                                        $arry['fixed']                              = $stop_files['fixed'][$stfkey];
                                        $arry['include_w_billing']                  = isset($stop_files['include_w_billing'][$stfkey]) && $stop_files['include_w_billing'][$stfkey]=='yes' ? 'yes' : 'no';
                                        $arry['custom']                             = isset($stop_files['custom'][$stfkey]) && $stop_files['custom'][$stfkey]=='yes' ? 'yes' : 'no';
                                        $stop_files_array[]                         = $arry;
                                    }
                                }
                            }

                            $stop_files_upload                                      = isset($formdata['stop_files_upload'][$stkey])?$formdata['stop_files_upload'][$stkey]:[];
                            $stop_files_upload_array                                = [];
                            if(!empty($stop_files_upload)){
                                if (array_key_exists('name_id', $stop_files_upload)) {
                                    $stop_files_upload_name_ids                     = array_filter($stop_files_upload['name_id'], function ($var) {
                                        return $var !== null && $var !== '';
                                    });
                                    foreach($stop_files_upload_name_ids as $ctfkey => $stop_files_upload_name_id){
                                        $arry                                       = [];
                                        $arry['name_id']                            = $stop_files_upload_name_id;
                                        $arry['name']                               = isset($stop_files_upload['name'][$ctfkey]) ? $stop_files_upload['name'][$ctfkey] : '';
                                        $arry['is_required']                        = isset($stop_files_upload['is_required'][$ctfkey]) ? $stop_files_upload['is_required'][$ctfkey] : 'off';
                                        $arry['type']                               = $stop_files_upload['type'][$ctfkey];
                                        $arry['fixed']                              = $stop_files_upload['fixed'][$ctfkey];
                                        $arry['include_w_billing']                  = isset($stop_files_upload['include_w_billing'][$ctfkey]) && $stop_files_upload['include_w_billing'][$ctfkey]=='yes' ? 'yes' : 'no';
                                        $arry['custom']                             = isset($stop_files_upload['custom'][$ctfkey]) && $stop_files_upload['custom'][$ctfkey]=='yes' ? 'yes' : 'no';

                                        $arry['is_received']                        = isset($stop_files_upload['is_received'][$ctfkey]) ? $stop_files_upload['is_received'][$ctfkey] : 'off';
                                        $arry['hide_from_driver']                   = isset($stop_files_upload['hide_from_driver'][$ctfkey]) && $stop_files_upload['hide_from_driver'][$ctfkey]=='yes' ? 'yes' : 'no';
                                        $arry['file_not_provided']                  = isset($stop_files_upload['file_not_provided'][$ctfkey]) ? $stop_files_upload['file_not_provided'][$ctfkey] : 'off';
                                        if(isset($stop_files_upload['file'][$ctfkey])){
                                            $arry['is_received']                    = 'on';
                                            $arry['file']                           = UploadImagePdf($stop_files_upload['file'][$ctfkey], 'companyAdmin/load_detail_document');
                                        }else{
                                            $arry['file']                           = null;
                                        }
                                        if($arry['is_received'] == 'on'){
                                            $arry['upload_user_type']               = auth()->guard('company-admin')->user()->type;
                                            $arry['upload_by']                      = auth()->guard('company-admin')->user()->id;
                                            $arry['uploaded_at']                    = Carbon::now();
                                        }
                                        $stop_files_upload_array[]                  = $arry;
                                    }
                                }
                            }

                            if($customer_type==1){
                                if(!empty($stop_files_array)){
                                    $stop_array['stop_shipper_files']               = serialize($stop_files_array);
                                }
                                if(!empty($stop_files_upload_array)){
                                    $stop_array['stop_shipper_files_upload']        = serialize($stop_files_upload_array);
                                }
                            }else{
                                if(!empty($stop_files_array)){
                                    $stop_array['stop_consignee_files']             = serialize($stop_files_array);
                                }
                                if(!empty($stop_files_upload_array)){
                                    $stop_array['stop_consignee_files_upload']      = serialize($stop_files_upload_array);
                                }
                            }

                            $stop_array['status']                                   = 0;
                            $stop_array['status_at']                                = Carbon::now()->format('Y-m-d H:i:s');
                            $stop_array['created_at']                               = Carbon::now()->format('Y-m-d H:i:s');

                            $stopDetail                                             = LoadStop::create($stop_array);
                            if($stopDetail){
                                $load_stop_accessorials                             = LoadAccessorialTemp::where('unique_id', $accessorial_unique_id)
                                    ->where('load_id', $dummy_load_id)
                                    ->where('random_id', $stop_random_id)
                                    ->where('type', 3)
                                    ->where('is_stop', 1)
                                    ->get();
                                if($load_stop_accessorials->isNotEmpty()){
                                    foreach ($load_stop_accessorials as $lsatkey => $load_stop_accessorial) {
                                        $load_accessorial                           = LoadAccessorial::create([
                                            'load_id'                               => $load->id,
                                            'load_detail_id'                        => $loadDetail->id,
                                            'load_stop_id'                          => $stopDetail->id,
                                            'type'                                  => 3, // stop
                                            'is_stop'                               => 1,

                                            'company_accessorial_id'                => $load_stop_accessorial->company_accessorial_id,
                                            'paid_by'                               => $load_stop_accessorial->paid_by,
                                            'charge_deduct'                         => $load_stop_accessorial->charge_deduct,
                                            'paid_type'                             => $load_stop_accessorial->paid_type,
                                            'reference'                             => $load_stop_accessorial->reference,

                                            'doc_required'                          => $load_stop_accessorial->doc_required,
                                            'qty'                                   => $load_stop_accessorial->qty,
                                            'rate'                                  => $load_stop_accessorial->rate,
                                            'total'                                 => $load_stop_accessorial->total,

                                            'owner_liable'                          => $load_stop_accessorial->owner_liable,
                                            'owner_id'                              => $load_stop_accessorial->owner_id,
                                            'owner_type'                            => $load_stop_accessorial->owner_type,
                                            'owner_pay_deduct'                      => $load_stop_accessorial->owner_pay_deduct,
                                            'owner_qty'                             => $load_stop_accessorial->owner_qty,
                                            'owner_rate'                            => $load_stop_accessorial->owner_rate,
                                            'owner_total'                           => $load_stop_accessorial->owner_total,

                                            'driver_liable'                         => $load_stop_accessorial->driver_liable,
                                            'driver_id'                             => $load_stop_accessorial->driver_id,
                                            'pay_deduct'                            => $load_stop_accessorial->pay_deduct,
                                            'driver_qty'                            => $load_stop_accessorial->driver_qty,
                                            'driver_rate'                           => $load_stop_accessorial->driver_rate,
                                            'driver_total'                          => $load_stop_accessorial->driver_total,

                                            'notes'                                 => $load_stop_accessorial->notes,
                                            'is_received'                           => $load_stop_accessorial->is_received,
                                            'is_deduction'                          => $load_stop_accessorial->is_deduction,
                                            'status'                                => $load_stop_accessorial->status,
                                            'created_at'                            => $load_stop_accessorial->created_at,
                                            'created_by'                            => $load_stop_accessorial->created_by
                                        ]);
                                        if($load_accessorial){
                                            Gallery::IsCompany()
                                                ->where('action_id', $load_stop_accessorial->id)
                                                ->where('source', 'load_accessorial_temps')
                                                ->where('field_name', 'accessorial_files')
                                                ->update(['action_id' => $load_accessorial->id, 'source' => 'load_accessorials']);
                                            $load_stop_accessorial->forceDelete();
                                        }
                                    }
                                }

                                $stop_appointment                                   = $stop['appointment'];
                                if($stopDetail->date_time_range == 0 && !is_null($stop_appointment)){
                                    $stop_appointment                               = json_decode($stop_appointment, true);
                                    if(!empty($stop_appointment)){
                                        $appointment                                = [];
                                        $appointment['broker_id']                   = $stop_appointment['req_brokerage_id'];
                                        $appointment['customer_id']                 = $stop_appointment['req_customer_id'];
                                        $appointment['load_detail_id']              = $loadDetail->id;
                                        $appointment['load_stop_id']                = $stopDetail->id;
                                        $appointment['type']                        = $customer_type;
                                        $appointment['is_stop']                     = 1;

                                        $appointment['request_date']                = date('Y-m-d', strtotime($stop_appointment['req_date']));
                                        $appointment['request_time']                = date('H:i:s', strtotime($stop_appointment['req_time']));

                                        $emails                                     = [];
                                        $appointment_emails                         = $stop_appointment['req_email[]'] ?? null;
                                        if (is_array($appointment_emails)) {
                                            foreach ($appointment_emails as $key => $appointment_email) {
                                                $appointment_email_array            = explode('|', $appointment_email);
                                                $emails[]                           = [
                                                    'table'                         => $appointment_email_array[0],
                                                    'field_name'                    => $appointment_email_array[1],
                                                    'email'                         => $appointment_email_array[2]
                                                ];
                                            }
                                        }else{
                                            if(!is_null($appointment_emails)){
                                                $appointment_email_array            = explode('|', $appointment_emails);
                                                $emails[]                           = [
                                                    'table'                         => $appointment_email_array[0],
                                                    'field_name'                    => $appointment_email_array[1],
                                                    'email'                         => $appointment_email_array[2]
                                                ];
                                            }
                                        }
                                        $appointment['emails']                      = !empty($emails) ? serialize($emails) : null;

                                        $phones                                     = [];
                                        $appointment_phones                         = $stop_appointment['req_phone[]'] ?? null;
                                        if (is_array($appointment_phones)) {
                                            foreach ($appointment_phones as $key => $appointment_phone) {
                                                $appointment_phone_array            = explode('|', $appointment_phone);
                                                $phones[]                           = [
                                                    'table'                         => $appointment_phone_array[0],
                                                    'field_name'                    => $appointment_phone_array[1],
                                                    'phone'                         => $appointment_phone_array[2]
                                                ];
                                            }
                                        }else{
                                            if(!is_null($appointment_phones)){
                                                $appointment_phone_array            = explode('|', $appointment_phones);
                                                $phones[]                           = [
                                                    'table'                         => $appointment_phone_array[0],
                                                    'field_name'                    => $appointment_phone_array[1],
                                                    'phone'                         => $appointment_phone_array[2]
                                                ];
                                            }
                                        }
                                        $appointment['phones']                      = !empty($phones) ? serialize($phones) : null;

                                        $confirmation_numbers                       = $stop_appointment['req_confirmation_number[]'] ?? null;
                                        if (is_array($confirmation_numbers)) {
                                            $confirmation_numbers                   = !empty($confirmation_numbers) ? implode(', ', $confirmation_numbers) : null;
                                        }
                                        $appointment['confirmation_numbers']        = $confirmation_numbers;

                                        $reminder_on                                = $stop_appointment['req_reminder_on[]'] ?? null;
                                        if (is_array($reminder_on)) {
                                            $reminder_on                            = !empty($reminder_on) ? implode(',', $reminder_on) : null;
                                        }
                                        $appointment['reminder_on']                 = $reminder_on;
                                        $appointment['reminder_type']               = $stop_appointment['req_reminder_type'] ?? null;
                                        if($appointment['reminder_type']=='Custom'){
                                            $appointment['reminder_repeat_every']   = $stop_appointment['req_reminder_repeat_every'] ?? 0;
                                            $appointment['reminder_custom_hours']   = $stop_appointment['req_reminder_custom_hours'];
                                        }
                                        $appointment['reminder_status']             = $stop_appointment['req_reminder_status'] ?? 0;

                                        $appointment['status']                      = 0;
                                        $appointment['status_at']                   = Carbon::now()->format('Y-m-d H:i:s');
                                        $appointment['created_at']                  = Carbon::now()->format('Y-m-d H:i:s');
                                        $load_appointment                           = LoadAppointment::create($appointment);
                                        if($load_appointment){
                                            $load_appointment_log                   = LoadAppointmentLog::create([
                                                'load_appointment_id'               => $load_appointment->id,
                                                'date'                              => date('Y-m-d', strtotime($stop_appointment['req_date'])),
                                                'time'                              => date('H:i:s', strtotime($stop_appointment['req_time'])),
                                                'note'                              => $stop_appointment['req_note'] ?? null,
                                                'sender_id'                         => auth()->guard('company-admin')->user()->id,
                                                'sent_at'                           => Carbon::now()->format('Y-m-d H:i:s'),
                                                'source'                            => 1, // 1=Email, 2=SMS
                                                'reply_from'                        => auth()->guard('company-admin')->user()->email,
                                                'reply_at'                          => Carbon::now()->format('Y-m-d H:i:s'),
                                                'ip_address'                        => $request->ip(),
                                                'review_user_type'                  => 'Company Admin',
                                                'review_by'                         => auth()->guard('company-admin')->user()->id,
                                                'review_status'                     => 0,
                                                'review_at'                         => Carbon::now()->format('Y-m-d H:i:s'),
                                                'created_at'                        => Carbon::now()->format('Y-m-d H:i:s'),
                                            ]);
                                            if($load_appointment_log){
                                                // appointmentRequestSend($load_appointment);
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }

                // Load create time one driver for code not for multiple driver
                $drivers                                                = isset($formdata['drivers'])?$formdata['drivers']:[];
                if(!empty($drivers)){
                    foreach ($drivers as $key => $value) {
                        $load_drivers                                   = [];
                        $load_drivers['load_id']                        = $load->id;
                        $load_drivers['load_detail_id']                 = $loadDetail->id;
                        $load_drivers['driver_id']                      = $formdata['driver_id']; // Main Driver Id or 0 value add no select driver
                        $load_drivers['empty_miles']                    = $load_occupied ? $value['empty_miles'] : null;
                        $load_drivers['loaded_miles']                   = $load_occupied ? $value['loaded_miles'] : null;
                        $load_drivers['total_miles']                    = $load_occupied ? $value['total_miles'] : null;
                        $load_drivers['pay_type']                       = $load_occupied ? $value['pay_type'] : null;
                        $load_drivers['gross_wage']                     = $load_occupied ? $value['gross_wage'] : null;
                        $load_drivers['total_bill']                     = $load_occupied ? $value['total_bill'] : null;
                        $load_drivers['pay_percentage']                 = 100;
                        $load_drivers['mileage_percentage']             = 100;
                        $load_drivers['pay']                            = $load_occupied ? $value['total_bill'] : null;
                        $load_drivers['miles']                          = $load_occupied ? $value['loaded_miles'] : null;
                        $load_drivers['created_at']                     = Carbon::now()->format('Y-m-d H:i:s');
                        LoadDriver::create($load_drivers);
                    }
                }

                $trucks                                                 = isset($formdata['trucks'])?$formdata['trucks']:[];
                if(!empty($trucks)){
                    foreach ($trucks as $key => $value) {
                        $load_truck_owners                              = [];
                        $load_truck_owners['load_id']                   = $load->id;
                        $load_truck_owners['load_detail_id']            = $loadDetail->id;
                        $load_truck_owners['driver_id']                 = $formdata['driver_id']; // Main Driver Id or 0 value add no select driver

                        $driver                                         = Driver::find($formdata['driver_id']);
                        if(!is_null($driver)){
                            $truck                                      = $driver->driver_information->truck ?? null;
                            if(!is_null($truck)){
                                $load_truck_owners['owner_id']          = $truck->owner_id ?? null;
                                $load_truck_owners['owner_type']        = $truck->owner_type ?? null;
                            }
                        }
                        $load_truck_owners['empty_miles']               = $load_occupied ? $value['empty_miles'] : null;
                        $load_truck_owners['loaded_miles']              = $load_occupied ? $value['loaded_miles'] : null;
                        $load_truck_owners['total_miles']               = $load_occupied ? $value['total_miles'] : null;
                        $load_truck_owners['pay_type']                  = $load_occupied ? $value['pay_type'] : null;
                        $load_truck_owners['gross_wage']                = $load_occupied ? $value['gross_wage'] : null;
                        $load_truck_owners['total_bill']                = $load_occupied ? $value['total_bill'] : null;
                        $load_truck_owners['pay_percentage']            = 100;
                        $load_truck_owners['mileage_percentage']        = 100;
                        $load_truck_owners['pay']                       = $load_occupied ? $value['total_bill'] : null;
                        $load_truck_owners['miles']                     = $load_occupied ? $value['loaded_miles'] : null;
                        $load_truck_owners['created_at']                = Carbon::now()->format('Y-m-d H:i:s');
                        LoadTruckOwner::create($load_truck_owners);
                    }
                }

                if(isset($loadDetail->driver_id) && $loadDetail->driver_id != '0'){
                    // Update trailer  number in 'driver_informations' table base on latest created load
                    DriverInformation::query()->where('driver_id', $loadDetail->driver_id)->update(['trailer_number' => $loadDetail->trailer_number]);
                    // Assign driver report
                    isReportDriversZero($loadDetail->driver_id);
                    // send load assign mail
                    if (isset($input['send_notification']) && $input['send_notification'] == '1') {
                        $driver = Driver::find($loadDetail->driver_id);
                        if(!is_null($driver)){
                            $mailData = [];
                            $mailData['company_id'] = auth()->guard('company-admin')->user()->company_id;
                            $mailData['name'] = isset($driver->full_name) ? $driver->full_name : '';

                            if(in_array($loadDetail->load_type, ['0', '6'])){
                                // 0 = OCCUPIED, 6 = TONU
                                $mailData['load_number'] = $loadDetail->load_number;
                            }else{
                                // 1 = MAINTENANCE, 2 = UNAUTHORIZED, 3 = HOS, 4 = NO DISPATCH, 5 = TIME OFF
                                $mailData['load_number'] = getLoadTypeList()[$loadDetail->load_type] ?? '';
                            }

                            if(isset($driver->email) && $driver->email != ''){
                                /*
                                try {
                                    Mail::to($driver->email)->send(new LoadAssignMailToDriver($mailData));
                                } catch (\Swift_TransportException $e) {
                                    // Log the error message
                                    Log::error('Email sending failed: ' . $e->getMessage());
                                } catch (\Exception $e) {
                                    // Log the error message
                                    Log::error('An error occurred while sending the email: ' . $e->getMessage());
                                }
                                */

                                sendEmail($driver->email, new LoadAssignMailToDriver($mailData));
                            }
                        }
                    }
                }

                if($request->has('offer_id') && $request->offer_id!=''){
                    $offer                                              = Offer::where('id', $request->offer_id)->first();
                    if($offer){
                        $offer->status                                  = 3;
                        $offer->status_at                               = Carbon::now();
                        $offer->updated_at                              = Carbon::now();
                        $offer->updated_by                              = auth()->guard('company-admin')->user()->id;
                        $offer->save();
                    }
                }

                /*------------------------------------------
                --------------------------------------------
                Commit Transaction to Save Data to Database
                --------------------------------------------
                --------------------------------------------*/
                // DB::commit();
                // If everything is successful, commit the transaction

                // add alert
                if((isset($input['is_on_hold']) && $input['is_on_hold'] == 1) && (isset($loadDetail->driver_id) && $loadDetail->driver_id!='0')){ // on hold status
                    if(isset($loadDetail->self_dispatch) && $loadDetail->self_dispatch==1){
                        createNotification(
                            3, // source
                            'Attention!', // name
                            $loadDetail->driver->dispatcher->id, // user_id
                            $loadDetail->driver->dispatcher->type, // user_type
                            2, // type
                            $loadDetail->load_id, // action_id
                            'Load placed on hold - '.$loadDetail->load_number, // description
                            'Alert', // module
                            [], // properties
                            $loadDetail->driver->dispatcher->company_id // company_id
                        );
                    }elseif (isset($loadDetail->dispatcher) && !is_null($loadDetail->dispatcher)){
                        createNotification(
                            3, // source
                            'Attention!', // name
                            $loadDetail->dispatcher->id, // user_id
                            $loadDetail->dispatcher->type, // user_type
                            2, // type
                            $loadDetail->load_id, // action_id
                            'Load placed on hold - '.$loadDetail->load_number, // description
                            'Alert', // module
                            [], // properties
                            $loadDetail->dispatcher->company_id // company_id
                        );
                    }
                }

                if($load_occupied){
                    $jobData                                            = [
                        'id'            => $loadDetail->id, // current load detail id
                        'company_id'    => auth()->guard('company-admin')->user()->company_id,
                        'user_id'       => auth()->guard('company-admin')->user()->id,
                        'user_type'     => 'Company Admin'
                    ];
                    dispatch(new \App\Jobs\DeadHeadUpdateJob($jobData));
                }

                notification('success', $this->crudMessage('create', 'Load'));
                if($request->save_and_continue=='1'){
                    return redirect()->route('company.admin.loads.edit', base64Encode($load->id));
                }
                if (!is_null($request->from) && $request->from == 'load_by_week') {
                    return redirect()->route('company.admin.loads.by.week.index');
                }
                if($request->has('offer_id') && $request->offer_id!=''){
                    return redirect()->route('company.admin.dispatch.hub.index');
                }
                $urlarry = explode('/', $request->backurl);
                if(isset($request->backurl) && !empty($request->backurl)){ // && !in_array('loads', $urlarry)
                    return redirect($request->backurl);
                }
                return redirect()->route('company.admin.loads.index');
            }else{
                notification('error', 'Oops! Something went wrong..');
                return redirect()->back();
            }
        } catch (\Exception $e) {
            dd($e->getMessage());

            /*------------------------------------------
            --------------------------------------------
            Rollback Database Entry
            --------------------------------------------
            --------------------------------------------*/
            // DB::rollback();
            // Something went wrong, rollback the transaction
            notification('error', 'Oops! Something went wrong..'); // $e->getMessage()
            return redirect()->back();
        }
    }

    /**
     * Display the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id){
        $id             = base64Decode($id);
        $loadDetail     = LoadDetail::where('id', $id)->first();
        if(!is_null($loadDetail)){
            if($loadDetail->is_disable == 1){
                notification('error', 'Load is disable.');
                return redirect()->back();
            }else if(!in_array($loadDetail->load_type, ['0', '6'])){
                notification('error', 'Load is unoccupied.');
                return redirect()->back();
            }

            $getCompanyAdmin                                            = auth()->guard('company-admin')->user();

            $this->data['getField']                                     = '';
            $isCheck                                                    = Bookmark::where('company_id',getUserCompnayId())
                ->where('user_id', $getCompanyAdmin->id)
                ->where('user_type', $getCompanyAdmin->type)
                ->where('table_id','table_audit_load')
                ->first();
            if(!empty($isCheck->id)){
                //$this->data['getField']                                 = unserialize($isCheck->config);
                $this->data['getField']                                 = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_audit_load_first'));
            }else{
                $this->data['getField']                                 = config('settings.table_audit_load_first');
            }

            $this->data['getTimeZone']                                  = $this->timeZone;
            $this->data['getTimeZoneId']                                = $this->timeZoneId;

            $load                                                       = $loadDetail->loads;
            $this->data['load']                                         = $load;
            $this->data['loadDetail']                                   = $loadDetail;

            $this->data['loadDrivers']                                  = $loadDetail->load_drivers;
            $this->data['loadTruckOwners']                              = $loadDetail->load_truck_owners;
            $this->data['totalPendingDetention']                        = $loadDetail->detentions()->whereNotIn('review_status', ['Completed','Denied'])->count();

            // Document Request
            $loadDriversArray                                           = [];
            if(isset($loadDetail->driver)){
                $adriver                                                = $loadDetail->driver;
                $loadDriversArray[$adriver->id]                         = [
                    'name'                  => $adriver->last_name.', '.$adriver->first_name,
                    'email'                 => $adriver->email,
                    'cell_phone'            => $adriver->cell_phone,
                ];
            }
            if(isset($loadDetail->co_driver)){
                $adriver                                                = $loadDetail->co_driver;
                $loadDriversArray[$adriver->id]                         = [
                    'name'                  => $adriver->last_name.', '.$adriver->first_name,
                    'email'                 => $adriver->email,
                    'cell_phone'            => $adriver->cell_phone,
                ];
            }
            if(isset($loadDetail->load_drivers)){
                $aload_drivers                                          = $loadDetail->load_drivers;
                foreach ($aload_drivers as $key => $aload_driver) {
                    $adriver                                            = $aload_driver->driver;
                    if(isset($adriver)){
                        $loadDriversArray[$adriver->id]                 = [
                            'name'          => $adriver->last_name.', '.$adriver->first_name,
                            'email'         => $adriver->email,
                            'cell_phone'    => $adriver->cell_phone,
                        ];
                    }
                }
            }
            $this->data['loadDriversArray']                             = $loadDriversArray;
            // Document Request

            // Merge both arrays into a new array
            $firstTrailerTypeArray                                      = array(
                $loadDetail->trailer_type ?? null
            );
            $secondTrailerTypeArray                                     = $load->load_trailers ? $load->load_trailers->pluck('trailer_type')->toArray() : [];
            $mergedTrailerTypeArray                                     = array_merge($firstTrailerTypeArray, $secondTrailerTypeArray);
            // Custom callback function to remove null and blank values
            $filteredTrailerTypeArray                                   = array_filter($mergedTrailerTypeArray, function ($var) {
                // Remove elements that are null or empty strings
                return !is_null($var) && $var !== '' && $var !== 0;
            });
            // Remove duplicate elements
            $loadTrailerTypes                                           = array_unique($filteredTrailerTypeArray);
            // Check temp exists
            $reeferTempExists                                           = TrailerType::whereIn('id', $loadTrailerTypes)
                ->where('is_temp_required', 1)
                ->exists();

            //
            $safetyEventLabel                                           = '';
            $currentLocation                                            = [];
            $mileageCoords                                              = [];
            $pastGPSCoords                                              = [];

            //
            $truck                                                      = $loadDetail->truck ?? null;
            $truck_length                                               = $truck->length ?? null;
            $truck_width                                                = $truck->width ?? null;
            $truck_height                                               = $truck->height ?? null;
            $truck_weight                                               = 0;
            $itemize                                                    = $loadDetail->itemize ?? 0;
            if($itemize == 1){
                $truck_weight                                           += $loadDetail->shipper_stop_weight ?? 0;
                $truck_weight                                           += $load->load_stops()->where('customer_type', 1)->sum('stop_weight');
            }else{
                $truck_weight                                           = $loadDetail->weight ?? 0;
            }
            if(isset($truck)){
                $startTime                                              = null;
                $endTime                                                = null;
                if(in_array($loadDetail->load_type, ['0', '6'])){
                    $startTime                                          = $loadDetail->shipper_date_time ? $loadDetail->getRawOriginal('shipper_date_time') : null;
                    if($loadDetail->delivery_time_range == 0){
                        $endTime                                        = $loadDetail->delivery_date_time ? $loadDetail->getRawOriginal('delivery_date_time') : null;
                    }else{
                        $endTime                                        = $loadDetail->delivery_date_time_end ? $loadDetail->getRawOriginal('delivery_date_time_end ') : null;
                    }
                }else{
                    $startTime                                          = $loadDetail->start_date ? date('Y-m-d H:i:s', strtotime($loadDetail->start_date)) : null;
                    $endTime                                            = $loadDetail->end_date ? date('Y-m-d H:i:s', strtotime($loadDetail->end_date)) : null;
                }
                if(isset($startTime) && isset($endTime)){
                    $getAllSafetyEvents                                 = getAllSafetyEvents($truck, $startTime, $endTime);
                    if(!empty($getAllSafetyEvents)){
                        $latestSafetyEvents                             = isset($getAllSafetyEvents[0]) && !empty($getAllSafetyEvents[0]) ? $getAllSafetyEvents[0] : [];
                        if(!empty($latestSafetyEvents)){
                            $safetyEventLabel                           = $latestSafetyEvents->behaviorLabels[0]->name ?? '';
                        }
                    }
                }

                $currentLocation                                        = truckCurrentLocation($truck);
                if(!empty($currentLocation) && in_array($loadDetail->load_type, ['0', '6']) && in_array($loadDetail->load_status, ['4']) && !in_array($loadDetail->is_on_hold, ['2'])){
                    // Load Type 0 = OCCUPIED, 6 = TONU
                    // Load Status 4 = In Transit
                    // Is On Hold 2 = Cancel
                    $deadheadLocation                                   = [];
                    if(isset($loadDetail->deadhead_mileage_options)){
                        $deadheadLocation                               = json_decode($loadDetail->deadhead_mileage_options, true);
                    }elseif((isset($loadDetail->shipper_latitude) && $loadDetail->shipper_latitude!='') && (isset($loadDetail->shipper_longitude) && $loadDetail->shipper_longitude!='')){
                        $deadheadLocation['latitude']                   = $loadDetail->shipper_latitude;
                        $deadheadLocation['longitude']                  = $loadDetail->shipper_longitude;
                        $deadheadLocation['city']                       = $loadDetail->shipper_city;
                        $deadheadLocation['state']                      = $loadDetail->shipper_state;
                        $deadheadLocation['zip']                        = $loadDetail->shipper_zip;
                    }
                    if(!empty($deadheadLocation)){
                        $mileageCoords['deadheadLocation']              = $deadheadLocation;
                        $mileageCoords['currentLocation']               = $currentLocation;
                    }
                    if(isset($loadDetail->load_trip_id) && $loadDetail->load_trip_id!=''){
                        $getPastGPSCoords                               = $this->getGPSCoords($loadDetail->load_trip_id);
                        if(!empty($getPastGPSCoords)){
                            $pastGPSCoords                              = array_map(function ($item) {
                                return [(float)$item->coords->lon, (float)$item->coords->lat];
                            }, $getPastGPSCoords);
                        }
                    }
                }
            }
            //

            $trimbleMapParams                                           = [];
            $trimbleMapParams['map_toll_roads']                         = $loadDetail->map_toll_roads;
            $trimbleMapParams['map_max_elevation']                      = $loadDetail->map_max_elevation;
            $trimbleMapParams['map_close_borders']                      = $loadDetail->map_close_borders;
            $trimbleMapParams['hazardous_load']                         = $loadDetail->hazardous_load;
            $trimbleMapParams['hazardous_options']                      = $loadDetail->hazardous_options;
            $trimbleMapParams['truck_length']                           = $truck_length;
            $trimbleMapParams['truck_width']                            = $truck_width;
            $trimbleMapParams['truck_height']                           = $truck_height;
            $trimbleMapParams['truck_weight']                           = $truck_weight > 0 ? $truck_weight : null;

            $trimbleTripDetails                                         = null;
            $trimbleTripStopsTotal                                      = 0;
            $actualTripStopsTotal                                       = 0;
            $position                                                   = 0;

            $stopNo                                                     = 1;
            $stopIndex                                                  = 0;

            $stopsArry                                                  = [];
            $stopStatusArry                                             = [];
            $truckStopArry                                              = [];

            if(isset($loadDetail->load_trip_id) && $loadDetail->load_trip_id!=''){
                $trimbleTripDetails                                     = $this->getTripDetails($loadDetail->load_trip_id);
            }
            $trimbleTripStopsTotal                                      = isset($trimbleTripDetails->stops) ? count($trimbleTripDetails->stops): 0;

            // Load Type 0 = OCCUPIED, 6 = TONU
            // Load Status '0' => 'Pending', '1' => 'Accepted', '2' => 'Preplaned', 11 => 'Send To Driver'
            if(in_array($loadDetail->load_type, ['0', '6'])){
                //
                $stopsArry[]                                            = [
                    'stop_no'                                           => $stopNo,
                    'load_id'                                           => $loadDetail->load_id,
                    'load_detail_id'                                    => $loadDetail->id,
                    'load_stop_id'                                      => null,
                    'type'                                              => 1, // pickup
                    'is_stop'                                           => 0,
                    'address_one'                                       => $loadDetail->shipper_address_one ?? null,
                    'state'                                             => $loadDetail->shipper_state ?? null,
                    'city'                                              => $loadDetail->shipper_city ?? null,
                    'zip'                                               => $loadDetail->shipper_zip ?? null
                ];

                $actualTripStopsTotal                                   = 2;
                $actualTripStopsTotal                                   += isset($load->load_stops) ? $load->load_stops->count() : 0;
                if(isset($loadDetail->deadhead_mileage_options)){
                    $actualTripStopsTotal                               += 1;
                    ++$position;
                }

                $is_detained                                            = 0;
                $pending_required_docs                                  = [];
                if(isset($loadDetail->shipper_files_upload) && is_serialized($loadDetail->shipper_files_upload) && !empty(unserialize($loadDetail->shipper_files_upload))){
                    $pending_required_docs                              = unserialize($loadDetail->shipper_files_upload);
                    $pending_required_docs                              = array_filter($pending_required_docs, function ($var) {
                        return (isset($var['name_id']) && $var['name_id'] !== null && $var['is_required'] == 'on' && $var['is_received'] == 'off');
                    });
                }
                $pending_accessorial_docs                               = 0;
                if(isset($loadDetail->shipper_accessorials) && $loadDetail->shipper_accessorials->isNotEmpty()){
                    $pending_accessorial_docs                           = $loadDetail->shipper_accessorials()->where('doc_required', 1)->where('is_received', 0)->count();
                }
                if(!empty($pending_required_docs) || $pending_accessorial_docs > 0){
                    $is_pending_docs                                    = 1;
                }else{
                    $is_pending_docs                                    = 0;
                }

                $stopStatus                                             = 'Pending';
                $stopClass                                              = 'text-warning';
                if((isset($loadDetail->shipper_is_arrived) && $loadDetail->shipper_is_arrived == 1) && (isset($loadDetail->shipper_arrived_at) && $loadDetail->shipper_arrived_at != '')){
                    if((isset($loadDetail->shipper_is_leaves) && $loadDetail->shipper_is_leaves == 1) && (isset($loadDetail->shipper_leaves_at) && $loadDetail->shipper_leaves_at != '')){
                        // Click on leave button
                        $stopStatus                                     = 'Picked Up';
                        if(empty($pending_required_docs) && $pending_accessorial_docs == 0){
                            $stopClass                                  = 'text-success';
                        }else{
                            $stopClass                                  = 'text-danger';
                        }
                    }else{
                        // Click on arrive button
                        $stopStatus                                     = 'On Location';
                        $stopClass                                      = 'text-success';
                        if(isset($loadDetail->shipper_detention)){
                            $detention_exists                           = $loadDetail->shipper_detention()->whereNotIn('review_status', ['Completed','Denied'])->exists();
                            if($detention_exists){
                                $stopStatus                             = 'Detained';
                                $stopClass                              = 'text-danger';
                                $is_detained                            = 1;
                            }
                        }
                    }
                }else{
                    if($actualTripStopsTotal > 0 && isset($trimbleTripDetails) && $trimbleTripStopsTotal == $actualTripStopsTotal){
                        if(isset($trimbleTripDetails->stops[$position]->stopArrivalStatus) && $trimbleTripDetails->stops[$position]->stopArrivalStatus == 'Late'){
                            $stopStatus                                 = $trimbleTripDetails->stops[$position]->stopArrivalStatus;
                            $stopClass                                  = 'text-danger';
                        }
                    }
                }

                $stopStatusArry[$stopIndex]['index']                    = $stopIndex;
                $stopStatusArry[$stopIndex]['stop_no']                  = $stopNo;
                $stopStatusArry[$stopIndex]['type']                     = 1;
                $stopStatusArry[$stopIndex]['is_stop']                  = 0;
                $stopStatusArry[$stopIndex]['stop_id']                  = 0;
                $stopStatusArry[$stopIndex]['is_arrived']               = $loadDetail->shipper_is_arrived ?? 0;
                $stopStatusArry[$stopIndex]['is_leaves']                = $loadDetail->shipper_is_leaves ?? 0;
                $stopStatusArry[$stopIndex]['is_detained']              = $is_detained;
                $stopStatusArry[$stopIndex]['is_pending_docs']          = $is_pending_docs;
                $stopStatusArry[$stopIndex]['status']                   = $stopStatus;
                $stopStatusArry[$stopIndex]['class']                    = $stopClass;
                $stopStatusArry[$stopIndex]['position']                 = $position;
                ++$position;
                ++$stopIndex;
                //

                //
                if(isset($load->load_stops) && $load->load_stops->isNotEmpty()){
                    foreach ($load->load_stops as $key => $stop) {
                        ++$stopNo;

                        $stopsArry[]                                    = [
                            'stop_no'                                   => $stopNo,
                            'load_id'                                   => $loadDetail->load_id,
                            'load_detail_id'                            => $loadDetail->id,
                            'load_stop_id'                              => $stop->id,
                            'type'                                      => $stop->customer_type, // stop
                            'is_stop'                                   => 1,
                            'address_one'                               => $stop->address_one ?? null,
                            'state'                                     => $stop->state ?? null,
                            'city'                                      => $stop->city ?? null,
                            'zip'                                       => $stop->zip ?? null
                        ];

                        $is_detained                                    = 0;
                        $pending_required_docs                          = [];
                        if($stop->customer_type == 1){
                            if(isset($stop->stop_shipper_files_upload) && is_serialized($stop->stop_shipper_files_upload) && !empty(unserialize($stop->stop_shipper_files_upload))){
                                $pending_required_docs                  = unserialize($stop->stop_shipper_files_upload);
                                $pending_required_docs                  = array_filter($pending_required_docs, function ($var) {
                                    return (isset($var['name_id']) && $var['name_id'] !== null && $var['is_required'] == 'on' && $var['is_received'] == 'off');
                                });
                            }
                        }else{
                            if(isset($stop->stop_consignee_files_upload) && is_serialized($stop->stop_consignee_files_upload) && !empty(unserialize($stop->stop_consignee_files_upload))){
                                $pending_required_docs                  = unserialize($stop->stop_consignee_files_upload);
                                $pending_required_docs                  = array_filter($pending_required_docs, function ($var) {
                                    return (isset($var['name_id']) && $var['name_id'] !== null && $var['is_required'] == 'on' && $var['is_received'] == 'off');
                                });
                            }
                        }
                        $pending_accessorial_docs                       = 0;
                        if(isset($stop->accessorials) && $stop->accessorials->isNotEmpty()){
                            $pending_accessorial_docs                   = $stop->accessorials()->where('doc_required', 1)->where('is_received', 0)->count();
                        }
                        if(!empty($pending_required_docs) || $pending_accessorial_docs > 0){
                            $is_pending_docs                            = 1;
                        }else{
                            $is_pending_docs                            = 0;
                        }

                        $stopStatus                                     = 'Pending';
                        $stopClass                                      = 'text-warning';
                        if((isset($stop->is_arrived) && $stop->is_arrived == 1) && (isset($stop->arrived_at) && $stop->arrived_at != '')){
                            if((isset($stop->is_leaves) && $stop->is_leaves == 1) && (isset($stop->is_leaves) && $stop->is_leaves != '')){
                                // Click on leave button
                                $stopStatus                             = $stop->customer_type == 1 ? 'Picked Up': 'Delivered';
                                if(empty($pending_required_docs) && $pending_accessorial_docs == 0){
                                    $stopClass                          = 'text-success';
                                }else{
                                    $stopClass                          = 'text-danger';
                                }
                            }else{
                                // Click on arrive button
                                if($actualTripStopsTotal > 0 && isset($trimbleTripDetails) && $trimbleTripStopsTotal == $actualTripStopsTotal){
                                    if(isset($trimbleTripDetails->stops[$position]->stopArrivalStatus) && $trimbleTripDetails->stops[$position]->stopArrivalStatus == 'Late'){
                                        $stopStatus                     = $trimbleTripDetails->stops[$position]->stopArrivalStatus;
                                        $stopClass                      = 'text-danger';
                                    }
                                }
                                $lastStopStatusArry                     = last($stopStatusArry);
                                if(isset($lastStopStatusArry['is_leaves']) && $lastStopStatusArry['is_leaves'] == 1 && $stopStatus!='Late'){
                                    $stopStatus                         = 'On Location';
                                    $stopClass                          = 'text-success';
                                }
                                if(isset($stop->detention)){
                                    $detention_exists                   = $stop->detention()->whereNotIn('review_status', ['Completed','Denied'])->exists();
                                    if($detention_exists){
                                        $stopStatus                     = 'Detained';
                                        $stopClass                      = 'text-danger';
                                        $is_detained                    = 1;
                                    }
                                }
                            }
                        }else{
                            if($actualTripStopsTotal > 0 && isset($trimbleTripDetails) && $trimbleTripStopsTotal == $actualTripStopsTotal){
                                if(isset($trimbleTripDetails->stops[$position]->stopArrivalStatus) && $trimbleTripDetails->stops[$position]->stopArrivalStatus == 'Late'){
                                    $stopStatus                         = $trimbleTripDetails->stops[$position]->stopArrivalStatus;
                                    $stopClass                          = 'text-danger';
                                }
                            }
                            $lastStopStatusArry                         = last($stopStatusArry);
                            if(isset($lastStopStatusArry['is_leaves']) && $lastStopStatusArry['is_leaves'] == 1 && $stopStatus!='Late'){
                                $stopStatus                             = 'In Transit';
                                $stopClass                              = 'text-success';
                            }
                        }
                        $stopStatusArry[$stopIndex]['index']            = $stopIndex;
                        $stopStatusArry[$stopIndex]['stop_no']          = $stopNo;
                        $stopStatusArry[$stopIndex]['type']             = $stop->customer_type;
                        $stopStatusArry[$stopIndex]['is_stop']          = 1;
                        $stopStatusArry[$stopIndex]['stop_id']          = $stop->id;
                        $stopStatusArry[$stopIndex]['is_arrived']       = $stop->is_arrived ?? 0;
                        $stopStatusArry[$stopIndex]['is_leaves']        = $stop->is_leaves ?? 0;
                        $stopStatusArry[$stopIndex]['is_detained']      = $is_detained;
                        $stopStatusArry[$stopIndex]['is_pending_docs']  = $is_pending_docs;
                        $stopStatusArry[$stopIndex]['status']           = $stopStatus;
                        $stopStatusArry[$stopIndex]['class']            = $stopClass;
                        $stopStatusArry[$stopIndex]['position']         = $position;
                        ++$position;
                        ++$stopIndex;
                    }
                }
                //

                $stopsArry[]                                            = [
                    'stop_no'                                           => 99,
                    'load_id'                                           => $loadDetail->load_id,
                    'load_detail_id'                                    => $loadDetail->id,
                    'load_stop_id'                                      => null,
                    'type'                                              => 2, // delivery
                    'is_stop'                                           => 0,
                    'address_one'                                       => $loadDetail->delivery_address_one ?? null,
                    'state'                                             => $loadDetail->delivery_state ?? null,
                    'city'                                              => $loadDetail->delivery_city ?? null,
                    'zip'                                               => $loadDetail->delivery_zip ?? null
                ];

                $is_detained                                            = 0;
                $pending_required_docs                                  = [];
                if(isset($loadDetail->consignee_files_upload) && is_serialized($loadDetail->consignee_files_upload) && !empty(unserialize($loadDetail->consignee_files_upload))){
                    $pending_required_docs                              = unserialize($loadDetail->consignee_files_upload);
                    $pending_required_docs                              = array_filter($pending_required_docs, function ($var) {
                        return (isset($var['name_id']) && $var['name_id'] !== null && $var['is_required'] == 'on' && $var['is_received'] == 'off');
                    });
                }

                $pending_accessorial_docs                               = 0;
                if(isset($loadDetail->receiver_accessorials) && $loadDetail->receiver_accessorials->isNotEmpty()){
                    $pending_accessorial_docs                           = $loadDetail->receiver_accessorials()->where('doc_required', 1)->where('is_received', 0)->count();
                }
                if(!empty($pending_required_docs) || $pending_accessorial_docs > 0){
                    $is_pending_docs                                    = 1;
                }else{
                    $is_pending_docs                                    = 0;
                }

                $stopStatus                                             = 'Pending';
                $stopClass                                              = 'text-warning';
                if((isset($loadDetail->delivery_is_arrived) && $loadDetail->delivery_is_arrived == 1) && (isset($loadDetail->delivery_arrived_at) && $loadDetail->delivery_arrived_at != '')){
                    if((isset($loadDetail->delivery_is_leaves) && $loadDetail->delivery_is_leaves == 1) && (isset($loadDetail->delivery_leaves_at) && $loadDetail->delivery_leaves_at != '')){
                        // Click on leave button
                        $stopStatus                                     = 'Delivered';
                        if(empty($pending_required_docs) && $pending_accessorial_docs == 0){
                            $stopClass                                  = 'text-success';
                        }else{
                            $stopClass                                  = 'text-danger';
                        }
                    }else{
                        // Click on arrive button
                        if($actualTripStopsTotal > 0 && isset($trimbleTripDetails) && $trimbleTripStopsTotal == $actualTripStopsTotal){
                            if(isset($trimbleTripDetails->stops[$position]->stopArrivalStatus) && $trimbleTripDetails->stops[$position]->stopArrivalStatus == 'Late'){
                                $stopStatus                             = $trimbleTripDetails->stops[$position]->stopArrivalStatus;
                                $stopClass                              = 'text-danger';
                            }
                        }
                        $lastStopStatusArry                             = last($stopStatusArry);
                        if(isset($lastStopStatusArry['is_leaves']) && $lastStopStatusArry['is_leaves'] == 1 && $stopStatus!='Late'){
                            $stopStatus                                 = 'On Location';
                            $stopClass                                  = 'text-success';
                        }
                        if(isset($loadDetail->receiver_detention)){
                            $detention_exists                           = $loadDetail->receiver_detention()->whereNotIn('review_status', ['Completed','Denied'])->exists();
                            if($detention_exists){
                                $stopStatus                             = 'Detained';
                                $stopClass                              = 'text-danger';
                                $is_detained                            = 1;
                            }
                        }
                    }
                }else{
                    if($actualTripStopsTotal > 0 && isset($trimbleTripDetails) && $trimbleTripStopsTotal == $actualTripStopsTotal){
                        if(isset($trimbleTripDetails->stops[$position]->stopArrivalStatus) && $trimbleTripDetails->stops[$position]->stopArrivalStatus == 'Late'){
                            $stopStatus                                 = $trimbleTripDetails->stops[$position]->stopArrivalStatus;
                            $stopClass                                  = 'text-danger';
                        }
                    }
                    $lastStopStatusArry                                 = last($stopStatusArry);
                    if(isset($lastStopStatusArry['is_leaves']) && $lastStopStatusArry['is_leaves'] == 1 && $stopStatus!='Late'){
                        $stopStatus                                     = 'In Transit';
                        $stopClass                                      = 'text-success';
                    }
                }
                $stopStatusArry[$stopIndex]['index']                    = $stopIndex;
                $stopStatusArry[$stopIndex]['stop_no']                  = 99;
                $stopStatusArry[$stopIndex]['type']                     = 2;
                $stopStatusArry[$stopIndex]['is_stop']                  = 0;
                $stopStatusArry[$stopIndex]['stop_id']                  = 0;
                $stopStatusArry[$stopIndex]['is_arrived']               = $loadDetail->delivery_is_arrived ?? 0;
                $stopStatusArry[$stopIndex]['is_leaves']                = $loadDetail->delivery_is_leaves ?? 0;
                $stopStatusArry[$stopIndex]['is_detained']              = $is_detained;
                $stopStatusArry[$stopIndex]['is_pending_docs']          = $is_pending_docs;
                $stopStatusArry[$stopIndex]['status']                   = $stopStatus;
                $stopStatusArry[$stopIndex]['class']                    = $stopClass;
                $stopStatusArry[$stopIndex]['position']                 = $position;
                //

                if(!empty($stopStatusArry)){
                    if(in_array($loadDetail->load_status, [5,6,10,8])){
                        $truckStopArry['index']                         = $stopIndex; // 99
                        $truckStopArry['status']                        = 'Delivered';
                    }else{
                        $firstStopArrived                               = $stopStatusArry[0]['is_arrived'] ?? 0;
                        if($firstStopArrived == 1){
                            foreach ($stopStatusArry as $key => $value) {
                                if($value['is_arrived'] == 0 && $value['is_leaves'] == 0){
                                    $truckStopArry['index']             = $value['index'];
                                    $truckStopArry['status']            = 'In Transit';
                                    break;
                                }elseif($value['is_arrived'] == 1 && $value['is_leaves'] == 0){
                                    $truckStopArry['index']             = $value['index'];
                                    $truckStopArry['status']            = 'On Location';
                                    break;
                                }else{
                                    $truckStopArry['index']             = $value['index'];
                                    $truckStopArry['status']            = 'Delivered';
                                }
                            }
                        }
                    }
                }
            }
            //

            $truckStopPercentage                                        = 0;
            if(!empty($truckStopArry)){
                $truckStopIndex                                         = $truckStopArry['index'];
                $truckStopStatus                                        = $truckStopArry['status'];
                $truckStopTotal                                         = count($stopStatusArry);
                $truckStopIn                                            = (float)number_format((float)(100/$truckStopTotal), 2, '.', '');
                $truckStopOn                                            = (float)number_format((float)($truckStopIn/2), 2, '.', '');
                if($truckStopStatus == 'In Transit'){
                    $truckStopPercentage                                = $truckStopIndex*$truckStopIn;
                }elseif($truckStopStatus == 'On Location'){
                    $truckStopPercentage                                = $truckStopIndex*$truckStopIn+$truckStopOn;
                }else{
                    $truckStopPercentage                                = 100;
                }
            }
            $truckStopArry['percentage']                                = $truckStopPercentage;

            $loadStatusArry                                             = [];
            if(!empty($stopStatusArry)){
                // Filter the array based on a condition (e.g., age greater than 30)
                $filteredArray                                          = array_filter($stopStatusArry, function ($var) {
                    return $var['is_detained'] == 1;
                });
                if(!empty($filteredArray)){
                    // Get the last array from the filtered array
                    $lastArray                                          = end($filteredArray);
                    $loadStatusArry['stop_no']                          = $lastArray['stop_no'];
                    $loadStatusArry['status']                           = 'Detained';
                }else{
                    if(isset($loadDetail->load_status) && in_array($loadDetail->load_status, [5,6,10,8])){
                        $filteredArray                                  = array_filter($stopStatusArry, function ($var) {
                            return $var['is_pending_docs'] == 1;
                        });
                        $loadStatusArry['stop_no']                      = 99;
                        $loadStatusArry['status']                       = 'Delivered';
                        if(!empty($filteredArray)){
                            $loadStatusArry['is_pending_docs']          = 1;
                        }
                    }else{
                        foreach ($stopStatusArry as $key => $value) {
                            if($value['is_arrived'] == 0 && $value['is_leaves'] == 0){
                                // Check if it's the last iteration
                                if ($key === count($stopStatusArry) - 1) {
                                    if($actualTripStopsTotal > 0 && isset($trimbleTripDetails) && $trimbleTripStopsTotal == $actualTripStopsTotal){
                                        if(isset($trimbleTripDetails->stops[$value['position']]->stopArrivalStatus) && $trimbleTripDetails->stops[$value['position']]->stopArrivalStatus == 'Late'){
                                            $stopArrivalStatus          = $trimbleTripDetails->stops[$value['position']]->stopArrivalStatus;
                                        }
                                    }
                                    $loadStatusArry['stop_no']          = $value['stop_no'];
                                    $loadStatusArry['status']           = $stopArrivalStatus ?? 'In Transit';
                                }else{
                                    $loadStatusArry['stop_no']          = $value['stop_no'];
                                    $loadStatusArry['status']           = 'In Transit';
                                    break;
                                }
                            }elseif($value['is_arrived'] == 1 && $value['is_leaves'] == 0){
                                $loadStatusArry['stop_no']              = $value['stop_no'];
                                $loadStatusArry['status']               = 'On Location';
                                break;
                            }
                        }
                    }
                }
            }

            $this->data['reeferTempExists']                             = $reeferTempExists;
            $this->data['safetyEventLabel']                             = $safetyEventLabel;
            $this->data['currentLocation']                              = $currentLocation;
            $this->data['mileageCoords']                                = $mileageCoords;
            $this->data['pastGPSCoords']                                = $pastGPSCoords;
            $this->data['trimbleMapParams']                             = $trimbleMapParams;
            $this->data['trimbleTripDetails']                           = $trimbleTripDetails;
            $this->data['stopsArry']                                    = $stopsArry;
            $this->data['stopStatusArry']                               = $stopStatusArry;
            $this->data['truckStopArry']                                = $truckStopArry;
            $this->data['loadStatusArry']                               = $loadStatusArry;

            return view('load_view_1', $this->data);
            // return view('companyAdmin.load.show', compact('loadDetail'));
        }else{
            return abort(404);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id){
        $id                                                         = base64Decode($id);
        $load                                                       = Load::findOrFail($id);
        if(is_null($load->load_detail_id)){
            $load_detail                                            = LoadDetail::where('load_id', $load->id)->latest()->first();
            if(!is_null($load_detail)){
                $load->load_detail_id                               = $load_detail->id;
                $load->save();
            }
        }
        $broker                                                     = isset($load->load_detail->broker)?$load->load_detail->broker:null;

        $load['cod']                                                = $load->galleries()->pluck('image', 'field_name')->toArray();
        $this->data['load']                                         = $load;
        $this->data['loadDetail']                                   = $load->load_detail;

        /* Fetch Load number base on 'desired_option' added by Dhaval Thakor - 23-12-2022 - Start */
        $carrierDetails                                             = DriverInformation::with('carrier')->where('driver_id', $this->data['loadDetail']['driver_id'])->first();
        if(isset($carrierDetails->carrier) && !is_null($carrierDetails->carrier)){
            if($carrierDetails->carrier->identifier != ""){
                $this->data['loadDetail']['identifier']             = $carrierDetails->carrier->identifier."-";

                if($carrierDetails->carrier->identifier.'-' == substr($this->data['loadDetail']['load_number'], 0, 4)){
                    $this->data['loadDetail']['load_number']        = substr($this->data['loadDetail']['load_number'], 4);
                }
            }
        }
        $this->data['carrierDetails']                               = $carrierDetails;
        /* Fetch Load number base on 'desired_option' added by Dhaval Thakor - 23-12-2022 - End */

        $this->data['loadDetail']['truck_company']                  = "";
        $this->data['loadDetail']['truck_length']                   = "";
        $this->data['loadDetail']['truck_width']                    = "";
        $this->data['loadDetail']['truck_height']                   = "";
        $this->data['loadDetail']['truck_max_load_weight']          = "";
        if(isset($this->data['loadDetail']->truck_number) && $this->data['loadDetail']->truck_number != ""){
            $truckDetails                                           = $this->data['loadDetail']->truck;
            if($truckDetails){
                $this->data['loadDetail']['truck_company']          = $truckDetails->getCompany->name;
                $this->data['loadDetail']['truck_length']           = $truckDetails->length;
                $this->data['loadDetail']['truck_width']            = $truckDetails->width;
                $this->data['loadDetail']['truck_height']           = $truckDetails->height;
                $this->data['loadDetail']['truck_max_load_weight']  = $truckDetails->max_load_weight;
            }
        }

        if($this->data['loadDetail']['terms'] == "" && (isset($broker->billing_terms) && $broker->billing_terms != "")){
            $this->data['loadDetail']['terms']                      = $broker->billing_terms;
        }

        // Drop Trailer Schedule
        $load_assign_trailers                                       = getLoadAssignTrailers(['id' => $load->load_detail->id]);
        $load_available_trailers                                    = getLoadAvailableTrailers($load_assign_trailers);
        $this->data['load_available_trailers']                      = $load_available_trailers;
        $load_pickup_trailers                                       = getLoadPickUpTrailers($load_assign_trailers, $load_available_trailers);
        $this->data['load_pickup_trailers']                         = $load_pickup_trailers;
        // Drop Trailer Schedule

        $this->data['loadDrivers']                                  = $load->load_detail->load_drivers;
        $this->data['loadTruckOwners']                              = $load->load_detail->load_truck_owners;

        $this->data['stop_index']                                   = count($load->load_stops);
        $this->data['totalPendingDetention']                        = $load->load_detail->detentions()->whereNotIn('review_status', ['Completed','Denied'])->count();

        // Broker Info get
        $broker_email_arry                                          = [];
        $broker_phone_arry                                          = [];

        if(isset($broker->email))
            $broker_email_arry[]                                    = [
                'table'                                             => 'brokers',
                'field_name'                                        => 'email',
                'name'                                              => $broker->name,
                'email'                                             => $broker->email,
                'primary_contact'                                   => 0
            ];
        if(isset($broker->phone))
            $broker_phone_arry[]                                    = [
                'table'                                             => 'brokers',
                'field_name'                                        => 'phone',
                'name'                                              => $broker->name,
                'phone'                                             => $broker->phone,
                'primary_contact'                                   => 0
            ];

        if(isset($broker->billing_email))
            $broker_email_arry[]                                    = [
                'table'                                             => 'brokers',
                'field_name'                                        => 'billing_email',
                'name'                                              => $broker->bill_to_name,
                'email'                                             => $broker->billing_email,
                'primary_contact'                                   => 0
            ];
        if(isset($broker->billing_phone))
            $broker_phone_arry[]                                    = [
                'table'                                             => 'brokers',
                'field_name'                                        => 'billing_phone',
                'name'                                              => $broker->bill_to_name,
                'phone'                                             => $broker->billing_phone,
                'primary_contact'                                   => 0
            ];

        $broker_contact_html                                        = '';
        if(isset($broker->dispatch_contact_name) && $broker->dispatch_contact_name!=''){
            $broker_contact_html                                    .= '<option value="'.$broker->dispatch_contact_name.'" data-phone="'.$broker->dispatch_contact_phone.'" data-ext="'.$broker->dispatch_contact_contact_ext.'" data-email="'.$broker->dispatch_contact_email.'">'.$broker->dispatch_contact_name.'</option>';
        }
        if(isset($broker->broker_contact) && $broker->broker_contact->isNotEmpty()){
            foreach ($broker->broker_contact as $key => $cdata) {
                $primary_contact                                    = 0;
                if($cdata->primary_contact==1 && !is_null($cdata->primary_contact_id)){
                    if(in_array(auth()->guard('company-admin')->id(), explode(',', $cdata->primary_contact_id))){
                        $primary_contact                            = 1;
                    }
                }

                if(!is_null($cdata->email))
                    $broker_email_arry[]                            = [
                        'table'                                     => 'broker_contacts',
                        'field_name'                                => 'email',
                        'name'                                      => $cdata->name,
                        'email'                                     => $cdata->email,
                        'primary_contact'                           => $primary_contact
                    ];
                if(!is_null($cdata->cell_number))
                    $broker_phone_arry[]                            = [
                        'table'                                     => 'broker_contacts',
                        'field_name'                                => 'cell_number',
                        'name'                                      => $cdata->name,
                        'phone'                                     => $cdata->cell_number,
                        'primary_contact'                           => $primary_contact
                    ];

                $broker_contact_html                                .= '<option value="'.$cdata->name.'" data-phone="'.$cdata->phone_number.'" data-ext="'.$cdata->ext.'" data-email="'.$cdata->email.'" data-primary_contact="'.$primary_contact.'">'.$cdata->name.'</option>';
            }
        }
        $this->data['broker_contact_html']                          = $broker_contact_html;

        $broker_email_html                                          = '';
        foreach ($broker_email_arry as $key => $broker_email_row) {
            $email_id                                               = $broker_email_row['table']. '|' .$broker_email_row['field_name']. '|' .$broker_email_row['email'];
            $email_text                                             = $broker_email_row['name']. ' - '.$broker_email_row['email'];
            $broker_email_html                                      .= '<option value="'.$email_id.'" data-primary_contact="'.$broker_email_row['primary_contact'].'">'.$email_text.'</option>';
        }
        $this->data['broker_email_html']                            = $broker_email_html;

        $broker_phone_html                                          = '';
        foreach ($broker_phone_arry as $key => $broker_phone_row) {
            $phone_id                                               = $broker_phone_row['table']. '|' .$broker_phone_row['field_name']. '|' .$broker_phone_row['phone'];
            $phone_text                                             = $broker_phone_row['name']. ' - '.$broker_phone_row['phone'];
            $broker_phone_html                                      .= '<option value="'.$phone_id.'" data-primary_contact="'.$broker_phone_row['primary_contact'].'">'.$phone_text.'</option>';
        }
        $this->data['broker_phone_html']                            = $broker_phone_html;

        $broker_shipper_files                                       = [];
        if(isset($broker->shipper_files) && !empty($broker->shipper_files)){
            $broker_shipper_files                                   = unserialize($broker->shipper_files);
            $broker_shipper_files                                   = array_filter($broker_shipper_files, function($var) {
                return isset($var['name_id']) && $var['name_id'] !== null;
            });
        }
        $this->data['broker_shipper_files']                         = $broker_shipper_files;

        $broker_consignee_files                                     = [];
        if(isset($broker->consignee_files) && !empty($broker->consignee_files)){
            $broker_consignee_files                                 = unserialize($broker->consignee_files);
            $broker_consignee_files                                 = array_filter($broker_consignee_files, function($var) {
                return isset($var['name_id']) && $var['name_id'] !== null;
            });
        }
        $this->data['broker_consignee_files']                       = $broker_consignee_files;
        // Broker info

        // Accessorial info
        /* Added by Dhaval Thakor for multiple Accessorial dropdown - 27-12-2022 - START */
        $accessorialList                                            = CompanyAccessorial::isCompany()->get(['id', 'name', 'default_amount', 'gl_code']);
        $accessorialDropDown                                        = "";
        if($accessorialList->count() > 0){
            $accessorialDropDown                                    .= '<option value="">Select accessorial</option>';
            foreach ($accessorialList as $accessorial){
                $broker_rate                                        = '';
                if($broker){
                    $broker_accessorial                             = $broker->broker_accessorials()
                        ->where('company_accessorial_id', $accessorial->id)
                        ->latest()
                        ->first();
                    if($broker_accessorial){
                        $broker_rate                                = $broker_accessorial->rate;
                    }
                }
                $accessorialDropDown                                .= '<option value="'.$accessorial->id.'" data-default-amount="'.$accessorial->default_amount.'" data-broker-rate="'.$broker_rate.'">'.$accessorial->name.'</option>';
            }
        }else{
            $accessorialDropDown                                    .= '<option value="" data-default-amount="">Select accessorial</option>';
        }
        $this->data['accessorialDropDown']                          = $accessorialDropDown;
        /* Added by Dhaval Thakor for multiple Accessorial dropdown - 27-12-2022 - END */

        $accessorialDrivers                                         = [];
        $accessorialTruckOwners                                     = [];
        if(isset($load->load_detail->driver)){
            $adriver                                                = $load->load_detail->driver;
            $accessorialDrivers[$adriver->id]                       = $adriver->last_name.', '.$adriver->first_name;
        }
        if(isset($load->load_detail->co_driver)){
            $adriver                                                = $load->load_detail->co_driver;
            $accessorialDrivers[$adriver->id]                       = $adriver->last_name.', '.$adriver->first_name;
        }
        if(isset($load->load_detail->load_drivers)){
            $aload_drivers                                          = $load->load_detail->load_drivers;
            foreach ($aload_drivers as $key => $aload_driver) {
                $adriver                                            = $aload_driver->driver;
                if(isset($adriver)){
                    $accessorialDrivers[$adriver->id]               = $adriver->last_name.', '.$adriver->first_name;
                }
            }
        }
        $this->data['accessorialDrivers']                           = $accessorialDrivers;

        $accessorialOwners                                          = [];
        if(!empty($accessorialDrivers)){
            $drivers                                                = Driver::whereIn('id', array_keys($accessorialDrivers))->get();
            $array                                                  = [];
            if($drivers->isNotEmpty()){
                foreach ($drivers as $key => $driver) {
                    $truck                                          = $driver->driver_information->truck;
                    if($truck){
                        // $owner_type.'_'.$owner_id;
                        $owner_id                                   = $truck->owner_id ?? null;
                        if($owner_id){
                            $type                                   = $truck->owner_type;
                            if($type==1){
                                $carrier                            = Carrier::find($owner_id);
                                if($carrier){
                                    $owner_name                     = $carrier->name;
                                    $array[$type][$owner_id]= $owner_name;
                                }
                            }else if ($type==2) {
                                $truckOwner                         = TruckOwner::find($owner_id);
                                if($truckOwner){
                                    $owner_name                     = $truckOwner->name;
                                    $array[$type][$owner_id]        = $owner_name;
                                }
                            }
                        }
                    }
                }
            }
            ksort($array);
            foreach ($array as $owner_type => $mul) {
                foreach ($mul as $owner_id => $row) {
                    $accessorialOwners[$owner_type.'_'.$owner_id]   = $row;
                }
            }
        }
        $this->data['accessorialOwners']                            = $accessorialOwners;
        // Accessorial info

        /****************************************** DropTrailers - START *****************************************/
        $getVendors                                                 = Vendor::isCompany()->get(['id', 'name', 'address', 'address_2', 'city', 'state', 'zip', DB::raw('1 as user_type')])->toArray();
        $getCarriers                                                = Carrier::isCompany()->get(['id', 'name', 'address', 'address_2', 'city', 'state', 'zip', DB::raw('2 as user_type')])->toArray();
        //$getShippers                                              = Shipper::isCompany()->get(['id', 'name', 'address', 'address2 as address_2', 'city', 'state', 'zip', DB::raw('3 as user_type')])->toArray();
        $getShippers                                                = Customer::isCompany()->get(['id', 'name', 'address', 'address2 as address_2', 'city', 'state', 'zip', DB::raw('3 as user_type')])->toArray();
        $getBrokers                                                 = Broker::isCompany()->get(['id', 'name', 'address', 'address_2', 'city', 'state', 'zip', DB::raw('4 as user_type')])->toArray();
        //$getTerminals                                             = Terminal::isCompany()->get(['id', 'name', 'address', 'address_2', 'city', 'state', 'zip', DB::raw('5 as user_type')])->toArray();
        //$mergeData                                                = array_merge($getVendors, $getCarriers, $getShippers, $getBrokers, $getTerminals);
        $mergeData                                                  = array_merge($getVendors, $getCarriers, $getShippers, $getBrokers);

        $dropSearchDropDown                                         = "";
        if(count($mergeData) > 0){
            $dropSearchDropDown                                     .= '<option value="">Select drop location</option>';
            foreach ($mergeData as $data){
                $dropSearchDropDown                                 .= '<option value="'.$data['id'].'" data-address="'.$data['address'].'" data-address_2="'.$data['address_2'].'" data-city="'.$data['city'].'" data-state="'.$data['state'].'" data-zip="'.$data['zip'].'" data-user-type="'.$data['user_type'].'">'.$data['name'].'</option>';
            }
        }else{
            $dropSearchDropDown                                     .= '<option value="" data-default-amount="">Select accessorial</option>';
        }
        $this->data['dropSearchDropDown']                           = $dropSearchDropDown;

        $dropTrailers                                               = DropTrailer::select('id', 'load_id', 'stop_number', 'type', 'trailer_number', 'empty_loaded', 'drop_at_stop', 'keep_assigned', DB::raw('DATE_FORMAT(drop_date, "%m/%d/%Y %l:%i %p") as drop_date'), 'user_type', 'loc', 'add1', 'add2', 'city', 'state', 'zip', 'latitude', 'longitude', 'timezone', 'timezone_offset', 'timezone_abbr', 'address_verified', 'notes', 'drop_or_keep_driver', 'retrieval_notification', 'notify_date', 'notify_users', DB::raw('(SELECT CONCAT(first_name," ",last_name) FROM company_admins where id = drop_trailers.created_by) as created_by'))->where('load_id', $id)->orderBy('stop_number', 'ASC')->orderBy('type', 'ASC')->get();

        if(count($dropTrailers) > 0){
            $this->data['shippingDropDetails']                      = $dropTrailers->where('stop_number', '1')->where('type', '1')->first();
            $this->data['shippingDropHookDetails']                  = $dropTrailers->where('stop_number', '1')->where('type', '2')->first();

            $this->data['dropTrailerDetails']                       = ($dropTrailers->whereNotIn('stop_number', ['1', '99'])->where('type', '1')->count() > 0) ? array_values($dropTrailers->whereNotIn('stop_number', ['1', '99'])->where('type', '1')->toArray()) : [];

            if (count($this->data['dropTrailerDetails']) > 0){
                foreach ($this->data['dropTrailerDetails'] as $key => $dropTrailerDetail){
                    $this->data['dropTrailerDetails'][$key]['dropTrailerHookDetail'] = array_values($dropTrailers->where('load_id', $dropTrailerDetail['load_id'])->where('stop_number', $dropTrailerDetail['stop_number'])->where('type', '2')->toArray())[0] ?? '';
                }
            }

            $this->data['deliveryDropDetails']                      = $dropTrailers->where('stop_number', '99')->where('type', '1')->first();
            $this->data['deliveryDropHookDetails']                  = $dropTrailers->where('stop_number', '99')->where('type', '2')->first();
        }else{
            $this->data['shippingDropDetails']                      = [];
            $this->data['shippingDropHookDetails']                  = [];

            $this->data['dropTrailerDetails']                       = [];

            $this->data['deliveryDropDetails']                      = [];
            $this->data['deliveryDropHookDetails']                  = [];
        }
        /****************************************** DropTrailers - END *****************************************/

        $getCompanyAdmin                                            = auth()->guard('company-admin')->user();

        $this->data['getField']                                     = '';
        $isCheck                                                    = Bookmark::where('company_id',getUserCompnayId())
            ->where('user_id',$getCompanyAdmin->id)
            ->where('user_type',$getCompanyAdmin->type)
            ->where('table_id','table_audit_load')->first();
        if(!empty($isCheck->id)){
            //$this->data['getField']                                 = unserialize($isCheck->config);
            $this->data['getField']                                 = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_audit_load_first'));
        }else{
            $this->data['getField']                                 = config('settings.table_audit_load_first');
        }

        $this->data['getTimeZone']                                  = $this->timeZone;
        $this->data['getTimeZoneId']                                = $this->timeZoneId;

        LoadAccessorial::where('load_id', $id)->where('load_detail_id', $load->load_detail->id)->update(['temp_details' => null]);

        $dropTrailers                                               = [];
        if(isset($this->data['loadDetail']->trailer_number) && !is_null($this->data['loadDetail']->trailer_number)){
            $dropTrailers[]                                         = $this->data['loadDetail']->trailer_number;
        }
        if(count($this->data['load']->load_trailers->toArray()) > 0){
            foreach ($this->data['load']->load_trailers->toArray() as $trailerDetail){
                $dropTrailers[]                                     = $trailerDetail['trailer_number'];
            }
        }
        $this->data['dropTrailers']                                 = $dropTrailers;

        return view('companyAdmin.load.create', $this->data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Load $load, Request $request){
        try {
            // dd('Edit Load', $load, $request->all());

            /*------------------------------------------
            --------------------------------------------
            Start DB Transaction
            --------------------------------------------
            --------------------------------------------*/
            // DB::beginTransaction();

            /* Edit Load */
            $setting                = auth()->guard('company-admin')->user()->getCompany;
            $company_id             = auth()->guard('company-admin')->user()->company_id;

            $formdata               = $request->all();
            $accessorial_unique_id  = $formdata['accessorial_unique_id'];

            $load_type              = $formdata['load_type'];
            $load_occupied          = false;
            // 1 = MAINTENANCE, 2 = UNAUTHORIZED, 3 = HOS, 4 = NO DISPATCH, 5 = TIME OFF
            if(in_array($load_type, ['0', '6'])){
                // 0 = OCCUPIED, 6 = TONU
                $load_occupied      = true;
            }

            $old_load_type          = $load->load_detail->load_type;
            $old_load_occupied      = false;
            // 1 = MAINTENANCE, 2 = UNAUTHORIZED, 3 = HOS, 4 = NO DISPATCH, 5 = TIME OFF
            if(in_array($old_load_type, ['0', '6'])){
                // 0 = OCCUPIED, 6 = TONU
                $old_load_occupied  = true;
            }

            $old_brokerage_firm     = $load->load_detail->brokerage_firm;

            $old_driver_id          = $load->load_detail->driver_id;
            $old_send_notification  = $load->load_detail->send_notification;

            $input                                                      = [];

            // some case reset value
            if($load_occupied !== $old_load_occupied){
                if($old_load_occupied){
                    // 0 = OCCUPIED, 6 = TONU
                    // set blank occupied field

                    $input['brokerage_firm']                            = null;
                    $input['brokerage_mc']                              = null;
                    $input['terms']                                     = null;
                    $input['rep']                                       = null;
                    $input['phone']                                     = null;
                    $input['broker_email']                              = null;
                    $input['ext']                                       = null;

                    $input['is_cod']                                    = 0;

                    $input['score_ratting']                             = null;
                    $input['score_credit']                              = null;
                    $input['score_updated_at']                          = null;

                    $input['up_front_amount']                           = null;
                    $input['up_front_payment_type']                     = null;
                    $input['up_front_ref_number']                       = null;
                    $input['up_front_is_paid']                          = '0';

                    $input['at_pickup_amount']                          = null;
                    $input['at_pickup_payment_type']                    = null;
                    $input['at_pickup_ref_number']                      = null;
                    $input['at_pickup_is_paid']                         = '0';

                    $input['at_delivery_amount']                        = null;
                    $input['at_delivery_payment_type']                  = null;
                    $input['at_delivery_ref_number']                    = null;
                    $input['at_delivery_is_paid']                       = '0';

                    $isFileUploaded                                     = Gallery::IsCompany()
                        ->where('action_id', $load->id)
                        ->where('source', 'load')
                        ->whereIn('field_name', ['up_front_file','at_pickup_file','at_delivery_file'])
                        ->get();
                    if($isFileUploaded->isNotEmpty()){
                        foreach ($isFileUploaded as $key => $value) {
                            $path = 'storage/companyAdmin/gallery/'.$value->image;
                            if (File::exists($path)) {
                                File::delete($path);
                            }
                            $value->delete();
                        }
                    }

                    $input['itemize']                                   = 0;
                    $input['load_type_2']                               = null;

                    $input['temp_type']                                 = 0;
                    $input['temp']                                      = null;
                    $input['commodity']                                 = null;
                    $input['weight']                                    = null;
                    $input['load_value']                                = null;
                    $input['pickup_number']                             = null;

                    $input['broker_load_number']                        = null;
                    $input['bol_number']                                = null;
                    $input['delivery_number']                           = null;
                    $input['po_Number']                                 = null;
                    $input['sku_number']                                = null;

                    $input['other_number']                              = null;

                    $input['hazardous_load']                            = 0;
                    $input['hazardous_options']                         = null;

                    $input['occupied_pickup_day']                       = 0;

                    $input['deadhead_mileage_options']                  = null;

                    $input['shipper_id']                                = null;
                    $input['shipper_address_one']                       = null;
                    $input['shipper_address_two']                       = null;
                    $input['shipper_state']                             = null;
                    $input['shipper_city']                              = null;
                    $input['shipper_zip']                               = null;

                    $input['shipper_latitude']                          = null;
                    $input['shipper_longitude']                         = null;
                    $input['shipper_timezone']                          = null;
                    $input['shipper_timezone_offset']                   = null;
                    $input['shipper_timezone_abbr']                     = null;
                    $input['shipper_address_verified']                  = 0;

                    $input['shipper_note']                              = null;

                    $input['shipper_commodity']                         = null;
                    $input['shipper_stop_value']                        = null;
                    $input['shipper_stop_weight']                       = null;
                    $input['shipper_reefer_mode']                       = null;
                    $input['shipper_reefer_temp_type']                  = 0;
                    $input['shipper_reefer_temp']                       = null;
                    $input['shipper_pickup_number']                     = null;

                    $input['shipper_dimension']                         = null;

                    $input['shipper_drop_trailer_schedule']             = 0;
                    $input['shipper_drop_trailer_id']                   = null;
                    $input['shipper_pickup_trailer_id']                 = null;

                    $input['shipper_files']                             = null;
                    $input['shipper_files_upload']                      = null;

                    $input['receiver_id']                               = null;
                    $input['delivery_address_one']                      = null;
                    $input['delivery_address_two']                      = null;
                    $input['delivery_state']                            = null;
                    $input['delivery_city']                             = null;
                    $input['delivery_zip']                              = null;

                    $input['delivery_latitude']                         = null;
                    $input['delivery_longitude']                        = null;
                    $input['delivery_timezone']                         = null;
                    $input['delivery_timezone_offset']                  = null;
                    $input['delivery_timezone_abbr']                    = null;
                    $input['delivery_address_verified']                 = 0;

                    $input['delivery_note']                             = null;

                    $input['delivery_commodity']                        = null;
                    $input['delivery_stop_value']                       = null;
                    $input['delivery_stop_weight']                      = null;
                    $input['delivery_reefer_mode']                      = null;
                    $input['delivery_reefer_temp_type']                 = 0;
                    $input['delivery_reefer_temp']                      = null;
                    $input['delivery_pickup_number']                    = null;

                    $input['delivery_dimension']                        = null;

                    $input['delivery_drop_trailer_schedule']            = 0;
                    $input['delivery_drop_trailer_id']                  = null;
                    $input['delivery_pickup_trailer_id']                = null;

                    $input['consignee_files']                           = null;
                    $input['consignee_files_upload']                    = null;

                    $input['empty_miles']                               = null;
                    $input['loaded_miles']                              = null;
                    $input['total_miles']                               = null;
                    $input['agreed_upon_rate']                          = null;
                    $input['fuel_surcharge_cost_per_mile']              = null;
                    $input['fuel_surcharge']                            = null;
                    $input['line_haul']                                 = null;

                    $input['total_bill']                                = null;
                    $input['driver_revenue']                            = null;

                    $input['map_toll_roads']                            = null;
                    $input['map_max_elevation']                         = null;
                    $input['map_close_borders']                         = null;
                    $input['load_trip_id']                              = null;
                    $input['load_tms_trip_id']                          = null;
                }else{
                    // 1 = MAINTENANCE, 2 = UNAUTHORIZED, 3 = HOS, 4 = NO DISPATCH, 5 = TIME OFF
                    // set blank unoccupied field
                    $input['start_date']                                = null;
                    $input['end_date']                                  = null;
                    $input['notes']                                     = null;
                }
            }

            // Update Load number base on 'desired_option' added by Dhaval Thakor - 23-12-2022 - Start
            $load_number                                                = null;
            $old_load_number                                            = $load->load_detail->load_number;
            $request_load_number                                        = $formdata['identifier'].$formdata['load_number'];
            if($request_load_number !== $old_load_number){
                if(isset($formdata['carrier_id'])){
                    $carrier                                            = Carrier::find($formdata['carrier_id']);
                    if(!is_null($carrier)){
                        if(trim($carrier->desired_option) != ""){
                            if($carrier->desired_option == "0"){
                                $desired_load_number                    = $carrier->desired_load_number + 1;
                                $carrier->desired_load_number           = $desired_load_number;
                                if($carrier->save()){
                                    if(trim($carrier->identifier) != ""){
                                        $load_number                    .= $carrier->identifier."-";
                                    }
                                    $load_number                        .= $desired_load_number;
                                }
                            }else if($carrier->desired_option == "1"){
                                if(!is_null($formdata['load_number'])){
                                    if(trim($carrier->identifier) != ""){
                                        $load_number                    .= $carrier->identifier."-";
                                    }
                                    $load_number                        .= $formdata['load_number'];
                                }
                            }else{
                                if(!is_null($formdata['load_number'])){
                                    if(trim($formdata['identifier']) != ""){
                                        $load_number                    .= $formdata['identifier'];
                                    }
                                    $load_number                        .= $formdata['load_number'];
                                }
                            }
                        }else{
                            if(!is_null($formdata['load_number'])){
                                if(trim($formdata['identifier']) != ""){
                                    $load_number                        .= $formdata['identifier'];
                                }
                                $load_number                            .= $formdata['load_number'];
                            }
                        }
                    }else{
                        if(!is_null($formdata['load_number'])){
                            if(trim($formdata['identifier']) != ""){
                                $load_number                            .= $formdata['identifier'];
                            }
                            $load_number                                .= $formdata['load_number'];
                        }
                    }
                }else{
                    if(!is_null($formdata['load_number'])){
                        if(trim($formdata['identifier']) != ""){
                            $load_number                                .= $formdata['identifier'];
                        }
                        $load_number                                    .= $formdata['load_number'];
                    }
                }
            }else{
                if(!is_null($formdata['load_number'])){
                    if(trim($formdata['identifier']) != ""){
                        $load_number                                    .= $formdata['identifier'];
                    }
                    $load_number                                        .= $formdata['load_number'];
                }
            }
            $input['load_number']                                       = $load_number;
            // Update Load number base on 'desired_option' added by Dhaval Thakor - 23-12-2022 - End

            $input['booked_by']                                         = $formdata['booked_by'];
            $input['self_dispatch']                                     = $formdata['self_dispatch'] ?? 0;
            if (isset($formdata['self_dispatch'])) {
                $input['booked_by']                                     = 0;
            } elseif (!isset($formdata['self_dispatch']) && !isset($formdata['booked_by'])) {
                $manager                                                = Driver::whereId($formdata['driver_id'])->first();
                if(!is_null($manager)){
                    $input['booked_by']                                 = $manager->manager_id;
                }else{
                    $input['booked_by']                                 = 0;
                }
            }
            $input['load_type']                                         = $formdata['load_type'];
            $input['load_status']                                       = $formdata['load_status'];
            // NEW CODE TO STORE STATUS SORT ORDER - START
            $input['load_status_order']                                 = Common::getLoadStatusOrderById( $formdata['load_status'] );
            // NEW CODE TO STORE STATUS SORT ORDER - END
            $input['is_on_hold']                                        = $formdata['is_on_hold'] ?? 0;
            $input['notification_reason']                               = $load_occupied ? $formdata['notification_reason'] : null;
            $input['reason_on_hold']                                    = $load_occupied ? $formdata['reason_on_hold'] : null;
            if ($input['is_on_hold']=='1') {
                $input['load_on_hold_datetime']                         = Carbon::now()->format('Y-m-d H:i:s');
            }else{
                $input['load_on_hold_datetime']                         = null;
            }

            $input['driver_id']                                         = $formdata['driver_id'];
            if($old_driver_id != $input['driver_id']){
                $input['driver_read_at']                                = null;
            }
            $input['co_driver_id']                                      = $formdata['co_driver_id'] ?? null;
            $input['trucking_company']                                  = $formdata['truck_company'];
            $input['truck_number']                                      = $formdata['truck_number'];
            $input['trailer_number']                                    = $formdata['trailer_number'];
            $input['trailer_type']                                      = $formdata['trailer_type'];
            $input['carrier_id']                                        = $formdata['carrier_id'];
            $input['terminal_id']                                       = $formdata['terminal_id'];

            $driver_oos_pending             = 0;
            $equipment_oos_pending          = 0;
            $input['oos_pending']           = 0;
            if($setting->oos_driver == 3 && $load->load_detail->oos_pending == 0){
                if(checkOosDriver($formdata['driver_id'])){
                    $driver_oos_pending     = 1;
                    $input['oos_pending']   = 1;
                }
            }
            if($setting->oos_equipment == 3 && $load->load_detail->oos_pending == 0){
                if(checkOosTrailer($formdata['trailer_number'])){
                    $equipment_oos_pending  = 1;
                    $input['oos_pending']   = 1;
                }
                if(checkOosTruck($formdata['truck_number'])){
                    $equipment_oos_pending  = 1;
                    $input['oos_pending']   = 1;
                }
            }
            if($driver_oos_pending==1 || $equipment_oos_pending==1){
                if(!empty(getManagerList())){
                    foreach(getManagerList() as $key => $manager){
                        if($driver_oos_pending==1){
                            $description    = 'Load created with OOS Driver - '.$load->id;
                            createNotification(
                                15, // source
                                'OOS Driver', // name
                                $key, // user_id
                                1, // user_type
                                1, // type
                                $load->id, // action_id
                                $description // description
                            );
                        }
                        if($equipment_oos_pending==1){
                            $description    = 'Load created with OOS Equipment - '.$load->id;
                            createNotification(
                                15, // source
                                'OOS Equipment', // name
                                $key, // user_id
                                1, // user_type
                                1, // type
                                $load->id, // action_id
                                $description // description
                            );
                        }
                    }
                }
            }

            if($load_occupied){
                // 0 = OCCUPIED, 6 = TONU

                $input['brokerage_firm']                                = $formdata['brokerage_firm'];
                $input['brokerage_mc']                                  = $formdata['brokerage_mc'];
                $input['terms']                                         = $formdata['terms'];
                $input['rep']                                           = $formdata['rep'];
                $input['phone']                                         = $formdata['phone'];
                $input['broker_email']                                  = $formdata['broker_email'];
                $input['ext']                                           = $formdata['ext'];

                $is_cod                                                 = $formdata['is_cod'] ?? '0';
                $input['is_cod']                                        = $is_cod;
                if($is_cod == '1'){
                    $input['score_ratting']                             = null;
                    $input['score_credit']                              = null;
                    $input['score_updated_at']                          = null;

                    $input['up_front_amount']                           = $formdata['up_front_amount'];
                    $input['up_front_payment_type']                     = $formdata['up_front_payment_type'];
                    $input['up_front_ref_number']                       = $formdata['up_front_ref_number'];
                    $input['up_front_is_paid']                          = $formdata['up_front_is_paid'] ?? '0';

                    $input['at_pickup_amount']                          = $formdata['at_pickup_amount'];
                    $input['at_pickup_payment_type']                    = $formdata['at_pickup_payment_type'];
                    $input['at_pickup_ref_number']                      = $formdata['at_pickup_ref_number'];
                    $input['at_pickup_is_paid']                         = $formdata['at_pickup_is_paid'] ?? '0';

                    $input['at_delivery_amount']                        = $formdata['at_delivery_amount'];
                    $input['at_delivery_payment_type']                  = $formdata['at_delivery_payment_type'];
                    $input['at_delivery_ref_number']                    = $formdata['at_delivery_ref_number'];
                    $input['at_delivery_is_paid']                       = $formdata['at_delivery_is_paid'] ?? '0';
                }else{
                    $input['score_ratting']                             = $formdata['score_ratting'];
                    $input['score_credit']                              = $formdata['score_credit'];
                    $input['score_updated_at']                          = $formdata['score_updated_at'];

                    $input['up_front_amount']                           = null;
                    $input['up_front_payment_type']                     = null;
                    $input['up_front_ref_number']                       = null;
                    $input['up_front_is_paid']                          = '0';

                    $input['at_pickup_amount']                          = null;
                    $input['at_pickup_payment_type']                    = null;
                    $input['at_pickup_ref_number']                      = null;
                    $input['at_pickup_is_paid']                         = '0';

                    $input['at_delivery_amount']                        = null;
                    $input['at_delivery_payment_type']                  = null;
                    $input['at_delivery_ref_number']                    = null;
                    $input['at_delivery_is_paid']                       = '0';

                    $isFileUploaded                                     = Gallery::IsCompany()
                        ->where('action_id', $load->id)
                        ->where('source', 'load')
                        ->whereIn('field_name', ['up_front_file','at_pickup_file','at_delivery_file'])
                        ->get();
                    if($isFileUploaded->isNotEmpty()){
                        foreach ($isFileUploaded as $key => $value) {
                            $path = 'storage/companyAdmin/gallery/'.$value->image;
                            if (File::exists($path)) {
                                File::delete($path);
                            }
                            $value->delete();
                        }
                    }
                }

                $itemize                                                = $formdata['itemize'] ?? 0;
                $input['itemize']                                       = $itemize;
                $input['load_type_2']                                   = $formdata['load_type_2'];
                if($itemize == 0){
                    $input['temp_type']                                 = $formdata['reefer_temp_type'] ?? 0;
                    $input['temp']                                      = $formdata['reefer_temp'];
                    $input['commodity']                                 = $formdata['commodity'];
                    $input['weight']                                    = $formdata['weight'];
                    $input['load_value']                                = $formdata['load_value'];
                    $input['pickup_number']                             = $formdata['pickup_number'];
                }else{
                    $input['temp_type']                                 = 0;
                    $input['temp']                                      = null;
                    $input['commodity']                                 = null;
                    $input['weight']                                    = null;
                    $input['load_value']                                = null;
                    $input['pickup_number']                             = null;
                }
                $input['broker_load_number']                            = $formdata['broker_load_number'];
                $input['bol_number']                                    = $formdata['bol_number'];
                $input['delivery_number']                               = $formdata['delivery_number'];
                $input['po_Number']                                     = $formdata['po_Number'];
                $input['sku_number']                                    = $formdata['sku_number'];

                $other_number                                           = $formdata['other_number'] ?? [];
                $other_number_arry                                      = [];
                if(!empty($other_number)){
                    if(array_key_exists('name', $other_number)){
                        $other_number_names                             = $other_number['name'];
                        foreach ($other_number_names as $key => $value) {
                            $arry                                       = [];
                            $arry['other_name']                         = $value;
                            $arry['other_number']                       = $other_number['number'][$key] ?? null;
                            $other_number_arry[]                        = $arry;
                        }
                    }
                }
                if(!empty($other_number_arry)){
                    $input['other_number']                              = serialize($other_number_arry);
                }else{
                    $input['other_number']                              = null;
                }

                $input['hazardous_load']                                = $formdata['hazardous_load'];
                if($formdata['hazardous_load'] == '1'){
                    $input['hazardous_options']                         = $formdata['hazardous_options'];
                }else{
                    $input['hazardous_options']                         = null;
                }

                $input['occupied_pickup_day']                           = $formdata['occupied_pickup_day'] ?? 0;

                $input['deadhead_mileage_options']                      = null;
                if(isset($formdata['deadhead_mileage_options'])){
                    $deadhead_mileage_options                           = json_decode($formdata['deadhead_mileage_options'], true);
                    if(!empty($deadhead_mileage_options)){
                        // $deadhead_mileage_options['type']            = 0;
                        $input['deadhead_mileage_options']              = json_encode($deadhead_mileage_options);
                    }
                }

                $shipping_time_range                                    = $formdata['shipping_time_range'];

                $input['shipper_id']                                    = $formdata['shipper_id'];
                $input['shipper_address_one']                           = $formdata['shipper_address_one'];
                $input['shipper_address_two']                           = $formdata['shipper_address_two'];
                $input['shipper_state']                                 = $formdata['shipper_state'];
                $input['shipper_city']                                  = $formdata['shipper_city'];
                $input['shipper_zip']                                   = $formdata['shipper_zip'];

                if($formdata['shipper_address_verified']==0){
                    $input['shipper_latitude']                          = null;
                    $input['shipper_longitude']                         = null;
                    $input['shipper_timezone']                          = null;
                    $input['shipper_timezone_offset']                   = null;
                    $input['shipper_timezone_abbr']                     = null;
                    $input['shipper_address_verified']                  = 0;
                }else{
                    $shipper_timezone                                   = null;
                    $shipper_timezone_offset                            = null;
                    if(!is_null($formdata['shipper_timezone_abbr'])){
                        $shipper_timezone                               = timezone_name_from_abbr($formdata['shipper_timezone_abbr']);
                        $shipper_timezone_offset                        = Carbon::createFromTimestamp(time(), $shipper_timezone)->getOffsetString();
                    }
                    $input['shipper_latitude']                          = $formdata['shipper_latitude'];
                    $input['shipper_longitude']                         = $formdata['shipper_longitude'];
                    $input['shipper_timezone']                          = $shipper_timezone;
                    $input['shipper_timezone_offset']                   = $shipper_timezone_offset;
                    $input['shipper_timezone_abbr']                     = $formdata['shipper_timezone_abbr'];
                    $input['shipper_address_verified']                  = 1;
                }

                $input['shipper_note']                                  = $formdata['shipper_note'];

                if($itemize == 1){
                    $input['shipper_commodity']                         = $formdata['shipper_commodity'];
                    $input['shipper_stop_value']                        = $formdata['shipper_stop_value'];
                    $input['shipper_stop_weight']                       = $formdata['shipper_stop_weight'];
                    $input['shipper_reefer_mode']                       = $formdata['shipper_reefer_mode'];
                    $input['shipper_reefer_temp_type']                  = $formdata['shipper_reefer_temp_type'] ?? 0;
                    $input['shipper_reefer_temp']                       = $formdata['shipper_reefer_temp'];
                    $input['shipper_pickup_number']                     = $formdata['shipper_pickup_number'];
                }else{
                    $input['shipper_commodity']                         = null;
                    $input['shipper_stop_value']                        = null;
                    $input['shipper_stop_weight']                       = null;
                    $input['shipper_reefer_mode']                       = null;
                    $input['shipper_reefer_temp_type']                  = 0;
                    $input['shipper_reefer_temp']                       = null;
                    $input['shipper_pickup_number']                     = null;
                }
                if(isset($formdata['shipper_dimension']) && !empty($formdata['shipper_dimension'])){
                    $input['shipper_dimension']                         = serialize($formdata['shipper_dimension']);
                }else{
                    $input['shipper_dimension']                         = null;
                }

                $input['shipper_drop_trailer_schedule']                 = $formdata['shipper_drop_trailer_schedule'] ?? 0;
                if($input['shipper_drop_trailer_schedule'] == 1){
                    $input['shipper_drop_trailer_id']                   = $formdata['shipper_drop_trailer_id'] ?? null;
                    $input['shipper_pickup_trailer_id']                 = null;
                } else if($input['shipper_drop_trailer_schedule'] == 2){
                    $input['shipper_drop_trailer_id']                   = $formdata['shipper_drop_trailer_id'] ?? null;
                    $input['shipper_pickup_trailer_id']                 = $formdata['shipper_pickup_trailer_id'] ?? null; // isset($formdata['shipper_pickup_trailer_id']) ? str_replace('TRAILERDROP', '', $formdata['shipper_pickup_trailer_id']) : null;
                } else{
                    $input['shipper_drop_trailer_id']                   = null;
                    $input['shipper_pickup_trailer_id']                 = null;
                }

                $shipper_files                                          = $formdata['shipper_files'] ?? [];
                if(!empty($shipper_files)){
                    $shipper_files_array                                = [];
                    if (array_key_exists('name_id', $shipper_files)) {
                        $shipper_files_name_ids                         = array_filter($shipper_files['name_id'], function ($var) {
                            return $var !== null && $var !== '';
                        });
                        if(!empty($shipper_files_name_ids)){
                            foreach($shipper_files_name_ids as $sfkey => $shipper_files_name_id){
                                $arry                                   = [];
                                $arry['name_id']                        = $shipper_files_name_id;
                                $arry['name']                           = isset($shipper_files['name'][$sfkey]) ? $shipper_files['name'][$sfkey] : '';
                                $arry['is_required']                    = isset($shipper_files['is_required'][$sfkey]) ? $shipper_files['is_required'][$sfkey] : 'off';
                                $arry['type']                           = $shipper_files['type'][$sfkey];
                                $arry['fixed']                          = $shipper_files['fixed'][$sfkey];
                                $arry['include_w_billing']              = isset($shipper_files['include_w_billing'][$sfkey]) && $shipper_files['include_w_billing'][$sfkey]=='yes' ? 'yes' : 'no';
                                $arry['custom']                         = isset($shipper_files['custom'][$sfkey]) && $shipper_files['custom'][$sfkey]=='yes' ? 'yes' : 'no';
                                $shipper_files_array[]                  = $arry;
                            }
                        }
                    }
                    if(!empty($shipper_files_array)){
                        $input['shipper_files']                         = serialize($shipper_files_array);
                    }else{
                        $input['shipper_files']                         = null;
                    }
                }else{
                    $input['shipper_files']                             = null;
                }

                $shipper_files_upload                                   = $formdata['shipper_files_upload'] ?? [];
                if(!empty($shipper_files_upload)){
                    $shipper_files_upload_array                         = [];
                    if (array_key_exists('name_id', $shipper_files_upload)) {
                        $shipper_files_upload_name_ids                  = array_filter($shipper_files_upload['name_id'], function ($var) {
                            return $var !== null && $var !== '';
                        });
                        if(!empty($shipper_files_upload_name_ids)){
                            foreach($shipper_files_upload_name_ids as $sfkey => $shipper_files_upload_name_id){
                                $arry                                   = [];
                                $arry['name_id']                        = $shipper_files_upload_name_id;
                                $arry['name']                           = isset($shipper_files_upload['name'][$sfkey]) ? $shipper_files_upload['name'][$sfkey] : '';
                                $arry['is_required']                    = isset($shipper_files_upload['is_required'][$sfkey]) ? $shipper_files_upload['is_required'][$sfkey] : 'off';
                                $arry['type']                           = $shipper_files_upload['type'][$sfkey];
                                $arry['fixed']                          = $shipper_files_upload['fixed'][$sfkey];
                                $arry['include_w_billing']              = isset($shipper_files_upload['include_w_billing'][$sfkey]) && $shipper_files_upload['include_w_billing'][$sfkey]=='yes' ? 'yes' : 'no';
                                $arry['custom']                         = isset($shipper_files_upload['custom'][$sfkey]) && $shipper_files_upload['custom'][$sfkey]=='yes' ? 'yes' : 'no';

                                $arry['is_received']                    = isset($shipper_files_upload['is_received'][$sfkey]) ? $shipper_files_upload['is_received'][$sfkey] : 'off';
                                $arry['hide_from_driver']               = isset($shipper_files_upload['hide_from_driver'][$sfkey]) && $shipper_files_upload['hide_from_driver'][$sfkey]=='yes' ? 'yes' : 'no';
                                $arry['file_not_provided']              = isset($shipper_files_upload['file_not_provided'][$sfkey]) ? $shipper_files_upload['file_not_provided'][$sfkey] : 'off';
                                if(isset($shipper_files_upload['file'][$sfkey])){
                                    $arry['is_received']                = 'on';
                                    $arry['file']                       = UploadImagePdf($shipper_files_upload['file'][$sfkey], 'companyAdmin/load_detail_document');
                                    $arry['upload_user_type']           = auth()->guard('company-admin')->user()->type;
                                    $arry['upload_by']                  = auth()->guard('company-admin')->user()->id;
                                    $arry['uploaded_at']                = Carbon::now();
                                }else{
                                    if(isset($shipper_files_upload['file_exists'][$sfkey])){
                                        $arry['is_received']            = 'on';
                                        $arry['file']                   = $shipper_files_upload['file_exists'][$sfkey];
                                        $arry['upload_user_type']       = $shipper_files_upload['upload_user_type'][$sfkey];
                                        $arry['upload_by']              = $shipper_files_upload['upload_by'][$sfkey];
                                        $arry['uploaded_at']            = $shipper_files_upload['uploaded_at'][$sfkey];
                                    }else{
                                        $arry['file']                   = null;
                                    }
                                }
                                if($arry['type'] == 2){
                                    if(isset($shipper_files_upload['old_is_received'][$sfkey]) && $shipper_files_upload['old_is_received'][$sfkey] == 'on'){
                                        if($arry['is_received'] == 'on'){
                                            $arry['upload_user_type']   = $shipper_files_upload['upload_user_type'][$sfkey] ?? auth()->guard('company-admin')->user()->type;
                                            $arry['upload_by']          = $shipper_files_upload['upload_by'][$sfkey] ?? auth()->guard('company-admin')->user()->id;
                                            $arry['uploaded_at']        = $shipper_files_upload['uploaded_at'][$sfkey] ?? Carbon::now();
                                        }
                                    }else{
                                        if($arry['is_received'] == 'on'){
                                            $arry['upload_user_type']   = auth()->guard('company-admin')->user()->type;
                                            $arry['upload_by']          = auth()->guard('company-admin')->user()->id;
                                            $arry['uploaded_at']        = Carbon::now();
                                        }
                                    }
                                }
                                $shipper_files_upload_array[]           = $arry;
                            }
                        }
                    }
                    if(!empty($shipper_files_upload_array)){
                        $input['shipper_files_upload']                  = serialize($shipper_files_upload_array);
                    }else{
                        $input['shipper_files_upload']                  = null;
                    }
                }else{
                    $input['shipper_files_upload']                      = null;
                }

                $delivery_time_range                                    = $formdata['delivery_time_range'];

                $input['receiver_id']                                   = $formdata['receiver_id'];
                $input['delivery_address_one']                          = $formdata['delivery_address_one'];
                $input['delivery_address_two']                          = $formdata['delivery_address_two'];
                $input['delivery_state']                                = $formdata['delivery_state'];
                $input['delivery_city']                                 = $formdata['delivery_city'];
                $input['delivery_zip']                                  = $formdata['delivery_zip'];

                if($formdata['delivery_address_verified']==0){
                    $input['delivery_latitude']                         = null;
                    $input['delivery_longitude']                        = null;
                    $input['delivery_timezone']                         = null;
                    $input['delivery_timezone_offset']                  = null;
                    $input['delivery_timezone_abbr']                    = null;
                    $input['delivery_address_verified']                 = 0;
                }else{
                    $delivery_timezone                                  = null;
                    $delivery_timezone_offset                           = null;
                    if(!is_null($formdata['delivery_timezone_abbr'])){
                        $delivery_timezone                              = timezone_name_from_abbr($formdata['delivery_timezone_abbr']);
                        $delivery_timezone_offset                       = Carbon::createFromTimestamp(time(), $delivery_timezone)->getOffsetString();
                    }
                    $input['delivery_latitude']                         = $formdata['delivery_latitude'];
                    $input['delivery_longitude']                        = $formdata['delivery_longitude'];
                    $input['delivery_timezone']                         = $delivery_timezone;
                    $input['delivery_timezone_offset']                  = $delivery_timezone_offset;
                    $input['delivery_timezone_abbr']                    = $formdata['delivery_timezone_abbr'];
                    $input['delivery_address_verified']                 = 1;
                }

                $input['delivery_note']                                 = $formdata['delivery_note'];

                if($itemize == 1){
                    $input['delivery_commodity']                        = $formdata['delivery_commodity'];
                    $input['delivery_stop_value']                       = $formdata['delivery_stop_value'];
                    $input['delivery_stop_weight']                      = $formdata['delivery_stop_weight'];
                    $input['delivery_reefer_mode']                      = $formdata['delivery_reefer_mode'];
                    $input['delivery_reefer_temp_type']                 = $formdata['delivery_reefer_temp_type'] ?? 0;
                    $input['delivery_reefer_temp']                      = $formdata['delivery_reefer_temp'];
                    $input['delivery_pickup_number']                    = $formdata['delivery_pickup_number'];
                }else{
                    $input['delivery_commodity']                        = null;
                    $input['delivery_stop_value']                       = null;
                    $input['delivery_stop_weight']                      = null;
                    $input['delivery_reefer_mode']                      = null;
                    $input['delivery_reefer_temp_type']                 = 0;
                    $input['delivery_reefer_temp']                      = null;
                    $input['delivery_pickup_number']                    = null;
                }
                if(isset($formdata['delivery_dimension']) && !empty($formdata['delivery_dimension'])){
                    $input['delivery_dimension']                        = serialize($formdata['delivery_dimension']);
                }else{
                    $input['delivery_dimension']                        = null;
                }

                $input['delivery_drop_trailer_schedule']                = $formdata['delivery_drop_trailer_schedule'] ?? 0;
                if($input['delivery_drop_trailer_schedule'] == 1){
                    $input['delivery_drop_trailer_id']                  = $formdata['delivery_drop_trailer_id'] ?? null;
                    $input['delivery_pickup_trailer_id']                = null;
                } else if($input['delivery_drop_trailer_schedule'] == 2){
                    $input['delivery_drop_trailer_id']                  = $formdata['delivery_drop_trailer_id'] ?? null;
                    $input['delivery_pickup_trailer_id']                = $formdata['delivery_pickup_trailer_id'] ?? null; // isset($formdata['delivery_pickup_trailer_id']) ? str_replace('TRAILERDROP', '', $formdata['delivery_pickup_trailer_id']) : null;
                } else{
                    $input['delivery_drop_trailer_id']                  = null;
                    $input['delivery_pickup_trailer_id']                = null;
                }

                $consignee_files                                        = $formdata['consignee_files'] ?? [];
                if(!empty($consignee_files)){
                    $consignee_files_array                              = [];
                    if (array_key_exists('name_id', $consignee_files)) {
                        $consignee_files_name_ids                       = array_filter($consignee_files['name_id'], function ($var) {
                            return $var !== null && $var !== '';
                        });
                        if(!empty($consignee_files_name_ids)){
                            foreach($consignee_files_name_ids as $cfkey => $consignee_files_name_id){
                                $arry                                   = [];
                                $arry['name_id']                        = $consignee_files_name_id;
                                $arry['name']                           = isset($consignee_files['name'][$cfkey]) ? $consignee_files['name'][$cfkey] : '';
                                $arry['is_required']                    = isset($consignee_files['is_required'][$cfkey]) ? $consignee_files['is_required'][$cfkey] : 'off';
                                $arry['type']                           = $consignee_files['type'][$cfkey];
                                $arry['fixed']                          = $consignee_files['fixed'][$cfkey];
                                $arry['include_w_billing']              = isset($consignee_files['include_w_billing'][$cfkey]) && $consignee_files['include_w_billing'][$cfkey]=='yes' ? 'yes' : 'no';
                                $arry['custom']                         = isset($consignee_files['custom'][$cfkey]) && $consignee_files['custom'][$cfkey]=='yes' ? 'yes' : 'no';
                                $consignee_files_array[]                = $arry;
                            }
                        }
                    }
                    if(!empty($consignee_files_array)){
                        $input['consignee_files']                       = serialize($consignee_files_array);
                    }else{
                        $input['consignee_files']                       = null;
                    }
                }else{
                    $input['consignee_files']                           = null;
                }

                $consignee_files_upload                                 = $formdata['consignee_files_upload'] ?? [];
                if(!empty($consignee_files_upload)){
                    $consignee_files_upload_array                       = [];
                    if (array_key_exists('name_id', $consignee_files_upload)) {
                        $consignee_files_upload_name_ids                = array_filter($consignee_files_upload['name_id'], function ($var) {
                            return $var !== null && $var !== '';
                        });
                        if(!empty($consignee_files_upload_name_ids)){
                            foreach($consignee_files_upload_name_ids as $cfkey => $consignee_files_upload_name_id){
                                $arry                                   = [];
                                $arry['name_id']                        = $consignee_files_upload_name_id;
                                $arry['name']                           = isset($consignee_files_upload['name'][$cfkey]) ? $consignee_files_upload['name'][$cfkey] : '';
                                $arry['is_required']                    = isset($consignee_files_upload['is_required'][$cfkey]) ? $consignee_files_upload['is_required'][$cfkey] : 'off';
                                $arry['type']                           = $consignee_files_upload['type'][$cfkey];
                                $arry['fixed']                          = $consignee_files_upload['fixed'][$cfkey];
                                $arry['include_w_billing']              = isset($consignee_files_upload['include_w_billing'][$cfkey]) && $consignee_files_upload['include_w_billing'][$cfkey]=='yes' ? 'yes' : 'no';
                                $arry['custom']                         = isset($consignee_files_upload['custom'][$cfkey]) && $consignee_files_upload['custom'][$cfkey]=='yes' ? 'yes' : 'no';

                                $arry['is_received']                    = isset($consignee_files_upload['is_received'][$cfkey]) ? $consignee_files_upload['is_received'][$cfkey] : 'off';
                                $arry['hide_from_driver']               = isset($consignee_files_upload['hide_from_driver'][$cfkey]) && $consignee_files_upload['hide_from_driver'][$cfkey]=='yes' ? 'yes' : 'no';
                                $arry['file_not_provided']              = isset($consignee_files_upload['file_not_provided'][$cfkey]) ? $consignee_files_upload['file_not_provided'][$cfkey] : 'off';
                                if(isset($consignee_files_upload['file'][$cfkey])){
                                    $arry['is_received']                = 'on';
                                    $arry['file']                       = UploadImagePdf($consignee_files_upload['file'][$cfkey], 'companyAdmin/load_detail_document');
                                    $arry['upload_user_type']           = auth()->guard('company-admin')->user()->type;
                                    $arry['upload_by']                  = auth()->guard('company-admin')->user()->id;
                                    $arry['uploaded_at']                = Carbon::now();
                                }else{
                                    if(isset($consignee_files_upload['file_exists'][$cfkey])){
                                        $arry['is_received']            = 'on';
                                        $arry['file']                   = $consignee_files_upload['file_exists'][$cfkey];
                                        $arry['upload_user_type']       = $consignee_files_upload['upload_user_type'][$cfkey];
                                        $arry['upload_by']              = $consignee_files_upload['upload_by'][$cfkey];
                                        $arry['uploaded_at']            = $consignee_files_upload['uploaded_at'][$cfkey];
                                    }else{
                                        $arry['file']                   = null;
                                    }
                                }
                                if($arry['type'] == 2){
                                    if(isset($consignee_files_upload['old_is_received'][$cfkey]) && $consignee_files_upload['old_is_received'][$cfkey] == 'on'){
                                        if($arry['is_received'] == 'on'){
                                            $arry['upload_user_type']   = $consignee_files_upload['upload_user_type'][$cfkey] ?? auth()->guard('company-admin')->user()->type;
                                            $arry['upload_by']          = $consignee_files_upload['upload_by'][$cfkey] ?? auth()->guard('company-admin')->user()->id;
                                            $arry['uploaded_at']        = $consignee_files_upload['uploaded_at'][$cfkey] ?? Carbon::now();
                                        }
                                    }else{
                                        if($arry['is_received'] == 'on'){
                                            $arry['upload_user_type']   = auth()->guard('company-admin')->user()->type;
                                            $arry['upload_by']          = auth()->guard('company-admin')->user()->id;
                                            $arry['uploaded_at']        = Carbon::now();
                                        }
                                    }
                                }
                                $consignee_files_upload_array[]         = $arry;
                            }
                        }
                    }
                    if(!empty($consignee_files_upload_array)){
                        $input['consignee_files_upload']                = serialize($consignee_files_upload_array);
                    }else{
                        $input['consignee_files_upload']                = null;
                    }
                }else{
                    $input['consignee_files_upload']                    = null;
                }

                $input['empty_miles']                                   = $formdata['empty_miles'];
                $input['loaded_miles']                                  = $formdata['loaded_miles'];
                $input['total_miles']                                   = $formdata['total_miles'];
                $input['agreed_upon_rate']                              = $formdata['agreed_upon_rate'];
                $input['fuel_surcharge_cost_per_mile']                  = $formdata['fuel_surcharge_cost_per_mile'];
                $input['fuel_surcharge']                                = $formdata['fuel_surcharge'];
                $input['line_haul']                                     = $formdata['line_haul'];

                $input['total_bill']                                    = $formdata['total_bill'];
                $driver_revenue                                         = 0;
                if(isset($formdata['total_bill']) && $formdata['total_bill'] > 0){
                    $driver_revenue                                     += (float) str_replace(',', '', $formdata['total_bill']);
                }
                // if(isset($formdata['lumper']) && $formdata['lumper'] > 0){
                //     $driver_revenue                                  -= $formdata['lumper'];
                // }
                $input['driver_revenue']                                = $driver_revenue;

                $input['map_toll_roads']                                = $formdata['map_toll_roads'];
                $input['map_max_elevation']                             = $formdata['map_max_elevation'];
                $input['map_close_borders']                             = $formdata['map_close_borders'];
                $input['load_trip_id']                                  = $formdata['load_trip_id'];
                $input['load_tms_trip_id']                              = $formdata['load_tms_trip_id'];
            }else{
                // 1 = MAINTENANCE, 2 = UNAUTHORIZED, 3 = HOS, 4 = NO DISPATCH, 5 = TIME OFF
                $input['start_date']                                    = date('Y-m-d', strtotime($formdata['start_date']));
                $input['end_date']                                      = date('Y-m-d', strtotime($formdata['end_date']));

                $shipping_time_range                                    = 0;
                $delivery_time_range                                    = 0;

                //
                $formdata['shipper_date_time']                          = Carbon::parse(date('Y-m-d h:i A', strtotime($input['start_date'])))->format(getTimeLayout());
                // $formdata['shipper_date_time_end']                   = null;

                $formdata['intransit_driver_acknowledgement']           = 0;
                $formdata['intransit_shipping_information']             = 0;
                $formdata['intransit_date_time']                        = Carbon::parse(date('Y-m-d h:i A', strtotime($input['start_date'])))->format(getTimeLayout());

                $formdata['delivery_date_time']                         = Carbon::parse(date('Y-m-d h:i A', strtotime($input['end_date'].' 12:00 PM')))->format(getTimeLayout());
                // $formdata['delivery_date_time_end']                  = null;

                $formdata['delivered_driver_acknowledgement']           = 0;
                $formdata['delivered_delivery_information']             = 0;
                $formdata['delivered_date_time']                        = Carbon::parse(date('Y-m-d h:i A', strtotime($input['end_date'].' 12:00 PM')))->format(getTimeLayout());
                //

                $input['notes']                                         = $formdata['notes'];
            }

            $input['shipping_time_range']                               = $shipping_time_range;
            $input['shipper_date_time']                                 = $formdata['shipper_date_time'];
            if ($shipping_time_range == 0) {
                $input['shipper_date_time_end']                         = null;
            } else {
                $input['shipper_date_time_end']                         = $formdata['shipper_date_time_end'];
            }

            if (!is_null($input['shipper_date_time_end'])) {
                $input['actual_shipper_date']                           = !is_null($input['shipper_date_time_end']) ? Carbon::createFromFormat(getTimeLayout(),$input['shipper_date_time_end'])->format('Y-m-d H:i:s') : null;
            } else {
                $input['actual_shipper_date']                           = !is_null($input['shipper_date_time']) ? Carbon::createFromFormat(getTimeLayout(),$input['shipper_date_time'])->format('Y-m-d H:i:s') : null;
            }

            $input['delivery_time_range']                               = $delivery_time_range;
            $input['delivery_date_time']                                = $formdata['delivery_date_time'];
            if ($delivery_time_range == 0) {
                $input['delivery_date_time_end']                        = null;
            } else {
                $input['delivery_date_time_end']                        = $formdata['delivery_date_time_end'];
            }

            if (!is_null($input['delivery_date_time_end'])) {
                $input['actual_delivery_date']                          = !is_null($input['delivery_date_time_end']) ? Carbon::createFromFormat(getTimeLayout(),$input['delivery_date_time_end'])->format('Y-m-d H:i:s') : null;
            } else {
                $input['actual_delivery_date']                          = !is_null($input['delivery_date_time']) ? Carbon::createFromFormat(getTimeLayout(),$input['delivery_date_time'])->format('Y-m-d H:i:s') : null;
            }

            $input['send_notification']                                 = $formdata['send_notification'] ?? 0;
            $input['preplaned_driver_acknowledgement']                  = $formdata['preplaned_driver_acknowledgement'] ?? 0;
            $input['sent_to_driver']                                    = $formdata['sent_to_driver'] ?? 0;
            $input['default_current_time']                              = $formdata['default_current_time'];

            $input['confirmed_driver_acknowledgement']                  = $formdata['confirmed_driver_acknowledgement'] ?? 0;

            $input['intransit_driver_acknowledgement']                  = $formdata['intransit_driver_acknowledgement'] ?? 0;
            $input['intransit_shipping_information']                    = $formdata['intransit_shipping_information'] ?? 0;
            $input['intransit_date_time']                               = $formdata['intransit_date_time'];
            if(in_array($input['load_status'], [4,5,6,10,8])){
                if(!empty($input['intransit_date_time'])){
                    $input['actual_shipper_date']                       = !is_null($input['intransit_date_time']) ? Carbon::createFromFormat(getTimeLayout(),$input['intransit_date_time'])->format('Y-m-d H:i:s') : null;
                }else{
                    if($input['intransit_shipping_information'] == 0){
                        $input['actual_shipper_date']                   = !is_null($input['shipper_date_time']) ? Carbon::createFromFormat(getTimeLayout(),$input['shipper_date_time'])->format('Y-m-d H:i:s') : null;
                    }elseif($input['intransit_shipping_information'] == 1){
                        $input['actual_shipper_date']                   = Carbon::now()->format('Y-m-d H:i:s');
                    }else{
                        $input['actual_shipper_date']                   = Carbon::now()->format('Y-m-d H:i:s');
                    }
                }
            }else{
                $input['intransit_shipping_information']                = 0;
                $input['intransit_date_time']                           = null;
            }

            $input['delivered_driver_acknowledgement']                  = $formdata['delivered_driver_acknowledgement'] ?? 0;
            $input['delivered_delivery_information']                    = $formdata['delivered_delivery_information'] ?? 0;
            $input['delivered_date_time']                               = $formdata['delivered_date_time'];
            if(in_array($input['load_status'], [5,6,10,8])){
                if(!empty($input['delivered_date_time'])){
                    $input['actual_delivery_date']                      = !is_null($input['delivered_date_time']) ? Carbon::createFromFormat(getTimeLayout(),$input['delivered_date_time'])->format('Y-m-d H:i:s') : null;
                }else{
                    if($input['delivered_delivery_information'] == 0){
                        $input['actual_delivery_date']                  = !is_null($input['delivery_date_time']) ? Carbon::createFromFormat(getTimeLayout(),$input['delivery_date_time'])->format('Y-m-d H:i:s') : null;
                    }elseif($input['delivered_delivery_information'] == 1){
                        $input['actual_delivery_date']                  = Carbon::now()->format('Y-m-d H:i:s');
                    }else{
                        $input['actual_delivery_date']                  = Carbon::now()->format('Y-m-d H:i:s');
                    }
                }
            }else{
                $input['delivered_delivery_information']                = 0;
                $input['delivered_date_time']                           = null;
            }

            if (isset($formdata['setcustomdateshipping']) && !empty($formdata['setcustomdateshipping'])) {
                if(in_array($input['load_status'], [6,10,8])){
                    if($input['shipping_time_range'] == 1){
                        $input['shipper_date_time_end']                 = Carbon::createFromFormat(getTimeLayout(), $formdata['setcustomdateshipping'])->format('Y-m-d H:i:s');
                        $input['actual_shipper_date']                   = Carbon::createFromFormat(getTimeLayout(), $formdata['setcustomdateshipping'])->format('Y-m-d H:i:s');
                    }else{
                        $input['shipper_date_time']                     = Carbon::createFromFormat(getTimeLayout(), $formdata['setcustomdateshipping'])->format('Y-m-d H:i:s');
                        $input['actual_shipper_date']                   = Carbon::createFromFormat(getTimeLayout(), $formdata['setcustomdateshipping'])->format('Y-m-d H:i:s');
                    }
                }
            }

            if (isset($formdata['setcustomdatedelivery']) && !empty($formdata['setcustomdatedelivery'])) {
                if(in_array($input['load_status'], [6,10,8])){
                    if($input['delivery_time_range'] == 1){
                        $input['delivery_date_time_end']                = Carbon::createFromFormat(getTimeLayout(), $formdata['setcustomdatedelivery'])->format('Y-m-d H:i:s');
                        $input['actual_delivery_date']                  = Carbon::createFromFormat(getTimeLayout(), $formdata['setcustomdatedelivery'])->format('Y-m-d H:i:s');
                    }else{
                        $input['delivery_date_time']                    = Carbon::createFromFormat(getTimeLayout(), $formdata['setcustomdatedelivery'])->format('Y-m-d H:i:s');
                        $input['actual_delivery_date']                  = Carbon::createFromFormat(getTimeLayout(), $formdata['setcustomdatedelivery'])->format('Y-m-d H:i:s');
                    }
                }
            }
            $input['overdimensional']                                   = $formdata['overdimensional'];

            $input['updated_at']                                        = Carbon::now()->format('Y-m-d H:i:s');

            $oldData                                                    = LoadDetail::where('load_id', $load->id)->latest()->first()->toArray();
            $loadDetail                                                 = $load->load_detail->update($input);
            $this->setLoadAudit($load->id, 'update', 'Load detail updated', $load->load_detail->getChanges(), $oldData);
            if($loadDetail){
                createLoadLog($load->load_detail->getChanges(), $load->load_detail, 'edit');

                // if inside true pass that reson redeclare - ohk
                $loadDetail                                             = $load->load_detail;

                // some case reset value
                if($load_occupied !== $old_load_occupied){
                    if($old_load_occupied){
                        // 0 = OCCUPIED, 6 = TONU
                        // set blank occupied field
                        $this->convertUnoccupiedLoad($load);
                    }else{
                        // 1 = MAINTENANCE, 2 = UNAUTHORIZED, 3 = HOS, 4 = NO DISPATCH, 5 = TIME OFF
                        // set blank unoccupied field
                    }
                }

                //
                $addtrauier                                             = isset($formdata['addtrauier'])?$formdata['addtrauier']:[];

                $addtrauier_old_id                                      = array_column($addtrauier, 'old_id');
                $addtrauier_remove_query                                = LoadTrailer::where('load_id', $load->id);
                if(!empty($addtrauier_old_id)){
                    $addtrauier_remove_query->whereNotIn('id', $addtrauier_old_id);
                }
                $addtrauier_remove_query_result                         = $addtrauier_remove_query->get();

                if(!empty($addtrauier)){
                    foreach ($addtrauier as $key => $value) {
                        if(isset($value['old_id']) && $value['old_id']!=''){
                            $load_trailer                               = LoadTrailer::where('id', '=', $value['old_id'])->first();
                            if(!is_null($load_trailer)){
                                $oldData                                = [];
                                $oldData                                = $load_trailer->toArray();

                                $oldDataupdate                          = [];
                                $oldDataupdate['trailer_number']        = $oldData['trailer_number'] ?? null;
                                $oldDataupdate['trailer_type']          = isset($oldData['trailer_type']) ? getTrailerTypeList()[$oldData['trailer_type']] : 'none' ;

                                $load_trailer->trailer_number           = $value['trailer_number'];
                                $load_trailer->trailer_type             = $value['trailer_type'];
                                if($load_trailer->save()){
                                    $this->setLoadAudit($load->id, 'update', 'Load trailer updated', $load_trailer->getChanges(), $oldDataupdate);
                                }
                            }else{
                                $load_trailer                           = [];
                                $load_trailer['company_id']             = auth()->guard('company-admin')->user()->company_id;
                                $load_trailer['load_id']                = $load->id;
                                $load_trailer['trailer_number']         = $value['trailer_number'];
                                $load_trailer['trailer_type']           = $value['trailer_type'];
                                LoadTrailer::create($load_trailer);
                            }
                        }else{
                            $load_trailer                               = [];
                            $load_trailer['company_id']                 = auth()->guard('company-admin')->user()->company_id;
                            $load_trailer['load_id']                    = $load->id;
                            $load_trailer['trailer_number']             = $value['trailer_number'];
                            $load_trailer['trailer_type']               = $value['trailer_type'];
                            LoadTrailer::create($load_trailer);
                        }
                    }
                }

                if($addtrauier_remove_query_result->count() > 0){
                    foreach ($addtrauier_remove_query_result as $remove) {
                        if($remove->delete()){
                            $oldData                                    = [];
                            $oldData                                    = $remove->toArray();

                            $oldDataupdate                              = [];
                            $oldDataupdate['trailer_number']            = $oldData['trailer_number'] ?? null;
                            $oldDataupdate['trailer_type']              = isset($oldData['trailer_type']) ? getTrailerTypeList()[$oldData['trailer_type']] : 'none' ;
                            $oldDataupdate['deleted_at']                = null;

                            $changeData                                 = [];
                            $changeData                                 = $oldDataupdate;
                            $changeData['deleted_at']                   = Carbon::now();
                            $this->setLoadAudit($load->id, 'delete', 'Load requirements deleted', $changeData, $oldDataupdate);
                        }
                    }
                }

                $trailerOther                                           = isset($formdata['trailerOther'])?$formdata['trailerOther']:[];
                if(!empty($trailerOther)){
                    foreach($trailerOther as $value){
                        if($value['trailer_number'] != "" && $value['trailer_type'] != ""){
                            $load_trailer                               = [];
                            $load_trailer['company_id']                 = auth()->guard('company-admin')->user()->company_id;
                            $load_trailer['load_id']                    = $load->id;
                            $load_trailer['trailer_number']             = $value['trailer_number'];
                            $load_trailer['trailer_type']               = $value['trailer_type'];
                            LoadTrailer::create($load_trailer);
                        }
                    }
                }

                if($load_occupied){
                    // 0 = OCCUPIED, 6 = TONU
                    if($old_brokerage_firm!=$load->load_detail->brokerage_firm){
                        if(isset($loadDetail->load_document_request_items) && $loadDetail->load_document_request_items->isNotEmpty()){
                            foreach ($loadDetail->load_document_request_items as $key => $remove) {
                                $remove->makeHidden(['laravel_through_key']);
                                $oldData                                            = [];
                                $oldData                                            = $remove->toArray();

                                $remove->deleted_by                                 = auth()->guard('company-admin')->user()->id;
                                $remove->deleted_by_type                            = auth()->guard('company-admin')->user()->type;
                                if($remove->save()){
                                    if($remove->delete()){
                                        $remove->makeHidden(['laravel_through_key']);
                                        $this->setLoadAudit($load->id, 'delete', 'Load document request item deleted', $remove->toArray(), $oldData);
                                    }
                                }
                            }
                        }
                        if(isset($loadDetail->load_document_request)){
                            $load_document_request                                  = $loadDetail->load_document_request;

                            $oldData                                                = [];
                            $oldData                                                = $load_document_request->toArray();

                            $load_document_request->deleted_by                      = auth()->guard('company-admin')->user()->id;
                            $load_document_request->deleted_by_type                 = auth()->guard('company-admin')->user()->type;
                            if($load_document_request->save()){
                                if($load_document_request->delete()){
                                    $this->setLoadAudit($load->id, 'delete', 'Load document request deleted', $load_document_request->toArray(), $oldData);
                                }
                            }
                        }
                        if(isset($loadDetail->load_appointments) && $loadDetail->load_appointments->isNotEmpty()){
                            foreach ($loadDetail->load_appointments as $key => $load_appointment) {
                                $oldData                                            = [];
                                $oldData                                            = $load_appointment->toArray();
                                if($load_appointment->delete()){
                                    $this->setLoadAudit($load->id, 'delete', 'Load appointment deleted', $load_appointment->toArray(), $oldData);
                                }
                            }
                        }
                    }

                    if($loadDetail->shipping_time_range == 0){
                        $shipper_appointment                                        = $formdata['shipper_appointment'];
                        if(!is_null($shipper_appointment)){
                            $shipper_appointment                                    = json_decode($shipper_appointment, true);
                            if(!empty($shipper_appointment)){
                                $appointment                                        = [];
                                $appointment['broker_id']                           = $shipper_appointment['req_brokerage_id'];
                                $appointment['customer_id']                         = $shipper_appointment['req_customer_id'];
                                $appointment['load_detail_id']                      = $loadDetail->id;
                                $appointment['type']                                = 1;
                                $appointment['is_stop']                             = 0;

                                $appointment['request_date']                        = date('Y-m-d', strtotime($shipper_appointment['req_date']));
                                $appointment['request_time']                        = date('H:i:s', strtotime($shipper_appointment['req_time']));

                                $emails                                             = [];
                                $appointment_emails                                 = $shipper_appointment['req_email[]'] ?? null;
                                if (is_array($appointment_emails)) {
                                    foreach ($appointment_emails as $key => $appointment_email) {
                                        $appointment_email_array                    = explode('|', $appointment_email);
                                        $emails[]                                   = [
                                            'table'                                 => $appointment_email_array[0],
                                            'field_name'                            => $appointment_email_array[1],
                                            'email'                                 => $appointment_email_array[2]
                                        ];
                                    }
                                }else{
                                    if(!is_null($appointment_emails)){
                                        $appointment_email_array                    = explode('|', $appointment_emails);
                                        $emails[]                                   = [
                                            'table'                                 => $appointment_email_array[0],
                                            'field_name'                            => $appointment_email_array[1],
                                            'email'                                 => $appointment_email_array[2]
                                        ];
                                    }
                                }
                                $appointment['emails']                              = !empty($emails) ? serialize($emails) : null;

                                $phones                                             = [];
                                $appointment_phones                                 = $shipper_appointment['req_phone[]'] ?? null;
                                if (is_array($appointment_phones)) {
                                    foreach ($appointment_phones as $key => $appointment_phone) {
                                        $appointment_phone_array                    = explode('|', $appointment_phone);
                                        $phones[]                                   = [
                                            'table'                                 => $appointment_phone_array[0],
                                            'field_name'                            => $appointment_phone_array[1],
                                            'phone'                                 => $appointment_phone_array[2]
                                        ];
                                    }
                                }else{
                                    if(!is_null($appointment_phones)){
                                        $appointment_phone_array                    = explode('|', $appointment_phones);
                                        $phones[]                                   = [
                                            'table'                                 => $appointment_phone_array[0],
                                            'field_name'                            => $appointment_phone_array[1],
                                            'phone'                                 => $appointment_phone_array[2]
                                        ];
                                    }
                                }
                                $appointment['phones']                              = !empty($phones) ? serialize($phones) : null;

                                $confirmation_numbers                               = $shipper_appointment['req_confirmation_number[]'] ?? null;
                                if (is_array($confirmation_numbers)) {
                                    $confirmation_numbers                           = !empty($confirmation_numbers) ? implode(', ', $confirmation_numbers) : null;
                                }
                                $appointment['confirmation_numbers']                = $confirmation_numbers;

                                $reminder_on                                        = $shipper_appointment['req_reminder_on[]'] ?? null;
                                if (is_array($reminder_on)) {
                                    $reminder_on                                    = !empty($reminder_on) ? implode(',', $reminder_on) : null;
                                }
                                $appointment['reminder_on']                         = $reminder_on;
                                $appointment['reminder_type']                       = $shipper_appointment['req_reminder_type'] ?? null;
                                if($appointment['reminder_type']=='Custom'){
                                    $appointment['reminder_repeat_every']           = $shipper_appointment['req_reminder_repeat_every'] ?? 0;
                                    $appointment['reminder_custom_hours']           = $shipper_appointment['req_reminder_custom_hours'];
                                }
                                $appointment['reminder_status']                     = $shipper_appointment['req_reminder_status'] ?? 0;

                                $appointment['status']                              = 0;
                                $appointment['status_at']                           = Carbon::now()->format('Y-m-d H:i:s');
                                $appointment['created_at']                          = Carbon::now()->format('Y-m-d H:i:s');
                                $load_appointment                                   = LoadAppointment::create($appointment);
                                if($load_appointment){
                                    $load_appointment_log                           = LoadAppointmentLog::create([
                                        'load_appointment_id'                       => $load_appointment->id,
                                        'date'                                      => date('Y-m-d', strtotime($shipper_appointment['req_date'])),
                                        'time'                                      => date('H:i:s', strtotime($shipper_appointment['req_time'])),
                                        'note'                                      => $shipper_appointment['req_note'] ?? null,
                                        'sender_id'                                 => auth()->guard('company-admin')->user()->id,
                                        'sent_at'                                   => Carbon::now()->format('Y-m-d H:i:s'),
                                        'source'                                    => 1, // 1=Email, 2=SMS
                                        'reply_from'                                => auth()->guard('company-admin')->user()->email,
                                        'reply_at'                                  => Carbon::now()->format('Y-m-d H:i:s'),
                                        'ip_address'                                => $request->ip(),
                                        'review_user_type'                          => 'Company Admin',
                                        'review_by'                                 => auth()->guard('company-admin')->user()->id,
                                        'review_status'                             => 0,
                                        'review_at'                                 => Carbon::now()->format('Y-m-d H:i:s'),
                                        'created_at'                                => Carbon::now()->format('Y-m-d H:i:s'),
                                    ]);
                                    if($load_appointment_log){
                                        // appointmentRequestSend($load_appointment);
                                    }
                                }
                            }
                        }
                    }else{
                        $shipper_appointment                                        = isset($loadDetail->shipper_appointment)?$loadDetail->shipper_appointment:null;
                        if(!is_null($shipper_appointment)){
                            $oldData                                                = [];
                            $oldData                                                = $shipper_appointment->toArray();
                            if($shipper_appointment->delete()){
                                $this->setLoadAudit($load->id, 'delete', 'Load appointment deleted', $shipper_appointment->toArray(), $oldData);
                            }
                        }
                    }

                    if($loadDetail->delivery_time_range == 0){
                        $delivery_appointment                                       = $formdata['delivery_appointment'];
                        if(!is_null($delivery_appointment)){
                            $delivery_appointment                                   = json_decode($delivery_appointment, true);
                            if(!empty($delivery_appointment)){
                                $appointment                                        = [];
                                $appointment['broker_id']                           = $delivery_appointment['req_brokerage_id'];
                                $appointment['customer_id']                         = $delivery_appointment['req_customer_id'];
                                $appointment['load_detail_id']                      = $loadDetail->id;
                                $appointment['type']                                = 2;
                                $appointment['is_stop']                             = 0;

                                $appointment['request_date']                        = date('Y-m-d', strtotime($delivery_appointment['req_date']));
                                $appointment['request_time']                        = date('H:i:s', strtotime($delivery_appointment['req_time']));

                                $emails                                             = [];
                                $appointment_emails                                 = $delivery_appointment['req_email[]'] ?? null;
                                if (is_array($appointment_emails)) {
                                    foreach ($appointment_emails as $key => $appointment_email) {
                                        $appointment_email_array                    = explode('|', $appointment_email);
                                        $emails[]                                   = [
                                            'table'                                 => $appointment_email_array[0],
                                            'field_name'                            => $appointment_email_array[1],
                                            'email'                                 => $appointment_email_array[2]
                                        ];
                                    }
                                }else{
                                    if(!is_null($appointment_emails)){
                                        $appointment_email_array                    = explode('|', $appointment_emails);
                                        $emails[]                                   = [
                                            'table'                                 => $appointment_email_array[0],
                                            'field_name'                            => $appointment_email_array[1],
                                            'email'                                 => $appointment_email_array[2]
                                        ];
                                    }
                                }
                                $appointment['emails']                              = !empty($emails) ? serialize($emails) : null;

                                $phones                                             = [];
                                $appointment_phones                                 = $delivery_appointment['req_phone[]'] ?? null;
                                if (is_array($appointment_phones)) {
                                    foreach ($appointment_phones as $key => $appointment_phone) {
                                        $appointment_phone_array                    = explode('|', $appointment_phone);
                                        $phones[]                                   = [
                                            'table'                                 => $appointment_phone_array[0],
                                            'field_name'                            => $appointment_phone_array[1],
                                            'phone'                                 => $appointment_phone_array[2]
                                        ];
                                    }
                                }else{
                                    if(!is_null($appointment_phones)){
                                        $appointment_phone_array                    = explode('|', $appointment_phones);
                                        $phones[]                                   = [
                                            'table'                                 => $appointment_phone_array[0],
                                            'field_name'                            => $appointment_phone_array[1],
                                            'phone'                                 => $appointment_phone_array[2]
                                        ];
                                    }
                                }
                                $appointment['phones']                              = !empty($phones) ? serialize($phones) : null;

                                $confirmation_numbers                               = $delivery_appointment['req_confirmation_number[]'] ?? null;
                                if (is_array($confirmation_numbers)) {
                                    $confirmation_numbers                           = !empty($confirmation_numbers) ? implode(', ', $confirmation_numbers) : null;
                                }
                                $appointment['confirmation_numbers']                = $confirmation_numbers;

                                $reminder_on                                        = $delivery_appointment['req_reminder_on[]'] ?? null;
                                if (is_array($reminder_on)) {
                                    $reminder_on                                    = !empty($reminder_on) ? implode(',', $reminder_on) : null;
                                }
                                $appointment['reminder_on']                         = $reminder_on;
                                $appointment['reminder_type']                       = $delivery_appointment['req_reminder_type'] ?? null;
                                if($appointment['reminder_type']=='Custom'){
                                    $appointment['reminder_repeat_every']           = $delivery_appointment['req_reminder_repeat_every'] ?? 0;
                                    $appointment['reminder_custom_hours']           = $delivery_appointment['req_reminder_custom_hours'];
                                }
                                $appointment['reminder_status']                     = $delivery_appointment['req_reminder_status'] ?? 0;

                                $appointment['status']                              = 0;
                                $appointment['status_at']                           = Carbon::now()->format('Y-m-d H:i:s');
                                $appointment['created_at']                          = Carbon::now()->format('Y-m-d H:i:s');
                                $load_appointment                                   = LoadAppointment::create($appointment);
                                if($load_appointment){
                                    $load_appointment_log                           = LoadAppointmentLog::create([
                                        'load_appointment_id'                       => $load_appointment->id,
                                        'date'                                      => date('Y-m-d', strtotime($delivery_appointment['req_date'])),
                                        'time'                                      => date('H:i:s', strtotime($delivery_appointment['req_time'])),
                                        'note'                                      => $delivery_appointment['req_note'] ?? null,
                                        'sender_id'                                 => auth()->guard('company-admin')->user()->id,
                                        'sent_at'                                   => Carbon::now()->format('Y-m-d H:i:s'),
                                        'source'                                    => 1, // 1=Email, 2=SMS
                                        'reply_from'                                => auth()->guard('company-admin')->user()->email,
                                        'reply_at'                                  => Carbon::now()->format('Y-m-d H:i:s'),
                                        'ip_address'                                => $request->ip(),
                                        'review_user_type'                          => 'Company Admin',
                                        'review_by'                                 => auth()->guard('company-admin')->user()->id,
                                        'review_status'                             => 0,
                                        'review_at'                                 => Carbon::now()->format('Y-m-d H:i:s'),
                                        'created_at'                                => Carbon::now()->format('Y-m-d H:i:s'),
                                    ]);
                                    if($load_appointment_log){
                                        // appointmentRequestSend($load_appointment);
                                    }
                                }
                            }
                        }
                    }else{
                        $delivery_appointment                                       = isset($loadDetail->receiver_appointment)?$loadDetail->receiver_appointment:null;
                        if(!is_null($delivery_appointment)){
                            $oldData                                                = [];
                            $oldData                                                = $delivery_appointment->toArray();
                            if($delivery_appointment->delete()){
                                $this->setLoadAudit($load->id, 'delete', 'Load appointment deleted', $delivery_appointment->toArray(), $oldData);
                            }
                        }
                    }

                    $stops                                                          = isset($formdata['stop'])?$formdata['stop']:[];
                    if(!empty($stops)){
                        foreach ($stops as $stkey => $stop) {
                            $stop_row_id                                            = $stop['id'] ?? null;
                            $stop_random_id                                         = $stop['random_id'] ?? null;

                            $customer_type                                          = $stop['customer_type'];

                            $stop_array                                             = [];
                            $stop_array['stop_no']                                  = $stop['stop_no'] ?? null;
                            $stop_array['company_id']                               = auth()->guard('company-admin')->user()->company_id;
                            $stop_array['load_id']                                  = $load->id;
                            $stop_array['date_time_range']                          = $stop['date_time_range'];
                            $stop_array['date_time']                                = $stop['date_time'];
                            $stop_array['date_time_end']                            = $stop['date_time_range']!=0?$stop['date_time_end']:null;
                            $stop_array['customer_type']                            = $customer_type;
                            $stop_array['customer_id']                              = $stop['customer_id'];
                            $stop_array['address_one']                              = $stop['address_one'];
                            $stop_array['address_two']                              = $stop['address_two'];
                            $stop_array['city']                                     = $stop['city'];
                            $stop_array['state']                                    = $stop['state'];
                            $stop_array['zip']                                      = $stop['zip'];

                            $address_verified                                       = $stop['address_verified'] ?? 0;
                            if($address_verified==0){
                                $stop_array['latitude']                             = null;
                                $stop_array['longitude']                            = null;
                                $stop_array['timezone']                             = null;
                                $stop_array['timezone_offset']                      = null;
                                $stop_array['timezone_abbr']                        = null;
                                $stop_array['address_verified']                     = 0;
                            }else{
                                $stop_timezone                                      = null;
                                $stop_timezone_offset                               = null;
                                $stop_timezone_abbr                                 = $stop['timezone_abbr'] ?? null;
                                if(!is_null($stop_timezone_abbr)){
                                    $stop_timezone                                  = timezone_name_from_abbr($stop_timezone_abbr);
                                    $stop_timezone_offset                           = Carbon::createFromTimestamp(time(), $stop_timezone)->getOffsetString();
                                }

                                $stop_array['latitude']                             = $stop['latitude'] ?? null;
                                $stop_array['longitude']                            = $stop['longitude'] ?? null;
                                $stop_array['timezone']                             = $stop_timezone;
                                $stop_array['timezone_offset']                      = $stop_timezone_offset;
                                $stop_array['timezone_abbr']                        = $stop_timezone_abbr;
                                $stop_array['address_verified']                     = 1;
                            }

                            $stop_array['stop_note']                                = $stop['stop_note'];

                            if($itemize == 1){
                                $stop_array['commodity']                            = $stop['commodity'];
                                $stop_array['stop_value']                           = $stop['stop_value'];
                                $stop_array['stop_weight']                          = $stop['stop_weight'];
                                $stop_array['reefer_mode']                          = $stop['reefer_mode'];
                                $stop_array['reefer_temp_type']                     = $stop['reefer_temp_type'] ?? 0;
                                $stop_array['reefer_temp']                          = $stop['reefer_temp'] ?? null;
                                $stop_array['pickup_number']                        = $stop['pickup_number'];
                            }else{
                                $stop_array['commodity']                            = null;
                                $stop_array['stop_value']                           = null;
                                $stop_array['stop_weight']                          = null;
                                $stop_array['reefer_mode']                          = null;
                                $stop_array['reefer_temp_type']                     = 0;
                                $stop_array['reefer_temp']                          = null;
                                $stop_array['pickup_number']                        = null;
                            }
                            if(isset($stop['dimension']) && !empty($stop['dimension'])){
                                $stop_array['dimension']                            = serialize($stop['dimension']);
                            }else{
                                $stop_array['dimension']                            = null;
                            }

                            $stop_array['drop_trailer_schedule']                    = $stop['drop_trailer_schedule'] ?? 0;
                            if($stop_array['drop_trailer_schedule'] == 1){
                                $stop_array['drop_trailer_id']                      = $stop['drop_trailer_id'] ?? null;
                                $stop_array['pickup_trailer_id']                    = null;
                            } else if($stop_array['drop_trailer_schedule'] == 2){
                                $stop_array['drop_trailer_id']                      = $stop['drop_trailer_id'] ?? null;
                                $stop_array['pickup_trailer_id']                    = $stop['pickup_trailer_id'] ?? null; // isset($stop['pickup_trailer_id']) ? str_replace('TRAILERDROP', '', $stop['pickup_trailer_id']) : null;
                            } else{
                                $stop_array['drop_trailer_id']                      = null;
                                $stop_array['pickup_trailer_id']                    = null;
                            }

                            $stop_files                                             = isset($formdata['stop_files'][$stkey])?$formdata['stop_files'][$stkey]:[];
                            $stop_files_array                                       = [];
                            if(!empty($stop_files)){
                                if (array_key_exists('name_id', $stop_files)) {
                                    $stop_files_name_ids                            = array_filter($stop_files['name_id'], function ($var) {
                                        return $var !== null && $var !== '';
                                    });
                                    if(!empty($stop_files_name_ids)){
                                        foreach($stop_files_name_ids as $stfkey => $stop_files_name_id){
                                            $arry                                   = [];
                                            $arry['name_id']                        = $stop_files_name_id;
                                            $arry['name']                           = isset($stop_files['name'][$stfkey]) ? $stop_files['name'][$stfkey] : '';
                                            $arry['is_required']                    = isset($stop_files['is_required'][$stfkey]) ? $stop_files['is_required'][$stfkey] : 'off';
                                            $arry['type']                           = $stop_files['type'][$stfkey];
                                            $arry['fixed']                          = $stop_files['fixed'][$stfkey];
                                            $arry['include_w_billing']              = isset($stop_files['include_w_billing'][$stfkey]) && $stop_files['include_w_billing'][$stfkey]=='yes' ? 'yes' : 'no';
                                            $arry['custom']                         = isset($stop_files['custom'][$stfkey]) && $stop_files['custom'][$stfkey]=='yes' ? 'yes' : 'no';
                                            $stop_files_array[]                     = $arry;
                                        }
                                    }
                                }
                            }

                            $stop_files_upload                                      = isset($formdata['stop_files_upload'][$stkey])?$formdata['stop_files_upload'][$stkey]:[];
                            $stop_files_upload_array                                = [];
                            if(!empty($stop_files_upload)){
                                if (array_key_exists('name_id', $stop_files_upload)) {
                                    $stop_files_upload_name_ids                     = array_filter($stop_files_upload['name_id'], function ($var) {
                                        return $var !== null && $var !== '';
                                    });
                                    if(!empty($stop_files_upload_name_ids)){
                                        foreach($stop_files_upload_name_ids as $ctfkey => $stop_files_upload_name_id){
                                            $arry                                   = [];
                                            $arry['name_id']                        = $stop_files_upload_name_id;
                                            $arry['name']                           = isset($stop_files_upload['name'][$ctfkey]) ? $stop_files_upload['name'][$ctfkey] : '';
                                            $arry['is_required']                    = isset($stop_files_upload['is_required'][$ctfkey]) ? $stop_files_upload['is_required'][$ctfkey] : 'off';
                                            $arry['type']                           = $stop_files_upload['type'][$ctfkey];
                                            $arry['fixed']                          = $stop_files_upload['fixed'][$ctfkey];
                                            $arry['include_w_billing']              = isset($stop_files_upload['include_w_billing'][$ctfkey]) && $stop_files_upload['include_w_billing'][$ctfkey]=='yes' ? 'yes' : 'no';
                                            $arry['custom']                         = isset($stop_files_upload['custom'][$ctfkey]) && $stop_files_upload['custom'][$ctfkey]=='yes' ? 'yes' : 'no';

                                            $arry['is_received']                    = isset($stop_files_upload['is_received'][$ctfkey]) ? $stop_files_upload['is_received'][$ctfkey] : 'off';
                                            $arry['hide_from_driver']               = isset($stop_files_upload['hide_from_driver'][$ctfkey]) && $stop_files_upload['hide_from_driver'][$ctfkey]=='yes' ? 'yes' : 'no';
                                            $arry['file_not_provided']              = isset($stop_files_upload['file_not_provided'][$ctfkey]) ? $stop_files_upload['file_not_provided'][$ctfkey] : 'off';
                                            if(isset($stop_files_upload['file'][$ctfkey])){
                                                $arry['is_received']                = 'on';
                                                $arry['file']                       = UploadImagePdf($stop_files_upload['file'][$ctfkey], 'companyAdmin/load_detail_document');
                                                $arry['upload_user_type']           = auth()->guard('company-admin')->user()->type;
                                                $arry['upload_by']                  = auth()->guard('company-admin')->user()->id;
                                                $arry['uploaded_at']                = Carbon::now();
                                            }else{
                                                if(isset($stop_files_upload['file_exists'][$ctfkey])){
                                                    $arry['is_received']            = 'on';
                                                    $arry['file']                   = $stop_files_upload['file_exists'][$ctfkey];
                                                    $arry['upload_user_type']       = $stop_files_upload['upload_user_type'][$ctfkey];
                                                    $arry['upload_by']              = $stop_files_upload['upload_by'][$ctfkey];
                                                    $arry['uploaded_at']            = $stop_files_upload['uploaded_at'][$ctfkey];
                                                }else{
                                                    $arry['file']                   = null;
                                                }
                                            }
                                            if($arry['type'] == 2){
                                                if(isset($stop_files_upload['old_is_received'][$ctfkey]) && $stop_files_upload['old_is_received'][$ctfkey] == 'on'){
                                                    if($arry['is_received'] == 'on'){
                                                        $arry['upload_user_type']   = $stop_files_upload['upload_user_type'][$ctfkey] ?? auth()->guard('company-admin')->user()->type;
                                                        $arry['upload_by']          = $stop_files_upload['upload_by'][$ctfkey] ?? auth()->guard('company-admin')->user()->id;
                                                        $arry['uploaded_at']        = $stop_files_upload['uploaded_at'][$ctfkey] ?? Carbon::now();
                                                    }
                                                }else{
                                                    if($arry['is_received'] == 'on'){
                                                        $arry['upload_user_type']   = auth()->guard('company-admin')->user()->type;
                                                        $arry['upload_by']          = auth()->guard('company-admin')->user()->id;
                                                        $arry['uploaded_at']        = Carbon::now();
                                                    }
                                                }
                                            }
                                            $stop_files_upload_array[]              = $arry;
                                        }
                                    }
                                }
                            }

                            if($customer_type==1){
                                if(!empty($stop_files_array)){
                                    $stop_array['stop_shipper_files']               = serialize($stop_files_array);
                                }else{
                                    $stop_array['stop_shipper_files']               = null;
                                }
                                if(!empty($stop_files_upload_array)){
                                    $stop_array['stop_shipper_files_upload']        = serialize($stop_files_upload_array);
                                }else{
                                    $stop_array['stop_shipper_files_upload']        = null;
                                }
                                $stop_array['stop_consignee_files']                 = null;
                                $stop_array['stop_consignee_files_upload']          = null;
                            }else{
                                if(!empty($stop_files_array)){
                                    $stop_array['stop_consignee_files']             = serialize($stop_files_array);
                                }else{
                                    $stop_array['stop_consignee_files']             = null;
                                }
                                if(!empty($stop_files_upload_array)){
                                    $stop_array['stop_consignee_files_upload']      = serialize($stop_files_upload_array);
                                }else{
                                    $stop_array['stop_consignee_files_upload']      = null;
                                }
                                $stop_array['stop_shipper_files']                   = null;
                                $stop_array['stop_shipper_files_upload']            = null;
                            }

                            $stop_mode                                              = false;
                            if(!is_null($stop_row_id)){
                                $stop_array['updated_at']                           = Carbon::now()->format('Y-m-d H:i:s');

                                $stopDetail                                         = LoadStop::where('id', $stop_row_id)->first();
                                if(!is_null($stopDetail)){
                                    $oldData                                        = [];
                                    $oldData                                        = $stopDetail->toArray();
                                    foreach ($stop_array as $sfield_key => $sfield_value) {
                                        $stopDetail->$sfield_key                    = $sfield_value;
                                    }
                                    if($stopDetail->save()){
                                        $stop_mode                                  = true;
                                        $this->setLoadAudit($load->id, 'update', 'Load stop updated', $stopDetail->getChanges(), $oldData);
                                    }
                                }
                            }else{
                                $stop_array['status']                               = 0;
                                $stop_array['status_at']                            = Carbon::now()->format('Y-m-d H:i:s');
                                $stop_array['created_at']                           = Carbon::now()->format('Y-m-d H:i:s');
                                $stopDetail                                         = LoadStop::create($stop_array);
                                if($stopDetail){
                                    $stop_mode                                      = true;
                                    $load_stop_accessorials                         = LoadAccessorialTemp::where('unique_id', $accessorial_unique_id)
                                        ->where('load_id', $load->id)
                                        ->where('load_detail_id', $loadDetail->id)
                                        ->where('random_id', $stop_random_id)
                                        ->where('type', 3)
                                        ->where('is_stop', 1)
                                        ->get();
                                    if($load_stop_accessorials->isNotEmpty()){
                                        foreach ($load_stop_accessorials as $lsatkey => $load_stop_accessorial) {
                                            $load_accessorial                       = LoadAccessorial::create([
                                                'load_id'                           => $load_stop_accessorial->load_id,
                                                'load_detail_id'                    => $load_stop_accessorial->load_detail_id,
                                                'load_stop_id'                      => $stopDetail->id,
                                                'type'                              => 3, // stop
                                                'is_stop'                           => 1,

                                                'company_accessorial_id'            => $load_stop_accessorial->company_accessorial_id,
                                                'paid_by'                           => $load_stop_accessorial->paid_by,
                                                'charge_deduct'                     => $load_stop_accessorial->charge_deduct,
                                                'paid_type'                         => $load_stop_accessorial->paid_type,
                                                'reference'                         => $load_stop_accessorial->reference,

                                                'doc_required'                      => $load_stop_accessorial->doc_required,
                                                'qty'                               => $load_stop_accessorial->qty,
                                                'rate'                              => $load_stop_accessorial->rate,
                                                'total'                             => $load_stop_accessorial->total,

                                                'owner_liable'                      => $load_stop_accessorial->owner_liable,
                                                'owner_id'                          => $load_stop_accessorial->owner_id,
                                                'owner_type'                        => $load_stop_accessorial->owner_type,
                                                'owner_pay_deduct'                  => $load_stop_accessorial->owner_pay_deduct,
                                                'owner_qty'                         => $load_stop_accessorial->owner_qty,
                                                'owner_rate'                        => $load_stop_accessorial->owner_rate,
                                                'owner_total'                       => $load_stop_accessorial->owner_total,

                                                'driver_liable'                     => $load_stop_accessorial->driver_liable,
                                                'driver_id'                         => $load_stop_accessorial->driver_id,
                                                'pay_deduct'                        => $load_stop_accessorial->pay_deduct,
                                                'driver_qty'                        => $load_stop_accessorial->driver_qty,
                                                'driver_rate'                       => $load_stop_accessorial->driver_rate,
                                                'driver_total'                      => $load_stop_accessorial->driver_total,

                                                'notes'                             => $load_stop_accessorial->notes,
                                                'is_received'                       => $load_stop_accessorial->is_received,
                                                'is_deduction'                      => $load_stop_accessorial->is_deduction,
                                                'status'                            => $load_stop_accessorial->status,
                                                'created_at'                        => $load_stop_accessorial->created_at,
                                                'created_by'                        => $load_stop_accessorial->created_by
                                            ]);
                                            if($load_accessorial){
                                                Gallery::IsCompany()
                                                    ->where('action_id', $load_stop_accessorial->id)
                                                    ->where('source', 'load_accessorial_temps')
                                                    ->where('field_name', 'accessorial_files')
                                                    ->update(['action_id' => $load_accessorial->id, 'source' => 'load_accessorials']);
                                                $load_stop_accessorial->forceDelete();
                                            }
                                        }
                                    }
                                }
                            }

                            if($stop_mode){
                                if($stopDetail->date_time_range == 0){
                                    $stop_appointment                               = $stop['appointment'];
                                    if(!is_null($stop_appointment)){
                                        $stop_appointment                           = json_decode($stop_appointment, true);
                                        if(!empty($stop_appointment)){
                                            $appointment                            = [];
                                            $appointment['broker_id']               = $stop_appointment['req_brokerage_id'];
                                            $appointment['customer_id']             = $stop_appointment['req_customer_id'];
                                            $appointment['load_detail_id']          = $loadDetail->id;
                                            $appointment['load_stop_id']            = $stopDetail->id;
                                            $appointment['type']                    = $customer_type;
                                            $appointment['is_stop']                 = 1;

                                            $appointment['request_date']            = date('Y-m-d', strtotime($stop_appointment['req_date']));
                                            $appointment['request_time']            = date('H:i:s', strtotime($stop_appointment['req_time']));

                                            $emails                                 = [];
                                            $appointment_emails                     = $stop_appointment['req_email[]'] ?? null;
                                            if (is_array($appointment_emails)) {
                                                foreach ($appointment_emails as $key => $appointment_email) {
                                                    $appointment_email_array        = explode('|', $appointment_email);
                                                    $emails[]                       = [
                                                        'table'                     => $appointment_email_array[0],
                                                        'field_name'                => $appointment_email_array[1],
                                                        'email'                     => $appointment_email_array[2]
                                                    ];
                                                }
                                            }else{
                                                if(!is_null($appointment_emails)){
                                                    $appointment_email_array        = explode('|', $appointment_emails);
                                                    $emails[]                       = [
                                                        'table'                     => $appointment_email_array[0],
                                                        'field_name'                => $appointment_email_array[1],
                                                        'email'                     => $appointment_email_array[2]
                                                    ];
                                                }
                                            }
                                            $appointment['emails']                  = !empty($emails) ? serialize($emails) : null;

                                            $phones                                 = [];
                                            $appointment_phones                     = $stop_appointment['req_phone[]'] ?? null;
                                            if (is_array($appointment_phones)) {
                                                foreach ($appointment_phones as $key => $appointment_phone) {
                                                    $appointment_phone_array        = explode('|', $appointment_phone);
                                                    $phones[]                       = [
                                                        'table'                     => $appointment_phone_array[0],
                                                        'field_name'                => $appointment_phone_array[1],
                                                        'phone'                     => $appointment_phone_array[2]
                                                    ];
                                                }
                                            }else{
                                                if(!is_null($appointment_phones)){
                                                    $appointment_phone_array        = explode('|', $appointment_phones);
                                                    $phones[]                       = [
                                                        'table'                     => $appointment_phone_array[0],
                                                        'field_name'                => $appointment_phone_array[1],
                                                        'phone'                     => $appointment_phone_array[2]
                                                    ];
                                                }
                                            }
                                            $appointment['phones']                  = !empty($phones) ? serialize($phones) : null;

                                            $confirmation_numbers                   = $stop_appointment['req_confirmation_number[]'] ?? null;
                                            if (is_array($confirmation_numbers)) {
                                                $confirmation_numbers               = !empty($confirmation_numbers) ? implode(', ', $confirmation_numbers) : null;
                                            }
                                            $appointment['confirmation_numbers']    = $confirmation_numbers;

                                            $reminder_on                            = $stop_appointment['req_reminder_on[]'] ?? null;
                                            if (is_array($reminder_on)) {
                                                $reminder_on                        = !empty($reminder_on) ? implode(',', $reminder_on) : null;
                                            }
                                            $appointment['reminder_on']             = $reminder_on;
                                            $appointment['reminder_type']           = $stop_appointment['req_reminder_type'] ?? null;
                                            if($appointment['reminder_type']=='Custom'){
                                              $appointment['reminder_repeat_every'] = $stop_appointment['req_reminder_repeat_every'] ?? 0;
                                              $appointment['reminder_custom_hours'] = $stop_appointment['req_reminder_custom_hours'];
                                            }
                                            $appointment['reminder_status']         = $stop_appointment['req_reminder_status'] ?? 0;

                                            $appointment['status']                  = 0;
                                            $appointment['status_at']               = Carbon::now()->format('Y-m-d H:i:s');
                                            $appointment['created_at']              = Carbon::now()->format('Y-m-d H:i:s');
                                            $load_appointment                       = LoadAppointment::create($appointment);
                                            if($load_appointment){
                                                $load_appointment_log               = LoadAppointmentLog::create([
                                                    'load_appointment_id'           => $load_appointment->id,
                                                    'date'                          => date('Y-m-d', strtotime($stop_appointment['req_date'])),
                                                    'time'                          => date('H:i:s', strtotime($stop_appointment['req_time'])),
                                                    'note'                          => $stop_appointment['req_note'] ?? null,
                                                    'sender_id'                     => auth()->guard('company-admin')->user()->id,
                                                    'sent_at'                       => Carbon::now()->format('Y-m-d H:i:s'),
                                                    'source'                        => 1, // 1=Email, 2=SMS
                                                    'reply_from'                    => auth()->guard('company-admin')->user()->email,
                                                    'reply_at'                      => Carbon::now()->format('Y-m-d H:i:s'),
                                                    'ip_address'                    => $request->ip(),
                                                    'review_user_type'              => 'Company Admin',
                                                    'review_by'                     => auth()->guard('company-admin')->user()->id,
                                                    'review_status'                 => 0,
                                                    'review_at'                     => Carbon::now()->format('Y-m-d H:i:s'),
                                                    'created_at'                    => Carbon::now()->format('Y-m-d H:i:s'),
                                                ]);
                                                if($load_appointment_log){
                                                    // appointmentRequestSend($load_appointment);
                                                }
                                            }
                                        }
                                    }
                                }else{
                                    $stop_appointment                               = isset($stopDetail->appointment)?$stopDetail->appointment:null;
                                    if(!is_null($stop_appointment)){
                                        $oldData                                    = [];
                                        $oldData                                    = $stop_appointment->toArray();
                                        if($stop_appointment->delete()){
                                            $this->setLoadAudit($load->id, 'delete', 'Load appointment deleted', $stop_appointment->toArray(), $oldData);
                                        }
                                    }
                                }
                            }
                        }
                    }

                    // Update requested documents
                    $load_document_request_items                                    = isset($formdata['load_document_request']) && !empty($formdata['load_document_request']) ? $formdata['load_document_request'] : [];
                    if(!empty($load_document_request_items)){
                        foreach ($load_document_request_items as $item_id => $value) {
                            $load_document_request_item                             = LoadDocumentRequestItem::where('id', $item_id)->first();
                            if(!is_null($load_document_request_item)){
                                $oldData                                            = [];
                                $oldData                                            = $load_document_request_item->toArray();

                                $filearry                                           = [];
                                if(isset($load_document_request_item->files) && is_serialized($load_document_request_item->files) && !empty(unserialize($load_document_request_item->files))){
                                    $filearry                                       = unserialize($load_document_request_item->files);
                                    if(!empty($filearry)){
                                        // name_id, name, is_required, type, fixed, include_w_billing, custom, hide_from_driver, file_not_provided
                                        $filearry['is_received']                    = isset($value['is_received']) && $value['is_received']=='on' ? 'on' : 'off';
                                        if(isset($value['file']) && !empty($value['file'])){
                                            // exists file array
                                            if(isset($filearry['file']) && !empty($filearry['file'])){
                                                foreach ($filearry['file'] as $key => $file) {
                                                    $path                           = 'storage/companyAdmin/load_detail_document/'.$file;
                                                    if (File::exists($path)) {
                                                        File::delete($path);
                                                    }
                                                }
                                            }
                                            $filearry['is_received']                = 'on';
                                            $filearry['file']                       = UploadImagePdf($value['file'], 'companyAdmin/load_detail_document');
                                            $filearry['upload_user_type']           = auth()->guard('company-admin')->user()->type;
                                            $filearry['upload_by']                  = auth()->guard('company-admin')->user()->id;
                                            $filearry['uploaded_at']                = Carbon::now();
                                        }else{
                                            if(isset($value['file_exists'])){
                                                $filearry['is_received']            = 'on';
                                                $filearry['file']                   = $value['file_exists'];
                                                $filearry['upload_user_type']       = $value['upload_user_type'];
                                                $filearry['upload_by']              = $value['upload_by'];
                                                $filearry['uploaded_at']            = $value['uploaded_at'];
                                            }else{
                                                $filearry['file']                   = null;
                                            }
                                        }
                                        if($filearry['type'] == 2){
                                            if(!(isset($value['old_is_received']) && $value['old_is_received'] == 'on')){
                                                if($filearry['is_received'] == 'on'){
                                                    $filearry['upload_user_type']   = auth()->guard('company-admin')->user()->type;
                                                    $filearry['upload_by']          = auth()->guard('company-admin')->user()->id;
                                                    $filearry['uploaded_at']        = Carbon::now();
                                                }
                                            }
                                        }
                                    }
                                }

                                $load_document_request_item->files                  = !empty($filearry) ? serialize($filearry) : null;
                                $load_document_request_item->updated_at             = Carbon::now()->format('Y-m-d H:i:s');
                                $load_document_request_item->updated_by             = auth()->guard('company-admin')->user()->id;
                                $load_document_request_item->updated_by_type        = auth()->guard('company-admin')->user()->type;
                                if($load_document_request_item->save()){
                                    $this->setLoadAudit($load->id, 'update', 'Load document request item updated', $load_document_request_item->getChanges(), $oldData);
                                }
                            }
                        }
                    }

                    // Drop Trailer
                    // delete drop data if exists with load_id
                    DropTrailer::where('load_id', $load->id)->delete();

                    // Insert Drop Trailers data - Start
                    $dropTrailers                                                = array();
                    if((isset($request->shipper_drop_loc_by_user) && $request->shipper_drop_loc_by_user != "") || (isset($request->shipper_drop_loc_by_stop) && $request->shipper_drop_loc_by_stop != "") || (isset($request->shipper_drop_loc_by_custom) && $request->shipper_drop_loc_by_custom == '1')){
                        if(isset($request->shipper_drop_loc_by_custom) && $request->shipper_drop_loc_by_custom == '1'){
                            $dropAtStop                                             = '2';
                            $userType                                               = null;
                            $loc                                                    = null;
                        }else{
                            $dropAtStop                                             = (isset($request->shipper_drop_at_stop) && $request->shipper_drop_at_stop == '1') ? $request->shipper_drop_at_stop : '0';
                            $userType                                               = (!isset($request->shipper_drop_at_stop)) ? $request->shipper_drop_user_type : null;
                            $loc                                                    = (isset($request->shipper_drop_at_stop)) ? $request->shipper_drop_loc_by_stop : $request->shipper_drop_loc_by_user;
                        }

                        $shipperDropLatitude                                        = null;
                        $shipperDropLongitude                                       = null;
                        $shipperDropTimezone                                        = null;
                        $shipperDropTimezoneOffset                                  = null;
                        $shipperDropTimezoneAbbr                                    = null;
                        $shipperDropAddressVerified                                 = 0;
                        if($request->shipper_drop_address_verified == 1){
                            $shipperDropLatitude                                    = ($request->shipper_drop_latitude != "") ? $request->shipper_drop_latitude : null;
                            $shipperDropLongitude                                   = ($request->shipper_drop_longitude != "") ? $request->shipper_drop_longitude : null;
                            $shipperDropTimezoneAbbr                                = ($request->shipper_drop_timezone_abbr != "") ? $request->shipper_drop_timezone_abbr : null;
                            $shipperDropAddressVerified                             = ($request->shipper_drop_address_verified != "") ? $request->shipper_drop_address_verified : 0;

                            if(isset($request->shipper_drop_timezone_abbr)){
                                $shipperDropTimezone                                = timezone_name_from_abbr($shipperDropTimezoneAbbr);
                                $shipperDropTimezoneOffset                          = Carbon::createFromTimestamp(time(), $shipperDropTimezone)->getOffsetString();
                            }

                            $getTrailer                                             = Trailer::IsCompany()->where('trailer_id', $request->shipper_drop_trailer_number)->first();
                            if(!is_null($getTrailer)){
                                $getTrailer->last_location_load_status              = (isset($request->shipper_drop_empty_loaded) && $request->shipper_drop_empty_loaded == '0') ? $request->shipper_drop_empty_loaded : '1';
                                $getTrailer->last_location_address                  = (isset($request->shipper_drop_add1) && $request->shipper_drop_add1 != "") ? $request->shipper_drop_add1 : null;
                                $getTrailer->last_location_address_2                = (isset($request->shipper_drop_add2) && $request->shipper_drop_add2 != "") ? $request->shipper_drop_add2 : null;
                                $getTrailer->last_location_city                     = (isset($request->shipper_drop_city) && $request->shipper_drop_city != "") ? $request->shipper_drop_city : null;
                                $getTrailer->last_location_state                    = (isset($request->shipper_drop_state) && $request->shipper_drop_state != "") ? $request->shipper_drop_state : null;
                                $getTrailer->last_location_zip                      = (isset($request->shipper_drop_zip) && $request->shipper_drop_zip != "") ? $request->shipper_drop_zip : null;
                                $getTrailer->last_location_latitude                 = $shipperDropLatitude;
                                $getTrailer->last_location_longitude                = $shipperDropLongitude;
                                $getTrailer->last_location_timezone                 = $shipperDropTimezone;
                                $getTrailer->last_location_timezone_offset          = $shipperDropTimezoneOffset;
                                $getTrailer->last_location_timezone_abbr            = $shipperDropTimezoneAbbr;
                                $getTrailer->last_location_address_verified         = $shipperDropAddressVerified;
                                $getTrailer->last_location_notes                    = (isset($request->shipper_drop_notes) && $request->shipper_drop_notes != "") ? $request->shipper_drop_notes : null;
                                $getTrailer->save();
                            }
                        }

                        $dropTrailers[]                                          = array(
                            'load_id'                                               => $load->id,
                            'stop_number'                                           => '1',
                            'type'                                                  => '1',
                            'driver_id'                                             => $loadDetail->driver_id,
                            'truck_number'                                          => $request->truck_number,
                            'trailer_number'                                        => $request->shipper_drop_trailer_number,
                            'empty_loaded'                                          => (isset($request->shipper_drop_empty_loaded) && $request->shipper_drop_empty_loaded == '0') ? $request->shipper_drop_empty_loaded : '1',
                            'drop_at_stop'                                          => $dropAtStop,
                            'keep_assigned'                                         => (isset($request->shipper_drop_keep_assigned) && $request->shipper_drop_keep_assigned == '1') ? $request->shipper_drop_keep_assigned : '0',
                            'drop_date'                                             => (isset($request->shipper_dorp_date) && $request->shipper_dorp_date != "") ? $request->shipper_dorp_date : null,
                            'user_type'                                             => $userType,
                            'loc'                                                   => $loc,
                            'add1'                                                  => (isset($request->shipper_drop_add1) && $request->shipper_drop_add1 != "") ? $request->shipper_drop_add1 : null,
                            'add2'                                                  => (isset($request->shipper_drop_add2) && $request->shipper_drop_add2 != "") ? $request->shipper_drop_add2 : null,
                            'city'                                                  => (isset($request->shipper_drop_city) && $request->shipper_drop_city != "") ? $request->shipper_drop_city : null,
                            'state'                                                 => (isset($request->shipper_drop_state) && $request->shipper_drop_state != "") ? $request->shipper_drop_state : null,
                            'zip'                                                   => (isset($request->shipper_drop_zip) && $request->shipper_drop_zip != "") ? $request->shipper_drop_zip : null,
                            'latitude'                                              => $shipperDropLatitude,
                            'longitude'                                             => $shipperDropLongitude,
                            'timezone'                                              => $shipperDropTimezone,
                            'timezone_offset'                                       => $shipperDropTimezoneOffset,
                            'timezone_abbr'                                         => $shipperDropTimezoneAbbr,
                            'address_verified'                                      => $shipperDropAddressVerified,
                            'notes'                                                 => (isset($request->shipper_drop_notes) && $request->shipper_drop_notes != "") ? $request->shipper_drop_notes : null,
                            'drop_or_keep_driver'                                   => (isset($request->shipper_drop_or_keep_driver)) ? $request->shipper_drop_or_keep_driver : null,
                            'retrieval_notification'                                => (isset($request->shipper_drop_retrieval_notification)) ? $request->shipper_drop_retrieval_notification : '0',
                            'notify_date'                                           => (isset($request->shipper_drop_notify_date) && $request->shipper_drop_notify_date != "") ? $request->shipper_drop_notify_date : null,
                            'notify_users'                                          => (isset($request->shipper_drop_notify_users) && count($request->shipper_drop_notify_users) > 0) ? implode(',', $request->shipper_drop_notify_users) : null,
                            'created_by'                                            => auth()->guard('company-admin')->user()->id,
                            'created_at'                                            => now(),
                        );

                        if(isset($request->shipper_drop_or_keep_driver) && $request->shipper_drop_or_keep_driver == '1'){
                            $loadDetail->update([
                                'driver_id' => 0,
                                'load_type' => 0,
                                'is_on_hold' => 3
                            ]);

                            if((isset($request->shipper_drop_notify_users) && count($request->shipper_drop_notify_users) > 0)){
                                sendDroppedDropTrailerNotification($request->shipper_drop_notify_users, ['load_number' => $loadDetail->load_number]);
                            }
                        }else if(isset($request->shipper_drop_or_keep_driver) && $request->shipper_drop_or_keep_driver == '2'){
                            $loadDetail->update([
                                'is_on_hold' => 1,
                                'load_on_hold_datetime' => Carbon::now()->format('Y-m-d H:i:s')
                            ]);

                            if((isset($request->shipper_drop_notify_users) && count($request->shipper_drop_notify_users) > 0)){
                                sendOnHoldDropTrailerNotification($request->shipper_drop_notify_users, ['load_number' => $loadDetail->load_number]);
                            }
                        }

                        if((isset($request->shipper_drop_hook_loc_by_user) && $request->shipper_drop_hook_loc_by_user != "") || (isset($request->shipper_drop_hook_loc_by_stop) && $request->shipper_drop_hook_loc_by_stop != "") || (isset($request->shipper_drop_hook_loc_by_custom) && $request->shipper_drop_hook_loc_by_custom == '1')){
                            if(isset($request->shipper_drop_hook_loc_by_custom) && $request->shipper_drop_hook_loc_by_custom == '1'){
                                $dropHookAtStop                                         = '2';
                                $hookUserType                                           = null;
                                $hookLoc                                                = null;
                            }else{
                                $dropHookAtStop                                         = (isset($request->shipper_drop_hook_at_stop) && $request->shipper_drop_hook_at_stop == '1') ? $request->shipper_drop_hook_at_stop : '0';
                                 $hookUserType                                          = (!isset($request->shipper_drop_hook_at_stop)) ? $request->shipper_drop_hook_user_type : null;
                                 $hookLoc                                               = (isset($request->shipper_drop_hook_at_stop)) ? $request->shipper_drop_hook_loc_by_stop : $request->shipper_drop_hook_loc_by_user;
                            }

                            $shipperDropHookLatitude                                        = null;
                            $shipperDropHookLongitude                                       = null;
                            $shipperDropHookTimezone                                        = null;
                            $shipperDropHookTimezoneOffset                                  = null;
                            $shipperDropHookTimezoneAbbr                                    = null;
                            $shipperDropHookAddressVerified                                 = 0;
                            if($request->shipper_drop_hook_address_verified == 1){
                                $shipperDropHookLatitude                                    = ($request->shipper_drop_hook_latitude != "") ? $request->shipper_drop_hook_latitude : null;
                                $shipperDropHookLongitude                                   = ($request->shipper_drop_hook_longitude != "") ? $request->shipper_drop_hook_longitude : null;
                                $shipperDropHookTimezoneAbbr                                = ($request->shipper_drop_hook_timezone_abbr != "") ? $request->shipper_drop_hook_timezone_abbr : null;
                                $shipperDropHookAddressVerified                             = ($request->shipper_drop_hook_address_verified != "") ? $request->shipper_drop_hook_address_verified : 0;

                                if(isset($request->shipper_drop_hook_timezone_abbr)){
                                    $shipperDropHookTimezone                                = timezone_name_from_abbr($shipperDropHookTimezoneAbbr);
                                    $shipperDropHookTimezoneOffset                          = Carbon::createFromTimestamp(time(), $shipperDropHookTimezone)->getOffsetString();
                                }

                                $getTrailer                                             = Trailer::IsCompany()->where('trailer_id', $request->shipper_drop_hook_trailer_number)->first();
                                if(!is_null($getTrailer)){
                                    $getTrailer->last_location_load_status              = (isset($request->shipper_drop_hook_empty_loaded) && $request->shipper_drop_hook_empty_loaded == '0') ? $request->shipper_drop_hook_empty_loaded : '1';
                                    $getTrailer->last_location_address                  = (isset($request->shipper_drop_hook_add1) && $request->shipper_drop_hook_add1 != "") ? $request->shipper_drop_hook_add1 : null;
                                    $getTrailer->last_location_address_2                = (isset($request->shipper_drop_hook_add2) && $request->shipper_drop_hook_add2 != "") ? $request->shipper_drop_hook_add2 : null;
                                    $getTrailer->last_location_city                     = (isset($request->shipper_drop_hook_city) && $request->shipper_drop_hook_city != "") ? $request->shipper_drop_hook_city : null;
                                    $getTrailer->last_location_state                    = (isset($request->shipper_drop_hook_state) && $request->shipper_drop_hook_state != "") ? $request->shipper_drop_hook_state : null;
                                    $getTrailer->last_location_zip                      = (isset($request->shipper_drop_hook_zip) && $request->shipper_drop_hook_zip != "") ? $request->shipper_drop_hook_zip : null;
                                    $getTrailer->last_location_latitude                 = $shipperDropHookLatitude;
                                    $getTrailer->last_location_longitude                = $shipperDropHookLongitude;
                                    $getTrailer->last_location_timezone                 = $shipperDropHookTimezone;
                                    $getTrailer->last_location_timezone_offset          = $shipperDropHookTimezoneOffset;
                                    $getTrailer->last_location_timezone_abbr            = $shipperDropHookTimezoneAbbr;
                                    $getTrailer->last_location_address_verified         = $shipperDropHookAddressVerified;
                                    $getTrailer->last_location_notes                    = (isset($request->shipper_drop_hook_notes) && $request->shipper_drop_hook_notes != "") ? $request->shipper_drop_hook_notes : null;
                                    $getTrailer->save();
                                }
                            }

                            $dropTrailers[]                                          = array(
                                'load_id'                                               => $load->id,
                                'stop_number'                                           => '1',
                                'type'                                                  => '2',
                                'driver_id'                                             => $loadDetail->driver_id,
                                'truck_number'                                          => $request->truck_number,
                                'trailer_number'                                        => $request->shipper_drop_hook_trailer_number,
                                'empty_loaded'                                          => (isset($request->shipper_drop_hook_empty_loaded) && $request->shipper_drop_hook_empty_loaded == '0') ? $request->shipper_drop_hook_empty_loaded : '1',
                                'drop_at_stop'                                          => $dropHookAtStop,
                                'keep_assigned'                                         => (isset($request->shipper_drop_hook_keep_assigned) && $request->shipper_drop_hook_keep_assigned == '1') ? $request->shipper_drop_hook_keep_assigned : '0',
                                'drop_date'                                             => (isset($request->shipper_dorp_hook_date) && $request->shipper_dorp_hook_date != "") ? $request->shipper_dorp_hook_date : null,
                                'user_type'                                             => $hookUserType,
                                'loc'                                                   => $hookLoc,
                                'add1'                                                  => (isset($request->shipper_drop_hook_add1) && $request->shipper_drop_hook_add1 != "") ? $request->shipper_drop_hook_add1 : null,
                                'add2'                                                  => (isset($request->shipper_drop_hook_add2) && $request->shipper_drop_hook_add2 != "") ? $request->shipper_drop_hook_add2 : null,
                                'city'                                                  => (isset($request->shipper_drop_hook_city) && $request->shipper_drop_hook_city != "") ? $request->shipper_drop_hook_city : null,
                                'state'                                                 => (isset($request->shipper_drop_hook_state) && $request->shipper_drop_hook_state != "") ? $request->shipper_drop_hook_state : null,
                                'zip'                                                   => (isset($request->shipper_drop_hook_zip) && $request->shipper_drop_hook_zip != "") ? $request->shipper_drop_hook_zip : null,
                                'latitude'                                              => $shipperDropHookLatitude,
                                'longitude'                                             => $shipperDropHookLongitude,
                                'timezone'                                              => $shipperDropHookTimezone,
                                'timezone_offset'                                       => $shipperDropHookTimezoneOffset,
                                'timezone_abbr'                                         => $shipperDropHookTimezoneAbbr,
                                'address_verified'                                      => $shipperDropHookAddressVerified,
                                'notes'                                                 => (isset($request->shipper_drop_hook_notes) && $request->shipper_drop_hook_notes != "") ? $request->shipper_drop_hook_notes : null,
                                'drop_or_keep_driver'                                   => (isset($request->shipper_drop_or_keep_driver)) ? $request->shipper_drop_or_keep_driver : null,
                                'retrieval_notification'                                => (isset($request->shipper_drop_retrieval_notification)) ? $request->shipper_drop_retrieval_notification : '0',
                                'notify_date'                                           => (isset($request->shipper_drop_notify_date) && $request->shipper_drop_notify_date != "") ? $request->shipper_drop_notify_date : null,
                                'notify_users'                                          => (isset($request->shipper_drop_notify_users) && count($request->shipper_drop_notify_users) > 0) ? implode(',', $request->shipper_drop_notify_users) : null,
                                'created_by'                                            => auth()->guard('company-admin')->user()->id,
                                'created_at'                                            => now(),
                            );
                        }
                    }

                    if(isset($request->drop) && count($request->drop) > 0){
                        foreach ($request->drop as $key => $dynamicDropDtails){
                            if((isset($dynamicDropDtails['loc_by_user']) && $dynamicDropDtails['loc_by_user'] != "") || (isset($dynamicDropDtails['loc_by_stop']) && $dynamicDropDtails['loc_by_stop'] != "") || (isset($dynamicDropDtails['loc_by_custom']) && $dynamicDropDtails['loc_by_custom'] == '1')){
                                if(isset($dynamicDropDtails['loc_by_custom']) && $dynamicDropDtails['loc_by_custom'] == '1'){
                                    $dropAtStop                                     = '2';
                                    $userType                                       = null;
                                    $loc                                            = null;
                                }else{
                                    $dropAtStop                                     = (isset($dynamicDropDtails['drop_at_stop']) && $dynamicDropDtails['drop_at_stop'] == '1') ? $dynamicDropDtails['drop_at_stop'] : '0';
                                    $userType                                       = (!isset($dynamicDropDtails['drop_at_stop'])) ? $dynamicDropDtails['user_type'] : null;
                                    $loc                                            = (isset($dynamicDropDtails['drop_at_stop'])) ? $dynamicDropDtails['loc_by_stop'] : $dynamicDropDtails['loc_by_user'];
                                }

                                $dropLatitude                                       = null;
                                $dropLongitude                                      = null;
                                $dropTimezone                                       = null;
                                $dropTimezoneOffset                                 = null;
                                $dropTimezoneAbbr                                   = null;
                                $dropAddressVerified                                = 0;
                                if($dynamicDropDtails['drop_address_verified'] == 1){
                                    $dropLatitude                                   = ($dynamicDropDtails['drop_latitude'] != "") ? $dynamicDropDtails['drop_latitude'] : null;
                                    $dropLongitude                                  = ($dynamicDropDtails['drop_longitude'] != "") ? $dynamicDropDtails['drop_longitude'] : null;
                                    $dropTimezoneAbbr                               = ($dynamicDropDtails['drop_timezone_abbr'] != "") ? $dynamicDropDtails['drop_timezone_abbr'] : null;
                                    $dropAddressVerified                            = ($dynamicDropDtails['drop_address_verified'] != "") ? $dynamicDropDtails['drop_address_verified'] : 0;

                                    if(isset($dynamicDropDtails['drop_timezone_abbr'])){
                                        $dropTimezone                               = timezone_name_from_abbr($dropTimezoneAbbr);
                                        $dropTimezoneOffset                         = Carbon::createFromTimestamp(time(), $dropTimezone)->getOffsetString();
                                    }

                                    $getTrailer                                     = Trailer::IsCompany()->where('trailer_id', $dynamicDropDtails['drop_trailer_number'])->first();
                                    if(!is_null($getTrailer)){
                                        $getTrailer->last_location_load_status      = (isset($dynamicDropDtails['empty_loaded']) && $dynamicDropDtails['empty_loaded'] == '0') ? $dynamicDropDtails['empty_loaded'] : '1';
                                        $getTrailer->last_location_address          = (isset($dynamicDropDtails['drop_add1']) && $dynamicDropDtails['drop_add1'] != "") ? $dynamicDropDtails['drop_add1'] : null;
                                        $getTrailer->last_location_address_2        = (isset($dynamicDropDtails['drop_add2']) && $dynamicDropDtails['drop_add2'] != "") ? $dynamicDropDtails['drop_add2'] : null;
                                        $getTrailer->last_location_city             = (isset($dynamicDropDtails['drop_city']) && $dynamicDropDtails['drop_city'] != "") ? $dynamicDropDtails['drop_city'] : null;
                                        $getTrailer->last_location_state            = (isset($dynamicDropDtails['drop_state']) && $dynamicDropDtails['drop_state'] != "") ? $dynamicDropDtails['drop_state'] : null;
                                        $getTrailer->last_location_zip              = (isset($dynamicDropDtails['drop_zip']) && $dynamicDropDtails['drop_zip'] != "") ? $dynamicDropDtails['drop_zip'] : null;
                                        $getTrailer->last_location_latitude         = $dropLatitude;
                                        $getTrailer->last_location_longitude        = $dropLongitude;
                                        $getTrailer->last_location_timezone         = $dropTimezone;
                                        $getTrailer->last_location_timezone_offset  = $dropTimezoneOffset;
                                        $getTrailer->last_location_timezone_abbr    = $dropTimezoneAbbr;
                                        $getTrailer->last_location_address_verified = $dropAddressVerified;
                                        $getTrailer->last_location_notes            = (isset($dynamicDropDtails['drop_notes']) && $dynamicDropDtails['drop_notes'] != "") ? $dynamicDropDtails['drop_notes'] : null;
                                        $getTrailer->save();
                                    }
                                }

                                $dropTrailers[]                                  = array(
                                    'load_id'                                       => $load->id,
                                    'type'                                          => '1',
                                    'stop_number'                                   => $dynamicDropDtails['stop_number'],
                                    'driver_id'                                     => $loadDetail->driver_id,
                                    'truck_number'                                  => $request->truck_number,
                                    'trailer_number'                                => $dynamicDropDtails['drop_trailer_number'],
                                    'empty_loaded'                                  => (isset($dynamicDropDtails['empty_loaded']) && $dynamicDropDtails['empty_loaded'] == '0') ? $dynamicDropDtails['empty_loaded'] : '1',
                                    'drop_at_stop'                                  => $dropAtStop,
                                    'keep_assigned'                                 => (isset($dynamicDropDtails['keep_assigned']) && $dynamicDropDtails['keep_assigned'] == '1') ? $dynamicDropDtails['keep_assigned'] : '0',
                                    'drop_date'                                     => (isset($dynamicDropDtails['dorp_date']) && $dynamicDropDtails['dorp_date'] != "") ? $dynamicDropDtails['dorp_date'] : null,
                                    'user_type'                                     => $userType,
                                    'loc'                                           => $loc,
                                    'add1'                                          => (isset($dynamicDropDtails['drop_add1']) && $dynamicDropDtails['drop_add1'] != "") ? $dynamicDropDtails['drop_add1'] : null,
                                    'add2'                                          => (isset($dynamicDropDtails['drop_add2']) && $dynamicDropDtails['drop_add2'] != "") ? $dynamicDropDtails['drop_add2'] : null,
                                    'city'                                          => (isset($dynamicDropDtails['drop_city']) && $dynamicDropDtails['drop_city'] != "") ? $dynamicDropDtails['drop_city'] : null,
                                    'state'                                         => (isset($dynamicDropDtails['drop_state']) && $dynamicDropDtails['drop_state'] != "") ? $dynamicDropDtails['drop_state'] : null,
                                    'zip'                                           => (isset($dynamicDropDtails['drop_zip']) && $dynamicDropDtails['drop_zip'] != "") ? $dynamicDropDtails['drop_zip'] : null,
                                    'latitude'                                      => $dropLatitude,
                                    'longitude'                                     => $dropLongitude,
                                    'timezone'                                      => $dropTimezone,
                                    'timezone_offset'                               => $dropTimezoneOffset,
                                    'timezone_abbr'                                 => $dropTimezoneAbbr,
                                    'address_verified'                              => $dropAddressVerified,
                                    'notes'                                         => (isset($dynamicDropDtails['drop_notes']) && $dynamicDropDtails['drop_notes'] != "") ? $dynamicDropDtails['drop_notes'] : null,
                                    'drop_or_keep_driver'                           => (isset($dynamicDropDtails['drop_or_keep_driver']) && $dynamicDropDtails['drop_or_keep_driver'] != "") ? $dynamicDropDtails['drop_or_keep_driver'] : null,
                                    'retrieval_notification'                        => (isset($dynamicDropDtails['retrieval_notification']) && $dynamicDropDtails['retrieval_notification'] != "") ? $dynamicDropDtails['retrieval_notification'] : '0',
                                    'notify_date'                                   => (isset($dynamicDropDtails['notify_date']) && $dynamicDropDtails['notify_date'] != "") ? $dynamicDropDtails['notify_date'] : null,
                                    'notify_users'                                  => (isset($dynamicDropDtails['notify_users']) && count($dynamicDropDtails['notify_users']) > 0) ? implode(',', $dynamicDropDtails['notify_users']) : null,
                                    'created_by'                                    => auth()->guard('company-admin')->user()->id,
                                    'created_at'                                    => now(),
                                );

                                if(isset($dynamicDropDtails['drop_or_keep_driver']) && $dynamicDropDtails['drop_or_keep_driver'] == '1'){
                                    $loadDetail->update([
                                        'driver_id' => 0,
                                        'load_type' => 0,
                                        'is_on_hold' => 3
                                    ]);

                                    if((isset($dynamicDropDtails['notify_users']) && count($dynamicDropDtails['notify_users']) > 0)){
                                        sendDroppedDropTrailerNotification($dynamicDropDtails['notify_users'], ['load_number' => $loadDetail->load_number]);
                                    }
                                }else if(isset($dynamicDropDtails['drop_or_keep_driver']) && $dynamicDropDtails['drop_or_keep_driver'] == '2'){
                                    $loadDetail->update([
                                        'is_on_hold' => 1,
                                        'load_on_hold_datetime' => Carbon::now()->format('Y-m-d H:i:s')
                                    ]);

                                    if((isset($dynamicDropDtails['notify_users']) && count($dynamicDropDtails['notify_users']) > 0)){
                                        sendOnHoldDropTrailerNotification($dynamicDropDtails['notify_users'], ['load_number' => $loadDetail->load_number]);
                                    }
                                }

                                if((isset($request->drophook[$key]['loc_by_user']) && $request->drophook[$key]['loc_by_user'] != "") || (isset($request->drophook[$key]['loc_by_stop']) && $request->drophook[$key]['loc_by_stop'] != "") || (isset($request->drophook[$key]['loc_by_custom']) && $request->drophook[$key]['loc_by_custom'] == '1')){
                                    if(isset($request->drophook[$key]['loc_by_custom']) && $request->drophook[$key]['loc_by_custom'] == '1'){
                                        $dropAtStop                                     = '2';
                                        $userType                                       = null;
                                        $loc                                            = null;
                                    }else{
                                        $dropAtStop                                     = (isset($request->drophook[$key]['drop_at_stop']) && $request->drophook[$key]['drop_at_stop'] == '1') ? $request->drophook[$key]['drop_at_stop'] : '0';
                                        $userType                                       = (!isset($request->drophook[$key]['drop_at_stop'])) ? $request->drophook[$key]['user_type'] : null;
                                        $loc                                            = (isset($request->drophook[$key]['drop_at_stop'])) ? $request->drophook[$key]['loc_by_stop'] : $request->drophook[$key]['loc_by_user'];
                                    }

                                    $dropHookLatitude                                       = null;
                                    $dropHookLongitude                                      = null;
                                    $dropHookTimezone                                       = null;
                                    $dropHookTimezoneOffset                                 = null;
                                    $dropHookTimezoneAbbr                                   = null;
                                    $dropHookAddressVerified                                = 0;
                                    if($request->drophook[$key]['drop_address_verified'] == 1){
                                        $dropHookLatitude                                   = ($request->drophook[$key]['drop_latitude'] != "") ? $request->drophook[$key]['drop_latitude'] : null;
                                        $dropHookLongitude                                  = ($request->drophook[$key]['drop_longitude'] != "") ? $request->drophook[$key]['drop_longitude'] : null;
                                        $dropHookTimezoneAbbr                               = ($request->drophook[$key]['drop_timezone_abbr'] != "") ? $request->drophook[$key]['drop_timezone_abbr'] : null;
                                        $dropHookAddressVerified                            = ($request->drophook[$key]['drop_address_verified'] != "") ? $request->drophook[$key]['drop_address_verified'] : 0;

                                        if(isset($request->drophook[$key]['drop_timezone_abbr'])){
                                            $dropHookTimezone                               = timezone_name_from_abbr($dropHookTimezoneAbbr);
                                            $dropHookTimezoneOffset                         = Carbon::createFromTimestamp(time(), $dropHookTimezone)->getOffsetString();
                                        }

                                        $getTrailer                                     = Trailer::IsCompany()->where('trailer_id', $request->drophook[$key]['drop_trailer_number'])->first();
                                        if(!is_null($getTrailer)){
                                            $getTrailer->last_location_load_status      = (isset($request->drophook[$key]['empty_loaded']) && $request->drophook[$key]['empty_loaded'] == '0') ? $request->drophook[$key]['empty_loaded'] : '1';
                                            $getTrailer->last_location_address          = (isset($request->drophook[$key]['drop_add1']) && $request->drophook[$key]['drop_add1'] != "") ? $request->drophook[$key]['drop_add1'] : null;
                                            $getTrailer->last_location_address_2        = (isset($request->drophook[$key]['drop_add2']) && $request->drophook[$key]['drop_add2'] != "") ? $request->drophook[$key]['drop_add2'] : null;
                                            $getTrailer->last_location_city             = (isset($request->drophook[$key]['drop_city']) && $request->drophook[$key]['drop_city'] != "") ? $request->drophook[$key]['drop_city'] : null;
                                            $getTrailer->last_location_state            = (isset($request->drophook[$key]['drop_state']) && $request->drophook[$key]['drop_state'] != "") ? $request->drophook[$key]['drop_state'] : null;
                                            $getTrailer->last_location_zip              = (isset($request->drophook[$key]['drop_zip']) && $request->drophook[$key]['drop_zip'] != "") ? $request->drophook[$key]['drop_zip'] : null;
                                            $getTrailer->last_location_latitude         = $dropHookLatitude;
                                            $getTrailer->last_location_longitude        = $dropHookLongitude;
                                            $getTrailer->last_location_timezone         = $dropHookTimezone;
                                            $getTrailer->last_location_timezone_offset  = $dropHookTimezoneOffset;
                                            $getTrailer->last_location_timezone_abbr    = $dropHookTimezoneAbbr;
                                            $getTrailer->last_location_address_verified = $dropHookAddressVerified;
                                            $getTrailer->last_location_notes            = (isset($request->drophook[$key]['drop_notes']) && $request->drophook[$key]['drop_notes'] != "") ? $request->drophook[$key]['drop_notes'] : null;
                                            $getTrailer->save();
                                        }
                                    }

                                    $dropTrailers[]                                  = array(
                                        'load_id'                                       => $load->id,
                                        'type'                                          => '2',
                                        'stop_number'                                   => $dynamicDropDtails['stop_number'],
                                        'driver_id'                                     => $loadDetail->driver_id,
                                        'truck_number'                                  => $request->truck_number,
                                        'trailer_number'                                => $request->drophook[$key]['drop_trailer_number'],
                                        'empty_loaded'                                  => (isset($request->drophook[$key]['empty_loaded']) && $request->drophook[$key]['empty_loaded'] == '0') ? $request->drophook[$key]['empty_loaded'] : '1',
                                        'drop_at_stop'                                  => $dropAtStop,
                                        'keep_assigned'                                 => (isset($request->drophook[$key]['keep_assigned']) && $request->drophook[$key]['keep_assigned'] == '1') ? $request->drophook[$key]['keep_assigned'] : '0',
                                        'drop_date'                                     => (isset($request->drophook[$key]['dorp_date']) && $request->drophook[$key]['dorp_date'] != "") ? $request->drophook[$key]['dorp_date'] : null,
                                        'user_type'                                     => $userType,
                                        'loc'                                           => $loc,
                                        'add1'                                          => (isset($request->drophook[$key]['drop_add1']) && $request->drophook[$key]['drop_add1'] != "") ? $request->drophook[$key]['drop_add1'] : null,
                                        'add2'                                          => (isset($request->drophook[$key]['drop_add2']) && $request->drophook[$key]['drop_add2'] != "") ? $request->drophook[$key]['drop_add2'] : null,
                                        'city'                                          => (isset($request->drophook[$key]['drop_city']) && $request->drophook[$key]['drop_city'] != "") ? $request->drophook[$key]['drop_city'] : null,
                                        'state'                                         => (isset($request->drophook[$key]['drop_state']) && $request->drophook[$key]['drop_state'] != "") ? $request->drophook[$key]['drop_state'] : null,
                                        'zip'                                           => (isset($request->drophook[$key]['drop_zip']) && $request->drophook[$key]['drop_zip'] != "") ? $request->drophook[$key]['drop_zip'] : null,
                                        'latitude'                                      => $dropHookLatitude,
                                        'longitude'                                     => $dropHookLongitude,
                                        'timezone'                                      => $dropHookTimezone,
                                        'timezone_offset'                               => $dropHookTimezoneOffset,
                                        'timezone_abbr'                                 => $dropHookTimezoneAbbr,
                                        'address_verified'                              => $dropHookAddressVerified,
                                        'notes'                                         => (isset($request->drophook[$key]['drop_notes']) && $request->drophook[$key]['drop_notes'] != "") ? $request->drophook[$key]['drop_notes'] : null,
                                        'drop_or_keep_driver'                           => (isset($dynamicDropDtails['drop_or_keep_driver']) && $dynamicDropDtails['drop_or_keep_driver'] != "") ? $dynamicDropDtails['drop_or_keep_driver'] : null,
                                        'retrieval_notification'                        => (isset($dynamicDropDtails['retrieval_notification']) && $dynamicDropDtails['retrieval_notification'] != "") ? $dynamicDropDtails['retrieval_notification'] : '0',
                                        'notify_date'                                   => (isset($dynamicDropDtails['notify_date']) && $dynamicDropDtails['notify_date'] != "") ? $dynamicDropDtails['notify_date'] : null,
                                        'notify_users'                                  => (isset($dynamicDropDtails['notify_users']) && count($dynamicDropDtails['notify_users']) > 0) ? implode(',', $dynamicDropDtails['notify_users']) : null,
                                        'created_by'                                    => auth()->guard('company-admin')->user()->id,
                                        'created_at'                                    => now(),
                                    );
                                }
                            }
                        }
                    }

                    if((isset($request->delivery_drop_loc_by_user) && $request->delivery_drop_loc_by_user != "") || (isset($request->delivery_drop_loc_by_stop) && $request->delivery_drop_loc_by_stop != "") || (isset($request->delivery_drop_loc_by_custom) && $request->delivery_drop_loc_by_custom == '1')){
                        if(isset($request->delivery_drop_loc_by_custom) && $request->delivery_drop_loc_by_custom == '1'){
                            $dropAtStop                                             = '2';
                            $userType                                               = null;
                            $loc                                                    = null;
                        }else{
                            $dropAtStop                                             = (isset($request->delivery_drop_at_stop) && $request->delivery_drop_at_stop == '1') ? $request->delivery_drop_at_stop : '0';
                            $userType                                               = (!isset($request->delivery_drop_at_stop)) ? $request->delivery_drop_user_type : null;
                            $loc                                                    = (isset($request->delivery_drop_at_stop)) ? $request->delivery_drop_loc_by_stop : $request->delivery_drop_loc_by_user;
                        }

                        $deliveryDropLatitude                                       = null;
                        $deliveryDropLongitude                                      = null;
                        $deliveryDropTimezone                                       = null;
                        $deliveryDropTimezoneOffset                                 = null;
                        $deliveryDropTimezoneAbbr                                   = null;
                        $deliveryDropAddressVerified                                = null;
                        if($request->delivery_drop_address_verified == 1){
                            $deliveryDropLatitude                                   = ($request->delivery_drop_latitude != "") ? $request->delivery_drop_latitude : null;
                            $deliveryDropLongitude                                  = ($request->delivery_drop_longitude != "") ? $request->delivery_drop_longitude : null;
                            $deliveryDropTimezoneAbbr                               = ($request->delivery_drop_timezone_abbr != "") ? $request->delivery_drop_timezone_abbr : null;
                            $deliveryDropAddressVerified                            = ($request->delivery_drop_address_verified != "") ? $request->delivery_drop_address_verified : null;

                            if(isset($request->delivery_drop_timezone_abbr)){
                                $deliveryDropTimezone                               = timezone_name_from_abbr($deliveryDropTimezoneAbbr);
                                $deliveryDropTimezoneOffset                         = Carbon::createFromTimestamp(time(), $deliveryDropTimezone)->getOffsetString();
                            }

                            $getTrailer                                             = Trailer::IsCompany()->where('trailer_id', $request->delivery_drop_trailer_number)->first();
                            if(!is_null($getTrailer)){
                                $getTrailer->last_location_load_status              = (isset($request->delivery_drop_empty_loaded) && $request->delivery_drop_empty_loaded == '0') ? $request->delivery_drop_empty_loaded : '1';
                                $getTrailer->last_location_address                  = (isset($request->delivery_drop_add1) && $request->delivery_drop_add1 != "") ? $request->delivery_drop_add1 : null;
                                $getTrailer->last_location_address_2                = (isset($request->delivery_drop_add2) && $request->delivery_drop_add2 != "") ? $request->delivery_drop_add2 : null;
                                $getTrailer->last_location_city                     = (isset($request->delivery_drop_city) && $request->delivery_drop_city != "") ? $request->delivery_drop_city : null;
                                $getTrailer->last_location_state                    = (isset($request->delivery_drop_state) && $request->delivery_drop_state != "") ? $request->delivery_drop_state : null;
                                $getTrailer->last_location_zip                      = (isset($request->delivery_drop_zip) && $request->delivery_drop_zip != "") ? $request->delivery_drop_zip : null;
                                $getTrailer->last_location_latitude                 = $deliveryDropLatitude;
                                $getTrailer->last_location_longitude                = $deliveryDropLongitude;
                                $getTrailer->last_location_timezone                 = $deliveryDropTimezone;
                                $getTrailer->last_location_timezone_offset          = $deliveryDropTimezoneOffset;
                                $getTrailer->last_location_timezone_abbr            = $deliveryDropTimezoneAbbr;
                                $getTrailer->last_location_address_verified         = $deliveryDropAddressVerified;
                                $getTrailer->last_location_notes                    = (isset($request->delivery_drop_notes) && $request->delivery_drop_notes != "") ? $request->delivery_drop_notes : null;
                                $getTrailer->save();
                            }
                        }

                        $dropTrailers[]                                          = array(
                            'load_id'                                               => $load->id,
                            'stop_number'                                           => '99',
                            'type'                                                  => '1',
                            'driver_id'                                             => $loadDetail->driver_id,
                            'truck_number'                                          => $request->truck_number,
                            'trailer_number'                                        => $request->delivery_drop_trailer_number,
                            'empty_loaded'                                          => (isset($request->delivery_drop_empty_loaded) && $request->delivery_drop_empty_loaded == '0') ? $request->delivery_drop_empty_loaded : '1',
                            'drop_at_stop'                                          => $dropAtStop,
                            'keep_assigned'                                         => (isset($request->delivery_drop_keep_assigned) && $request->delivery_drop_keep_assigned == '1') ? $request->delivery_drop_keep_assigned : '0',
                            'drop_date'                                             => (isset($request->delivery_dorp_date) && $request->delivery_dorp_date != "") ? $request->delivery_dorp_date : null,
                            'user_type'                                             => $userType,
                            'loc'                                                   => $loc,
                            'add1'                                                  => (isset($request->delivery_drop_add1) && $request->delivery_drop_add1 != "") ? $request->delivery_drop_add1 : null,
                            'add2'                                                  => (isset($request->delivery_drop_add2) && $request->delivery_drop_add2 != "") ? $request->delivery_drop_add2 : null,
                            'city'                                                  => (isset($request->delivery_drop_city) && $request->delivery_drop_city != "") ? $request->delivery_drop_city : null,
                            'state'                                                 => (isset($request->delivery_drop_state) && $request->delivery_drop_state != "") ? $request->delivery_drop_state : null,
                            'zip'                                                   => (isset($request->delivery_drop_zip) && $request->delivery_drop_zip != "") ? $request->delivery_drop_zip : null,
                            'latitude'                                              => $deliveryDropLatitude,
                            'longitude'                                             => $deliveryDropLongitude,
                            'timezone'                                              => $deliveryDropTimezone,
                            'timezone_offset'                                       => $deliveryDropTimezoneOffset,
                            'timezone_abbr'                                         => $deliveryDropTimezoneAbbr,
                            'address_verified'                                      => $deliveryDropAddressVerified,
                            'notes'                                                 => (isset($request->delivery_drop_notes) && $request->delivery_drop_notes != "") ? $request->delivery_drop_notes : null,
                            'drop_or_keep_driver'                                   => (isset($request->delivery_drop_or_keep_driver)) ? $request->delivery_drop_or_keep_driver : null,
                            'retrieval_notification'                                => (isset($request->delivery_drop_retrieval_notification)) ? $request->delivery_drop_retrieval_notification : '0',
                            'notify_date'                                           => (isset($request->delivery_drop_notify_date) && $request->delivery_drop_notify_date != "") ? $request->delivery_drop_notify_date : null,
                            'notify_users'                                          => (isset($request->delivery_drop_notify_users) && count($request->delivery_drop_notify_users) > 0) ? implode(',', $request->delivery_drop_notify_users) : null,
                            'created_by'                                            => auth()->guard('company-admin')->user()->id,
                            'created_at'                                            => now(),
                        );

                        if(isset($request->delivery_drop_or_keep_driver) && $request->delivery_drop_or_keep_driver == '1'){
                            $loadDetail->update([
                                'driver_id' => 0,
                                'load_type' => 0,
                                'is_on_hold' => 3
                            ]);

                            if((isset($request->delivery_drop_notify_users) && count($request->delivery_drop_notify_users) > 0)){
                                sendDroppedDropTrailerNotification($request->delivery_drop_notify_users, ['load_number' => $loadDetail->load_number]);
                            }
                        }else if(isset($request->delivery_drop_or_keep_driver) && $request->delivery_drop_or_keep_driver == '2'){
                            $loadDetail->update([
                                'is_on_hold' => 1,
                                'load_on_hold_datetime' => Carbon::now()->format('Y-m-d H:i:s')
                            ]);

                            if((isset($request->delivery_drop_notify_users) && count($request->delivery_drop_notify_users) > 0)){
                                sendOnHoldDropTrailerNotification($request->delivery_drop_notify_users, ['load_number' => $loadDetail->load_number]);
                            }
                        }

                        if((isset($request->delivery_drop_hook_loc_by_user) && $request->delivery_drop_hook_loc_by_user != "") || (isset($request->delivery_drop_hook_loc_by_stop) && $request->delivery_drop_hook_loc_by_stop != "") || (isset($request->delivery_drop_hook_loc_by_custom) && $request->delivery_drop_hook_loc_by_custom == '1')){
                            if(isset($request->delivery_drop_hook_loc_by_custom) && $request->delivery_drop_hook_loc_by_custom == '1'){
                                $dropHookAtStop                                         = '2';
                                $hookUserType                                           = null;
                                $hookLoc                                                = null;
                            }else{
                                $dropHookAtStop                                         = (isset($request->delivery_drop_hook_at_stop) && $request->delivery_drop_hook_at_stop == '1') ? $request->delivery_drop_hook_at_stop : '0';
                                $hookUserType                                          = (!isset($request->delivery_drop_hook_at_stop)) ? $request->delivery_drop_hook_user_type : null;
                                $hookLoc                                               = (isset($request->delivery_drop_hook_at_stop)) ? $request->delivery_drop_hook_loc_by_stop : $request->delivery_drop_hook_loc_by_user;
                            }

                            $deliveryDropHookLatitude                                        = null;
                            $deliveryDropHookLongitude                                       = null;
                            $deliveryDropHookTimezone                                        = null;
                            $deliveryDropHookTimezoneOffset                                  = null;
                            $deliveryDropHookTimezoneAbbr                                    = null;
                            $deliveryDropHookAddressVerified                                 = 0;
                            if($request->delivery_drop_hook_address_verified == 1){
                                $deliveryDropHookLatitude                                    = ($request->delivery_drop_hook_latitude != "") ? $request->delivery_drop_hook_latitude : null;
                                $deliveryDropHookLongitude                                   = ($request->delivery_drop_hook_longitude != "") ? $request->delivery_drop_hook_longitude : null;
                                $deliveryDropHookTimezoneAbbr                                = ($request->delivery_drop_hook_timezone_abbr != "") ? $request->delivery_drop_hook_timezone_abbr : null;
                                $deliveryDropHookAddressVerified                             = ($request->delivery_drop_hook_address_verified != "") ? $request->delivery_drop_hook_address_verified : 0;

                                if(isset($request->delivery_drop_hook_timezone_abbr)){
                                    $deliveryDropHookTimezone                                = timezone_name_from_abbr($deliveryDropHookTimezoneAbbr);
                                    $deliveryDropHookTimezoneOffset                          = Carbon::createFromTimestamp(time(), $deliveryDropHookTimezone)->getOffsetString();
                                }

                                $getTrailer                                             = Trailer::IsCompany()->where('trailer_id', $request->delivery_drop_hook_trailer_number)->first();
                                if(!is_null($getTrailer)){
                                    $getTrailer->last_location_load_status              = (isset($request->delivery_drop_hook_empty_loaded) && $request->delivery_drop_hook_empty_loaded == '0') ? $request->delivery_drop_hook_empty_loaded : '1';
                                    $getTrailer->last_location_address                  = (isset($request->delivery_drop_hook_add1) && $request->delivery_drop_hook_add1 != "") ? $request->delivery_drop_hook_add1 : null;
                                    $getTrailer->last_location_address_2                = (isset($request->delivery_drop_hook_add2) && $request->delivery_drop_hook_add2 != "") ? $request->delivery_drop_hook_add2 : null;
                                    $getTrailer->last_location_city                     = (isset($request->delivery_drop_hook_city) && $request->delivery_drop_hook_city != "") ? $request->delivery_drop_hook_city : null;
                                    $getTrailer->last_location_state                    = (isset($request->delivery_drop_hook_state) && $request->delivery_drop_hook_state != "") ? $request->delivery_drop_hook_state : null;
                                    $getTrailer->last_location_zip                      = (isset($request->delivery_drop_hook_zip) && $request->delivery_drop_hook_zip != "") ? $request->delivery_drop_hook_zip : null;
                                    $getTrailer->last_location_latitude                 = $deliveryDropHookLatitude;
                                    $getTrailer->last_location_longitude                = $deliveryDropHookLongitude;
                                    $getTrailer->last_location_timezone                 = $deliveryDropHookTimezone;
                                    $getTrailer->last_location_timezone_offset          = $deliveryDropHookTimezoneOffset;
                                    $getTrailer->last_location_timezone_abbr            = $deliveryDropHookTimezoneAbbr;
                                    $getTrailer->last_location_address_verified         = $deliveryDropHookAddressVerified;
                                    $getTrailer->last_location_notes                    = (isset($request->delivery_drop_hook_notes) && $request->delivery_drop_hook_notes != "") ? $request->delivery_drop_hook_notes : null;
                                    $getTrailer->save();
                                }
                            }

                            $dropTrailers[]                                          = array(
                                'load_id'                                               => $load->id,
                                'stop_number'                                           => '99',
                                'type'                                                  => '2',
                                'driver_id'                                             => $loadDetail->driver_id,
                                'truck_number'                                          => $request->truck_number,
                                'trailer_number'                                        => $request->delivery_drop_hook_trailer_number,
                                'empty_loaded'                                          => (isset($request->delivery_drop_hook_empty_loaded) && $request->delivery_drop_hook_empty_loaded == '0') ? $request->delivery_drop_hook_empty_loaded : '1',
                                'drop_at_stop'                                          => $dropHookAtStop,
                                'keep_assigned'                                         => (isset($request->delivery_drop_hook_keep_assigned) && $request->delivery_drop_hook_keep_assigned == '1') ? $request->delivery_drop_hook_keep_assigned : '0',
                                'drop_date'                                             => (isset($request->delivery_dorp_hook_date) && $request->delivery_dorp_hook_date != "") ? $request->delivery_dorp_hook_date : null,
                                'user_type'                                             => $hookUserType,
                                'loc'                                                   => $hookLoc,
                                'add1'                                                  => (isset($request->delivery_drop_hook_add1) && $request->delivery_drop_hook_add1 != "") ? $request->delivery_drop_hook_add1 : null,
                                'add2'                                                  => (isset($request->delivery_drop_hook_add2) && $request->delivery_drop_hook_add2 != "") ? $request->delivery_drop_hook_add2 : null,
                                'city'                                                  => (isset($request->delivery_drop_hook_city) && $request->delivery_drop_hook_city != "") ? $request->delivery_drop_hook_city : null,
                                'state'                                                 => (isset($request->delivery_drop_hook_state) && $request->delivery_drop_hook_state != "") ? $request->delivery_drop_hook_state : null,
                                'zip'                                                   => (isset($request->delivery_drop_hook_zip) && $request->delivery_drop_hook_zip != "") ? $request->delivery_drop_hook_zip : null,
                                'latitude'                                              => $deliveryDropHookLatitude,
                                'longitude'                                             => $deliveryDropHookLongitude,
                                'timezone'                                              => $deliveryDropHookTimezone,
                                'timezone_offset'                                       => $deliveryDropHookTimezoneOffset,
                                'timezone_abbr'                                         => $deliveryDropHookTimezoneAbbr,
                                'address_verified'                                      => $deliveryDropHookAddressVerified,
                                'notes'                                                 => (isset($request->delivery_drop_hook_notes) && $request->delivery_drop_hook_notes != "") ? $request->delivery_drop_hook_notes : null,
                                'drop_or_keep_driver'                                   => (isset($request->delivery_drop_or_keep_driver)) ? $request->delivery_drop_or_keep_driver : null,
                                'retrieval_notification'                                => (isset($request->delivery_drop_retrieval_notification)) ? $request->delivery_drop_retrieval_notification : '0',
                                'notify_date'                                           => (isset($request->delivery_drop_notify_date) && $request->delivery_drop_notify_date != "") ? $request->delivery_drop_notify_date : null,
                                'notify_users'                                          => (isset($request->delivery_drop_notify_users) && count($request->delivery_drop_notify_users) > 0) ? implode(',', $request->delivery_drop_notify_users) : null,
                                'created_by'                                            => auth()->guard('company-admin')->user()->id,
                                'created_at'                                            => now(),
                            );
                        }
                    }

                    if(count($dropTrailers) > 0){
                        LoadLog::Company()->where('load_id', $load->id)->where('description', 'like', '%Drop Trailer%')->orWhere('description', 'like', '%Hook Trailer%')->delete();
                        foreach ($dropTrailers as $dropTrailer){
                            $droppedTrailer = DropTrailer::create($dropTrailer); //Added Drop Trailer data
                            $droppedTrailer->load_status = $load->load_detail->load_status;
                            $droppedTrailer->load_type = $load->load_detail->load_type;

                            createLoadLog(['drop_trailer' => 1], $droppedTrailer, 'edit');
                        }
                    }
                    // Insert Drop Trailers data - End
                    // Drop Trailer

                    $temp_detail_accessorials                           = LoadAccessorial::where('load_id', $load->id)
                        ->where('load_detail_id', $loadDetail->id)
                        ->whereNotNull('temp_details')
                        ->get();
                    if($temp_detail_accessorials->isNotEmpty()){
                        foreach ($temp_detail_accessorials as $key => $load_accessorial) {
                            $oldData                                    = [];
                            $oldData                                    = $load_accessorial->toArray();
                            if(isset($load_accessorial->temp_details) && is_serialized($load_accessorial->temp_details) && !empty(unserialize($load_accessorial->temp_details))){
                                $temp_details                           = unserialize($load_accessorial->temp_details);

                                if(isset($temp_details['owner_id'])){
                                    $load_accessorial->owner_id         = $temp_details['owner_id'];
                                    $load_accessorial->owner_type       = $temp_details['owner_type'];
                                }else{
                                    $load_accessorial->owner_liable     = 0;
                                    $load_accessorial->owner_id         = null;
                                    $load_accessorial->owner_type       = null;
                                    $load_accessorial->owner_pay_deduct = 1;
                                    $load_accessorial->owner_qty        = null;
                                    $load_accessorial->owner_rate       = null;
                                    $load_accessorial->owner_total      = null;
                                }

                                if(isset($temp_details['driver_id'])){
                                    $load_accessorial->driver_id        = $temp_details['driver_id'];
                                }else{
                                    $load_accessorial->driver_liable    = 0;
                                    $load_accessorial->driver_id        = null;
                                    $load_accessorial->pay_deduct       = 1;
                                    $load_accessorial->is_deduction     = 0;
                                    $load_accessorial->driver_qty       = null;
                                    $load_accessorial->driver_rate      = null;
                                    $load_accessorial->driver_total     = null;
                                    $load_accessorial->file_not_provided= 'off';
                                }

                                $load_accessorial->status               = $temp_details['status'] ?? $load_accessorial->status;
                                $load_accessorial->updated_at           = Carbon::now();
                                // $load_accessorial->temp_details      = null;
                                if($load_accessorial->save()){
                                    $this->setLoadAudit($load->id, 'update', 'Load accessorial updated', $load_accessorial->getChanges(), $oldData);
                                    $load_accessorial->temp_details     = null;
                                    $load_accessorial->save();
                                }
                            }
                        }
                    }
                }else{
                    // 1 = MAINTENANCE, 2 = UNAUTHORIZED, 3 = HOS, 4 = NO DISPATCH, 5 = TIME OFF
                    // some case reset value
                    if($load_occupied === $old_load_occupied){
                        $this->convertUnoccupiedLoad($load);
                    }
                }

                $drivers                                                = isset($formdata['drivers'])?$formdata['drivers']:[];
                if(!empty($drivers)){
                    foreach ($drivers as $key => $value) {
                        $load_drivers                                   = [];
                        if($key==0){
                            $load_drivers['driver_id']                  = $formdata['driver_id']; // Main Driver Id or 0 value add no select driver
                        }
                        $load_drivers['empty_miles']                    = $load_occupied ? $value['empty_miles'] : null;
                        $load_drivers['loaded_miles']                   = $load_occupied ? $value['loaded_miles'] : null;
                        $load_drivers['total_miles']                    = $load_occupied ? $value['total_miles'] : null;
                        $load_drivers['pay_type']                       = $load_occupied ? $value['pay_type'] : null;
                        $load_drivers['gross_wage']                     = $load_occupied ? $value['gross_wage'] : null;
                        $load_drivers['detention']                      = $load_occupied ? ($value['detention'] ?? null) : null;
                        $load_drivers['total_bill']                     = $load_occupied ? $value['total_bill'] : null;

                        $data_id                                        = $value['data_id'] ?? null;
                        $load_driver                                    = LoadDriver::where('id', $data_id)->first();
                        if(!is_null($load_driver)){
                            $oldData                                    = [];
                            $oldData                                    = $load_driver->toArray();
                            foreach ($load_drivers as $dfield_key => $dfield_value) {
                                $load_driver->$dfield_key               = $dfield_value;
                            }
                            if($load_driver->save()){
                                $this->setLoadAudit($load->id, 'update', 'Load driver updated', $load_driver->getChanges(), $oldData);
                            }
                        }else{
                            $load_drivers['load_id']                    = $load->id;
                            $load_drivers['load_detail_id']             = $loadDetail->id;
                            $load_drivers['pay_percentage']             = 100;
                            $load_drivers['mileage_percentage']         = 100;
                            $load_drivers['pay']                        = $load_occupied ? $value['total_bill'] : null;
                            $load_drivers['miles']                      = $load_occupied ? $value['loaded_miles'] : null;
                            $load_drivers['created_at']                 = Carbon::now()->format('Y-m-d H:i:s');
                            LoadDriver::create($load_drivers);
                        }
                    }
                }

                $trucks                                                 = isset($formdata['trucks'])?$formdata['trucks']:[];
                if(!empty($trucks)){
                    foreach ($trucks as $key => $value) {
                        $load_truck_owners                              = [];
                        if($key==0){
                            $load_truck_owners['driver_id']             = $formdata['driver_id']; // Main Driver Id or 0 value add no select driver

                            $driver                                     = Driver::find($formdata['driver_id']);
                            if(!is_null($driver)){
                                $truck                                  = $driver->driver_information->truck ?? null;
                                if(!is_null($truck)){
                                    $load_truck_owners['owner_id']      = $truck->owner_id ?? null;
                                    $load_truck_owners['owner_type']    = $truck->owner_type ?? null;
                                }
                            }
                        }
                        $load_truck_owners['empty_miles']               = $load_occupied ? $value['empty_miles'] : null;
                        $load_truck_owners['loaded_miles']              = $load_occupied ? $value['loaded_miles'] : null;
                        $load_truck_owners['total_miles']               = $load_occupied ? $value['total_miles'] : null;
                        $load_truck_owners['pay_type']                  = $load_occupied ? $value['pay_type'] : null;
                        $load_truck_owners['gross_wage']                = $load_occupied ? $value['gross_wage'] : null;
                        $load_truck_owners['total_bill']                = $load_occupied ? $value['total_bill'] : null;

                        $data_id                                        = $value['data_id'] ?? null;
                        $load_truck_owner                               = LoadTruckOwner::where('id', $data_id)->first();
                        if(!is_null($load_truck_owner)){
                            $oldData                                    = [];
                            $oldData                                    = $load_truck_owner->toArray();
                            foreach ($load_truck_owners as $tfield_key => $tfield_value) {
                                $load_truck_owner->$tfield_key          = $tfield_value;
                            }
                            if($load_truck_owner->save()){
                                $this->setLoadAudit($load->id, 'update', 'Load truck owner updated', $load_truck_owner->getChanges(), $oldData);
                            }
                        }else{
                            $load_truck_owners['load_id']               = $load->id;
                            $load_truck_owners['load_detail_id']        = $loadDetail->id;
                            $load_truck_owners['pay_percentage']        = 100;
                            $load_truck_owners['mileage_percentage']    = 100;
                            $load_truck_owners['pay']                   = $load_occupied ? $value['total_bill'] : null;
                            $load_truck_owners['miles']                 = $load_occupied ? $value['loaded_miles'] : null;
                            $load_truck_owners['created_at']            = Carbon::now()->format('Y-m-d H:i:s');
                            LoadTruckOwner::create($load_truck_owners);
                        }
                    }
                }

                if(isset($loadDetail->driver_id) && $loadDetail->driver_id != '0'){
                    //Update 'trailer_number' in 'driver_informations' table base on load_status - Start
                    if(in_array($loadDetail->load_status, ['2','3','4','5'])){
                        $lDetails = LoadDetail::where('driver_id', $loadDetail->driver_id)->latest()->first();
                        if($lDetails){
                            DriverInformation::query()->where('driver_id', $loadDetail->driver_id)->update(['trailer_number' => $lDetails->trailer_number]);
                        }
                    }
                    // Assign driver report
                    isReportDriversZero($loadDetail->driver_id);
                    // send upldate load
                    if(isset($input['send_notification']) && $input['send_notification'] == '1'){
                        if ($old_driver_id == '0' || $old_send_notification == '0' || $old_driver_id != $loadDetail->driver_id) {
                            $driver = Driver::find($loadDetail->driver_id);
                            if(!is_null($driver)){
                                $mailData = [];
                                $mailData['company_id'] = auth()->guard('company-admin')->user()->company_id;
                                $mailData['name'] = isset($driver->full_name) ? $driver->full_name : '';

                                if(in_array($loadDetail->load_type, ['0', '6'])){
                                    // 0 = OCCUPIED, 6 = TONU
                                    $mailData['load_number'] = $loadDetail->load_number;
                                }else{
                                    // 1 = MAINTENANCE, 2 = UNAUTHORIZED, 3 = HOS, 4 = NO DISPATCH, 5 = TIME OFF
                                    $mailData['load_number'] = getLoadTypeList()[$loadDetail->load_type] ?? '';
                                }

                                if(isset($driver->email) && $driver->email != ''){
                                    /*
                                    try {
                                        Mail::to($driver->email)->send(new LoadUpdateMailToDriver($mailData));
                                    } catch (\Swift_TransportException $e) {
                                        // Log the error message
                                        Log::error('Email sending failed: ' . $e->getMessage());
                                    } catch (\Exception $e) {
                                        // Log the error message
                                        Log::error('An error occurred while sending the email: ' . $e->getMessage());
                                    }
                                    */

                                    sendEmail($driver->email, new LoadUpdateMailToDriver($mailData));
                                }
                            }
                        }
                    }
                }

                // add alert
                if((isset($input['is_on_hold']) && $input['is_on_hold'] == 1) && (isset($loadDetail->driver_id) && $loadDetail->driver_id!='0')){ // on hold status
                    if(isset($loadDetail->self_dispatch) && $loadDetail->self_dispatch==1){
                        createNotification(
                            3, // source
                            'Attention!', // name
                            $loadDetail->driver->dispatcher->id, // user_id
                            $loadDetail->driver->dispatcher->type, // user_type
                            2, // type
                            $loadDetail->load_id, // action_id
                            'Load placed on hold - '.$loadDetail->load_number, // description
                            'Alert', // module
                            [], // properties
                            $loadDetail->driver->dispatcher->company_id // company_id
                        );
                    }elseif (isset($loadDetail->dispatcher) && !is_null($loadDetail->dispatcher)){
                        createNotification(
                            3, // source
                            'Attention!', // name
                            $loadDetail->dispatcher->id, // user_id
                            $loadDetail->dispatcher->type, // user_type
                            2, // type
                            $loadDetail->load_id, // action_id
                            'Load placed on hold - '.$loadDetail->load_number, // description
                            'Alert', // module
                            [], // properties
                            $loadDetail->dispatcher->company_id // company_id
                        );
                    }
                }

                if($load_occupied){
                    $jobData                                            = [
                        'id'            => $loadDetail->id, // current load detail id
                        'company_id'    => auth()->guard('company-admin')->user()->company_id,
                        'user_id'       => auth()->guard('company-admin')->user()->id,
                        'user_type'     => 'Company Admin'
                    ];
                    dispatch(new \App\Jobs\DeadHeadUpdateJob($jobData));
                }

                notification('success', $this->crudMessage('update', 'Load'));
                if($request->save_and_continue=='1'){
                    return redirect()->route('company.admin.loads.edit', base64Encode($load->id));
                }
                if (!is_null($request->from) && $request->from == 'load_by_week') {
                    return redirect()->route('company.admin.loads.by.week.index');
                }
                $urlarry = explode('/', $request->backurl);
                if(isset($request->backurl) && !empty($request->backurl)){ // && !in_array('loads', $urlarry)
                    return redirect($request->backurl);
                }
                return redirect()->back(); //return redirect()->route('company.admin.loads.index');
            }else{
                notification('error', 'Oops! Something went wrong..');
                return redirect()->back();
            }

            /*------------------------------------------
            --------------------------------------------
            Commit Transaction to Save Data to Database
            --------------------------------------------
            --------------------------------------------*/
            // DB::commit();
            // If everything is successful, commit the transaction
        } catch (\Exception $e) {
            dd($e->getMessage());

            /*------------------------------------------
            --------------------------------------------
            Rollback Database Entry
            --------------------------------------------
            --------------------------------------------*/
            // DB::rollback();
            // Something went wrong, rollback the transaction
            notification('error', 'Oops! Something went wrong..'); // $e->getMessage()
            return redirect()->back();
        }
    }

    public function convertUnoccupiedLoad($load){
        $loadDetail                                     = $load->load_detail;

        $galleries                                      = Gallery::IsCompany()
            ->where('action_id', $load->id)
            ->where('source', 'load')
            ->whereIn('field_name', ['up_front_file','at_pickup_file','at_delivery_file'])
            ->get();
        if($galleries->isNotEmpty()){
            foreach ($galleries as $key => $gallery) {
                if (File::exists('storage/companyAdmin/gallery/'.$gallery->image)) {
                    File::delete('storage/companyAdmin/gallery/'.$gallery->image);
                }
                $gallery->delete();
            }
        }

        // delete drop data if exists with load_id
        DropTrailer::where('load_id', $load->id)->delete();

        $load_requirements                              = LoadRequirement::where('load_id', $load->id)->get();
        if($load_requirements->isNotEmpty()){
            foreach ($load_requirements as $key => $load_requirement) {
                if($load_requirement->delete()){
                    $oldData                            = [];
                    $oldData                            = $load_requirement->toArray();
                    $oldData['deleted_at']              = null;

                    $changeData                         = [];
                    $changeData                         = $oldData;
                    $changeData['deleted_at']           = Carbon::now();
                    $this->setLoadAudit($load->id, 'delete', 'Load requirements deleted', $changeData, $oldData);
                }
            }
        }

        if(isset($loadDetail->load_document_request_items) && $loadDetail->load_document_request_items->isNotEmpty()){
            foreach ($loadDetail->load_document_request_items as $key => $remove) {
                $remove->makeHidden(['laravel_through_key']);
                $oldData                                = [];
                $oldData                                = $remove->toArray();

                $remove->deleted_by                     = auth()->guard('company-admin')->user()->id;
                $remove->deleted_by_type                = auth()->guard('company-admin')->user()->type;
                if($remove->save()){
                    if($remove->delete()){
                        $remove->makeHidden(['laravel_through_key']);
                        $this->setLoadAudit($load->id, 'delete', 'Load document request item deleted', $remove->toArray(), $oldData);
                    }
                }
            }
        }

        if(isset($loadDetail->load_document_request)){
            $load_document_request                      = $loadDetail->load_document_request;

            $oldData                                    = [];
            $oldData                                    = $load_document_request->toArray();

            $load_document_request->deleted_by          = auth()->guard('company-admin')->user()->id;
            $load_document_request->deleted_by_type     = auth()->guard('company-admin')->user()->type;
            if($load_document_request->save()){
                if($load_document_request->delete()){
                    $this->setLoadAudit($load->id, 'delete', 'Load document request deleted', $load_document_request->toArray(), $oldData);
                }
            }
        }

        $shipper_appointment                            = isset($loadDetail->shipper_appointment)?$loadDetail->shipper_appointment:null;
        if(!is_null($shipper_appointment)){
            $oldData                                    = [];
            $oldData                                    = $shipper_appointment->toArray();
            if($shipper_appointment->delete()){
                $this->setLoadAudit($load->id, 'delete', 'Load appointment deleted', $shipper_appointment->toArray(), $oldData);
            }
        }

        $shipper_detention                              = isset($loadDetail->shipper_detention)?$loadDetail->shipper_detention:null;
        if(!is_null($shipper_detention)){
            $oldData                                    = [];
            $oldData                                    = $shipper_detention->toArray();
            if($shipper_detention->delete()){
                $this->setLoadAudit($load->id, 'delete', 'Load detention deleted', $shipper_detention->toArray(), $oldData);
            }
        }

        if(isset($loadDetail->shipper_accessorials) && $loadDetail->shipper_accessorials->isNotEmpty()){
            foreach ($loadDetail->shipper_accessorials as $key => $load_accessorial) {
                $oldData                                = [];
                $oldData                                = $load_accessorial->toArray();
                if($load_accessorial->delete()){
                    $this->setLoadAudit($load->id, 'delete', 'Load accessorial deleted', $load_accessorial->toArray(), $oldData);
                }
            }
        }

        if($load->load_stops->isNotEmpty()){
            foreach ($load->load_stops as $key => $load_stop) {
                $appointment                            = isset($load_stop->appointment)?$load_stop->appointment:null;
                if(!is_null($appointment)){
                    $oldData                            = [];
                    $oldData                            = $appointment->toArray();
                    if($appointment->delete()){
                        $this->setLoadAudit($load->id, 'delete', 'Load appointment deleted', $appointment->toArray(), $oldData);
                    }
                }
                $detention                              = isset($load_stop->detention)?$load_stop->detention:null;
                if(!is_null($detention)){
                    $oldData                            = [];
                    $oldData                            = $detention->toArray();
                    if($detention->delete()){
                        $this->setLoadAudit($load->id, 'delete', 'Load detention deleted', $detention->toArray(), $oldData);
                    }
                }
                if(isset($load_stop->accessorials) && $load_stop->accessorials->isNotEmpty()){
                    foreach ($load_stop->accessorials as $key => $load_accessorial) {
                        $oldData                        = [];
                        $oldData                        = $load_accessorial->toArray();
                        if($load_accessorial->delete()){
                            $this->setLoadAudit($load->id, 'delete', 'Load accessorial deleted', $load_accessorial->toArray(), $oldData);
                        }
                    }
                }

                $oldData                                = [];
                $oldData                                = $load_stop->getOriginal();
                if($load_stop->delete()){
                    $this->setLoadAudit($load->id, 'delete', 'Load stop deleted', $load_stop->getOriginal(), $oldData);
                }
            }
        }

        $receiver_appointment                           = isset($loadDetail->receiver_appointment)?$loadDetail->receiver_appointment:null;
        if(!is_null($receiver_appointment)){
            $oldData                                    = [];
            $oldData                                    = $receiver_appointment->toArray();
            if($receiver_appointment->delete()){
                $this->setLoadAudit($load->id, 'delete', 'Load appointment deleted', $receiver_appointment->toArray(), $oldData);
            }
        }

        $receiver_detention                             = isset($loadDetail->receiver_detention)?$loadDetail->receiver_detention:null;
        if(!is_null($receiver_detention)){
            $oldData                                    = [];
            $oldData                                    = $receiver_detention->toArray();
            if($receiver_detention->delete()){
                $this->setLoadAudit($load->id, 'delete', 'Load detention deleted', $receiver_detention->toArray(), $oldData);
            }
        }

        if(isset($loadDetail->receiver_accessorials) && $loadDetail->receiver_accessorials->isNotEmpty()){
            foreach ($loadDetail->receiver_accessorials as $key => $load_accessorial) {
                $oldData                                = [];
                $oldData                                = $load_accessorial->toArray();
                if($load_accessorial->delete()){
                    $this->setLoadAudit($load->id, 'delete', 'Load accessorial deleted', $load_accessorial->toArray(), $oldData);
                }
            }
        }

        if(isset($loadDetail->billing_accessorials) && $loadDetail->billing_accessorials->isNotEmpty()){
            foreach ($loadDetail->billing_accessorials as $key => $load_accessorial) {
                $oldData                                = [];
                $oldData                                = $load_accessorial->toArray();
                if($load_accessorial->delete()){
                    $this->setLoadAudit($load->id, 'delete', 'Load accessorial deleted', $load_accessorial->toArray(), $oldData);
                }
            }
        }
        return 'success';
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Load $load){
        $load->delete();
        notification('success', $this->crudMessage('delete', 'Load'));
        return redirect()->back();
    }

    public function permanentlyDestroy($id){
        $load               = Load::find($id);
        $load->forceDelete();

        $loadDetail         = LoadDetail::where('load_id',$load->id)->get();
        foreach($loadDetail as $loaddeta){
            $getLoadDetail = LoadDetail::find($loaddeta->id);
            $getLoadDetail->forceDelete();
        }

        $loadDriver         = LoadDriver::where('load_id',$load->id)->get();
        foreach($loadDriver as $loadDri){
            $getLoadDriver  = LoadDriver::find($loadDri->id);
            $getLoadDriver->forceDelete();
        }
        notification('success', $this->crudMessage('delete', 'Load'));
        return redirect()->route('company.admin.loads.index');
    }

    public function loadNoteSave(Request $request){
        $response['success']                                    = false;
        $response['message']                                    = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $arry                                           = [];
                $arry['load_id']                                = $request->load_id;
                $arry['created_by_type']                        = auth()->guard('company-admin')->user()->type;
                $arry['created_by']                             = auth()->guard('company-admin')->user()->id;
                $arry['type']                                   = (isset($request->type) && $request->type!='')?$request->type:0;
                $arry['request_type']                           = (isset($request->request_type) && $request->request_type!='')?$request->request_type:0;
                $arry['note']                                   = $request->note;
                $arry['notify_dispatcher']                      = (isset($request->notify_dispatcher) && $request->notify_dispatcher==1)?1:0;
                $arry['notify_dirver']                          = (isset($request->notify_dirver) && $request->notify_dirver==1)?1:0;
                $arry['notify_broker']                          = (isset($request->notify_broker) && $request->notify_broker==1)?1:0;
                $arry['notify_my']                              = (isset($request->notify_my) && $request->notify_my==1)?1:0;
                $arry['notify_private']                         = (isset($request->notify_private) && $request->notify_private==1)?1:0;
                if (isset($request->notify_private_company_admin_id) && count($request->notify_private_company_admin_id) > 0) {
                    $arry['notify_private_company_admin_id']    = implode(',', $request->notify_private_company_admin_id);
                }
                if (isset($request->note_file) && !empty($request->note_file)) {
                    $file_temp                                  = [];
                    $image_array                                = [];
                    foreach($request->note_file as $image){
                        $seme                                   = FileUpload::upload('companyAdmin/temp', $image);

                        $stopath                                = public_path('storage/companyAdmin/temp/'.$seme);
                        $data                                   = file_get_contents($stopath);
                        $type                                   = pathinfo($stopath, PATHINFO_EXTENSION);
                        if($type == 'png' || $type == 'jpeg' || $type == 'jpg' || $type == 'gif'){
                            $base64                             = 'data:image/' . $type . ';base64,' . base64_encode($data);
                            $file_temp[]                        = $base64;
                        }else{
                            $image_array[]  = $seme = FileUpload::upload('companyAdmin/loadfile', $image);
                        }
                    }

                    if(count($file_temp) > 0){
                        $fileName                               = 'load_'.$request->load_id;
                        $image_array[]                          = FileUpload::PDFupload('companyAdmin/loadfile', ['data' => $file_temp], $fileName);
                    }
                    $arry['document']                           = serialize($image_array); // FileUpload::upload('companyAdmin/loadfile', $request->note_file);
                }
                if(isset($request->is_dummy) && $request->is_dummy=='1'){
                    $arry['is_dummy']                           = 1;
                }

                $getLoadNote                                    = LoadNote::create($arry);
                if($getLoadNote){
                    if($getLoadNote->notify_dispatcher == 1){
                        $getLoad                                = LoadDetail::where('load_id',$getLoadNote->load_id)->latest()->first();
                        if(isset($getLoad->id)){
                            $userdata                           = CompanyAdmin::find($getLoad->booked_by);
                            // send notify
                            createNotification(
                                4, // source
                                'Added Note - '.$getLoad->load_number, // name
                                $userdata->id, // user_id
                                $userdata->type, // user_type
                                1, // type
                                $request->load_id, // action_id
                                $getLoadNote->note // description
                            );
                            $checkNotify                        = isUnreadDelay($userdata->id, $userdata->type, 4);
                            if(isset($checkNotify)){
                                if ($checkNotify->email == 1 && isset($userdata->email)) {
                                // send mail
                                    $mailData                   = [];
                                    $mailData['company_id']     = auth()->guard('company-admin')->user()->company_id;
                                    $mailData['emailto']        = $userdata->email;
                                    $mailData['hiname']         = $userdata->full_name;
                                    $mailData['phone']          = $userdata->cell_phone;
                                    $mailData['type']           = !empty($getLoadNote->type) ? getLoadNoteType()[$getLoadNote->type] : 'None';
                                    $mailData['request_type']   = !empty($getLoadNote->request_type) ? getNoteRequestType()[$getLoadNote->request_type] : 'None';
                                    $mailData['note']           = $getLoadNote->note;
                                    $mailData['document']       = $getLoadNote->note;

                                    $mailData['load_no']        = $getLoad->load_number;
                                    $mailData['load_url']       = route('company.admin.loads.show', $getLoad->id);
                                    //Mail::to($mailData['emailto'])->send(new LoadNoteCreate($mailData));
                                    sendEmail($mailData['emailto'], new LoadNoteCreate($mailData));
                                }

                                // send sms
                                if ($checkNotify->sms == 1 && isset($userdata->cell_phone)) {
                                    // Twilio's credentials are fetched from company table
                                    $getCompanyTwilioData       = getCompanyTwilioData();
                                    if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
                                        $message                = " You have a new note on load no: ".$getLoad->load_number;
                                        sendSMS($userdata->cell_phone, $message, $getCompanyTwilioData);
                                    }
                                }
                            }
                        }
                    }

                    if($getLoadNote->notify_dirver == 1){
                        $getLoad                                = LoadDetail::where('load_id',$getLoadNote->load_id)->latest()->first();
                        if(isset($getLoad->id)){
                            $userdata                           = Driver::find($getLoad->driver_id);
                            // send notify
                            createNotification(
                                4, // source
                                'Added Note - '.$getLoad->load_number, // name
                                $userdata->id, // user_id
                                3, // user_type
                                1, // type
                                $request->load_id, // action_id
                                $getLoadNote->note // description
                            );
                            $checkNotify                        = isUnreadDelay($userdata->id, 3, 4);
                            if(isset($checkNotify)){
                                if ($checkNotify->email == 1 && isset($userdata->email)) {
                                // send mail
                                    $mailData                   = [];
                                    $mailData['company_id']     = auth()->guard('company-admin')->user()->company_id;
                                    $mailData['emailto']        = $userdata->email;
                                    $mailData['hiname']         = $userdata->full_name;
                                    $mailData['phone']          = $userdata->cell_phone;
                                    $mailData['type']           = !empty($getLoadNote->type) ? getLoadNoteType()[$getLoadNote->type] : 'None';
                                    $mailData['request_type']   = !empty($getLoadNote->request_type) ? getNoteRequestType()[$getLoadNote->request_type] : 'None';
                                    $mailData['note']           = $getLoadNote->note;
                                    $mailData['document']       = $getLoadNote->note;
                                    $mailData['load_no']        = $getLoad->load_number;
                                    $mailData['load_url']       = route('company.admin.loads.show', $getLoad->id);
                                    //Mail::to($mailData['emailto'])->send(new LoadNoteCreate($mailData));
                                    sendEmail($mailData['emailto'], new LoadNoteCreate($mailData));
                                }
                                // send sms
                                if ($checkNotify->sms == 1 && isset($userdata->cell_phone)) {
                                    // Twilio's credentials are fetched from company table
                                    $getCompanyTwilioData       = getCompanyTwilioData();
                                    if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
                                        $message                = "You have a new note on load no: ".$getLoad->load_number;
                                        sendSMS($userdata->cell_phone, $message, $getCompanyTwilioData);
                                    }
                                }
                            }
                        }
                    }

                    if($getLoadNote->notify_broker == 1){
                        $getLoad                                = LoadDetail::where('load_id',$getLoadNote->load_id)->latest()->first();
                        if(!empty($getLoad->brokerage_firm)){
                            $userdata                           = Broker::find($getLoad->brokerage_firm);
                            if(!empty($userdata->email)){
                                $mailData                       = [];
                                $mailData['company_id']     = auth()->guard('company-admin')->user()->company_id;
                                $mailData['emailto']            = $userdata->email;
                                $mailData['hiname']             = $userdata->full_name;
                                $mailData['phone']              = $userdata->phone_number;
                                $mailData['type']               = !empty($getLoadNote->type) ? getLoadNoteType()[$getLoadNote->type] : 'None';
                                $mailData['request_type']       = !empty($getLoadNote->request_type) ? getNoteRequestType()[$getLoadNote->request_type] : 'None';
                                $mailData['note']               = $getLoadNote->note;
                                $mailData['document']           = $getLoadNote->note;
                                $mailData['load_no']            = $getLoad->load_number;
                                $mailData['load_url']           = '';
                                //Mail::to($mailData['emailto'])->send(new LoadNoteCreate($mailData));
                                sendEmail($mailData['emailto'], new LoadNoteCreate($mailData));
                            }
                            // send mail

                            // send sms
                            if (!empty($userdata->sms) && isset($userdata->phone_number)) {
                                // Twilio's credentials are fetched from company table
                                $getCompanyTwilioData           = getCompanyTwilioData();
                                if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
                                    $message                    = " You have a new note on load no: ".$getLoad->load_number;
                                    sendSMS($userdata->phone_number, $message, $getCompanyTwilioData);
                                }
                            }
                        }
                    }

                    if($getLoadNote->notify_my == 1){
                        $getLoad                                = LoadDetail::where('load_id',$getLoadNote->load_id)->latest()->first();
                        if(isset($getLoad->id)){
                            $userdata                           = CompanyAdmin::find(auth()->guard('company-admin')->user()->id);
                            // send notify
                            createNotification(
                                4, // source
                                'Added Note - '.$getLoad->load_number, // name
                                $userdata->id, // user_id
                                $userdata->type, // user_type
                                1, // type
                                $request->load_id, // action_id
                                $getLoadNote->note // description
                            );
                            $checkNotify                        = isUnreadDelay($userdata->id, $userdata->type, 4);
                            if(isset($checkNotify)){
                                if ($checkNotify->email == 1 && isset($userdata->email)) {
                                    // send mail
                                    $mailData                   = [];
                                    $mailData['company_id']     = auth()->guard('company-admin')->user()->company_id;
                                    $mailData['emailto']        = $userdata->email;
                                    $mailData['hiname']         = $userdata->full_name;
                                    $mailData['phone']          = $userdata->cell_phone;
                                    $mailData['type']           = !empty($getLoadNote->type) ? getLoadNoteType()[$getLoadNote->type] : 'None';
                                    $mailData['request_type']   = !empty($getLoadNote->request_type) ? getNoteRequestType()[$getLoadNote->request_type] : 'None';
                                    $mailData['note']           = $getLoadNote->note;
                                    $mailData['document']       = $getLoadNote->note;
                                    $mailData['load_no']        = $getLoad->load_number;
                                    $mailData['load_url']       = route('company.admin.loads.show', $getLoad->id);
                                    //Mail::to($mailData['emailto'])->send(new LoadNoteCreate($mailData));
                                    sendEmail($mailData['emailto'], new LoadNoteCreate($mailData));
                                }
                                // send sms
                                if ($checkNotify->sms == 1 && isset($userdata->cell_phone)) {
                                    // Twilio's credentials are fetched from company table
                                    $getCompanyTwilioData       = getCompanyTwilioData();
                                    if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
                                        $message                = " You have a new note on load no: ".$getLoad->load_number;
                                        sendSMS($userdata->cell_phone, $message, $getCompanyTwilioData);
                                    }
                                }
                            }
                        }
                    }

                    if($getLoadNote->notify_private == 1){
                        $getIds                                 = explode(',',$getLoadNote->notify_private_company_admin_id);
                        if(count($getIds) > 0){
                            foreach($getIds as $getId){
                                $getLoad                        = LoadDetail::where('load_id',$getLoadNote->load_id)->latest()->first();
                                if(isset($getLoad->id)){
                                    $userdata                   = CompanyAdmin::find($getId);
                                    // send notify
                                    createNotification(
                                        4, // source
                                        'Added Note - '.$getLoad->load_number, // name
                                        $userdata->id, // user_id
                                        $userdata->type, // user_type
                                        1, // type
                                        $request->load_id, // action_id
                                        $getLoadNote->note // description
                                    );
                                    $checkNotify                = isUnreadDelay($userdata->id, $userdata->type, 4);
                                    if(isset($checkNotify)){
                                        if ($checkNotify->email == 1 && isset($userdata->email)) {
                                            $mailData                   = [];
                                            $mailData['company_id']     = auth()->guard('company-admin')->user()->company_id;
                                            $mailData['emailto']        = $userdata->email;
                                            $mailData['hiname']         = $userdata->full_name;
                                            $mailData['phone']          = $userdata->cell_phone;

                                            $mailData['type']           = !empty($getLoadNote->type) ? getLoadNoteType()[$getLoadNote->type] : 'None';
                                            $mailData['request_type']   = !empty($getLoadNote->request_type) ? getNoteRequestType()[$getLoadNote->request_type] : 'None';
                                            $mailData['note']           = $getLoadNote->note;
                                            $mailData['document']       = $getLoadNote->note;
                                            $mailData['load_no']        = $getLoad->load_number;
                                            $mailData['load_url']       = route('company.admin.loads.show', $getLoad->id);
                                            //Mail::to($mailData['emailto'])->send(new LoadNoteCreate($mailData));
                                            sendEmail($mailData['emailto'], new LoadNoteCreate($mailData));
                                        }

                                        if ($checkNotify->sms == 1 && isset($userdata->cell_phone)) {
                                            // Twilio's credentials are fetched from company table
                                            $getCompanyTwilioData       = getCompanyTwilioData();
                                            if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
                                                $message                = " You have a new note on load no: ".$getLoad->load_number;
                                                sendSMS($userdata->cell_phone, $message, $getCompanyTwilioData);
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }

                    $response['success']                        = true;
                    $response['message']                        = 'Note create successfully';
                }else{
                    $response['success']                        = false;
                    $response['message']                        = 'Note create unsuccessfully';
                }
            }catch (\Exception $e) {
                $response['success']                            = false;
                $response['message']                            = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function loadNoteView(Request $request){
        $getTimeZone                = $this->timeZone;
        $getTimeZoneId              = $this->timeZoneId;
        $query                      = LoadNote::where('load_id',$request->id);
        if(isset($request->is_dummy) && $request->is_dummy=='1'){
            $query->where('is_dummy', 1);
        }
        $getNote                    = $query->orderBy('created_at','asc')->get();
        $view                       = view('companyAdmin.load.view.notes', compact('getNote','getTimeZone','getTimeZoneId'))->render();
        $getNotificationList        = getNotificationList();
        if(empty($getNotificationList)){
            $getNotificationList    = '<p class="pt-4 text-center">No Records Found</p>';
        }
        return response()->json(['view' => $view, 'getNotificationList' => $getNotificationList]);
    }

    public function destroyNote($id){
        $getLoadNote                = LoadNote::find($id);
        $oldData                    = LoadNote::where('id',$getLoadNote->id)->select('note')->first()->toArray();
        $this->setLoadAudit($getLoadNote->load_id, 'delete', 'Deleted communication note', $oldData, $oldData);

        File::delete('storage/companyAdmin/loadfile/'.$getLoadNote->document);
        $getLoadNote->delete();
        return 1;
    }

    public function loadFileSave(Request $request){
        // dd('loadFileSave', $request->all());
        // return 0;
        $company_id                                                     = auth()->guard('company-admin')->user()->company_id;
        $user_id                                                        = auth()->guard('company-admin')->user()->id;
        if(!is_null($request->file_source_id)){
            if(in_array($request->file_source_id, ['load_details','load_stops'])){
                $getArray                                               = [];
                if($request->file_source_id == 'load_details'){
                    $loadDetail                                         = LoadDetail::findOrFail($request->file_id);
                    if($request->file_field_name == 'invoice_files'){
                        $getArray                                       = isset($loadDetail->invoice_files) && is_serialized($loadDetail->invoice_files) && !empty(unserialize($loadDetail->invoice_files))?unserialize($loadDetail->invoice_files):[];
                    } else if ($request->file_field_name == 'rate_confirmation_files') {
                        $getArray                                       = isset($loadDetail->rate_confirmation_files) && is_serialized($loadDetail->rate_confirmation_files) && !empty(unserialize($loadDetail->rate_confirmation_files))?unserialize($loadDetail->rate_confirmation_files):[];
                    } else if ($request->file_field_name == 'shipper_files_upload') {
                        $getArray                                       = isset($loadDetail->shipper_files_upload) && is_serialized($loadDetail->shipper_files_upload) && !empty(unserialize($loadDetail->shipper_files_upload))?unserialize($loadDetail->shipper_files_upload):[];
                    } else if ($request->file_field_name == 'consignee_files_upload') {
                        $getArray                                       = isset($loadDetail->consignee_files_upload) && is_serialized($loadDetail->consignee_files_upload) && !empty(unserialize($loadDetail->consignee_files_upload))?unserialize($loadDetail->consignee_files_upload):[];
                    }
                }else{
                    $loadStop                                           = LoadStop::findOrFail($request->file_id);
                    if($request->file_field_name == 'stop_shipper_files_upload'){
                        $getArray                                       = isset($loadStop->stop_shipper_files_upload) && is_serialized($loadStop->stop_shipper_files_upload) && !empty(unserialize($loadStop->stop_shipper_files_upload))?unserialize($loadStop->stop_shipper_files_upload):[];
                    } else if ($request->file_field_name == 'stop_consignee_files_upload') {
                        $getArray                                       = isset($loadStop->stop_consignee_files_upload) && is_serialized($loadStop->stop_consignee_files_upload) && !empty(unserialize($loadStop->stop_consignee_files_upload))?unserialize($loadStop->stop_consignee_files_upload):[];
                    }
                }

                if(!empty($getArray)){
                    if(!in_array($request->file_field_name, ['invoice_files','rate_confirmation_files'])){
                        $saveArray                                      = [];
                        foreach($getArray as $data){
                            $files                                      = $data['file'];
                            if(isset($data['name_id']) && $data['name_id'] == $request->filename_id){
                                $updateData                             = [];
                                $updateData['name_id']                  = $data['name_id'] ?? '';
                                $updateData['name']                     = $data['name'];
                                $updateData['is_required']              = isset($data['is_required']) ? $data['is_required'] : 'off';
                                $updateData['type']                     = $data['type'];
                                $updateData['fixed']                    = $data['fixed'];
                                $updateData['include_w_billing']        = isset($request->file_include_with_billing) && $request->file_include_with_billing=='yes'?'yes':'no';
                                $updateData['custom']                   = isset($data['custom']) && $data['custom']=='yes' ? 'yes' : 'no';

                                $updateData['is_received']              = isset($data['is_received']) ? $data['is_received'] : 'off';
                                $updateData['hide_from_driver']         = isset($request->file_hide_from_driver) && $request->file_hide_from_driver=='yes'?'yes':'no';
                                $updateData['file_not_provided']        = isset($data['file_not_provided']) ? $data['file_not_provided'] : 'off';;
                                if(isset($request->file_documents)){
                                    if(isset($files) && !empty($files)){
                                        foreach ($files as $key => $file) {
                                            $path                       = 'storage/companyAdmin/load_detail_document/'.$file;
                                            if (File::exists($path)) {
                                                File::delete($path);
                                            }
                                        }
                                    }
                                    $updateData['is_received']          = 'on';
                                    $updateData['file']                 = UploadImagePdf($request->file_documents, 'companyAdmin/load_detail_document');
                                    $updateData['upload_user_type']     = auth()->guard('company-admin')->user()->type;
                                    $updateData['upload_by']            = auth()->guard('company-admin')->user()->id;
                                    $updateData['uploaded_at']          = Carbon::now();
                                }else{
                                    if(isset($files) && !empty($files)){
                                        $updateData['is_received']      = 'on';
                                        $updateData['file']             = $files;
                                        $updateData['upload_user_type'] = $data['upload_user_type'];
                                        $updateData['upload_by']        = $data['upload_by'];
                                        $updateData['uploaded_at']      = $data['uploaded_at'];
                                    }else{
                                        $updateData['file']             = null;
                                    }
                                }
                                $saveArray[]                            = $updateData;
                            }else{
                                $saveArray[]                            = $data;
                            }
                        }

                        if($request->file_field_name == 'shipper_files_upload'){
                            $oldData                                    = $loadDetail->toArray();
                            $loadDetail->update(['shipper_files_upload' => serialize($saveArray)]);
                            $this->setLoadAudit($request->load_id, 'update', 'Load detail updated', $loadDetail->getChanges(), $oldData);
                        }
                        if($request->file_field_name == 'consignee_files_upload'){
                            $oldData                                    = $loadDetail->toArray();
                            $loadDetail->update(['consignee_files_upload' => serialize($saveArray)]);
                            $this->setLoadAudit($request->load_id, 'update', 'Load detail updated', $loadDetail->getChanges(), $oldData);
                        }
                        if($request->file_field_name == 'stop_shipper_files_upload'){
                            $oldData                                    = $loadStop->toArray();
                            $loadStop->update(['stop_shipper_files_upload' => serialize($saveArray)]);
                            $this->setLoadAudit($request->load_id, 'update', 'Load stop updated', $loadStop->getChanges(), $oldData);
                        }
                        if($request->file_field_name == 'stop_consignee_files_upload'){
                            $oldData                                    = $loadStop->toArray();
                            $loadStop->update(['stop_consignee_files_upload' => serialize($saveArray)]);
                            $this->setLoadAudit($request->load_id, 'update', 'Load stop updated', $loadStop->getChanges(), $oldData);
                        }
                    }else{
                        if($request->file_field_name == 'invoice_files'){
                            $updateData                                 = [];
                            if(isset($request->file_documents)){
                                $files                                  = $getArray['file'];
                                if(!empty($files)){
                                    foreach ($files as $key => $file) {
                                        $path                           = 'storage/companyAdmin/load_detail_document/'.$file;
                                        if (File::exists($path)) {
                                            File::delete($path);
                                        }
                                    }
                                }
                                $updateData['file']                     = UploadImagePdf($request->file_documents, 'companyAdmin/load_detail_document');
                                $updateData['upload_user_type']         = auth()->guard('company-admin')->user()->type;
                                $updateData['upload_by']                = auth()->guard('company-admin')->user()->id;
                                $updateData['uploaded_at']              = Carbon::now();
                            }else{
                                $updateData['file']                     = $getArray['file'];
                                $updateData['upload_user_type']         = $getArray['upload_user_type'];
                                $updateData['upload_by']                = $getArray['upload_by'];
                                $updateData['uploaded_at']              = $getArray['uploaded_at'];
                            }
                            $updateData['include_w_billing']            = isset($request->file_include_with_billing) && $request->file_include_with_billing=='yes'?'yes':'no';
                            $updateData['hide_from_driver']             = isset($request->file_hide_from_driver) && $request->file_hide_from_driver=='yes'?'yes':'no';

                            $oldData                                    = $loadDetail->toArray();
                            $loadDetail->update(['invoice_files' => serialize($updateData)]);
                            $this->setLoadAudit($request->load_id, 'update', 'Load detail updated', $loadDetail->getChanges(), $oldData);
                        } else if ($request->file_field_name == 'rate_confirmation_files') {
                            $updateData                                 = [];
                            if(isset($request->file_documents)){
                                $files                                  = $getArray['file'];
                                if(!empty($files)){
                                    foreach ($files as $key => $file) {
                                        $path                           = 'storage/companyAdmin/load_detail_document/'.$file;
                                        if (File::exists($path)) {
                                            File::delete($path);
                                        }
                                    }
                                }
                                $updateData['file']                     = UploadImagePdf($request->file_documents, 'companyAdmin/load_detail_document');
                                $updateData['upload_user_type']         = auth()->guard('company-admin')->user()->type;
                                $updateData['upload_by']                = auth()->guard('company-admin')->user()->id;
                                $updateData['uploaded_at']              = Carbon::now();
                            }else{
                                $updateData['file']                     = $getArray['file'];
                                $updateData['upload_user_type']         = $getArray['upload_user_type'];
                                $updateData['upload_by']                = $getArray['upload_by'];
                                $updateData['uploaded_at']              = $getArray['uploaded_at'];
                            }
                            $updateData['include_w_billing']            = isset($request->file_include_with_billing) && $request->file_include_with_billing=='yes'?'yes':'no';
                            $updateData['hide_from_driver']             = isset($request->file_hide_from_driver) && $request->file_hide_from_driver=='yes'?'yes':'no';

                            $oldData                                    = $loadDetail->toArray();
                            $loadDetail->update(['rate_confirmation_files' => serialize($updateData)]);
                            $this->setLoadAudit($request->load_id, 'update', 'Load detail updated', $loadDetail->getChanges(), $oldData);
                        }
                    }
                }else{
                    if($request->file_field_name == 'invoice_files'){
                        $updateData                                     = [];
                        if(isset($request->file_documents)){
                            $updateData['file']                         = UploadImagePdf($request->file_documents, 'companyAdmin/load_detail_document');
                            $updateData['upload_user_type']             = auth()->guard('company-admin')->user()->type;
                            $updateData['upload_by']                    = auth()->guard('company-admin')->user()->id;
                            $updateData['uploaded_at']                  = Carbon::now();
                        }else{
                            $updateData['file']                         = null;
                        }
                        $updateData['include_w_billing']                = isset($request->file_include_with_billing) && $request->file_include_with_billing=='yes'?'yes':'no';
                        $updateData['hide_from_driver']                 = isset($request->file_hide_from_driver) && $request->file_hide_from_driver=='yes'?'yes':'no';

                        $oldData                                        = $loadDetail->toArray();
                        $loadDetail->update(['invoice_files' => serialize($updateData)]);
                        $this->setLoadAudit($request->load_id, 'update', 'Load detail updated', $loadDetail->getChanges(), $oldData);
                    } else if ($request->file_field_name == 'rate_confirmation_files') {
                        $updateData                                     = [];
                        if(isset($request->file_documents)){
                            $updateData['file']                         = UploadImagePdf($request->file_documents, 'companyAdmin/load_detail_document');
                            $updateData['upload_user_type']             = auth()->guard('company-admin')->user()->type;
                            $updateData['upload_by']                    = auth()->guard('company-admin')->user()->id;
                            $updateData['uploaded_at']                  = Carbon::now();
                        }else{
                            $updateData['file']                         = null;
                        }
                        $updateData['include_w_billing']                = isset($request->file_include_with_billing) && $request->file_include_with_billing=='yes'?'yes':'no';
                        $updateData['hide_from_driver']                 = isset($request->file_hide_from_driver) && $request->file_hide_from_driver=='yes'?'yes':'no';

                        $oldData                                        = $loadDetail->toArray();
                        $loadDetail->update(['rate_confirmation_files' => serialize($updateData)]);
                        $this->setLoadAudit($request->load_id, 'update', 'Load detail updated', $loadDetail->getChanges(), $oldData);
                    }
                }
            } else if ($request->file_source_id == 'load_cod_galleries') {
                $gallery                                                = Gallery::where('id', $request->file_id)->first();
                if(!is_null($gallery)){
                    if(isset($request->file_documents[0])){
                        $upload                                         = FileUpload::upload('companyAdmin/gallery', $request->file_documents[0]);
                        if($upload!=''){
                            $path                                       = 'storage/companyAdmin/gallery/'.$gallery->image;
                            if (File::exists($path)) {
                                File::delete($path);
                            }
                            $gallery->image                             = $upload;
                            $gallery->include_w_billing                 = isset($request->file_include_with_billing) && $request->file_include_with_billing=='yes'?'yes':'no';
                            $gallery->hide_from_driver                  = isset($request->file_hide_from_driver) && $request->file_hide_from_driver=='yes'?'yes':'no';
                            $gallery->created_by                        = auth()->guard('company-admin')->user()->id;
                            $gallery->created_by_type                   = auth()->guard('company-admin')->user()->type;
                            $gallery->uploaded_date                     = Carbon::now()->format('m/d/Y H:i');
                            $gallery->save();
                        }
                    }
                }
            } else if ($request->file_source_id == 'load_accessorials') {
                $load_accessorial                                       = LoadAccessorial::where('id', $request->file_id)->first();
                if(!is_null($load_accessorial)){
                    $oldData                                            = $load_accessorial->toArray();

                    $is_upload                                          = 0;
                    $gallery                                            = Gallery::IsCompany()
                        ->where('action_id', $load_accessorial->id)
                        ->where('source', 'load_accessorials')
                        ->where('field_name', 'accessorial_files')
                        ->first();
                    if(!is_null($gallery)){
                        $file_temp                                      = [];
                        $image_array                                    = [];
                        foreach($request->file_documents as $image){
                            $seme                                       = FileUpload::upload('companyAdmin/temp', $image);
                            $stopath                                    = public_path('storage/companyAdmin/temp/'.$seme);
                            $data                                       = file_get_contents($stopath);
                            $type                                       = pathinfo($stopath, PATHINFO_EXTENSION);
                            if($type == 'png' || $type == 'jpeg' || $type == 'jpg' || $type == 'gif'){
                                $base64                                 = 'data:image/' . $type . ';base64,' . base64_encode($data);
                                $file_temp[]                            = $base64;
                            }
                        }

                        $gallery->file_name                             = $request->filename;
                        if(count($file_temp) > 0){
                            $path                                       = 'storage/companyAdmin/gallery/'.$gallery->image;
                            if (File::exists($path)) {
                                File::delete($path);
                            }
                            $gallery->image                             = FileUpload::PDFupload('companyAdmin/gallery', ['data' => $file_temp], 'document_pdf');

                            $is_upload                                  = 1;
                        }
                        $gallery->include_w_billing                     = isset($request->file_include_with_billing) && $request->file_include_with_billing=='yes'?'yes':'no';
                        $gallery->hide_from_driver                      = isset($request->file_hide_from_driver) && $request->file_hide_from_driver=='yes'?'yes':'no';
                        $gallery->created_by                            = auth()->guard('company-admin')->user()->id;
                        $gallery->created_by_type                       = auth()->guard('company-admin')->user()->type;
                        $gallery->uploaded_date                         = Carbon::now()->format('m/d/Y H:i');
                        $gallery->save();
                    }else{
                        $file_temp                                      = [];
                        $image_array                                    = [];
                        foreach($request->file_documents as $image){
                            $seme                                       = FileUpload::upload('companyAdmin/temp', $image);
                            $stopath                                    = public_path('storage/companyAdmin/temp/'.$seme);
                            $data                                       = file_get_contents($stopath);
                            $type                                       = pathinfo($stopath, PATHINFO_EXTENSION);
                            if($type == 'png' || $type == 'jpeg' || $type == 'jpg' || $type == 'gif'){
                                $base64                                 = 'data:image/' . $type . ';base64,' . base64_encode($data);
                                $file_temp[]                            = $base64;
                            }
                        }

                        if(count($file_temp) > 0){
                            $input                                      = [];
                            $input['company_id']                        = auth()->guard('company-admin')->user()->company_id;
                            $input['action_id']                         = $load_accessorial->id;
                            $input['source']                            = 'load_accessorials';
                            $input['field_name']                        = 'accessorial_files';
                            $input['file_name']                         = $request->filename;
                            $input['file_type']                         = getRequestDocumentsList('load_accessorials','source')['file_type'];
                            $input['image']                             = FileUpload::PDFupload('companyAdmin/gallery', ['data' => $file_temp], 'document_pdf');
                            $input['include_w_billing']                 = isset($request->file_include_with_billing) && $request->file_include_with_billing=='yes'?'yes':'no';
                            $input['hide_from_driver']                  = isset($request->file_hide_from_driver) && $request->file_hide_from_driver=='yes'?'yes':'no';
                            $input['status']                            = 'approved';
                            $input['created_by']                        = auth()->guard('company-admin')->user()->id;
                            $input['created_by_type']                   = auth()->guard('company-admin')->user()->type;
                            $input['uploaded_date']                     = Carbon::now()->format('m/d/Y H:i');
                            Gallery::create($input);

                            $is_upload                                  = 1;
                        }
                    }

                    if($is_upload==1){
                        $gallery                                        = Gallery::IsCompany()
                            ->where('action_id', $load_accessorial->id)
                            ->where('source', 'load_accessorials')
                            ->where('field_name', 'accessorial_files')
                            ->first();
                        if(!is_null($gallery)){
                            $load_accessorial->is_received              = 1;

                            //status
                            $arry                                       = [];
                            $paid_type                                  = $load_accessorial->paid_type;
                            $reference                                  = $load_accessorial->reference;
                            $total                                      = $load_accessorial->total;

                            $owner_liable                               = $load_accessorial->owner_liable;
                            $owner_total                                = $load_accessorial->owner_total;

                            $driver_liable                              = $load_accessorial->driver_liable;
                            $driver_total                               = $load_accessorial->driver_total;

                            $doc_required                               = $load_accessorial->doc_required;

                            array_push($arry, $paid_type!=''?1:0);
                            array_push($arry, $reference!=''?1:0);
                            array_push($arry, $total!=''?1:0);
                            if($owner_liable=='1'){
                                array_push($arry, $owner_total!=''?1:0);
                            }
                            if($driver_liable=='1'){
                                array_push($arry, $driver_total!=''?1:0);
                            }

                            if(in_array(0, $arry)){
                                $load_accessorial->status               = 0; // Pending
                            }else{
                                if($doc_required=='1'){
                                    if($load_accessorial->is_received==1){
                                        $load_accessorial->status       = 1; // Completed
                                    }else{
                                        $load_accessorial->status       = 0; // Pending
                                    }
                                }else{
                                    $load_accessorial->status           = 1; // Completed
                                }
                            }
                            if ($driver_liable=='1' && $load_accessorial->status!=1 && isset($load_accessorial->file_not_provided) && $load_accessorial->file_not_provided=='on') {
                                $load_accessorial->status               = 2; // Driver Bypass
                            }
                            //status

                            $load_accessorial->save();
                            $this->setLoadAudit($load_accessorial->load_id, 'update', 'Load accessorial updated', $load_accessorial->getChanges(), $oldData);
                        }
                    }
                }
            } else if ($request->file_source_id == 'load_document_request_items') {
                $load_document_request_item                             = LoadDocumentRequestItem::where('id', $request->file_id)->first();
                if(!is_null($load_document_request_item)){
                    $oldData                                            = $load_document_request_item->toArray();

                    $updateData                                         = [];
                    if(isset($load_document_request_item->files) && is_serialized($load_document_request_item->files) && !empty(unserialize($load_document_request_item->files))){
                        $updateData                                     = unserialize($load_document_request_item->files);
                    }

                    if(!empty($updateData)){
                        $files                                          = isset($updateData['file']) && !empty($updateData['file']) ? $updateData['file'] : null;
                        $updateData['include_w_billing']                = isset($request->file_include_with_billing) && $request->file_include_with_billing=='yes'?'yes':'no';
                        $updateData['hide_from_driver']                 = isset($request->file_hide_from_driver) && $request->file_hide_from_driver=='yes'?'yes':'no';
                        if(isset($request->file_documents)){
                            if(isset($files) && !empty($files)){
                                foreach ($files as $key => $file) {
                                    $path                               = 'storage/companyAdmin/load_detail_document/'.$file;
                                    if (File::exists($path)) {
                                        File::delete($path);
                                    }
                                }
                            }
                            $updateData['is_received']                  = 'on';
                            $updateData['file']                         = UploadImagePdf($request->file_documents, 'companyAdmin/load_detail_document');
                            $updateData['upload_user_type']             = auth()->guard('company-admin')->user()->type;
                            $updateData['upload_by']                    = auth()->guard('company-admin')->user()->id;
                            $updateData['uploaded_at']                  = Carbon::now();
                        }else{
                            if(isset($files) && !empty($files)){
                                $updateData['is_received']              = 'on';
                                $updateData['file']                     = $files;
                                $updateData['upload_user_type']         = $data['upload_user_type'];
                                $updateData['upload_by']                = $data['upload_by'];
                                $updateData['uploaded_at']              = $data['uploaded_at'];
                            }else{
                                $updateData['file']                     = null;
                            }
                        }
                    }
                    $load_document_request_item->files                  = !empty($updateData) ? serialize($updateData) : null;
                    $load_document_request_item->updated_at             = Carbon::now()->format('Y-m-d H:i:s');
                    $load_document_request_item->updated_by             = auth()->guard('company-admin')->user()->id;
                    $load_document_request_item->updated_by_type        = auth()->guard('company-admin')->user()->type;
                    if($load_document_request_item->save()){
                        $this->setLoadAudit($load_document_request_item->load_id, 'update', 'Load document request item updated', $load_document_request_item->getChanges(), $oldData);
                    }
                }
            }
            return 1;
        }else{
            if(!empty($request->load_id)){
                $file_override                                          = isset($request->file_override) && $request->file_override=='1'?'1':'0';
                if(isset($request->file_id) && $request->file_id!=""){
                    $loadFile                                           = LoadFile::where('id', $request->file_id)->first();
                    if(!is_null($loadFile)){
                        // Audit log before change start
                        $oldData                                        = $loadFile->toArray();
                        // Audit log before  log  end
                        $loadFile->load_id                              = $request->load_id;
                        if($file_override=='0'){
                            $loadFile->load_file_type_id                = $request->filename_id;
                            $loadFile->filename                         = null;
                        }else{
                            $loadFile->load_file_type_id                = 0;
                            $loadFile->filename                         = $request->filename;
                        }
                        if (isset($request->file_documents)) {
                            $files                                      = [];
                            if(isset($loadFile->document) && is_serialized($loadFile->document) && !empty(unserialize($loadFile->document))){
                                $files                                  = unserialize($loadFile->document);
                            }
                            if(isset($files) && !empty($files)){
                                foreach ($files as $key => $file) {
                                    $path                               = 'storage/companyAdmin/loadfile/'.$file;
                                    if (File::exists($path)) {
                                        File::delete($path);
                                    }
                                }
                            }
                            $loadFile->document                         = serialize(UploadImagePdf($request->file_documents, 'companyAdmin/loadfile'));
                        }
                        $loadFile->note                                 = $request->file_note;
                        $loadFile->include_w_billing                    = isset($request->file_include_with_billing) && $request->file_include_with_billing=='yes'?'yes':'no';
                        $loadFile->hide_from_driver                     = isset($request->file_hide_from_driver) && $request->file_hide_from_driver=='yes'?'yes':'no';
                        $loadFile->upload_by                            = $user_id;
                        $loadFile->upload_user_type                     = 'Company Admin';
                        $loadFile->save();
                        // Audit log after change start
                        if(count($loadFile->getChanges())){
                            $this->setLoadAudit($request->load_id, 'update', 'Load document summary updated', $loadFile->getChanges(), $oldData);
                        }
                        // Audit log after log end
                    }
                }else{
                    $input                                              = [];
                    $input['load_id']                                   = $request->load_id;
                    if($file_override=='0'){
                        $input['load_file_type_id']                     = $request->filename_id;
                        $input['filename']                              = null;
                    }else{
                        $input['load_file_type_id']                     = 0;
                        $input['filename']                              = $request->filename;
                    }
                    if(isset($request->file_documents)){
                        $input['document']                              = serialize(UploadImagePdf($request->file_documents, 'companyAdmin/loadfile'));
                    }else{
                        $input['document']                              = null;
                    }
                    $input['note']                                      = $request->file_note;
                    $input['include_w_billing']                         = isset($request->file_include_with_billing) && $request->file_include_with_billing=='yes'?'yes':'no';
                    $input['hide_from_driver']                          = isset($request->file_hide_from_driver) && $request->file_hide_from_driver=='yes'?'yes':'no';
                    $input['upload_by']                                 = $user_id;
                    $input['upload_user_type']                          = 'Company Admin';
                    $load                                               = LoadFile::create($input);
                }
                return 1;
            }
        }
        return 0;
    }

    public function loadFileView(Request $request){
        // return response()->json(['view' => '']);

        $getTimeZone                                                = $this->timeZone;
        $getTimeZoneId                                              = $this->timeZoneId;
        $getTimeLayout                                              = getTimeLayout();

        $loadDetail                                                 = LoadDetail::where('load_id', $request->id)->latest()->first();
        $loadStop                                                   = LoadStop::where('load_id', $request->id)->orderBy('stop_no','ASC')->orderBy('date_time','ASC')->get();

        $static_files                                               = [];
        if(isset($loadDetail->invoice_files) && is_serialized($loadDetail->invoice_files) && !empty(unserialize($loadDetail->invoice_files))){
            $value                                                  = unserialize($loadDetail->invoice_files);
            $array                                                  = [];
            $array['id']                                            = $loadDetail->id;
            $array['source']                                        = 'load_details';
            $array['field_name']                                    = 'invoice_files';

            $array['name']                                          = 'Load';
            $array['filename']                                      = 'Invoice';
            $array['include_w_billing']                             = isset($value['include_w_billing']) && $value['include_w_billing']=='yes' ? 'yes' : 'no';
            $array['hide_from_driver']                              = isset($value['hide_from_driver']) && $value['hide_from_driver']=='yes' ? 'yes' : 'no';

            $status                                                 = 'Pending';
            $array['file']                                          = $value['file'] ?? null;
            if(isset($value['file']) && !empty($value['file'])){
                $status                                             = 'Complete';
                $array['upload_user_type']                          = isset($value['upload_user_type'])?$value['upload_user_type']:null;
                $array['uploaded_by']                               = isset($value['upload_by'])?getUserByType($value['upload_by'],$value['upload_user_type']):null;
                $array['uploaded_at']                               = isset($value['uploaded_at'])?Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format($getTimeLayout)." ".$this->timeZoneId:null;
            }
            $array['status']                                        = $status;

            $static_files[]                                         = $array;
        }else{
            $array                                                  = [];
            $array['id']                                            = $loadDetail->id;
            $array['source']                                        = 'load_details';
            $array['field_name']                                    = 'invoice_files';

            $array['name']                                          = 'Load';
            $array['filename']                                      = 'Invoice';
            $array['include_w_billing']                             = 'no';
            $array['hide_from_driver']                              = 'no';

            $array['file']                                          = null;
            $array['status']                                        = 'Pending';

            $static_files[]                                         = $array;
        }

        if(isset($loadDetail->rate_confirmation_files) && is_serialized($loadDetail->rate_confirmation_files) && !empty(unserialize($loadDetail->rate_confirmation_files))){
            $value                                                  = unserialize($loadDetail->rate_confirmation_files);
            $array                                                  = [];
            $array['id']                                            = $loadDetail->id;
            $array['source']                                        = 'load_details';
            $array['field_name']                                    = 'rate_confirmation_files';

            $array['name']                                          = 'Load';
            $array['filename']                                      = 'Rate Confirmation';
            $array['include_w_billing']                             = isset($value['include_w_billing']) && $value['include_w_billing']=='yes' ? 'yes' : 'no';
            $array['hide_from_driver']                              = isset($value['hide_from_driver']) && $value['hide_from_driver']=='yes' ? 'yes' : 'no';

            $status                                                 = 'Pending';
            $array['file']                                          = $value['file'] ?? null;
            if(isset($value['file']) && !empty($value['file'])){
                $status                                             = 'Complete';
                $array['upload_user_type']                          = isset($value['upload_user_type'])?$value['upload_user_type']:null;
                $array['uploaded_by']                               = isset($value['upload_by'])?getUserByType($value['upload_by'],$value['upload_user_type']):null;
                $array['uploaded_at']                               = isset($value['uploaded_at'])?Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format($getTimeLayout)." ".$this->timeZoneId:null;
            }
            $array['status']                                        = $status;

            $static_files[]                                         = $array;
        }else{
            $array                                                  = [];
            $array['id']                                            = $loadDetail->id;
            $array['source']                                        = 'load_details';
            $array['field_name']                                    = 'rate_confirmation_files';

            $array['name']                                          = 'Load';
            $array['filename']                                      = 'Rate Confirmation';
            $array['include_w_billing']                             = 'no';
            $array['hide_from_driver']                              = 'no';

            $array['file']                                          = null;
            $array['status']                                        = 'Pending';

            $static_files[]                                         = $array;
        }

        $required_files                                             = [];
        $requested_files                                            = [];
        //
        if(isset($loadDetail->shipper_files_upload) && is_serialized($loadDetail->shipper_files_upload) && !empty(unserialize($loadDetail->shipper_files_upload))){
            $uploads                                                = unserialize($loadDetail->shipper_files_upload);
            $uploads                                                = array_filter($uploads, function ($var) {
                return (isset($var['name_id']) && $var['name_id'] !== null && $var['type'] == 1);
            });
            foreach ($uploads as $key => $value) {
                $array                                              = [];
                $array['id']                                        = $loadDetail->id;
                $array['source']                                    = 'load_details';
                $array['field_name']                                = 'shipper_files_upload';

                $array['name']                                      = 1;
                $array['filename']                                  = $value['name'] ?? '';
                $array['filename_id']                               = $value['name_id'] ?? '';
                $array['include_w_billing']                         = isset($value['include_w_billing']) && $value['include_w_billing']=='yes' ? 'yes' : 'no';
                $array['hide_from_driver']                          = isset($value['hide_from_driver']) && $value['hide_from_driver']=='yes' ? 'yes' : 'no';

                $status                                             = 'Pending';
                $array['file']                                      = $value['file'] ?? null;
                if(isset($value['file']) && !empty($value['file'])){
                    $status                                         = 'Complete';
                    $array['upload_user_type']                      = isset($value['upload_user_type'])?$value['upload_user_type']:null;
                    $array['uploaded_by']                           = isset($value['upload_by'])?getUserByType($value['upload_by'],$value['upload_user_type']):null;
                    $array['uploaded_at']                           = isset($value['uploaded_at'])?Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format($getTimeLayout)." ".$this->timeZoneId:null;
                }else{
                    $file_not_provided                              = (isset($value['file_not_provided']) && $value['file_not_provided']=="on")? "on" : "off";
                    if($file_not_provided == 'on'){
                        $status                                     = 'Not provided';
                    }
                }
                $array['status']                                    = $status;

                $required_files[]                                   = $array;
            }
        }
        if(isset($loadDetail->shipper_load_document_request_items) && $loadDetail->shipper_load_document_request_items->isNotEmpty()){
            foreach ($loadDetail->shipper_load_document_request_items as $key => $item) {
                $value                                              = [];
                if(isset($item->files) && is_serialized($item->files) && !empty(unserialize($item->files))){
                    $value                                          = unserialize($item->files);
                }

                $array                                              = [];
                $array['id']                                        = $item->id;
                $array['source']                                    = 'load_document_request_items';
                $array['field_name']                                = 'files';

                $array['name']                                      = 1;
                $array['filename']                                  = $value['name'] ?? '';
                $array['filename_id']                               = $value['name_id'] ?? '';
                $array['include_w_billing']                         = isset($value['include_w_billing']) && $value['include_w_billing']=='yes' ? 'yes' : 'no';
                $array['hide_from_driver']                          = isset($value['hide_from_driver']) && $value['hide_from_driver']=='yes' ? 'yes' : 'no';

                $status                                             = 'Pending';
                $array['file']                                      = $value['file'] ?? null;
                if(isset($value['file']) && !empty($value['file'])){
                    $status                                         = 'Complete';
                    $array['upload_user_type']                      = isset($value['upload_user_type'])?$value['upload_user_type']:null;
                    $array['uploaded_by']                           = isset($value['upload_by'])?getUserByType($value['upload_by'],$value['upload_user_type']):null;
                    $array['uploaded_at']                           = isset($value['uploaded_at'])?Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format($getTimeLayout)." ".$this->timeZoneId:null;
                }else{
                    $file_not_provided                              = (isset($value['file_not_provided']) && $value['file_not_provided']=="on")? "on" : "off";
                    if($file_not_provided == 'on'){
                        $status                                     = 'Not provided';
                    }
                }
                $array['status']                                    = $status;

                $requested_files[]                                  = $array;
            }
        }
        //
        $stop_no                                                    = 2;
        if($loadStop->isNotEmpty()){
            foreach ($loadStop as $key => $stop) {
                //
                $customer_type                                      = $stop->customer_type;
                $field_name                                         = $customer_type=='1'?'stop_shipper_files_upload':'stop_consignee_files_upload';
                if(isset($stop->$field_name) && is_serialized($stop->$field_name) && !empty(unserialize($stop->$field_name))){
                    $uploads                                        = unserialize($stop->$field_name);
                    $uploads                                        = array_filter($uploads, function ($var) {
                        return (isset($var['name_id']) && $var['name_id'] !== null && $var['type'] == 1);
                    });
                    foreach ($uploads as $key => $value) {
                        $array                                      = [];
                        $array['id']                                = $stop->id;
                        $array['source']                            = 'load_stops';
                        $array['field_name']                        = $field_name;

                        $array['name']                              = $stop_no;
                        $array['filename']                          = $value['name'] ?? '';
                        $array['filename_id']                       = $value['name_id'] ?? '';
                        $array['include_w_billing']                 = isset($value['include_w_billing']) && $value['include_w_billing']=='yes' ? 'yes' : 'no';
                        $array['hide_from_driver']                  = isset($value['hide_from_driver']) && $value['hide_from_driver']=='yes' ? 'yes' : 'no';

                        $status                                     = 'Pending';
                        $array['file']                              = $value['file'] ?? null;
                        if(isset($value['file']) && !empty($value['file'])){
                            $status                                 = 'Complete';
                            $array['upload_user_type']              = isset($value['upload_user_type'])?$value['upload_user_type']:null;
                            $array['uploaded_by']                   = isset($value['upload_by'])?getUserByType($value['upload_by'],$value['upload_user_type']):null;
                            $array['uploaded_at']                   = isset($value['uploaded_at'])?Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format($getTimeLayout)." ".$this->timeZoneId:null;
                        }else{
                            $file_not_provided                      = (isset($value['file_not_provided']) && $value['file_not_provided']=="on")? "on" : "off";
                            if($file_not_provided == 'on'){
                                $status                             = 'Not provided';
                            }
                        }
                        $array['status']                            = $status;

                        $required_files[]                           = $array;
                    }
                }
                if(isset($stop->load_document_request_items) && $stop->load_document_request_items->isNotEmpty()){
                    foreach ($stop->load_document_request_items as $key => $item) {
                        $value                                      = [];
                        if(isset($item->files) && is_serialized($item->files) && !empty(unserialize($item->files))){
                            $value                                  = unserialize($item->files);
                        }

                        $array                                      = [];
                        $array['id']                                = $item->id;
                        $array['source']                            = 'load_document_request_items';
                        $array['field_name']                        = 'files';

                        $array['name']                              = $stop_no;
                        $array['filename']                          = $value['name'] ?? '';
                        $array['filename_id']                       = $value['name_id'] ?? '';
                        $array['include_w_billing']                 = isset($value['include_w_billing']) && $value['include_w_billing']=='yes' ? 'yes' : 'no';
                        $array['hide_from_driver']                  = isset($value['hide_from_driver']) && $value['hide_from_driver']=='yes' ? 'yes' : 'no';

                        $status                                     = 'Pending';
                        $array['file']                              = $value['file'] ?? null;
                        if(isset($value['file']) && !empty($value['file'])){
                            $status                                 = 'Complete';
                            $array['upload_user_type']              = isset($value['upload_user_type'])?$value['upload_user_type']:null;
                            $array['uploaded_by']                   = isset($value['upload_by'])?getUserByType($value['upload_by'],$value['upload_user_type']):null;
                            $array['uploaded_at']                   = isset($value['uploaded_at'])?Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format($getTimeLayout)." ".$this->timeZoneId:null;
                        }else{
                            $file_not_provided                      = (isset($value['file_not_provided']) && $value['file_not_provided']=="on")? "on" : "off";
                            if($file_not_provided == 'on'){
                                $status                             = 'Not provided';
                            }
                        }
                        $array['status']                            = $status;

                        $requested_files[]                          = $array;
                    }
                }
                //
                ++$stop_no;
            }
        }

        //
        if(isset($loadDetail->consignee_files_upload) && is_serialized($loadDetail->consignee_files_upload) && !empty(unserialize($loadDetail->consignee_files_upload))){
            $uploads                                                = unserialize($loadDetail->consignee_files_upload);
            $uploads                                                = array_filter($uploads, function ($var) {
                return (isset($var['name_id']) && $var['name_id'] !== null && $var['type'] == 1);
            });
            foreach ($uploads as $key => $value) {
                $array                                              = [];
                $array['id']                                        = $loadDetail->id;
                $array['source']                                    = 'load_details';
                $array['field_name']                                = 'consignee_files_upload';

                $array['name']                                      = 99;
                $array['filename']                                  = $value['name'] ?? '';
                $array['filename_id']                               = $value['name_id'] ?? '';
                $array['include_w_billing']                         = isset($value['include_w_billing']) && $value['include_w_billing']=='yes' ? 'yes' : 'no';
                $array['hide_from_driver']                          = isset($value['hide_from_driver']) && $value['hide_from_driver']=='yes' ? 'yes' : 'no';

                $status                                             = 'Pending';
                $array['file']                                      = $value['file'] ?? null;
                if(isset($value['file']) && !empty($value['file'])){
                    $status                                         = 'Complete';
                    $array['upload_user_type']                      = isset($value['upload_user_type'])?$value['upload_user_type']:null;
                    $array['uploaded_by']                           = isset($value['upload_by'])?getUserByType($value['upload_by'],$value['upload_user_type']):null;
                    $array['uploaded_at']                           = isset($value['uploaded_at'])?Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format($getTimeLayout)." ".$this->timeZoneId:null;
                }else{
                    $file_not_provided                              = (isset($value['file_not_provided']) && $value['file_not_provided']=="on")? "on" : "off";
                    if($file_not_provided == 'on'){
                        $status                                     = 'Not provided';
                    }
                }
                $array['status']                                    = $status;

                $required_files[]                                   = $array;
            }
        }
        if(isset($loadDetail->receiver_load_document_request_items) && $loadDetail->receiver_load_document_request_items->isNotEmpty()){
            foreach ($loadDetail->receiver_load_document_request_items as $key => $item) {
                $value                                              = [];
                if(isset($item->files) && is_serialized($item->files) && !empty(unserialize($item->files))){
                    $value                                          = unserialize($item->files);
                }

                $array                                              = [];
                $array['id']                                        = $item->id;
                $array['source']                                    = 'load_document_request_items';
                $array['field_name']                                = 'files';

                $array['name']                                      = 99;
                $array['filename']                                  = $value['name'] ?? '';
                $array['filename_id']                               = $value['name_id'] ?? '';
                $array['include_w_billing']                         = isset($value['include_w_billing']) && $value['include_w_billing']=='yes' ? 'yes' : 'no';
                $array['hide_from_driver']                          = isset($value['hide_from_driver']) && $value['hide_from_driver']=='yes' ? 'yes' : 'no';

                $status                                             = 'Pending';
                $array['file']                                      = $value['file'] ?? null;
                if(isset($value['file']) && !empty($value['file'])){
                    $status                                         = 'Complete';
                    $array['upload_user_type']                      = isset($value['upload_user_type'])?$value['upload_user_type']:null;
                    $array['uploaded_by']                           = isset($value['upload_by'])?getUserByType($value['upload_by'],$value['upload_user_type']):null;
                    $array['uploaded_at']                           = isset($value['uploaded_at'])?Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format($getTimeLayout)." ".$this->timeZoneId:null;
                }else{
                    $file_not_provided                              = (isset($value['file_not_provided']) && $value['file_not_provided']=="on")? "on" : "off";
                    if($file_not_provided == 'on'){
                        $status                                     = 'Not provided';
                    }
                }
                $array['status']                                    = $status;

                $requested_files[]                                  = $array;
            }
        }
        //

        $accessorial_files                                          = [];
        $shipper_accessorials                                       = $loadDetail->shipper_accessorials()->where('doc_required', '!=', 0)->get();
        if($shipper_accessorials->isNotEmpty()){
            foreach ($shipper_accessorials as $key => $load_accessorial) {
                $gallery                                            = Gallery::IsCompany()
                    ->where('action_id', $load_accessorial->id)
                    ->where('source', 'load_accessorials')
                    ->where('field_name', 'accessorial_files')
                    ->first();
                $filename                                           = $load_accessorial->company_accessorial->name;
                if(!is_null($gallery)){
                    $filename                                      .= isset($gallery->file_name) ? ' - '.$gallery->file_name : '';
                }
                $array                                              = [];
                $array['id']                                        = $load_accessorial->id;
                $array['source']                                    = 'load_accessorials';
                $array['field_name']                                = 'image';

                $array['name']                                      = 1;
                $array['filename']                                  = $filename;
                $array['include_w_billing']                         = isset($gallery->include_w_billing) && $gallery->include_w_billing=='yes' ? 'yes' : 'no';
                $array['hide_from_driver']                          = isset($gallery->hide_from_driver) && $gallery->hide_from_driver=='yes' ? 'yes' : 'no';

                $array['file']                                      = $gallery->image ?? null;
                //status
                if(isset($load_accessorial->temp_details) && is_serialized($load_accessorial->temp_details) && !empty(unserialize($load_accessorial->temp_details))){
                    $temp_details                                   = unserialize($load_accessorial->temp_details);
                    if(isset($temp_details['status'])){
                        $load_accessorial->status                   = $temp_details['status'];
                    }
                }
                $status                                             = 'Pending';
                if($load_accessorial->status=='1'){
                    $status                                         = 'Complete';
                }elseif ($load_accessorial->status=='2') {
                    $status                                         = 'Driver Bypass';
                }
                //

                if(isset($gallery->image) && !empty($gallery->image)){
                    $array['upload_user_type']                      = isset($gallery->created_by_type)?$gallery->created_by_type:null;
                    $array['uploaded_by']                           = isset($gallery->created_by)?getUserByType($gallery->created_by,$gallery->created_by_type):null;
                    $array['uploaded_at']                           = isset($gallery->created_at)?Carbon::createFromFormat('Y-m-d H:i:s', $gallery->created_at)->setTimezone($this->timeZone)->format($getTimeLayout)." ".$this->timeZoneId:null;
                }
                $array['status']                                    = $status;

                $accessorial_files[]                                = $array;
            }
        }

        $accessorial_no                                             = 2;
        foreach ($loadStop as $key => $stop) {
            $stop_accessorials                                      = $stop->accessorials()->where('doc_required', '!=', 0)->get();
            if($stop_accessorials->isNotEmpty()){
                foreach ($stop_accessorials as $key => $load_accessorial) {
                    $gallery                                        = Gallery::IsCompany()
                        ->where('action_id', $load_accessorial->id)
                        ->where('source', 'load_accessorials')
                        ->where('field_name', 'accessorial_files')
                        ->first();
                    $filename                                       = $load_accessorial->company_accessorial->name;
                    if(!is_null($gallery)){
                        $filename                                  .= isset($gallery->file_name) ? ' - '.$gallery->file_name : '';
                    }
                    $array                                          = [];
                    $array['id']                                    = $load_accessorial->id;
                    $array['source']                                = 'load_accessorials';
                    $array['field_name']                            = 'image';

                    $array['name']                                  = $accessorial_no;
                    $array['filename']                              = $filename;
                    $array['include_w_billing']                     = isset($gallery->include_w_billing) && $gallery->include_w_billing=='yes' ? 'yes' : 'no';
                    $array['hide_from_driver']                      = isset($gallery->hide_from_driver) && $gallery->hide_from_driver=='yes' ? 'yes' : 'no';

                    $array['file']                                  = $gallery->image ?? null;
                    //status
                    if(isset($load_accessorial->temp_details) && is_serialized($load_accessorial->temp_details) && !empty(unserialize($load_accessorial->temp_details))){
                        $temp_details                               = unserialize($load_accessorial->temp_details);
                        if(isset($temp_details['status'])){
                            $load_accessorial->status               = $temp_details['status'];
                        }
                    }
                    $status                                         = 'Pending';
                    if($load_accessorial->status=='1'){
                        $status                                     = 'Complete';
                    }elseif ($load_accessorial->status=='2') {
                        $status                                     = 'Driver Bypass';
                    }
                    //

                    if(isset($gallery->image) && !empty($gallery->image)){
                        $array['upload_user_type']                  = isset($gallery->created_by_type)?$gallery->created_by_type:null;
                        $array['uploaded_by']                       = isset($gallery->created_by)?getUserByType($gallery->created_by,$gallery->created_by_type):null;
                        $array['uploaded_at']                       = isset($gallery->created_at)?Carbon::createFromFormat('Y-m-d H:i:s', $gallery->created_at)->setTimezone($this->timeZone)->format($getTimeLayout)." ".$this->timeZoneId:null;
                    }
                    $array['status']                                = $status;

                    $accessorial_files[]                            = $array;
                }
            }
            ++$accessorial_no;
        }

        $receiver_accessorials                                      = $loadDetail->receiver_accessorials()->where('doc_required', '!=', 0)->get();
        if($receiver_accessorials->isNotEmpty()){
            foreach ($receiver_accessorials as $key => $load_accessorial) {
                $gallery                                            = Gallery::IsCompany()
                    ->where('action_id', $load_accessorial->id)
                    ->where('source', 'load_accessorials')
                    ->where('field_name', 'accessorial_files')
                    ->first();
                $filename                                           = $load_accessorial->company_accessorial->name;
                if(!is_null($gallery)){
                    $filename                                      .= isset($gallery->file_name) ? ' - '.$gallery->file_name : '';
                }
                $array                                              = [];
                $array['id']                                        = $load_accessorial->id;
                $array['source']                                    = 'load_accessorials';
                $array['field_name']                                = 'image';

                $array['name']                                      = 99;
                $array['filename']                                  = $filename;
                $array['include_w_billing']                         = isset($gallery->include_w_billing) && $gallery->include_w_billing=='yes' ? 'yes' : 'no';
                $array['hide_from_driver']                          = isset($gallery->hide_from_driver) && $gallery->hide_from_driver=='yes' ? 'yes' : 'no';

                $array['file']                                      = $gallery->image ?? null;
                //status
                if(isset($load_accessorial->temp_details) && is_serialized($load_accessorial->temp_details) && !empty(unserialize($load_accessorial->temp_details))){
                    $temp_details                                   = unserialize($load_accessorial->temp_details);
                    if(isset($temp_details['status'])){
                        $load_accessorial->status                   = $temp_details['status'];
                    }
                }
                $status                                             = 'Pending';
                if($load_accessorial->status=='1'){
                    $status                                         = 'Complete';
                }elseif ($load_accessorial->status=='2') {
                    $status                                         = 'Driver Bypass';
                }
                //

                if(isset($gallery->image) && !empty($gallery->image)){
                    $array['upload_user_type']                      = isset($gallery->created_by_type)?$gallery->created_by_type:null;
                    $array['uploaded_by']                           = isset($gallery->created_by)?getUserByType($gallery->created_by,$gallery->created_by_type):null;
                    $array['uploaded_at']                           = isset($gallery->created_at)?Carbon::createFromFormat('Y-m-d H:i:s', $gallery->created_at)->setTimezone($this->timeZone)->format($getTimeLayout)." ".$this->timeZoneId:null;
                }
                $array['status']                                    = $status;

                $accessorial_files[]                                = $array;
            }
        }

        $billing_accessorials                                       = $loadDetail->billing_accessorials()->where('doc_required', '!=', 0)->get();
        if($billing_accessorials->isNotEmpty()){
            foreach ($billing_accessorials as $key => $load_accessorial) {
                $gallery                                            = Gallery::IsCompany()
                    ->where('action_id', $load_accessorial->id)
                    ->where('source', 'load_accessorials')
                    ->where('field_name', 'accessorial_files')
                    ->first();
                $filename                                           = $load_accessorial->company_accessorial->name;
                if(!is_null($gallery)){
                    $filename                                      .= isset($gallery->file_name) ? ' - '.$gallery->file_name : '';
                }
                $array                                              = [];
                $array['id']                                        = $load_accessorial->id;
                $array['source']                                    = 'load_accessorials';
                $array['field_name']                                = 'image';

                $array['name']                                      = 'Load';
                $array['filename']                                  = $filename;
                $array['include_w_billing']                         = isset($gallery->include_w_billing) && $gallery->include_w_billing=='yes' ? 'yes' : 'no';
                $array['hide_from_driver']                          = isset($gallery->hide_from_driver) && $gallery->hide_from_driver=='yes' ? 'yes' : 'no';

                $array['file']                                      = $gallery->image ?? null;
                //status
                if(isset($load_accessorial->temp_details) && is_serialized($load_accessorial->temp_details) && !empty(unserialize($load_accessorial->temp_details))){
                    $temp_details                                   = unserialize($load_accessorial->temp_details);
                    if(isset($temp_details['status'])){
                        $load_accessorial->status                   = $temp_details['status'];
                    }
                }
                $status                                             = 'Pending';
                if($load_accessorial->status=='1'){
                    $status                                         = 'Complete';
                }elseif ($load_accessorial->status=='2') {
                    $status                                         = 'Driver Bypass';
                }
                //

                if(isset($gallery->image) && !empty($gallery->image)){
                    $array['upload_user_type']                      = isset($gallery->created_by_type)?$gallery->created_by_type:null;
                    $array['uploaded_by']                           = isset($gallery->created_by)?getUserByType($gallery->created_by,$gallery->created_by_type):null;
                    $array['uploaded_at']                           = isset($gallery->created_at)?Carbon::createFromFormat('Y-m-d H:i:s', $gallery->created_at)->setTimezone($this->timeZone)->format($getTimeLayout)." ".$this->timeZoneId:null;
                }
                $array['status']                                    = $status;

                $accessorial_files[]                                = $array;
            }
        }

        $cod_files                                                  = [];
        $get_cod_files                                              = Gallery::IsCompany()
            ->where('action_id', $request->id)
            ->where('source', 'load')
            ->whereIn('field_name', ['up_front_file', 'at_pickup_file', 'at_delivery_file'])
            ->get();
        if($get_cod_files->isNotEmpty()){
            foreach ($get_cod_files as $key => $cod_file) {
                if(isset($cod_file->image) && $cod_file->image!=''){
                    $array                                          = [];
                    $array['id']                                    = $cod_file->id;
                    $array['source']                                = 'load_cod_galleries';
                    $array['field_name']                            = 'image';

                    $array['name']                                  = 'COD';
                    $array['filename']                              = $cod_file->file_name;
                    $array['include_w_billing']                     = isset($cod_file->include_w_billing) && $cod_file->include_w_billing=='yes' ? 'yes' : 'no';
                    $array['hide_from_driver']                      = isset($cod_file->hide_from_driver) && $cod_file->hide_from_driver=='yes' ? 'yes' : 'no';

                    $array['file']                                  = $cod_file->image ?? null;
                    if(isset($cod_file->image) && !empty($cod_file->image)){
                        $array['upload_user_type']                  = isset($cod_file->created_by_type)?$cod_file->created_by_type:null;
                        $array['uploaded_by']                       = isset($cod_file->created_by)?getUserByType($cod_file->created_by,$cod_file->created_by_type):null;
                        $array['uploaded_at']                       = isset($cod_file->created_at)?Carbon::createFromFormat('Y-m-d H:i:s', $cod_file->created_at)->setTimezone($this->timeZone)->format($getTimeLayout)." ".$this->timeZoneId:null;
                    }
                    $array['status']                                = 'Complete';

                    $cod_files[]                                    = $array;
                }
            }
        }

        $getFile                                                    = LoadFile::where('load_id', $request->id)->orderBy('id','desc')->get();

        $view                                                       = view('companyAdmin.load.file.list', compact('static_files', 'required_files', 'requested_files', 'accessorial_files', 'cod_files', 'getFile', 'getTimeZone', 'getTimeZoneId', 'getTimeLayout'))->render(); // old => companyAdmin.load.file.view
        return response()->json(['view' => $view]);
    }

    public function destroyFile($id){
        $getFile    = LoadFile::find($id);
        $this->setLoadAudit($getFile->load_id, 'delete', 'Load document summary deleted', [], []);
        File::delete('storage/companyAdmin/loadfile/'.$getFile->document);
        $getFile->delete();
        return 1;
    }

    /**
     * Fetch the specified driver info from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function driverInfo(Request $request){
        $response['success']                = false;
        $response['message']                = "Oops! Something went wrong..";
        if(is_null($request->id) || $request->id==0){
            return response()->json($response);
        }

        $driver                             = Driver::find($request->id);

        $load_detail                        = LoadDetail::whereNotNull('trailer_number')->where('driver_id', $request->id)->latest()->first();
        if(isset($load_detail->trailer_number) && $load_detail->trailer_number!=''){
            $trailerNumber                  = $load_detail->trailer_number;
        }else{
            $trailerNumber                  = $driver->driver_information->trailer_number;
        }
        $checkOosTrailer                    = false;
        if(!is_null($trailerNumber) && checkOosTrailer($trailerNumber) == true){
            $checkOosTrailer                = true;
        }

        $getTerminal                        = Terminal::find($driver->driver_information->terminal_id);
        $termianlOption                     = '<option value="" selected="selected">Select Terminal</option>';
        if(isset($getTerminal->id)){
            $termianlOption                 = '<option value="'.$getTerminal->id.'" selected="selected">'.$getTerminal->name.'</option>';
        }

        $getCarrier                         = Carrier::find($driver->driver_information->carrier_id);
        $carrierOption                      = '<option value="" selected="selected">Select Carrier</option>';
        $desiredOption                      = "";
        $identifier                         = "";
        $carrierId                          = "";
        if(isset($getCarrier->id)){
            $carrierOption                  = '<option value="'.$getCarrier->id.'" selected="selected">'.$getCarrier->name.'</option>';
            $desiredOption                  = (!is_null($getCarrier->desired_option)) ? $getCarrier->desired_option : "";
            $identifier                     = (!is_null($getCarrier->identifier)) ? $getCarrier->identifier : "";
            $carrierId                      = $getCarrier->id;
        }

        $truck                              = $driver->driver_information->truck;
        $truck_owner_id                     = null;
        $truck_owner_type                   = null;
        $truck_owner_name                   = null;
        $truck_length                       = "";
        $truck_width                        = "";
        $truck_height                       = "";
        $truck_max_load_weight              = "";
        if($truck){
            // $owner_type.'_'.$owner_id;
            $truck_owner_id                 = $truck->owner_id ?? null;
            $truck_owner_type               = $truck->owner_type ?? null;
            if($truck_owner_type==1){
                $truckOwnerCarrier          = Carrier::find($truck_owner_id);
                if($truckOwnerCarrier){
                    $truck_owner_name       = $truckOwnerCarrier->name;
                }
            }else if ($truck_owner_type==2) {
                $truckOwner                 = TruckOwner::find($truck_owner_id);
                if($truckOwner){
                    $truck_owner_name       = $truckOwner->name;
                }
            }

            $truck_length                    = $truck->length;
            $truck_width                     = $truck->width;
            $truck_height                    = $truck->height;
            $truck_max_load_weight           = $truck->max_load_weight;
        }

        if (!is_null($driver)) {
            $data                           = [];
            $data['company']                = $driver->company->name;
            $data['dispatch_type']          = $driver->dispatch_type;

            $data['trailer_number']         = $trailerNumber;
            $data['checkOosTrailer']        = $checkOosTrailer;

            $data['truck_number']           = $driver->driver_information->truck_number;
            $data['truck_owner_id']         = $truck_owner_id;
            $data['truck_owner_type']       = $truck_owner_type;
            $data['truck_owner_name']       = $truck_owner_name;

            $data['truck_length']           = $truck_length;
            $data['truck_width']            = $truck_width;
            $data['truck_height']           = $truck_height;
            $data['truck_max_load_weight']  = $truck_max_load_weight;

            $data['termianl_option']        = $termianlOption;
            $data['carrier_option']         = $carrierOption;
            $data['desired_option']         = $desiredOption;
            $data['identifier']             = $identifier;
            $data['carrier_id']             = $carrierId;

            $response['success']            = true;
            $response['message']            = "Driver retrieved successfully.";
            $response['data']               = $data;
        }
        return response()->json($response);
    }

    public function truckOwnerOptions(Request $request){
        $response['success']                            = false;
        $response['message']                            = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $html                                   = '<option value="">Select Truck Owner</option>';
                $array                                  = [];
                $drivers                                = Driver::whereIn('id', $request->driver_ids ?  $request->driver_ids : [])->get();
                if($drivers->isNotEmpty()){
                    foreach ($drivers as $key => $driver) {
                        $truck                          = $driver->driver_information->truck;
                        if($truck){
                            // $owner_type.'_'.$owner_id;
                            $owner_id                   = $truck->owner_id ?? null;
                            if($owner_id){
                                $type                   = $truck->owner_type;
                                if($type==1){
                                    $carrier            = Carrier::find($owner_id);
                                    if($carrier){
                                        $owner_name     = $carrier->name;
                                        $array[$type][$owner_id] = $owner_name;
                                    }
                                }else if ($type==2) {
                                    $truckOwner         = TruckOwner::find($owner_id);
                                    if($truckOwner){
                                        $owner_name     = $truckOwner->name;
                                        $array[$type][$owner_id] = $owner_name;
                                    }
                                }
                            }
                        }
                    }
                }
                ksort($array);
                foreach ($array as $owner_type => $mul) {
                    $owner_type_name                    = 'Other';
                    if($owner_type==1){
                        $owner_type_name                = 'Carrier';
                    }else if ($owner_type==2) {
                        $owner_type_name                = 'Truck Owner';
                    }
                    $html                              .= '<optgroup label="'.$owner_type_name.'">';
                    foreach ($mul as $owner_id => $row) {
                        $value                          = $owner_type.'_'.$owner_id;
                        $html                          .= '<option value="'.$value.'">'.$row.'</option>'; // $owner_type.'_'.$owner_id;
                    }
                    $html                              .= '</optgroup>';
                }
                $response['html']                       = $html;
                $response['success']                    = true;
                $response['message']                    = "Truck owner options retrieved successfully.";
            }catch (\Exception $e) {
                $response['success']                    = false;
                $response['message']                    = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function deadheadLocation(Request $request){
        $response['success']                = false;
        $response['message']                = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $driver                     = Driver::whereId($request->id)->first();
                if($driver){
                    $response['locations']  = deadheadLocation($driver, $request->all());
                    $response['success']    = true;
                    $response['message']    = "Locations retrieved successfully.";
                }else{
                    $response['success']    = false;
                    $response['message']    = "Driver not found.";
                }
            }catch (\Exception $e) {
                $response['success']        = false;
                $response['message']        = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    /**
     * Fetch the specified fuel surcharge info from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function fuelSurchargeInfo(Request $request){
        $data           = '';
        if (!empty($request->start_date) && empty($request->end_date)) {
            $startDate  = Carbon::parse($request->start_date)->format('Y-m-d');
            $data       = WeeklyFuelSurcharge::isCompany()
                // ->whereDate('date', $startDate)
                ->where(\DB::raw('DATE_FORMAT(start_date, "%Y-%m-%d")'), '<=', $startDate)
                ->where(\DB::raw('DATE_FORMAT(end_date, "%Y-%m-%d")'), '>=', $startDate)
                ->first();
        } elseif (!empty($request->start_date) && !empty($request->end_date)) {
            $startDate  = Carbon::parse($request->start_date)->format('Y-m-d');
            $endDate    = Carbon::parse($request->end_date)->format('Y-m-d');
            $data       = WeeklyFuelSurcharge::isCompany()
                ->where(\DB::raw('DATE_FORMAT(start_date, "%Y-%m-%d")'), '<=', $startDate)
                ->where(\DB::raw('DATE_FORMAT(end_date, "%Y-%m-%d")'), '>=', $endDate)
                ->first();
        }
        return response()->json(['data' => $data]);
    }

    /**
     * Fetch the specified broker info from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function brokerInfo(Request $request){
        $broker                                 = Broker::find($request->id);

        $email_arry                             = [];
        $phone_arry                             = [];

        if(!is_null($broker->email))
            $email_arry[]                       = [
                'table'                         => 'brokers',
                'field_name'                    => 'email',
                'name'                          => $broker->name,
                'email'                         => $broker->email,
                'primary_contact'               => 0
            ];
        if(!is_null($broker->phone))
            $phone_arry[]                       = [
                'table'                         => 'brokers',
                'field_name'                    => 'phone',
                'name'                          => $broker->name,
                'phone'                         => $broker->phone,
                'primary_contact'               => 0
            ];

        if(!is_null($broker->billing_email))
            $email_arry[]                       = [
                'table'                         => 'brokers',
                'field_name'                    => 'billing_email',
                'name'                          => $broker->bill_to_name,
                'email'                         => $broker->billing_email,
                'primary_contact'               => 0
            ];
        if(!is_null($broker->billing_phone))
            $phone_arry[]                       = [
                'table'                         => 'brokers',
                'field_name'                    => 'billing_phone',
                'name'                          => $broker->name,
                'phone'                         => $broker->billing_phone,
                'primary_contact'               => 0
            ];

        $office_html                            = '<option value="">Select option</option>';
        if($broker->broker_offices->isNotEmpty()){
            foreach ($broker->broker_offices as $key => $office) {
                $office_id                      = $office->name;

                $office_array                   = [];
                $office_array[]                 = $office_id;
                if(!is_null($office->city))
                    $office_array[]             = $office->city;
                if(!is_null($office->state))
                    $office_array[]             = $office->state;
                if(!is_null($office->zip))
                    $office_array[]             = $office->zip;

                $office_text                    = implode(', ', $office_array);
                $office_html                   .= '<option value="'.$office->name.'">'.$office_text.'</option>';
            }
        }

        $department_arry                        = [];

        $contact_html                           = '';
        $contact_html                          .= '<select class="form-control broker-contact select2" name="rep">';
        $contact_html                          .= '<option value="">Select option</option>';
        if(!empty($broker->dispatch_contact_name)){
            $contact_html                       .= '<option value="'.$broker->dispatch_contact_name.'" data-phone="'.$broker->dispatch_contact_phone.'" data-ext="'.$broker->dispatch_contact_contact_ext.'" data-email="'.$broker->dispatch_contact_email.'">'.$broker->dispatch_contact_name.'</option>';
        }
        if($broker->broker_contact->isNotEmpty()){
            foreach ($broker->broker_contact as $key => $cdata) {
                $primary_contact                = 0;
                if($cdata->primary_contact==1 && !is_null($cdata->primary_contact_id)){
                    if(in_array(auth()->guard('company-admin')->id(), explode(',', $cdata->primary_contact_id))){
                        $primary_contact        = 1;
                    }
                }

                if(!is_null($cdata->email))
                    $email_arry[]               = [
                        'table'                 => 'broker_contacts',
                        'field_name'            => 'email',
                        'name'                  => $cdata->name,
                        'email'                 => $cdata->email,
                        'primary_contact'       => $primary_contact
                    ];
                if(!is_null($cdata->cell_number))
                    $phone_arry[]               = [
                        'table'                 => 'broker_contacts',
                        'field_name'            => 'cell_number',
                        'name'                  => $cdata->name,
                        'phone'                 => $cdata->cell_number,
                        'primary_contact'       => $primary_contact
                    ];

                if(!is_null($cdata->department))
                    $department_arry[]          = $cdata->department;

                $contact_html                  .= '<option value="'.$cdata->name.'" data-phone="'.$cdata->phone_number.'" data-ext="'.$cdata->ext.'" data-email="'.$cdata->email.'" data-primary_contact="'.$primary_contact.'">'.$cdata->name.'</option>';
            }
        }
        $contact_html                          .= '</select>';

        $department_html                        = '<option value="">Select option</option>';
        foreach (array_unique($department_arry) as $key => $department) {
            $department_html                   .= '<option value="'.$department.'">'.$department.'</option>';
        }

        $email_html                             = ''; // '<option value="">Select option</option>';
        foreach ($email_arry as $key => $email_row) {
            $email_id                           = $email_row['table']. '|' .$email_row['field_name']. '|' .$email_row['email'];
            $email_text                         = $email_row['name']. ' - '.$email_row['email'];
            $email_html                        .= '<option value="'.$email_id.'" data-primary_contact="'.$email_row['primary_contact'].'">'.$email_text.'</option>';
        }

        $phone_html                             = ''; // '<option value="">Select option</option>';
        foreach ($phone_arry as $key => $phone_row) {
            $phone_id                           = $phone_row['table']. '|' .$phone_row['field_name']. '|' .$phone_row['phone'];
            $phone_text                         = $phone_row['name']. ' - '.$phone_row['phone'];
            $phone_html                        .= '<option value="'.$phone_id.'" data-primary_contact="'.$phone_row['primary_contact'].'">'.$phone_text.'</option>';
        }

        $rts_score                              = [];
        $latestRtsScore                         = LoadDetail::where('brokerage_firm', $broker->id)
            ->where('id', $request->load_detail_id)
            ->orderBy('id', 'DESC')
            ->first();
        if($latestRtsScore){
            $rts_score['load_id']               = $latestRtsScore->load_id;
            $rts_score['score_ratting']         = $latestRtsScore->score_ratting;
            $rts_score['score_credit']          = $latestRtsScore->score_credit;
            $rts_score['score_update']          = $latestRtsScore->score_updated_at;
            $rts_score['convert_score_update']  = isset($latestRtsScore->score_updated_at) ? convertTimeToUSERzone([
                'str'           => $latestRtsScore->score_updated_at,
                'toFormat'      => getTimeLayout(),
                'fromFormat'    => 'Y-m-d H:i:s']
            ).' '.$this->timeZoneId : null;
        }

        $accessorials                           = CompanyAccessorial::isCompany()->get(['id', 'name', 'default_amount', 'gl_code']);
        $accessorials_html                      = "";
        if($accessorials->count() > 0){
            $accessorials_html                  .= '<option value="">Select accessorial</option>';
            foreach ($accessorials as $accessorial){
                $broker_rate                    = '';
                if($broker){
                    $broker_accessorial         = $broker->broker_accessorials()
                        ->where('company_accessorial_id', $accessorial->id)
                        ->latest()
                        ->first();
                    if($broker_accessorial){
                        $broker_rate            = $broker_accessorial->rate;
                    }
                }
                $accessorials_html             .= '<option value="'.$accessorial->id.'" data-default-amount="'.$accessorial->default_amount.'" data-broker-rate="'.$broker_rate.'">'.$accessorial->name.'</option>';
            }
        }else{
            $accessorials_html                 .= '<option value="" data-default-amount="">Select accessorial</option>';
        }

        $shipper_files                          = []; // unserialize(config('settings.shipper_files'));
        if(!empty($broker->shipper_files)){
            $shipper_files                      = unserialize($broker->shipper_files);
            $shipper_files                      = array_filter($shipper_files, function($var) {
                return isset($var['name_id']) && $var['name_id'] !== null;
            });
        }

        $consignee_files                        = []; // unserialize(config('settings.consignee_files'));
        if(!empty($broker->consignee_files)){
            $consignee_files                    = unserialize($broker->consignee_files);
            $consignee_files                    = array_filter($consignee_files, function($var) {
                return isset($var['name_id']) && $var['name_id'] !== null;
            });
        }

        $data                                   = $broker;
        $required_file                          = view('companyAdmin.load.view.required_file', compact('data'))->render();
        return response()->json([
            'data'              => $broker,
            'office_html'       => $office_html,
            'contact_html'      => $contact_html,
            'department_html'   => $department_html,
            'email_html'        => $email_html,
            'phone_html'        => $phone_html,
            'rts_score'         => $rts_score,
            'accessorials_html' => $accessorials_html,
            'shipper_files'     => $shipper_files,
            'consignee_files'   => $consignee_files,
            'required_file'     => $required_file
        ]);
    }

    public function rtsCreditScoreSave(Request $request){
        $response['success']                        = false;
        $response['message']                        = "Oops! Something went wrong..";
        if($request->ajax()){
            $rts_score                              = [];
            $score_update                           = Carbon::now()->format('Y-m-d H:i:s');
            $rts_score['score_ratting']             = $request->ratting;
            $rts_score['score_credit']              = $request->credit_available;
            $rts_score['score_update']              = $score_update;
            $rts_score['convert_score_update']      = convertTimeToUSERzone([
                'str'       => $score_update,
                'toFormat'  => getTimeLayout(),
                'fromFormat'=> 'Y-m-d H:i:s']
            ).' '.$this->timeZoneId;
            $response['rts_score']                  = $rts_score;
            $response['success']                    = true;
            $response['message']                    = "Submit successfully.";
        }
        return response()->json($response);
    }

    public function requiredDocumentsUpdate(Request $request){
        $response['success']                        = false;
        $response['message']                        = "Oops! Something went wrong..";
        if($request->ajax()){
            $files_required                         = [];
            if($request->has('shipper_files')){
                $shipper_files                      = $request->shipper_files;
                $names                              = (isset($shipper_files['name']) && !empty($shipper_files['name']))?$shipper_files['name']:[];
                foreach ($names as $key => $name) {
                    $arry                           = [];
                    $arry['is_required']            = isset($shipper_files['is_required'][$key]) ? $shipper_files['is_required'][$key] : 'off';
                    $arry['name_id']                = isset($shipper_files['name_id'][$key]) ? $shipper_files['name_id'][$key] : '';
                    $arry['name']                   = $name;
                    $arry['type']                   = $shipper_files['type'][$key];
                    $arry['fixed']                  = $shipper_files['fixed'][$key];
                    $arry['include_w_billing']      = (isset($shipper_files['include_w_billing'][$key]) && $shipper_files['include_w_billing'][$key]=='yes') ? 'yes' : 'no';
                    $arry['custom']                 = (isset($shipper_files['custom'][$key]) && $shipper_files['custom'][$key]=='yes') ? 'yes' : 'no';
                    $files_required[]               = $arry;
                }
            }elseif($request->has('consignee_files')){
                $consignee_files                    = $request->consignee_files;
                $names                              = (isset($consignee_files['name']) && !empty($consignee_files['name']))?$consignee_files['name']:[];
                foreach ($names as $key => $name) {
                    $arry                           = [];
                    $arry['is_required']            = isset($consignee_files['is_required'][$key]) ? $consignee_files['is_required'][$key] : 'off';
                    $arry['name_id']                = isset($consignee_files['name_id'][$key]) ? $consignee_files['name_id'][$key] : '';
                    $arry['name']                   = $name;
                    $arry['type']                   = $consignee_files['type'][$key];
                    $arry['fixed']                  = $consignee_files['fixed'][$key];
                    $arry['include_w_billing']      = (isset($consignee_files['include_w_billing'][$key]) && $consignee_files['include_w_billing'][$key]=='yes') ? 'yes' : 'no';
                    $arry['custom']                 = (isset($consignee_files['custom'][$key]) && $consignee_files['custom'][$key]=='yes') ? 'yes' : 'no';
                    $files_required[]               = $arry;
                }
            }elseif($request->has('stop_files')) {
                $stop_files                         = $request->stop_files;
                foreach ($stop_files as $skey => $stop_file) {
                    $names                          = (isset($stop_file['name']) && !empty($stop_file['name']))?$stop_file['name']:[];
                    foreach ($names as $key => $name) {
                        $arry                       = [];
                        $arry['is_required']        = isset($stop_file['is_required'][$key]) ? $stop_file['is_required'][$key] : 'off';
                        $arry['name_id']            = isset($stop_file['name_id'][$key]) ? $stop_file['name_id'][$key] : '';
                        $arry['name']               = $name;
                        $arry['type']               = $stop_file['type'][$key];
                        $arry['fixed']              = $stop_file['fixed'][$key];
                        $arry['include_w_billing']  = (isset($stop_file['include_w_billing'][$key]) && $stop_file['include_w_billing'][$key]=='yes') ? 'yes' : 'no';
                        $arry['custom']             = (isset($stop_file['custom'][$key]) && $stop_file['custom'][$key]=='yes') ? 'yes' : 'no';
                        $files_required[]           = $arry;
                    }
                }
            }

            $files_required                         = array_filter($files_required, function ($var) {
                return ($var['is_required'] == 'on');
            });

            $response['files_required']             = $files_required;
            $response['success']                    = true;
            $response['message']                    = "Submit successfully.";
        }
        return response()->json($response);
    }

    public function getLoadRequiredFile(Request $request){
        $data           = LoadDetail::find($request->load_details_id);
        $required_file  = view('companyAdmin.load.view.required_file', compact('data'))->render();
        return response()->json(['required_file' => $required_file]);
    }

    public function getLoadShipperFilesUpload(Request $request){
        $data = LoadDetail::find($request->load_details_id);
        $data = view('companyAdmin.load.view.getLoadShipperFilesUpload', compact('data'))->render();
        return response()->json(['data' => $data]);
    }

    public function getLoadConsigneeFilesUpload(Request $request){
        $data = LoadDetail::find($request->load_details_id);
        $data = view('companyAdmin.load.view.getLoadConsigneeFilesUpload', compact('data'))->render();
        return response()->json(['data' => $data]);
    }

    /**
     * Fetch the specified trailer info from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function trailerInfo(Request $request){
        $data = Trailer::where('trailer_id', $request->trailer_id)->first();
        return response()->json(['data' => $data]);
    }

    /**
     * Show the form for split the load.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function split($id){
        dd('split', $id);
        $id                                                 = base64Decode($id);
        $load                                               = Load::findOrFail($id);
        $this->data['load']                                 = $load;
        $this->data['loadDetail']                           = $load->load_detail;
        $this->data['loadDrivers']                          = $load->load_detail->load_drivers;
        $this->data['stop_index']                           = count($load->load_stops);
        $this->data['totalPendingDetention']                = $load->load_detail->detentions()->whereNotIn('review_status', ['Completed','Denied'])->count();
        /* Fetch Load number base on 'desired_option' added by Dhaval Thakor - 23-12-2022 - Start */
        $carrierDetails                                     = DriverInformation::with('carrier')->where('driver_id', $this->data['loadDetail']['driver_id'])->first();

        if(isset($carrierDetails->carrier) && !is_null($carrierDetails->carrier)){
            if($carrierDetails->carrier->identifier != ""){
                $this->data['loadDetail']['identifier']     = $carrierDetails->carrier->identifier."-";

                if($carrierDetails->carrier->identifier.'-' == substr($this->data['loadDetail']['load_number'], 0, 4)){
                    $this->data['loadDetail']['load_number']= substr($this->data['loadDetail']['load_number'], 4);
                }
            }
        }
        /* Fetch Load number base on 'desired_option' added by Dhaval Thakor - 23-12-2022 - End */

        $this->data['load_requirement']                     = CompanyLoadRequirement::isCompany()->select('name')->get()->pluck('name')->toArray();

        $broker                                             = isset($load->load_detail->broker)?$load->load_detail->broker:null;
        $this->data['broker_shipper_files']                 = [];
        if(isset($broker->shipper_files) && !empty($broker->shipper_files)){
            $this->data['broker_shipper_files']             = unserialize($broker->shipper_files);
        }
        $this->data['broker_consignee_files']               = [];
        if(isset($broker->consignee_files) && !empty($broker->consignee_files)){
            $this->data['broker_consignee_files']           = unserialize($broker->consignee_files);
        }

        $contact_html                                       = '';
        if($broker){
            $getBrokerContact                               = BrokerContact::where('source', 'broker')->where('action_id', $broker->id)->get();
            if(!empty($broker->dispatch_contact_name)){
                $contact_html                              .= '<option value="'.$broker->dispatch_contact_name.'" data-phone="'.$broker->dispatch_contact_phone.'" data-ext="'.$broker->dispatch_contact_contact_ext.'" data-email="'.$broker->dispatch_contact_email.'">'.$broker->dispatch_contact_name.'</option>';
            }
            foreach($getBrokerContact as $cdata){
                $contact_html                              .= '<option value="'.$cdata->name.'" data-phone="'.$cdata->phone_number.'" data-ext="'.$cdata->ext.'" data-email="'.$cdata->email.'">'.$cdata->name.'</option>';
            }
        }
        $this->data['contact_html']                         = $contact_html;

        $this->data['getTimeZone']                          = $this->timeZone;
        $this->data['getTimeZoneId']                        = $this->timeZoneId;

        $this->data['getField']                             = '';
        $getCompanyAdmin                                    = auth()->guard('company-admin')->user();
        $isCheck                                            = Bookmark::where('company_id',getUserCompnayId())
            ->where('user_id',$getCompanyAdmin->id)
            ->where('user_type',$getCompanyAdmin->type)
            ->where('table_id','table_audit_load')->first();

        if(!empty($isCheck->id)){
            //$this->data['getField'] = unserialize($isCheck->config);
            $this->data['getField'] = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_audit_load_first'));
        }else{
            $this->data['getField']= config('settings.table_audit_load_first');
        }

        return view('companyAdmin.load.split', $this->data)->with('carrierDetails', $carrierDetails);
    }

    public function splitStore(SplitLoadStoreRequest $request, $id){
        dd('splitStore', $id);
        $input                                  = $request->all();

        $oldLoadDetail2                         = LoadDetail::where('load_id', $id)->latest()->first();

        $totalPayPercentage                     = array_sum(array_column($input['drivers'], 'pay_percentage'));
        $totalMileagePercentage                 = array_sum(array_column($input['drivers'], 'mileage_percentage'));

        if ($totalPayPercentage > 100 && $totalMileagePercentage > 100) {
            return redirect()->back()->with([
                'pay_percentage_error'          => 'Total pay % must be within 100%',
                'mileage_percentage_error'      => 'Total mileage % must be within 100%'
            ])->withInput();
        }

        if ($totalPayPercentage > 100) {
            return redirect()->back()->with(['pay_percentage_error' => 'Total pay % must be within 100%'])->withInput();
        }

        if ($totalMileagePercentage > 100) {
            return redirect()->back()->with(['mileage_percentage_error' => 'Total mileage % must be within 100%'])->withInput();
        }

        $load                                   = Load::find($id);
        $oldLoadDetail                          = LoadDetail::where('load_id', $id)->first();
        $loadDetail                             = Load::find($id)->load_detail;
        $driver                                 = Driver::find($input['driver_id']);

        if($request->is_revert == '1'){
            $load_detail_id                     = $loadDetail->id;
            $load_number                        = $loadDetail->load_number;

            $loadDetail->self_dispatch          = $input['self_dispatch'] ?? 0;
            $loadDetail->split_date             = !is_null($input['split_date']) ? Carbon::createFromFormat('m/d/Y',$input['split_date'])->format('Y-m-d H:i:s') : NULL;
            $loadDetail->actual_shipper_date    = !is_null($input['split_date']) ? Carbon::createFromFormat('m/d/Y',$input['split_date'])->format('Y-m-d H:i:s') : NULL;
            $loadDetail->load_number            = $oldLoadDetail->load_number.'-'.$load->load_all_details()->where('id', '!=', $loadDetail->id)->count();

            if (isset($input['self_dispatch'])) {
                $loadDetail->booked_by          = 0;
            } elseif (!isset($input['self_dispatch']) && !isset($input['booked_by'])) {
                $loadDetail->booked_by          = Driver::find($input['driver_id'])->manager_id;
            }
            $loadDetail->save();

            LoadDriver::where('load_id', $id)->where('load_detail_id', $load_detail_id)->forceDelete();

            Load::find($id)->update(['is_split' => (count($request->drivers) == 1) ? 0 : 1]);
        }else{
            // copy and create new load
            $newLoadDetail                      = $loadDetail->replicate();
            $newLoadDetail->driver_id           = $input['driver_id'];
            $newLoadDetail->self_dispatch       = $input['self_dispatch'] ?? 0;
            $newLoadDetail->split_date          = !is_null($input['split_date']) ? Carbon::createFromFormat('m/d/Y',$input['split_date'])->format('Y-m-d H:i:s') : NULL;
            $newLoadDetail->actual_shipper_date = !is_null($input['split_date']) ? Carbon::createFromFormat('m/d/Y',$input['split_date'])->format('Y-m-d H:i:s') : NULL;
            $newLoadDetail->load_number         = $oldLoadDetail->load_number.'-'.$load->load_all_details()->count();
            $newLoadDetail->truck_number        = $driver->driver_information->truck_number;
            if (isset($input['self_dispatch'])) {
                $newLoadDetail->booked_by       = 0;
            } elseif (!isset($input['self_dispatch']) && !isset($input['booked_by'])) {
                $newLoadDetail->booked_by       = Driver::find($input['driver_id'])->manager_id;
            }
            $newLoadDetail->save();
            // create drivers with calculation

            $load_detail_id                     = $newLoadDetail->id;
            $load_number                        = $newLoadDetail->load_number;

            $loadDetail->update([
                'is_disable'                    => 1,
                'actual_delivery_date'          => Carbon::createFromFormat('m/d/Y',$input['split_date'])->format('Y-m-d H:i:s')
            ]);

            Load::find($id)->update([
                'load_detail_id'                => $load_detail_id,
                'is_split'                      => 1
            ]);

            LoadAccessorial::where('load_id', $id)->where('load_detail_id', $loadDetail->id)->update(['load_detail_id' =>  $load_detail_id]);
        }

        foreach ($request->drivers as $key => $driverarray) {
            $loadDriverDe                       = LoadDriver::where('load_detail_id', $oldLoadDetail2->id)->where('driver_id', $driverarray['driver_id'])->first();

            $loadDrivers                        = [];
            $loadDrivers['load_id']             = $id;
            $loadDrivers['load_detail_id']      = $load_detail_id;
            $loadDrivers['driver_id']           = $driverarray['driver_id'];
            $loadDrivers['pay_percentage']      = $driverarray['pay_percentage'];
            $loadDrivers['mileage_percentage']  = $driverarray['mileage_percentage'];
            $loadDrivers['pay']                 = $loadDetail->total_bill * $driverarray['pay_percentage'] / 100;
            $loadDrivers['miles']               = $loadDetail->total_miles * $driverarray['mileage_percentage'] / 100;

            $loadDrivers['total_miles']         = $loadDrivers['miles'];
            $loadDrivers['loaded_miles']        = $loadDrivers['miles'];
            $loadDrivers['gross_wage']          = $loadDrivers['pay'];
            $loadDrivers['total_bill']          = $loadDrivers['pay'];

            $loadDrivers['unload_pay']          = isset($loadDriverDe->unload_pay)? $loadDriverDe->unload_pay : 0;
            $loadDrivers['tarp_pay']            = isset($loadDriverDe->tarp_pay)? $loadDriverDe->tarp_pay : 0;
            $loadDrivers['deductions']          = isset($loadDriverDe->deductions)? $loadDriverDe->deductions : 0;
            $loadDrivers['detention']           = isset($loadDriverDe->detention)? $loadDriverDe->detention : 0;
            $loadDrivers['accessorial']         = isset($loadDriverDe->accessorial)? $loadDriverDe->accessorial : 0;


            $loadDrivers['empty_miles']         = 0;
            $loadDrivers['pay_type']            = 0;

            LoadDriver::create($loadDrivers);
        }

        // send load assign mail
        if (isset($input['send_notification'])) {
            $driver                     = Driver::find($input['driver_id']);
            $mailData                   = [];
            $mailData['company_id']     = auth()->guard('company-admin')->user()->company_id;
            $mailData['name']           = isset($driver->full_name) ? $driver->full_name : '';
            $mailData['load_number']    = $load_number;
            //Mail::to($driver->email)->send(new LoadAssignMailToDriver($mailData));
            sendEmail($driver->email, new LoadAssignMailToDriver($mailData));
        }

        notification('success', 'Split Load successfully');
        return redirect()->route('company.admin.loads.index');
    }

    /**
     * Check driver location.
     *
     * @return \Illuminate\Http\Response
     */
    public function checkDriverLocation(Request $request){
        $addressData    = $this->getAddressData($request->address);
        if (!empty($addressData)) {
            $data       = json_decode($addressData, true);
            if ($data["status"] == "OK") {
                if (count($data["results"]["0"]["address_components"]) == 8) {
                    $stateName = $data["results"]["0"]["address_components"]["5"]["long_name"];
                    $stateCode = $data["results"]["0"]["address_components"]["5"]["short_name"];
                } elseif (count($data["results"]["0"]["address_components"]) == 7) {
                    $stateName = $data["results"]["0"]["address_components"]["4"]["long_name"];
                    $stateCode = $data["results"]["0"]["address_components"]["4"]["short_name"];
                } elseif (count($data["results"]["0"]["address_components"]) == 6) {
                    $stateName = $data["results"]["0"]["address_components"]["3"]["long_name"];
                    $stateCode = $data["results"]["0"]["address_components"]["3"]["short_name"];
                } elseif (count($data["results"]["0"]["address_components"]) == 5) {
                    $stateName = $data["results"]["0"]["address_components"]["3"]["long_name"];
                    $stateCode = $data["results"]["0"]["address_components"]["3"]["short_name"];
                } elseif (count($data["results"]["0"]["address_components"]) == 4) {
                    $stateName = $data["results"]["0"]["address_components"]["2"]["long_name"];
                    $stateCode = $data["results"]["0"]["address_components"]["2"]["short_name"];
                } elseif (count($data["results"]["0"]["address_components"]) == 3) {
                    $stateName = $data["results"]["0"]["address_components"]["0"]["long_name"];
                    $stateCode = $data["results"]["0"]["address_components"]["0"]["short_name"];
                } elseif (count($data["results"]["0"]["address_components"]) == 2) {
                    $stateName = $data["results"]["0"]["address_components"]["0"]["long_name"];
                    $stateCode = $data["results"]["0"]["address_components"]["0"]["short_name"];
                }

                $state                  = State::where('name',$stateName)->first();
                $driverAvoidState       = DriverAvoidState::where('driver_id',$request->driver_id)->where('state_id',$state->id)->first();
                $driverRestrictedState  = DriverRestrictedState::where('driver_id',$request->driver_id)->where('state_id',$state->id)->first();
                if (!is_null($driverAvoidState)) {
                    return response()->json(['error' => 'The '.$request->location_type.' location state is added in States to avoid!']);
                } elseif (!is_null($driverRestrictedState)) {
                    return response()->json(['error' => 'The '.$request->location_type.' location state is added in Restricted States!']);
                }
                return response()->json(['success' => 'success']);
            }
        }
    }

    // Please check driver current dispatch query - Current Dispatch
    public function checkCurrentDispatch(Request $request){
        $response['success']                = false;
        $response['message']                = "Oops! Something went wrong..";
        if ($request->ajax()) {
            try {
                // Current Dispatch retrieved
                $current_dispatch           = LoadDetail::query();
                if($request->has('load_id') && $request->load_id!=''){
                    $current_dispatch->where('load_details.load_id', '!=', $request->load_id);
                }
                $current_dispatch->where('load_details.driver_id', $request->driver_id);
                $current_dispatch->where( function($query) {
                    $query->whereIn('load_details.load_status', [4]) // 4 = In Transit
                        ->where('load_details.load_type', 0) // 0 = OCCUPIED
                        ->where('load_details.dispatched', 1) // 1 = Dispatched
                        ->whereNotNull('load_details.dispatched_date_time') // Dispatched date time
                        ->where('load_details.is_disable', 0)
                        ->where(function($q) {
                            $q->whereNull('load_details.is_on_hold')->orWhereIn('load_details.is_on_hold', [0, 1]);
                        });
                });
                $current_dispatch->orderBy('load_details.load_status')->orderBy('load_details.actual_shipper_date');
                $load_detail                = $current_dispatch->first();
                if(!is_null($load_detail)){
                    $response['load_number']= $load_detail->load_number;
                }
                $response['success']        = true;
                $response['success']        = "Detail retrieved successfully.";
            } catch (\Exception $e) {
                $response['success']        = false;
                $response['message']        = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    /**
     * Check load overlapping.
     *
     * @return \Illuminate\Http\Response
     */
    public function checkLoadOverlap(Request $request){
        $input                  = $request->all();
        $deliveryDate           = Carbon::parse($input['delivery_date'])->format('Y-m-d');
        $deliveryEndDate        = Carbon::parse($input['delivery_end_date'])->format('Y-m-d');
        if (!is_null($input['driver_id']) && !is_null($input['delivery_date'])) {
            $loadDetail         = null;
            if (!is_null($input['delivery_date']) && !is_null($input['delivery_end_date'])) {
                $loadDetail     = LoadDetail::where('driver_id', $input['driver_id'])->where('is_disable',0);
                if (isset($input['load_id'])) {
                    $loadDetail = $loadDetail->where('load_id','!=',$input['load_id']);
                }
                $loadDetail     = $loadDetail->where(function ($query) use ($deliveryDate,$deliveryEndDate) {
                        $query->where(DB::raw('DATE_FORMAT(actual_shipper_date, "%Y-%m-%d")'), '<=', $deliveryDate)
                            ->where(DB::raw('DATE_FORMAT(actual_delivery_date, "%Y-%m-%d")'), '>=', $deliveryEndDate)
                            ->orWhere(DB::raw('DATE_FORMAT(actual_delivery_date, "%Y-%m-%d")'), $deliveryDate);
                    })
                    ->whereHas('loads', function($q){
                        $q->where('company_id', auth()->guard('company-admin')->user()->company_id);
                    })
                    ->first();
            } elseif (!is_null($input['delivery_date'])) {
                $loadDetail     = LoadDetail::where('driver_id', $input['driver_id'])->whereNotIn('load_status', [6,7,8,9])->where('is_disable',0);
                if (isset($input['load_id'])) {
                    $loadDetail = $loadDetail->where('load_id','!=',$input['load_id']);
                }
                $loadDetail     = $loadDetail->where(function ($query) use ($deliveryDate) {
                        $query->where(DB::raw('DATE_FORMAT(actual_shipper_date, "%Y-%m-%d")'), '<=', $deliveryDate)
                            ->where(DB::raw('DATE_FORMAT(actual_delivery_date, "%Y-%m-%d")'), '>=', $deliveryDate)
                            ->orWhere(DB::raw('DATE_FORMAT(actual_delivery_date, "%Y-%m-%d")'), $deliveryDate);
                    })->whereHas('loads', function($q){
                        $q->where('company_id', auth()->guard('company-admin')->user()->company_id);
                    })
                    ->first();
            }
            if (!is_null($loadDetail)) {
                return response()->json([
                    'driver_name'   => $loadDetail->driver->full_name,
                    'load_number'   => $loadDetail->load_number,
                    'error'         => 'There is already load assigned on this date to driver!'
                ]);
            }
        }
        return response()->json(['success' => 'success']);
    }

    /**
     * Check Customer Review
     *
     * @return \Illuminate\Http\Response
     */
    public function checkCustomerReview(Request $request){
        $response['success']                        = false;
        $response['message']                        = "Oops! Something went wrong..";
        if ($request->ajax()) {
            try {
                // Check record exists or not
                $whereArray                         = [
                    'customer_id'                   => $request->customer_id,
                    'is_stop'                       => $request->is_stop
                ];
                if ($request->has('is_stop') && $request->is_stop == 1) {
                    $whereArray['load_stop_id']     = $request->load_stop_id;
                }else{
                    $whereArray['load_detail_id']   = $request->load_detail_id;
                    $whereArray['type']             = $request->type;
                }
                $query                              = LoadStopReview::query();
                foreach ($whereArray as $key => $value) {
                    $query->where($key, $value);
                }
                $review                             = $query->first();
                if(!is_null($review)){
                    $response['review']             = $review;
                    $response['success']            = true;
                    $response['message']            = "Detail retrieved successfully.";
                }else{
                    $response['success']            = false;
                    $response['message']            = "Detail retrieved unsuccessfully.";
                }
            } catch (\Exception $e) {
                $response['success']                = false;
                $response['message']                = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function reviewDelete(Request $request){
        $response['success']                        = false;
        $response['message']                        = "Oops! Something went wrong..";
        if($request->ajax()){
            $review                                 = LoadStopReview::where('id', $request->id)->first();
            if(!is_null($review)){
                $oldData                            = $review->toArray();

                $review->deleted_by                 = auth()->guard('company-admin')->user()->id;
                $review->deleted_by_type            = auth()->guard('company-admin')->user()->type;
                if($review->save()){
                    if($review->delete()){
                        // $this->setLoadAudit($request->load_id, 'delete', 'Load stop review deleted', $review->toArray(), $oldData);

                        $response['success']            = true;
                        $response['message']            = "Review delete successfully.";
                    }
                }
            }
        }
        return response()->json($response);
    }

    /**
     * Get Address detail.
     *
     * @return \Illuminate\Http\Response
     */
    public function getAddressData($address){
        $address    = urlencode($address);
        $data       = "https://maps.googleapis.com/maps/api/geocode/json?address=" .$address . "&key=" . env("GOOGLE_MAPS_KEY");
        return file_get_contents($data, true);
    }

    /**
     * Get Address data.
     *
     * @return \Illuminate\Http\Response
     */
    public function addressInfo(Request $request){
        $addressData    = $this->getAddressData($request->address);
        info(["addressData",$addressData]);
        $details        = [];
        $originalArray  = [];
        if (!empty($addressData)) {
            $data       = json_decode($addressData, true);
            info(["data",$data]);
            if ($data["status"] == "OK") {
                for($j = 0 ; $j < count($data['results'][0]['address_components']) ; $j++) {
                    $details[$data['results'][0]['address_components'][$j]['types'][0]] = $data['results'][0]['address_components'][$j]['short_name'];
                }
                if (isset($details['street_number']) && isset($details['route'])) {
                    $originalArray['address_1'] = $details['street_number'].' '.$details['route'];
                }
                if (isset($details['street_number']) && !isset($details['route'])) {
                    $originalArray['address_1'] = $details['street_number'];
                }
                if (!isset($details['street_number']) && isset($details['route'])) {
                    $originalArray['address_1'] = $details['route'];
                }
                if (isset($details['establishment'])) {
                    $originalArray['address_2'] = $details['establishment'];
                }
                if (isset($details['administrative_area_level_1'])) {
                    $originalArray['state'] = $details['administrative_area_level_1'];
                }
                if (isset($details['locality'])) {
                    $originalArray['city'] = $details['locality'];
                }
                if (isset($details['postal_code'])) {
                    $originalArray['zip'] = $details['postal_code'];
                }
                info($originalArray);
                return response()->json(['data' => $originalArray]);
            }
        }
    }

    /**
     * Show the page for load by week.
     *
     * @return \Illuminate\Http\Response
     */
    public function loadByWeek(Request $request){
        $weeklyDay      = 0;
        if(!is_null($request->day)){
            $weeklyDay  = $request->day;
        }else{
            $weeklyDay  = auth()->guard('company-admin')->user()->weekly_strat_day;
        }
        $now            = Carbon::now()->timezone($this->timeZone);
        $year           = $now->startOfWeek($weeklyDay)->format('Y');
        $startDate      = $now->startOfWeek($weeklyDay)->format('Y-m-d');
        $endDate        = Carbon::parse($startDate)->addDays(6)->format('Y-m-d');

        return view('companyAdmin.load.loadByWeek', compact('startDate','endDate','weeklyDay','year'));
    }

    /**
     * Fetch view for load by week.
     *
     * @return \Illuminate\Http\Response
     */
    public function loadByWeekView(Request $request){
        $trailer_type           = null;
        $dispatcher             = null;

        $teamIds                = (isset($request->team_id)) ? $request->team_id : array();
        $dispatcherIds          = (isset($request->dispatcher)) ? $request->dispatcher : array();
        $equipmentIds           = (isset($request->equipment)) ? $request->equipment : array();
        $carrierIds             = (isset($request->carrier)) ? $request->carrier : array();

        if ($request->week == 'current') {
            $startDate          = Carbon::parse($request->start_date)->format('Y-m-d');
            $endDate            = Carbon::parse($request->end_date)->format('Y-m-d');
        } elseif ($request->week == 'next') {
            $startDate          = Carbon::parse($request->start_date)->addWeek()->format('Y-m-d');
            $endDate            = Carbon::parse($request->end_date)->addWeek()->format('Y-m-d');
        } elseif ($request->week == 'previous') {
            $startDate          = Carbon::parse($request->start_date)->subWeek()->format('Y-m-d');
            $endDate            = Carbon::parse($request->end_date)->subWeek()->format('Y-m-d');
        }

        $get_quarter            = Carbon::parse($endDate)->quarter;
        $get_year               = Carbon::parse($endDate)->year;

        $loads                  =  Driver::select(
                "drivers.id as driverid",
                "drivers.company_id as driver_company_id",
                "drivers.first_name",
                "drivers.last_name",
                "drivers.middle_name",
                "driver_financials.revenue_target as wgrr_seasonal",
                "driver_financials.occupancy as occupancy_commitment",
                "load_drivers.load_detail_id",
                "drivers.id as driver_id",
                "drivers.status",
                "drivers.termination_date")
            ->join("driver_informations","drivers.id","=","driver_informations.driver_id")
            ->leftjoin("load_drivers","drivers.id","=","load_drivers.driver_id")
            ->leftjoin("driver_financials","drivers.id","=","driver_financials.driver_id")
            ->where('drivers.company_id', auth()->guard('company-admin')->user()->company_id)
            ->where(function ($query) use ($startDate){
                $query->where('drivers.status', '!=', '2')->orWhere(function ($que) use ($startDate){
                    $que->where('drivers.status', '2')->where(DB::raw('DATE_FORMAT(drivers.termination_date, "%Y-%m-%d")'), '>=', $startDate);
                });
            })
            ->groupBy('drivers.id');

        if (count($teamIds) > 0) {
            $loads              = $loads->leftjoin("teams","drivers.team_id","=","teams.id")->whereIn('teams.id', $teamIds);
        }

        if (count($dispatcherIds) > 0) {
            $loads              = $loads->whereIn('drivers.manager_id', $dispatcherIds);
        }

        if (count($equipmentIds) > 0) {
            $loads              = $loads->leftjoin("load_details","drivers.id","=","load_details.driver_id");
            $loads              = $loads->where(function ($query) use ($startDate, $endDate) {
                $query->where(DB::raw('DATE_FORMAT(actual_shipper_date, "%Y-%m-%d")'), '<' ,$endDate)
                      ->where(DB::raw('DATE_FORMAT(actual_delivery_date, "%Y-%m-%d")'), '>=' ,$startDate);
            });
            $loads              = $loads->whereIn('load_details.trailer_type', $equipmentIds);
            $trailer_type       = $equipmentIds;
        }

        if (count($carrierIds) > 0) {
            $loads              = $loads->whereIn('driver_informations.carrier_id', $carrierIds);
        }

        if (!is_null($request->search_name)) {
            //$loads              = $loads->where('drivers.first_name','LIKE','%'.$request->search_name."%");
            //$loads              = $loads->orWhere('drivers.last_name','LIKE','%'.$request->search_name."%");

            $loads = $loads->where(function ($query) use ($request) {
                $query->where('drivers.first_name','LIKE','%'.$request->search_name."%")
                    ->orWhere('drivers.last_name','LIKE','%'.$request->search_name."%");
            });
        }

        $skip                   = $request->skip;
        if (!is_null($skip)) {
            $loads              = $loads->skip($skip);
        }
        if (!is_null($request->take)) {
            $loads              = $loads->take($request->take);
        }

        $loads                  = $loads->get();

        // show own drivers
        // $loads                  = $loads->filter(function ($value, $key) {
        //     return $value->driver_company_id == auth()->guard('company-admin')->user()->company_id;
        // });

        $load_count             = $loads->count();

        $view                   = view('companyAdmin.load.view.loadByWeekView', compact('loads','startDate','endDate','trailer_type','dispatcher','skip','load_count'))->render();

        $year                   = Carbon::parse($endDate)->year;
        $week                   = Carbon::parse($endDate)->weekOfYear;
        return response()->json(['view' => $view, 'start_date' => $startDate, 'end_date' => $endDate, 'year' => $year, 'week' => sprintf("%02d", $week), 'weekEndingDate' => \Carbon\Carbon::parse($endDate)->format('m/d/Y')]);
    }

    public function loadByWeekSave(Request $request){
        $response['success']                                = false;
        $response['message']                                = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $formdata                                   = $request->all();

                /**** This Code use for Top header Load Create popup replace attribute - START ****/
                if(isset($formdata['create_load_driver_id'])){
                    $formdata['driver_id'] = $formdata['create_load_driver_id'];
                    unset($formdata['create_load_driver_id']);
                }
                if(isset($formdata['create_load_booked_by'])){
                    $formdata['booked_by'] = $formdata['create_load_booked_by'];
                    unset($formdata['create_load_booked_by']);
                }
                if(isset($formdata['create_load_load_type'])){
                    $formdata['load_type'] = $formdata['create_load_load_type'];
                    unset($formdata['create_load_load_type']);
                }
                /**** This Code use for Top header Load Create popup replace attribute - END ****/

                $setting                                    = auth()->guard('company-admin')->user()->getCompany;
                $company_id                                 = auth()->guard('company-admin')->user()->company_id;
                $driver_id                                  = $formdata['driver_id'];

                $driver                                     = Driver::find($driver_id);
                if(!is_null($driver)){
                    $truck                                  = $driver->driver_information->truck ?? null;
                    if(!is_null($truck)){
                        $owner_id                           = $truck->owner_id ?? null;
                        $owner_type                         = $truck->owner_type ?? null;
                    }
                }
                $load_detail                                = LoadDetail::whereNotNull('trailer_number')
                    ->where('driver_id',$driver->id)
                    ->latest()
                    ->first();
                if(isset($load_detail->trailer_number) && $load_detail->trailer_number!=''){
                    $trailer_number                         = $load_detail->trailer_number;
                }else{
                    $trailer_number                         = $driver->driver_information->trailer_number ?? null;
                }

                $trailer                                    = Trailer::where('trailer_id', $trailer_number)->first();

                $load_number                                = null;
                $carrier_id                                 = $driver->driver_information->carrier_id ?? null;
                if(!is_null($carrier_id)){
                    $carrier                                = Carrier::find($carrier_id);
                    if(!is_null($carrier)){
                        if($carrier->desired_option == "0"){
                            $desired_load_number            = $carrier->desired_load_number + 1;
                            $carrier->desired_load_number   = $desired_load_number;
                            $carrier->save();
                            if(!is_null($carrier->identifier)){
                                $load_number                = $carrier->identifier."-".$desired_load_number;
                            }else{
                                $load_number                = $desired_load_number;
                            }
                        }
                    }
                }

                $array                                      = [];
                $array['company_id']                        = $company_id;
                $array['submitted_by']                      = auth()->guard('company-admin')->user()->id;
                $array['booked_by']                         = $formdata['booked_by'];
                if($formdata['booked_by']==0){
                    $array['self_dispatch']                 = 1;
                }

                $array['load_number']                       = $load_number;
                $array['load_type']                         = $formdata['load_type'];
                $array['load_status']                       = 8;
                // NEW CODE TO STORE STATUS SORT ORDER - START
                $array['load_status_order']                 = Common::getLoadStatusOrderById( $array['load_status'] );

                $array['notes']                             = $formdata['notes'];

                $array['driver_id']                         = $driver->id;
                $array['truck_number']                      = $driver->driver_information->truck_number ?? null;
                $array['trucking_company']                  = $driver->company->name ?? null;
                $array['trailer_number']                    = $trailer_number;
                $array['trailer_type']                      = $trailer->type ?? null;
                $array['carrier_id']                        = $carrier_id;
                $array['terminal_id']                       = $driver->driver_information->terminal_id ?? null;

                $driver_oos_pending                         = 0;
                $equipment_oos_pending                      = 0;
                $array['oos_pending']                       = 0;
                if($setting->oos_driver == 3){
                    if(isset($array['driver_id']) && checkOosDriver($array['driver_id'])){
                        $driver_oos_pending                 = 1;
                        $array['oos_pending']               = 1;
                    }
                }
                if($setting->oos_equipment == 3){
                    if(isset($array['trailer_number']) && checkOosTrailer($array['trailer_number'])){
                        $equipment_oos_pending              = 1;
                        $array['oos_pending']               = 1;
                    }
                    if(isset($array['truck_number']) && checkOosTruck($array['truck_number'])){
                        $equipment_oos_pending              = 1;
                        $array['oos_pending']               = 1;
                    }
                }

                $timeFormat                                 = getTimeFormat();

                // 1 = MAINTENANCE, 2 = UNAUTHORIZED, 3 = HOS, 4 = NO DISPATCH, 5 = TIME OFF
                $array['start_date']                        = date('Y-m-d', strtotime($formdata['start_date']));
                $array['end_date']                          = date('Y-m-d', strtotime($formdata['end_date']));

                $array['shipping_time_range']               = 0;
                $array['shipper_date_time']                 = Carbon::parse(date('Y-m-d', strtotime($formdata['start_date'])))->format(getTimeLayout());
                $array['shipper_date_time_end']             = null;
                $array['actual_shipper_date']               = Carbon::parse(date('Y-m-d', strtotime($formdata['start_date'])))->format('Y-m-d H:i:s');

                $array['delivery_time_range']               = 0;
                $array['delivery_date_time']                = Carbon::parse(date('Y-m-d h:i A', strtotime($formdata['end_date'].' 12:00 PM')))->format(getTimeLayout());
                $array['delivery_date_time_end']            = null;
                $array['actual_delivery_date']              = Carbon::parse(date('Y-m-d h:i A', strtotime($formdata['end_date'].' 12:00 PM')))->format('Y-m-d H:i:s');

                $array['default_current_time']              = Carbon::now()->format(getTimeLayout());

                $array['preplaned_driver_acknowledgement']  = 0;
                $array['confirmed_driver_acknowledgement']  = 0;
                $array['intransit_driver_acknowledgement']  = 0;

                $array['intransit_date_time']               = $array['shipper_date_time'];
                $array['intransit_shipping_information']    = 0;

                $array['delivered_date_time']               = $array['delivery_date_time'];
                $array['delivered_delivery_information']    = 0;

                $array['is_on_hold']                        = 0;

                $array['load_trip_id']                      = null;

                $tmsLoadDetail                              = new LoadDetail();
                $array['load_tms_trip_id']                  = $tmsLoadDetail->nextTmsTripId();

                $array['map_toll_roads']                    = '2';
                $array['map_max_elevation']                 = null;
                $array['map_close_borders']                 = '1';
                $load                                       = Load::create([
                    'company_id' => $company_id
                ]);
                if($load){
                    if($driver_oos_pending==1 || $equipment_oos_pending==1){
                        if(!empty(getManagerList())){
                            foreach(getManagerList() as $key => $manager){
                                if($driver_oos_pending==1){
                                    $description            = 'Load created with OOS Driver - '.$load->id;
                                    createNotification(
                                        15, // source
                                        'OOS Driver', // name
                                        $key, // user_id
                                        1, // user_type
                                        1, // type
                                        $load->id, // action_id
                                        $description // description
                                    );
                                }
                                if($equipment_oos_pending==1){
                                    $description            = 'Load created with OOS Equipment - '.$load->id;
                                    createNotification(
                                        15, // source
                                        'OOS Equipment', // name
                                        $key, // user_id
                                        1, // user_type
                                        1, // type
                                        $load->id, // action_id
                                        $description // description
                                    );
                                }
                            }
                        }
                    }

                    $array['load_id']                       = $load->id;
                    $array['created_at']                    = Carbon::now()->format('Y-m-d H:i:s');
                    // Add New Load Detail
                    $loadDetail                             = LoadDetail::create($array);
                    if($loadDetail){
                        createLoadLog($loadDetail->getChanges(), $loadDetail, 'create');

                        // update load
                        $load->update(['load_detail_id' => $loadDetail->id]);

                        $loadDriver                         = LoadDriver::create([
                            'load_id'                       => $load->id,
                            'load_detail_id'                => $loadDetail->id,
                            'driver_id'                     => $loadDetail->driver_id,
                            'pay_percentage'                => 100,
                            'mileage_percentage'            => 100
                        ]);

                        $loadtruckowner                     = LoadTruckOwner::create([
                            'load_id'                       => $load->id,
                            'load_detail_id'                => $loadDetail->id,
                            'driver_id'                     => $loadDetail->driver_id,
                            'owner_id'                      => $owner_id ?? null,
                            'owner_type'                    => $owner_type ?? null,
                            'pay_percentage'                => 100,
                            'mileage_percentage'            => 100
                        ]);

                        if(isset($loadDetail->driver_id) && $loadDetail->driver_id!='0'){
                            //Update 'trailer_number' in 'driver_informations' table base on latest created load
                            DriverInformation::where('driver_id', $loadDetail->driver_id)
                                ->update(['trailer_number' => $loadDetail->trailer_number]);

                            isReportDriversZero($loadDetail->driver_id);
                        }

                        $response['success']                = true;
                        $response['message']                = "Load create successfully.";
                    }
                }
            }catch (\Exception $e) {
                $response['success']                        = false;
                $response['message']                        = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function getWeekList(Request $request){
        $year           = $request->year;
        $weeklyDay      = $request->weeklyDay;
        $view           = view('companyAdmin.load.view.getWeekList', compact('year','weeklyDay'))->render();
        return response()->json(['view' => $view]);
    }

    public function addStop(Request $request){
        $formData       = $request->all();
        $view           = view('companyAdmin.load.view.addStop', compact('formData'))->render();
        return response()->json(['view' => $view]);
    }

    public function removeStop(Request $request){
        $response['success']                        = false;
        $response['message']                        = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $item                               = LoadStop::where('id',$request->id)->first();
                if(!is_null($item)){
                    $oldData                        = $item->toArray();
                    if($item->delete()){
                        $this->setLoadAudit($item->load_id, 'delete', 'Load stop deleted', $item->toArray(), $oldData);
                        $response['success']        = true;
                        $response['message']        = "Stop remove successfully.";
                    }else{
                        $response['success']        = false;
                        $response['message']        = "Stop remove unsuccessfully.";
                    }
                }
            }catch (\Exception $e) {
                $response['success']                = false;
                $response['message']                = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function detentionRequest(Request $request){
        $response['success']                = false;
        $response['message']                = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $response['html']           = $this->getDetentionView($request);
                $response['success']        = true;
                $response['message']        = "Detention view retrieved successfully.";
            }catch (\Exception $e) {
                $response['success']        = false;
                $response['message']        = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function getDetentionView($request){
        $formData                           = $request->all();

        $detention                          = null;
        if($request->has('detention_id') && $request->detention_id!=''){
            $detention                      = LoadDetention::whereId($request->detention_id)->first();
            $driver_id                      = $detention->driver_id;
            $broker_id                      = $detention->broker_id;
        }else{
            $driver_id                      = $formData['driver_id'];
            $broker_id                      = $formData['broker_id'];
        }

        $gpsLocation                        = null;
        $driver                             = Driver::whereId($driver_id)->first();
        if(!is_null($driver)){
            $samsara_id                     = (isset($driver->samsara_id) && $driver->samsara_id!='')?$driver->samsara_id:'';//4644765
            if($samsara_id!=''){
                $carrierId = (isset($driver->driver_information->carrier_id)) ? $driver->driver_information->carrier_id : null;
                $getAPIKey                  = IntegrationSetting::where('company_id', $driver->company_id)->where('carrier_id', $carrierId)->where('app_center_id', config('settings.app_id.samsara'))->where('sync_drivers', '1')->first();
                if(isset($getAPIKey->api_key) && !empty($getAPIKey->api_key)){
                    $client                                 = new \GuzzleHttp\Client();
                    $api_url                                = 'https://api.samsara.com/fleet/hos/clocks?driverIds='.$samsara_id;
                    $api_response                           = $client->request('GET', $api_url, [
                        'headers'                           => [
                            'Accept'                        => 'application/json',
                            'Authorization'                 => 'Bearer '.$getAPIKey->api_key,
                        ],
                    ]);
                    $api_data                               = json_decode($api_response->getBody());
                    if(!empty($api_data)){
                        $appData                            = $api_data->data[0];
                        if(!empty($appData)){
                            $vehicleIds                     = (isset($appData->currentVehicle->id) && $appData->currentVehicle->id!='')?$appData->currentVehicle->id:'';
                            if($vehicleIds!=''){
                                $api_url                    = 'https://api.samsara.com/fleet/vehicles/locations?vehicleIds='.$vehicleIds;
                                $api_response               = $client->request('GET', $api_url, [
                                    'headers'               => [
                                        'Accept'            => 'application/json',
                                        'Authorization'     => 'Bearer '.$getAPIKey->api_key,
                                    ],
                                ]);
                                $api_data                   = json_decode($api_response->getBody());
                                if(!empty($api_data)){
                                    $appData                = $api_data->data[0];
                                    if(!empty($appData) && (isset($appData->location->reverseGeo->formattedLocation) && $appData->location->reverseGeo->formattedLocation!='')){
                                        $gpsLocation        = $appData->location->reverseGeo->formattedLocation;
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
        $broker                             = Broker::whereId($broker_id)->first();

        $getGeoTimeZone                     = getGeoTimeZone();

        $html                               = view('companyAdmin.load.ajax.detentionRequest', compact('formData','detention','driver','gpsLocation','broker','getGeoTimeZone'))->render();
        return $html;
    }

    public function detentionSave(Request $request){
        $response['success']                                                = false;
        $response['message']                                                = "Oops! Something went wrong..";
        if($request->ajax()){
            if($request->has('detention_id') && $request->detention_id!==''){
                $item                                                       = LoadDetention::where('id',$request->detention_id)->first();
                if(!is_null($item)){
                    $oldData                                                = $item->toArray();

                    $item->load_detail_id                                   = $request->load_detail_id;
                    $item->driver_id                                        = $request->driver_id;
                    $item->broker_id                                        = $request->broker_id;
                    if($request->has('load_stop_id') && $request->load_stop_id!==''){
                        $item->load_stop_id                                 = $request->load_stop_id;
                    }
                    $item->type                                             = $request->type;
                    $item->is_stop                                          = $request->is_stop;

                    $item->detention_status                                 = $request->detention_status;

                    $item->detention_arrival_time                           = ($request->detention_arrival_time)?convertTimeToUTCzone(['str' => $request->detention_arrival_time, 'toFormat'=> 'Y-m-d H:i:s', 'fromFormat' => getTimeLayout(), 'userTimezone' => $request->timezone]):null;
                    $item->detention_start_time                             = ($request->detention_start_time)?convertTimeToUTCzone(['str' => $request->detention_start_time, 'toFormat'=> 'Y-m-d H:i:s', 'fromFormat' => getTimeLayout(), 'userTimezone' => $request->timezone]):null;
                    $item->detention_end_time                               = ($request->detention_end_time)?convertTimeToUTCzone(['str' => $request->detention_end_time, 'toFormat'=> 'Y-m-d H:i:s', 'fromFormat' => getTimeLayout(), 'userTimezone' => $request->timezone]):null;

                    $item->free_time                                        = isset($request->free_time)?$request->free_time:null;
                    $item->billed_time                                      = isset($request->billed_time)?$request->billed_time:null;
                    $item->rate                                             = isset($request->rate)?$request->rate:null;
                    $item->detention_due                                    = isset($request->detention_due)?$request->detention_due:null;

                    if(($request->has('is_adjusted_billed_time') && $request->is_adjusted_billed_time=='1') || ($request->has('is_adjusted_rate') && $request->is_adjusted_rate=='1')){
                        $item->adjusted_billed_time                         = null;
                        $item->adjusted_rate                                = null;
                        $item->adjusted_detention_due                       = null;
                    }else{
                        $item->adjusted_billed_time                         = $request->adjusted_billed_time;
                        $item->adjusted_rate                                = $request->adjusted_rate;
                        $item->adjusted_detention_due                       = $request->adjusted_detention_due;
                    }

                    if(isset($request->driver_comment_show_to_broker) && $request->driver_comment_show_to_broker==1)
                        $item->driver_comment_show_to_broker                = 1;
                    $item->driver_comment                                   = isset($request->driver_comment)?$request->driver_comment:null;
                    if(isset($request->reviewer_comment_show_to_broker) && $request->reviewer_comment_show_to_broker==1)
                        $item->reviewer_comment_show_to_broker              = 1;
                    $item->reviewer_comment                                 = isset($request->reviewer_comment)?$request->reviewer_comment:null;
                    if(isset($request->billing_comment_show_to_broker) && $request->billing_comment_show_to_broker==1)
                        $item->billing_comment_show_to_broker               = 1;
                    $item->comment                                          = isset($request->comment)?$request->comment:null;

                    if(isset($request->is_send_to_broker) && $request->is_send_to_broker==1){
                        $item->is_send_to_broker                            = $request->is_send_to_broker;
                        $item->is_send_to_broker_at                         = Carbon::now();
                    }else{
                        $item->is_send_to_broker                            = 0;
                        $item->is_send_to_broker_at                         = null;
                    }

                    $broker_emails                                          = null;
                    if(!empty(array_filter($request->broker_email))){
                        $broker_emails                                      = serialize(array_filter($request->broker_email));
                    }
                    $item->broker_emails                                    = $broker_emails;

                    if($request->detention_status==1){
                        if(is_null($item->acknowledged_at))
                            $item->acknowledged_user_type                   = 'Company Admin';
                            $item->acknowledged_at                          = Carbon::now();
                            $item->acknowledged_by                          = auth()->guard('company-admin')->user()->id;
                    }else{
                        if(is_null($item->submitted_at))
                            $item->submitted_user_type                      = 'Company Admin';
                            $item->submitted_at                             = Carbon::now();
                            $item->submitted_by                             = auth()->guard('company-admin')->user()->id;
                    }

                    if($request->review_status=='Completed'){
                        $item->approved_user_type                           = 'Company Admin';
                        $item->approved_at                                  = Carbon::now();
                        $item->approved_by                                  = auth()->guard('company-admin')->user()->id;
                        $item->approved_ip                                  = $request->ip();
                    }elseif ($request->review_status=='In Progress - Sent to broker') {
                        $item->sent_to_broker                               = 1;
                        $item->sent_to_broker_at                            = Carbon::now();
                        $item->sent_to                                      = $broker_emails;
                    }elseif ($request->review_status=='In Progress - Acknowledged - Sent to broker') {
                        $item->sent_acknowledgement_to_broker               = 1;
                        $item->sent_acknowledgement_to_broker_at            = Carbon::now();
                        $item->acknowledgement_emails                       = $broker_emails;
                    }

                    $item->review_user_type                                 = 'Company Admin';
                    $item->review_status                                    = $request->review_status;
                    $item->review_at                                        = Carbon::now();
                    $item->review_by                                        = auth()->guard('company-admin')->user()->id;
                    if($item->save()){
                        if($item->wasChanged()){
                            $this->setLoadAudit($item->load_detail->load_id, 'update', 'Load detention updated', $item->getChanges(), $oldData);
                        }
                        /*
                        if(isset($request->detention_arrival_time) && $request->detention_arrival_time!=''){
                            if($item->is_stop=='0'){
                                $item->load_detail()->update([
                                    $item->type=='1'?'shipper_arrived_at':'delivery_arrived_at' => ($request->detention_arrival_time)?convertTimeToUTCzone(['str' => $request->detention_arrival_time, 'toFormat'=> 'Y-m-d H:i:s', 'fromFormat' => getTimeLayout(), 'userTimezone' => $request->timezone]):null,
                                    $item->type=='1'?'shipper_is_arrived':'delivery_is_arrived' => 1
                                ]);
                            }else{
                                $item->stop()->update([
                                    'arrived_at'  => ($request->detention_arrival_time)?convertTimeToUTCzone(['str' => $request->detention_arrival_time, 'toFormat'=> 'Y-m-d H:i:s', 'fromFormat' => getTimeLayout(), 'userTimezone' => $request->timezone]):null,
                                    'is_arrived'  => 1
                                ]);
                            }
                        }
                        */

                        if(in_array($request->review_status, ['In Progress - Acknowledged - Sent to broker','In Progress - Sent to broker'])){
                            foreach (array_filter($request->broker_email) as $key => $broker_email) {
                                $details                                    = [];
                                $details['company_id']                     = auth()->guard('company-admin')->user()->company_id;
                                $details['detention']                       = $item;
                                $details['name']                            = isset($item->broker->name) ? $item->broker->name : '';
                                //Mail::to($broker_email)->send(new DetentionRequestBroker($details));
                                sendEmail($broker_email, new DetentionRequestBroker($details));
                            }
                        }
                        $response['detention']                              = $item;
                        $response['success']                                = true;
                        $response['message']                                = "Detention save successfully.";
                    }else{
                        $response['success']                                = false;
                        $response['message']                                = "Detention save unsuccessfully.";
                    }
                }else{
                    $response['success']                                    = false;
                    $response['message']                                    = "Detention record not found.";
                }
            }else{
                $item                                                       = new LoadDetention();
                $item->load_detail_id                                       = $request->load_detail_id;
                $item->driver_id                                            = $request->driver_id;
                $item->broker_id                                            = $request->broker_id;
                if($request->has('load_stop_id') && $request->load_stop_id!==''){
                    $item->load_stop_id                                     = $request->load_stop_id;
                }
                $item->type                                                 = $request->type;
                $item->is_stop                                              = $request->is_stop;

                $item->detention_status                                     = 3;

                $item->detention_arrival_time                               = ($request->detention_arrival_time)?convertTimeToUTCzone(['str' => $request->detention_arrival_time, 'toFormat'=> 'Y-m-d H:i:s', 'fromFormat' => getTimeLayout(), 'userTimezone' => $request->timezone]):null;
                $item->detention_start_time                                 = ($request->detention_start_time)?convertTimeToUTCzone(['str' => $request->detention_start_time, 'toFormat'=> 'Y-m-d H:i:s', 'fromFormat' => getTimeLayout(), 'userTimezone' => $request->timezone]):null;
                $item->detention_end_time                                   = ($request->detention_end_time)?convertTimeToUTCzone(['str' => $request->detention_end_time, 'toFormat'=> 'Y-m-d H:i:s', 'fromFormat' => getTimeLayout(), 'userTimezone' => $request->timezone]):null;

                $item->free_time                                            = isset($request->free_time)?$request->free_time:null;
                $item->billed_time                                          = isset($request->billed_time)?$request->billed_time:null;
                $item->rate                                                 = isset($request->rate)?$request->rate:null;
                $item->detention_due                                        = isset($request->detention_due)?$request->detention_due:null;

                if(isset($request->driver_comment_show_to_broker) && $request->driver_comment_show_to_broker==1)
                    $item->driver_comment_show_to_broker                    = 1;
                $item->driver_comment                                       = isset($request->driver_comment)?$request->driver_comment:null;
                if(isset($request->reviewer_comment_show_to_broker) && $request->reviewer_comment_show_to_broker==1)
                    $item->reviewer_comment_show_to_broker                  = 1;
                $item->reviewer_comment                                     = isset($request->reviewer_comment)?$request->reviewer_comment:null;
                if(isset($request->billing_comment_show_to_broker) && $request->billing_comment_show_to_broker==1)
                    $item->billing_comment_show_to_broker                   = 1;
                $item->comment                                              = isset($request->comment)?$request->comment:null;

                if(isset($request->is_send_to_broker) && $request->is_send_to_broker==1){
                    $item->is_send_to_broker                                = $request->is_send_to_broker;
                    $item->is_send_to_broker_at                             = Carbon::now();
                }else{
                    $item->is_send_to_broker                                = 0;
                    $item->is_send_to_broker_at                             = null;
                }

                $broker_emails                                              = null;
                if(!empty(array_filter($request->broker_email))){
                    $broker_emails                                          = serialize(array_filter($request->broker_email));
                }
                $item->broker_emails                                        = $broker_emails;

                $item->submitted_at                                         = Carbon::now();
                $item->submitted_by                                         = auth()->guard('company-admin')->user()->id;

                if($request->review_status=='Completed'){
                    $item->approved_user_type                               = 'Company Admin';
                    $item->approved_at                                      = Carbon::now();
                    $item->approved_by                                      = auth()->guard('company-admin')->user()->id;
                    $item->approved_ip                                      = $request->ip();
                }elseif ($request->review_status=='In Progress - Sent to broker') {
                    $item->sent_to_broker                                   = 1;
                    $item->sent_to_broker_at                                = Carbon::now();
                    $item->sent_to                                          = $broker_emails;
                }

                $item->review_user_type                                     = 'Company Admin';
                $item->review_status                                        = $request->review_status;
                $item->review_at                                            = Carbon::now();
                $item->review_by                                            = auth()->guard('company-admin')->user()->id;
                if($item->save()){
                    /*
                    if(isset($request->detention_arrival_time) && $request->detention_arrival_time!=''){
                        if($item->is_stop=='0'){
                            $item->load_detail()->update([
                                $item->type=='1'?'shipper_arrived_at':'delivery_arrived_at' => ($request->detention_arrival_time)?convertTimeToUTCzone(['str' => $request->detention_arrival_time, 'toFormat'=> 'Y-m-d H:i:s', 'fromFormat' => getTimeLayout(), 'userTimezone' => $request->timezone]):null,
                                $item->type=='1'?'shipper_is_arrived':'delivery_is_arrived' => 1
                            ]);
                        }else{
                            $item->stop()->update([
                                'arrived_at'  => ($request->detention_arrival_time)?convertTimeToUTCzone(['str' => $request->detention_arrival_time, 'toFormat'=> 'Y-m-d H:i:s', 'fromFormat' => getTimeLayout(), 'userTimezone' => $request->timezone]):null,
                                'is_arrived'  => 1
                            ]);
                        }
                    }
                    */

                    if(in_array($request->review_status, ['In Progress - Sent to broker'])){
                        foreach (array_filter($request->broker_email) as $key => $broker_email) {
                            $details                                        = [];
                            $details['company_id']                          = auth()->guard('company-admin')->user()->company_id;
                            $details['detention']                           = $item;
                            $details['name']                                = isset($item->broker->name) ? $item->broker->name : '';
                            //Mail::to($broker_email)->send(new DetentionRequestBroker($details));
                            sendEmail($broker_email, new DetentionRequestBroker($details));
                        }
                    }
                    $response['detention']                                  = $item;
                    $response['success']                                    = true;
                    $response['message']                                    = "Detention save successfully.";
                }else{
                    $response['success']                                    = false;
                    $response['message']                                    = "Detention save unsuccessfully.";
                }
            }
        }
        return response()->json($response);
    }

    public function detentionDeny(Request $request){
        $response['success']                        = false;
        $response['message']                        = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $item                               = LoadDetention::where('id',$request->detention_id)->first();
                if(!is_null($item)){
                    $oldData                        = $item->toArray();

                    $item->denied_user_type         = 'Company Admin';
                    $item->denied_at                = Carbon::now();
                    $item->denied_by                = auth()->guard('company-admin')->user()->id;
                    $item->denied_ip                = $request->ip();

                    $item->broker_review_status_ip  = null;
                    $item->review_user_type         = 'Company Admin';
                    $item->review_status            = 'Denied';
                    $item->review_at                = Carbon::now();
                    $item->review_by                = auth()->guard('company-admin')->user()->id;
                    if($item->save()){
                        if($item->wasChanged()){
                            $this->setLoadAudit($item->load_detail->load_id, 'update', 'Load detention updated', $item->getChanges(), $oldData);
                        }
                        $response['success']        = true;
                        $response['message']        = "Deny detention request successfully.";
                    }else{
                        $response['success']        = false;
                        $response['message']        = "Deny detention request unsuccessfully.";
                    }
                }
            }catch (\Exception $e) {
                $response['success']                = false;
                $response['message']                = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function detentionRevert(Request $request){
        $response['success']                                        = false;
        $response['message']                                        = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $detention                                          = LoadDetention::where('id',$request->detention_id)->first();
                if(!is_null($detention)){
                    $oldData                                        = $detention->toArray();

                    if($detention->review_status=='Denied'){
                        $detention->denied_user_type                = null;
                        $detention->denied_at                       = null;
                        $detention->denied_by                       = null;
                        $detention->denied_ip                       = null;
                    }
                    if($detention->review_status=='Completed'){
                        $detention->approved_user_type              = null;
                        $detention->approved_at                     = null;
                        $detention->approved_by                     = null;
                        $detention->approved_ip                     = null;
                    }

                    if($detention->detention_status=='1'){
                        if(is_null($detention->acknowledged_at)){
                            $detention->review_status               = 'In Progress';
                        }else{
                            if($detention->sent_acknowledgement_to_broker=='1'){
                                if(is_null($detention->broker_viewed_acknowledgement_at)){
                                    $detention->review_status       = 'In Progress - Acknowledged - Sent to broker';
                                }else{
                                    $detention->review_status       = 'In Progress - Acknowledged - Seen by broker';
                                }
                            }else{
                                $detention->review_status           = 'In Progress - Acknowledged';
                            }
                        }
                    }else{
                        if(!is_null($detention->submitted_at)){
                            //$detention->submitted_at              = null;
                            //$detention->submitted_by              = null;

                            if($detention->sent_to_broker=='1'){
                                if(is_null($detention->broker_view_at)){
                                    $detention->review_status       = 'In Progress - Sent to broker';
                                }else{
                                    if(!is_null($detention->adjusted_billed_time) || !is_null($detention->adjusted_rate)){
                                        $detention->review_status   = 'Broker Amendment Request';
                                     }elseif (!is_null($detention->broker_denied_at)) {
                                        $detention->review_status   = 'Broker Denied Request';
                                    }else{
                                        $detention->review_status   = 'Pending Broker Review';
                                    }
                                }
                            }else{
                                if(!is_null($detention->stopped_at)){
                                    $detention->review_status       = 'Detention Stopped - Pending Approval';
                                }else{
                                    $detention->review_status       = 'In Progress';
                                }
                            }
                        }else{
                            if(!is_null($detention->stopped_at)){
                                $detention->review_status           = 'Detention Stopped - Pending Approval';
                            }else{
                                $detention->review_status           = 'In Progress';
                            }
                        }
                    }
                    $detention->review_user_type                    = 'Company Admin';
                    $detention->review_at                           = Carbon::now();
                    $detention->review_by                           = auth()->guard('company-admin')->user()->id;
                    if($detention->save()){
                        if($detention->wasChanged()){
                            $this->setLoadAudit($detention->load_detail->load_id, 'update', 'Load detention updated', $detention->getChanges(), $oldData);
                        }
                        $response['html']                           = $this->getRfDetentionView($request,$detention);
                        $response['success']                        = true;
                        $response['message']                        = "Revert detention request successfully.";
                    }else{
                        $response['success']                        = false;
                        $response['message']                        = "Revert detention request unsuccessfully.";
                    }
                }
            }catch (\Exception $e) {
                $response['success']                                = false;
                $response['message']                                = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function detentionForceStop(Request $request){
        $response['success']                                        = false;
        $response['message']                                        = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $detention                                          = LoadDetention::where('id',$request->detention_id)->first();
                if(!is_null($detention)){
                    $oldData                                        = $detention->toArray();

                    $detention->detention_status                    = 2;
                    $detention->detention_end_time                  = Carbon::now();

                    $detention->stopped_user_type                   = 'Company Admin';
                    $detention->stopped_at                          = Carbon::now();
                    $detention->stopped_by                          = auth()->guard('company-admin')->user()->id;

                    $detention->review_user_type                    = 'Company Admin';
                    $detention->review_status                       = 'Detention Stopped - Pending Approval';
                    $detention->review_at                           = Carbon::now();
                    $detention->review_by                           = auth()->guard('company-admin')->user()->id;
                    if($detention->save()){
                        if($detention->wasChanged()){
                            $this->setLoadAudit($detention->load_detail->load_id, 'update', 'Load detention updated', $detention->getChanges(), $oldData);
                        }
                        $response['html']                           = $this->getRfDetentionView($request,$detention);
                        $response['success']                        = true;
                        $response['message']                        = "Stop detention request successfully.";
                    }else{
                        $response['success']                        = false;
                        $response['message']                        = "Stop detention request unsuccessfully.";
                    }
                }
            }catch (\Exception $e) {
                $response['success']                                = false;
                $response['message']                                = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function getRfDetentionView($request,$detention){
        $formData                   = $request->all();

        $gpsLocation                = null;
        $driver                     = $detention->driver;
        if(!is_null($driver)){
            $samsara_id             = (isset($driver->samsara_id) && $driver->samsara_id!='')?$driver->samsara_id:'';//4644765
            if($samsara_id!=''){
                $carrierId = (isset($driver->driver_information->carrier_id)) ? $driver->driver_information->carrier_id : null;
                $getAPIKey          = IntegrationSetting::where('company_id', $driver->company_id)->where('carrier_id', $carrierId)->where('app_center_id', config('settings.app_id.samsara'))->where('sync_drivers', '1')->first();
                if(isset($getAPIKey->api_key) && !empty($getAPIKey->api_key)){
                    $client                                 = new \GuzzleHttp\Client();
                    $api_url                                = 'https://api.samsara.com/fleet/hos/clocks?driverIds='.$samsara_id;
                    $api_response                           = $client->request('GET', $api_url, [
                        'headers'                           => [
                            'Accept'                        => 'application/json',
                            'Authorization'                 => 'Bearer '.$getAPIKey->api_key,
                        ],
                    ]);
                    $api_data                               = json_decode($api_response->getBody());
                    if(!empty($api_data)){
                        $appData                            = $api_data->data[0];
                        if(!empty($appData)){
                            $vehicleIds                     = (isset($appData->currentVehicle->id) && $appData->currentVehicle->id!='')?$appData->currentVehicle->id:'';
                            if($vehicleIds!=''){
                                $api_url                    = 'https://api.samsara.com/fleet/vehicles/locations?vehicleIds='.$vehicleIds;
                                $api_response               = $client->request('GET', $api_url, [
                                    'headers'               => [
                                        'Accept'            => 'application/json',
                                        'Authorization'     => 'Bearer '.$getAPIKey->api_key,
                                    ],
                                ]);
                                $api_data                   = json_decode($api_response->getBody());
                                if(!empty($api_data)){
                                    $appData                = $api_data->data[0];
                                    if(!empty($appData) && (isset($appData->location->reverseGeo->formattedLocation) && $appData->location->reverseGeo->formattedLocation!='')){
                                        $gpsLocation        = $appData->location->reverseGeo->formattedLocation;
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }

        $getGeoTimeZone             = getGeoTimeZone();

        $html                       = view('companyAdmin.load.ajax.detentionRequestRevert', compact('formData','detention','gpsLocation','getGeoTimeZone'))->render();
        return $html;
    }

    public function detentionRunning(Request $request){
        $response['success']                = false;
        $response['message']                = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $response['running']        = LoadDetention::where('driver_id', $request->driver_id)->where('load_detail_id', $request->load_detail_id)->whereIn('detention_status', [1])->exists();
                $response['success']        = true;
                $response['message']        = "Detention running check successfully.";
            }catch (\Exception $e) {
                $response['success']        = false;
                $response['message']        = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function pendingDetention(Request $request){
        $response['success']                        = false;
        $response['message']                        = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                if($request->has('html') && $request->html==true){
                    $load                           = Load::query()
                        ->with([
                            'load_stops',
                            'load_detail.detentions' => function ($q) {
                                $q->whereNotIn('review_status', ['Completed','Denied']);
                            }
                        ])
                        ->whereId($request->id)
                        ->first();
                    if(isset($load->load_detail->detentions) && $load->load_detail->detentions->isNotEmpty()){
                        // $html                   = '<div class="alert alert-danger" role="alert">
                        //   This is a danger alert—check it out!
                        // </div>';
                        $html                               = '';
                        $shipper_detention                  = $load->load_detail->shipper_detention()->whereNotIn('review_status', ['Completed','Denied'])->first();
                        if(!is_null($shipper_detention)){
                            $pTag                           = '<p style="margin:0;">';
                            $pTag                          .= 'Load Pickup - '.$shipper_detention->review_status;
                            $pTag                          .= '</p>';
                            $html                          .= $pTag;
                        }
                        if(isset($load->load_stops) && $load->load_stops->isNotEmpty()){
                            $stopIds                        = $load->load_stops->pluck('id')->toArray();
                            foreach ($stopIds as $stkey => $stopId) {
                                ++$stkey;
                                $stop                       = LoadStop::whereId($stopId)->first();
                                if(isset($stop->detention) && !in_array($stop->detention->review_status, ['Completed','Denied'])){
                                    if($stop->customer_type=='1'){
                                        $customer_type      = ' Pickup - ';
                                    }else{
                                        $customer_type      = ' Delivery - ';
                                    }
                                    $pTag                   = '<p style="margin:0;">';
                                    $pTag                  .= 'Stop '.$stop->stop_no.' '.$customer_type.$stop->detention->review_status;
                                    $pTag                  .= '</p>';
                                    $html                  .= $pTag;
                                }
                            }
                        }
                        $receiver_detention                 = $load->load_detail->receiver_detention()->whereNotIn('review_status', ['Completed','Denied'])->first();
                        if(!is_null($receiver_detention)){
                            $pTag                           = '<p style="margin:0;">';
                            $pTag                          .= 'Load Pickup - '.$receiver_detention->review_status;
                            $pTag                          .= '</p>';
                            $html                          .= $pTag;
                        }
                        $response['html']                   = $html;
                        $response['success']                = true;
                        $response['message']                = "Detention pending retrieved successfully.";
                    }else{
                        $response['success']                = true;
                        $response['message']                = "Detention pending not found.";
                    }
                }else{
                    $load                                   = Load::whereId($request->id)->first();

                    $response['detention']                  = $load->load_detail->detentions()->whereNotIn('review_status', ['Completed','Denied'])->count();

                    $html                                   = '';
                    if(isset($load->load_detail->detentions) && $load->load_detail->detentions->isNotEmpty()){
                        $shipper_detention                  = isset($load->load_detail->shipper_detention)?$load->load_detail->shipper_detention:null;
                        if(!is_null($shipper_detention)){
                            $pTag                           = '<p style="margin:0;font-size:14px;">';
                            $pTag                          .= 'Load Pickup - ';
                            if(in_array($shipper_detention->detention_status,[2,3])){
                                $pTag                      .= 'Detention Due ';
                                $due_class                  = ($shipper_detention->review_status!='Denied')?'detention-due':'';
                                $pTag                      .= '<span class="'.$due_class.'" data-detention_due="'.(float)$shipper_detention->detention_due.'" data-driver_id="'.$shipper_detention->driver_id.'">';
                                $pTag                      .= '$'.number_format((float)$shipper_detention->detention_due, 2, '.', ',');
                                $pTag                      .= '</span> ';
                            }
                            $pTag                          .= 'Status: '.$shipper_detention->review_status;
                            $pTag                          .= '&nbsp; <a href="javascript:void(0)" class="link" data-detention_id="'.$shipper_detention->id.'"><img src="/theme/images/edit-black.png" alt="Edit Detention"></a></p>';
                            $html                          .= $pTag;
                        }
                        if(isset($load->load_stops) && $load->load_stops->isNotEmpty()){
                            $stopIds                        = $load->load_stops->pluck('id')->toArray();
                            foreach ($stopIds as $stkey => $stopId) {
                                ++$stkey;
                                $stopd                      = LoadStop::whereId($stopId)->first();
                                if(isset($stopd->detention)){
                                    $pTag                   = '<p style="margin:0;font-size:14px;">';
                                    $pTag                  .= 'Stop '.$stopd->stop_no;
                                    if($stopd->customer_type=='1'){
                                        $pTag              .= ' Pickup - ';
                                    }else{
                                        $pTag              .= ' Delivery - ';
                                    }
                                    if(in_array($stopd->detention->detention_status,[2,3])){
                                        $pTag              .= 'Detention Due ';
                                        $due_class          = ($stopd->detention->review_status!='Denied')?'detention-due':'';
                                        $pTag              .= '<span class="'.$due_class.'" data-detention_due="'.(float)$stopd->detention->detention_due.'" data-driver_id="'.$stopd->detention->driver_id.'">';
                                        $pTag              .= '$'.number_format((float)$stopd->detention->detention_due, 2, '.', ',');
                                        $pTag              .= '</span> ';
                                    }
                                    $pTag                  .= 'Status: '.$stopd->detention->review_status;
                                    $pTag                  .= '&nbsp; <a href="javascript:void(0)" class="link" data-detention_id="'.$stopd->detention->id.'"><img src="/theme/images/edit-black.png" alt="Edit Detention"></a></p>';
                                    $html                  .= $pTag;
                                }
                            }
                        }
                        $receiver_detention                 = isset($load->load_detail->receiver_detention)?$load->load_detail->receiver_detention:null;
                        if(!is_null($receiver_detention)){
                            $pTag                           = '<p style="margin:0;font-size:14px;">';
                            $pTag                          .= 'Load Delivery - ';
                            if(in_array($receiver_detention->detention_status,[2,3])){
                                $pTag                      .= 'Detention Due ';
                                $due_class                  = ($receiver_detention->review_status!='Denied')?'detention-due':'';
                                $pTag                      .= '<span class="'.$due_class.'" data-detention_due="'.(float)$receiver_detention->detention_due.'" data-driver_id="'.$receiver_detention->driver_id.'">';
                                $pTag                      .= '$'.number_format((float)$receiver_detention->detention_due, 2, '.', ',');
                                $pTag                      .= '</span> ';
                            }
                            $pTag                          .= 'Status: '.$receiver_detention->review_status;
                            $pTag                          .= '&nbsp; <a href="javascript:void(0)" class="link" data-detention_id="'.$receiver_detention->id.'"><img src="/theme/images/edit-black.png" alt="Edit Detention"></a></p>';
                            $html                          .= $pTag;
                        }
                    }else{
                        $html                              .= '<p>No record found.</p>';
                    }
                    $response['html']                       = $html;

                    $response['success']                    = true;
                    $response['message']                    = "Detention pending retrieved successfully.";
                }
            }catch (\Exception $e) {
                $response['success']                        = false;
                $response['message']                        = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function LoadRequirement(Request $request){
        $input                  = $request->except('_method', '_token');
        if(isset($request->requ_id)){
            $oldData            = LoadRequirement::find($request->requ_id)->toArray();

            $UpdateData         = LoadRequirement::find($request->requ_id);
            $UpdateData->qty    = $request->qty;
            $UpdateData->name   = $request->name;
            $UpdateData->save();
            if (Load::where('id', '=', $request->load_id)->exists()) {
                $this->setLoadAudit($request->load_id, 'update', 'Load requirements updated', $UpdateData->getChanges(), $oldData);
            }
        }else{
            $UpdateData         = LoadRequirement::create($input);
        }
        return $UpdateData;
    }

    public function LoadRequirementView(Request $request){
        $input                  = $request->except('_method', '_token');
        $query                  = LoadRequirement::where('load_id', $input['load_id']);
        if(isset($input['is_dummy']) && $input['is_dummy']==1){
            $query->where('is_dummy', 1);
        }
        $getData                = $query->orderBy('id', 'ASC')->get();
        $view                   = view('companyAdmin.load.view.loadRequirements', compact('getData'))->render();
        return response()->json(['view' => $view]);
    }

    public function LoadRequirementDestroy($id){
        $load_requirement                       = LoadRequirement::find($id);
        if(!is_null($load_requirement)){
            if($load_requirement->delete()){
                if (Load::where('id', '=', $request->load_id)->exists()) {
                    $oldData                    = $load_requirement->toArray();
                    $oldData['deleted_at']      = null;
                    $changeData                 = [];
                    $changeData                 = $oldData;
                    $changeData['deleted_at']   = Carbon::now();
                    $this->setLoadAudit($request->load_id, 'delete', 'Load requirements deleted', $changeData, $oldData);
                }
            }
        }
        return 1;
    }

    public function getLoadRequirement($id){
        $getData                = LoadRequirement::find($id);
        return response()->json(['data' => $getData]);
    }

    public function LoadAccessorialSave(Request $request){
        $response['success']                            = false;
        $response['message']                            = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $formdata                               = $request->all();

                $temp                                   = $formdata['temp'];
                if($temp==0){
                    unset($formdata['unique_id']);
                }
                unset($formdata['id']);
                unset($formdata['temp']);
                unset($formdata['btn_unique_id']);

                unset($formdata['accessorial_owner_id']);
                unset($formdata['accessorial_driver_id']);

                $is_received                            = 0;
                if($request->doc_required=='0'){
                    if($request->has('file_upload_id') && $request->file_upload_id!==''){
                        $galleries                      = Gallery::IsCompany()
                            ->where('action_id', $request->file_upload_id)
                            ->where('source', ($temp==0)?'load_accessorials':'load_accessorial_temps')
                            ->get();
                        if($galleries->isNotEmpty()){
                            foreach ($galleries as $key => $gallery) {
                                $path                   = 'storage/companyAdmin/gallery/'.$gallery->image;
                                if (File::exists($path)) {
                                    File::delete($path);
                                }
                                $gallery->delete();
                            }
                        }
                    }
                }else{
                    if($request->has('file_upload_id') && $request->file_upload_id!==''){
                        $file_uploads                   = Gallery::IsCompany()
                            ->where('action_id', $request->file_upload_id)
                            ->where('source', ($temp==0)?'load_accessorials':'load_accessorial_temps')
                            ->count();
                        if($file_uploads > 0){
                            $is_received                = 1;
                        }
                    }
                }

                //status
                $arry                                   = [];
                $paid_type                              = $formdata['paid_type'];
                $reference                              = $formdata['reference'];
                $total                                  = $formdata['total'];

                $owner_liable                           = isset($formdata['owner_liable']) ? 1 : 0;
                $formdata['owner_liable']               = $owner_liable;
                $owner_total                            = $formdata['owner_total'];

                $driver_liable                          = isset($formdata['driver_liable']) ? 1 : 0;
                $formdata['driver_liable']              = $driver_liable;
                $driver_total                           = $formdata['driver_total'];

                $doc_required                           = $formdata['doc_required'];

                array_push($arry, $paid_type!=''?1:0);
                array_push($arry, $reference!=''?1:0);
                array_push($arry, $total!=''?1:0);
                if($owner_liable=='1'){
                    array_push($arry, $owner_total!=''?1:0);
                }
                if($driver_liable=='1'){
                    array_push($arry, $driver_total!=''?1:0);
                }

                if(in_array(0, $arry)){
                    $formdata['status']                 = 0; // Pending
                }else{
                    if($doc_required=='1'){
                        if($is_received==1){
                            $formdata['status']         = 1; // Completed
                        }else{
                            $formdata['status']         = 0; // Pending
                        }
                    }else{
                        $formdata['status']             = 1; // Completed
                    }
                }
                //status

                $accessorial_owner_id                   = $request->accessorial_owner_id;
                if(!is_null($accessorial_owner_id)){
                    $accessorial_owner_id               = explode('_', $accessorial_owner_id); // $owner_type.'_'.$owner_id;
                    $formdata['owner_id']               = $accessorial_owner_id[1];
                    $formdata['owner_type']             = $accessorial_owner_id[0];
                }else{
                    $formdata['owner_id']               = null;
                    $formdata['owner_type']             = null;
                }
                $formdata['driver_id']                  = $request->accessorial_driver_id;
                $formdata['is_received']                = $is_received;
                $formdata['is_deduction']               = 0;
                if($formdata['pay_deduct']==2){
                    $formdata['is_deduction']           = isset($request->is_deduction) && $request->is_deduction==1?1:0;
                }
                if($request->has('id') && $request->id!=''){
                    $formdata['updated_at']             = Carbon::now();
                }else{
                    $formdata['created_by']             = auth()->guard('company-admin')->user()->id;
                    $formdata['created_at']             = Carbon::now();
                }

                if($temp==0){
                    if($request->has('id') && $request->id!=''){
                        $item                           = LoadAccessorial::where('id', $request->id)->first();
                        if(!is_null($item)){
                            if ($formdata['driver_liable']=='1' && $formdata['status']!=1 && isset($item->file_not_provided) && $item->file_not_provided=='on') {
                                $formdata['status']     = 2; // Driver Bypass
                            }
                            $oldData                    = $item->toArray();
                            $item->update($formdata);
                            $this->setLoadAudit($item->load_id, 'update', 'Load accessorial updated', $item->getChanges(), $oldData);
                            if(isset($item->temp_details) && is_serialized($item->temp_details) && !empty(unserialize($item->temp_details))){
                                $item->temp_details     = null;
                                $item->save();
                            }
                        }
                    }else{
                        $item                           = LoadAccessorial::create($formdata);
                    }
                }else{
                    $item                               = LoadAccessorialTemp::updateOrCreate([
                                                            'id' => $request->id
                                                        ], $formdata);
                }
                if($item){
                    if($request->has('file_upload_id') && $request->file_upload_id!==''){
                        Gallery::IsCompany()
                            ->where('action_id', $request->file_upload_id)
                            ->where('source', ($temp==0)?'load_accessorials':'load_accessorial_temps')
                            ->update(['action_id' => $item->id]);
                    }
                    $response['html']                   = view('companyAdmin.load.ajax.accessorial.list', compact('temp','item'))->render();
                    $response['success']                = true;
                    $response['message']                = "Save successfully";
                }else{
                    $response['success']                = false;
                    $response['message']                = "Oops! Something went wrong..";
                }
            }catch (\Exception $e) {
                $response['success']                    = false;
                $response['message']                    = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function LoadAccessorialDestroy(Request $request){
        $response['success']                            = false;
        $response['message']                            = "Oops! Something went wrong..";
        if($request->ajax()){
            LoadAccessorial::find($request->id)->delete();
            $response['success']                = true;
            $response['message']                = "Destroy successfully";
        }
        return response()->json($response);
    }

    public function LoadAccessorialReceived(Request $request){
        $response['success']                            = false;
        $response['message']                            = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $formdata                               = $request->all();
                unset($formdata['id']);
                unset($formdata['temp']);

                $formdata['updated_at']                 = Carbon::now();
                if($request->temp==0){
                    $item                               = LoadAccessorial::where('id', $request->id)->first();
                    $oldData                            = $item->toArray();
                }else{
                    $item                               = LoadAccessorialTemp::where('id', $request->id)->first();
                }

                //status
                $arry                                   = [];
                $paid_type                              = $item->paid_type;
                $reference                              = $item->reference;
                $total                                  = $item->total;

                $owner_liable                           = $item->owner_liable;
                $owner_total                            = $item->owner_total;

                $driver_liable                          = $item->driver_liable;
                $driver_total                           = $item->driver_total;

                $doc_required                           = $item->doc_required;

                array_push($arry, $paid_type!=''?1:0);
                array_push($arry, $reference!=''?1:0);
                array_push($arry, $total!=''?1:0);
                if($owner_liable=='1'){
                    array_push($arry, $owner_total!=''?1:0);
                }
                if($driver_liable=='1'){
                    array_push($arry, $driver_total!=''?1:0);
                }

                if(in_array(0, $arry)){
                    $formdata['status']                 = 0; // Pending
                }else{
                    if($doc_required=='1'){
                        if($request->is_received==1){
                            $formdata['status']         = 1; // Completed
                        }else{
                            $formdata['status']         = 0; // Pending
                        }
                    }else{
                        $formdata['status']             = 1; // Completed
                    }
                }
                if ($driver_liable=='1' && $formdata['status']!=1 && isset($item->file_not_provided) && $item->file_not_provided=='on') {
                    $formdata['status']                 = 2; // Driver Bypass
                }
                //status

                $formdata['updated_at']                 = Carbon::now();
                foreach ($formdata as $key => $value) {
                    $item->$key                         = $value;
                }

                //
                if(isset($item->temp_details) && is_serialized($item->temp_details) && !empty(unserialize($item->temp_details))){
                    $temp_details                       = unserialize($item->temp_details);

                    $tarray                             = [];

                    if(isset($temp_details['owner_id'])){
                        $tarray['owner_id']             = $temp_details['owner_id'];
                        $tarray['owner_type']           = $temp_details['owner_type'];
                    }else{
                        $tarray['owner_liable']         = 0;
                        $tarray['owner_id']             = null;
                        $tarray['owner_type']           = null;
                        $tarray['owner_pay_deduct']     = 1;
                        $tarray['owner_qty']            = null;
                        $tarray['owner_rate']           = null;
                        $tarray['owner_total']          = null;
                    }
                    if(isset($temp_details['driver_id'])){
                        $tarray['driver_id']            = $temp_details['driver_id'];
                        $tarray['file_not_provided']    = 'off';
                    }else{
                        $tarray['driver_liable']        = 0;
                        $tarray['driver_id']            = null;
                        $tarray['pay_deduct']           = 1;
                        $tarray['is_deduction']         = 0;
                        $tarray['driver_qty']           = null;
                        $tarray['driver_rate']          = null;
                        $tarray['driver_total']         = null;
                        $tarray['file_not_provided']    = 'off';
                    }

                    //status
                    $arry                               = [];
                    $paid_type                          = $item->paid_type;
                    $reference                          = $item->reference;
                    $total                              = $item->total;

                    $owner_liable                       = isset($tarray['owner_liable'])?$tarray['owner_liable']:$item->owner_liable;
                    $owner_total                        = isset($tarray['owner_total'])?$tarray['owner_total']:$item->owner_total;

                    $driver_liable                      = isset($tarray['driver_liable'])?$tarray['driver_liable']:$item->driver_liable;
                    $driver_total                       = isset($tarray['driver_total'])?$tarray['driver_total']:$item->driver_total;

                    array_push($arry, $paid_type!=''?1:0);
                    array_push($arry, $reference!=''?1:0);
                    array_push($arry, $total!=''?1:0);
                    if($owner_liable=='1'){
                        array_push($arry, $owner_total!=''?1:0);
                    }
                    if($driver_liable=='1'){
                        array_push($arry, $driver_total!=''?1:0);
                    }

                    if(in_array(0, $arry)){
                        $tarray['status']               = 0; // Pending
                    }else{
                        if($item->doc_required=='1'){
                            if($item->is_received==1){
                                $tarray['status']       = 1; // Completed
                            }else{
                                $tarray['status']       = 0; // Pending
                            }
                        }else{
                            $tarray['status']           = 1; // Completed
                        }
                    }
                    //

                    $item->temp_details                 = serialize($tarray);
                }
                //
                if($item->save()){
                    if($request->temp==0 && isset($oldData) && !isset($item->temp_details)){
                        $this->setLoadAudit($item->load_id, 'update', 'Load accessorial updated', $item->getChanges(), $oldData);
                    }
                    $response['item']                   = $item;
                    if(isset($item->temp_details) && is_serialized($item->temp_details) && !empty(unserialize($item->temp_details))){
                        $response['temp_details']       = unserialize($item->temp_details);
                    }
                    $response['success']                = true;
                    $response['message']                = "Save successfully";
                }else{
                    $response['success']                = false;
                    $response['message']                = "Oops! Something went wrong..";
                }
            }catch (\Exception $e) {
                $response['success']                    = false;
                $response['message']                    = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function LoadAccessorialDetail(Request $request){
        $response['success']                            = false;
        $response['message']                            = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $temp                                   = $request->temp;
                if($temp==0){
                    $item                               = LoadAccessorial::where('id', $request->id)->first();
                }else{
                    $item                               = LoadAccessorialTemp::where('id', $request->id)->first();
                }
                if($item){
                    if($request->has('html')){
                        $response['html']               = view('companyAdmin.load.ajax.accessorial.list', compact('temp','item'))->render();
                    }else{
                        $response['item']               = $item;
                        $response['created_at']         = $item->created_at ? Carbon::createFromFormat('Y-m-d H:i:s', $item->created_at)->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : '';
                        $response['created_by']         = $item->creator->full_name ?? '';
                        $response['temp']               = $temp;
                        if(isset($item->temp_details) && is_serialized($item->temp_details) && !empty(unserialize($item->temp_details))){
                            $response['temp_details']   = unserialize($item->temp_details);
                        }
                    }

                    $response['success']                = true;
                    $response['message']                = "Retrieved successfully";
                }else{
                    $response['success']                = false;
                    $response['message']                = "Retrieved unsuccessfully";
                }
            }catch (\Exception $e) {
                $response['success']                    = false;
                $response['message']                    = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function LoadAccessorialDriverChange(Request $request){
        $response['success']                                = false;
        $response['message']                                = "Oops! Something went wrong..";

        if($request->has('mode')){
            $temp                                           = $request->temp;
            if($request->mode=='remove'){
                if($temp==0){
                    $item                                   = LoadAccessorial::query()
                        ->where('id', $request->id)
                        ->first();
                    if(!is_null($item)){
                        $tarray                             = [];

                        if($request->has('current_owner_liable')){
                            $tarray['owner_liable']         = 0;
                            $tarray['owner_id']             = null;
                            $tarray['owner_type']           = null;
                            $tarray['owner_pay_deduct']     = 1;
                            $tarray['owner_qty']            = null;
                            $tarray['owner_rate']           = null;
                            $tarray['owner_total']          = null;
                        }

                        if($request->has('current_driver_liable')){
                            $tarray['driver_liable']        = 0;
                            $tarray['driver_id']            = null;
                            $tarray['pay_deduct']           = 1;
                            $tarray['is_deduction']         = 0;
                            $tarray['driver_qty']           = null;
                            $tarray['driver_rate']          = null;
                            $tarray['driver_total']         = null;
                            $tarray['file_not_provided']    = 'off';
                        }

                        //status
                        $arry                               = [];
                        $paid_type                          = $item->paid_type;
                        $reference                          = $item->reference;
                        $total                              = $item->total;

                        $owner_liable                       = isset($tarray['owner_liable'])?$tarray['owner_liable']:$item->owner_liable;
                        $owner_total                        = isset($tarray['owner_total'])?$tarray['owner_total']:$item->owner_total;

                        $driver_liable                      = isset($tarray['driver_liable'])?$tarray['driver_liable']:$item->driver_liable;
                        $driver_total                       = isset($tarray['driver_total'])?$tarray['driver_total']:$item->driver_total;

                        array_push($arry, $paid_type!=''?1:0);
                        array_push($arry, $reference!=''?1:0);
                        array_push($arry, $total!=''?1:0);
                        if($owner_liable=='1'){
                            array_push($arry, $owner_total!=''?1:0);
                        }
                        if($driver_liable=='1'){
                            array_push($arry, $driver_total!=''?1:0);
                        }

                        if(in_array(0, $arry)){
                            $tarray['status']               = 0; // Pending
                        }else{
                            if($item->doc_required=='1'){
                                if($item->is_received==1){
                                    $tarray['status']       = 1; // Completed
                                }else{
                                    $tarray['status']       = 0; // Pending
                                }
                            }else{
                                $tarray['status']           = 1; // Completed
                            }
                        }
                        //

                        $item->temp_details                 = serialize($tarray);
                        if($item->save()){
                            $response['html']               = view('companyAdmin.load.ajax.accessorial.list', compact('temp','item'))->render();
                            $response['success']            = true;
                            $response['message']            = "Save successfully";
                        }
                    }
                }else{
                    $item                                   = LoadAccessorialTemp::query()
                        ->where('id', $request->id)
                        ->first();
                    if(!is_null($item)){
                        if($request->has('current_owner_liable')){
                            $item->owner_liable             = 0;
                            $item->owner_id                 = null;
                            $item->owner_type               = null;
                            $item->owner_pay_deduct         = 1;
                            $item->owner_qty                = null;
                            $item->owner_rate               = null;
                            $item->owner_total              = null;
                        }

                        if($request->has('current_driver_liable')){
                            $item->driver_liable            = 0;
                            $item->driver_id                = null;
                            $item->pay_deduct               = 1;
                            $item->is_deduction             = 0;
                            $item->driver_qty               = null;
                            $item->driver_rate              = null;
                            $item->driver_total             = null;
                        }

                        //status
                        $arry                               = [];
                        $paid_type                          = $item->paid_type;
                        $reference                          = $item->reference;
                        $total                              = $item->total;

                        $owner_liable                       = $item->owner_liable;
                        $owner_total                        = $item->owner_total;

                        $driver_liable                      = $item->driver_liable;
                        $driver_total                       = $item->driver_total;

                        array_push($arry, $paid_type!=''?1:0);
                        array_push($arry, $reference!=''?1:0);
                        array_push($arry, $total!=''?1:0);
                        if($owner_liable=='1'){
                            array_push($arry, $owner_total!=''?1:0);
                        }
                        if($driver_liable=='1'){
                            array_push($arry, $driver_total!=''?1:0);
                        }

                        if(in_array(0, $arry)){
                            $status                         = 0; // Pending
                        }else{
                            if($item->doc_required=='1'){
                                if($item->is_received==1){
                                    $status                 = 1; // Completed
                                }else{
                                    $status                 = 0; // Pending
                                }
                            }else{
                                $status                     = 1; // Completed
                            }
                        }
                        $item->status                       = $status;
                        //

                        $item->updated_at                   = Carbon::now();
                        if($item->save()){
                            $response['html']               = view('companyAdmin.load.ajax.accessorial.list', compact('temp','item'))->render();
                            $response['success']            = true;
                            $response['message']            = "Save successfully";
                        }
                    }
                }
            }elseif ($request->mode=='edit') {
                if($temp==0){
                    $item                                   = LoadAccessorial::query()
                        ->where('id', $request->id)
                        ->first();
                    if(!is_null($item)){
                        $tarray                             = [];

                        if($request->has('current_owner_liable')){
                            $truck_owner_id                 = $request->current_truck_owner_id;
                            if($truck_owner_id==''){
                                $tarray['owner_liable']     = 0;
                                $tarray['owner_id']         = null;
                                $tarray['owner_type']       = null;
                                $tarray['owner_pay_deduct'] = 1;
                                $tarray['owner_qty']        = null;
                                $tarray['owner_rate']       = null;
                                $tarray['owner_total']      = null;
                            }else{
                                $truck_owner_id             = explode('_', $truck_owner_id);
                                $tarray['owner_type']       = $truck_owner_id[0];
                                $tarray['owner_id']         = $truck_owner_id[1];
                            }
                        }

                        if($request->has('current_driver_liable')){
                            $driver_id                      = $request->current_driver_id;
                            if($driver_id==0 || $driver_id==''){
                                $tarray['driver_liable']    = 0;
                                $tarray['driver_id']        = null;
                                $tarray['pay_deduct']       = 1;
                                $tarray['is_deduction']     = 0;
                                $tarray['driver_qty']       = null;
                                $tarray['driver_rate']      = null;
                                $tarray['driver_total']     = null;
                                $tarray['file_not_provided']= 'off';
                            }else{
                                $tarray['driver_id']        = $driver_id;
                                $tarray['file_not_provided']= 'off';
                            }
                        }


                        //status
                        $arry                               = [];
                        $paid_type                          = $item->paid_type;
                        $reference                          = $item->reference;
                        $total                              = $item->total;

                        $owner_liable                       = isset($tarray['owner_liable'])?$tarray['owner_liable']:$item->owner_liable;
                        $owner_total                        = isset($tarray['owner_total'])?$tarray['owner_total']:$item->owner_total;

                        $driver_liable                      = isset($tarray['driver_liable'])?$tarray['driver_liable']:$item->driver_liable;
                        $driver_total                       = isset($tarray['driver_total'])?$tarray['driver_total']:$item->driver_total;

                        array_push($arry, $paid_type!=''?1:0);
                        array_push($arry, $reference!=''?1:0);
                        array_push($arry, $total!=''?1:0);
                        if($owner_liable=='1'){
                            array_push($arry, $owner_total!=''?1:0);
                        }
                        if($driver_liable=='1'){
                            array_push($arry, $driver_total!=''?1:0);
                        }

                        if(in_array(0, $arry)){
                            $tarray['status']               = 0; // Pending
                        }else{
                            if($item->doc_required=='1'){
                                if($item->is_received==1){
                                    $tarray['status']       = 1; // Completed
                                }else{
                                    $tarray['status']       = 0; // Pending
                                }
                            }else{
                                $tarray['status']           = 1; // Completed
                            }
                        }
                        //

                        $item->temp_details                 = serialize($tarray);
                        if($item->save()){
                            $response['html']               = view('companyAdmin.load.ajax.accessorial.list', compact('temp','item'))->render();
                            $response['success']            = true;
                            $response['message']            = "Save successfully";
                        }
                    }
                }else{
                    $item                                   = LoadAccessorialTemp::query()
                        ->where('id', $request->id)
                        ->first();
                    if(!is_null($item)){
                        if($request->has('current_owner_liable')){
                            $truck_owner_id                 = $request->current_truck_owner_id;
                            if($truck_owner_id==''){
                                $item->owner_liable         = 0;
                                $item->owner_id             = null;
                                $item->owner_type           = null;
                                $item->owner_pay_deduct     = 1;
                                $item->owner_qty            = null;
                                $item->owner_rate           = null;
                                $item->owner_total          = null;
                            }else{
                                $truck_owner_id             = explode('_', $truck_owner_id);
                                $item->owner_type           = $truck_owner_id[0];
                                $item->owner_id             = $truck_owner_id[1];
                            }
                        }

                        if($request->has('current_driver_liable')){
                            $driver_id                      = $request->current_driver_id;
                            if($driver_id==0 || $driver_id==''){
                                $item->driver_liable        = 0;
                                $item->driver_id            = null;
                                $item->pay_deduct           = 1;
                                $item->is_deduction         = 0;
                                $item->driver_qty           = null;
                                $item->driver_rate          = null;
                                $item->driver_total         = null;
                            }else{
                                $item->driver_id            = $driver_id;
                            }
                        }

                        //status
                        $arry                               = [];
                        $paid_type                          = $item->paid_type;
                        $reference                          = $item->reference;
                        $total                              = $item->total;

                        $owner_liable                       = $item->owner_liable;
                        $owner_total                        = $item->owner_total;

                        $driver_liable                      = $item->driver_liable;
                        $driver_total                       = $item->driver_total;

                        array_push($arry, $paid_type!=''?1:0);
                        array_push($arry, $reference!=''?1:0);
                        array_push($arry, $total!=''?1:0);
                        if($owner_liable=='1'){
                            array_push($arry, $owner_total!=''?1:0);
                        }
                        if($driver_liable=='1'){
                            array_push($arry, $driver_total!=''?1:0);
                        }

                        if(in_array(0, $arry)){
                            $status                         = 0; // Pending
                        }else{
                            if($item->doc_required=='1'){
                                if($item->is_received==1){
                                    $status                 = 1; // Completed
                                }else{
                                    $status                 = 0; // Pending
                                }
                            }else{
                                $status                     = 1; // Completed
                            }
                        }
                        $item->status                       = $status;
                        //

                        $item->updated_at                   = Carbon::now();
                        if($item->save()){
                            $response['html']               = view('companyAdmin.load.ajax.accessorial.list', compact('temp','item'))->render();
                            $response['success']            = true;
                            $response['message']            = "Save successfully";
                        }
                    }
                }
            }
        }
        return response()->json($response);
    }

    public function appointmentRequest(Request $request){
        $response['success']                                = false;
        $response['message']                                = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $appointment                                = LoadAppointment::whereId($request->id)->first();
                if(!is_null($appointment)){
                    $response['html']                       = view('companyAdmin.load.ajax.appointmentRequest', compact('appointment'))->render();
                    $response['success']                    = true;
                    $response['message']                    = "Appointment view retrieved successfully.";
                }
            }catch (\Exception $e) {
                $response['success']                        = false;
                $response['message']                        = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function appointmentSave(Request $request){
        $response['success']                                = false;
        $response['message']                                = "Oops! Something went wrong..";
        if($request->ajax()){
            if($request->has('id') && $request->id!==''){
                $item                                       = LoadAppointment::whereId($request->id)->first();
                if(!is_null($item)){
                    $oldData                                = $item->toArray();
                    // 0=Pending,1=Confirm,2=Reject,3=Amended
                    $latestLog                              = $item->logs()->latest()->first();
                    if($request->review_status == '0'){
                        // Request Again
                        $item->request_date                 = date('Y-m-d', strtotime($request->pen_req_date));
                        $item->request_time                 = date('H:i:s', strtotime($request->pen_req_time));
                    }elseif($request->review_status == '1'){
                        // Accept
                        $item->confirm_date                 = $latestLog->date;
                        $item->confirm_time                 = $latestLog->time;
                    }elseif($request->review_status == '2'){
                        // Reject
                    }
                    $item->status                           = $request->review_status;
                    $item->status_at                        = Carbon::now()->format('Y-m-d H:i:s');
                    $item->updated_at                       = Carbon::now()->format('Y-m-d H:i:s');
                    if($item->save()){
                        if($item->wasChanged()){
                            $this->setLoadAudit($item->load_detail->load_id, 'update', 'Load appointment updated', $item->getChanges(), $oldData);
                        }

                        $newRecord                          = $latestLog->replicate();
                        if($request->review_status == '0'){
                            // Request Again
                            $newRecord->date                = date('Y-m-d', strtotime($request->pen_req_date));
                            $newRecord->time                = date('H:i:s', strtotime($request->pen_req_time));
                            $newRecord->sender_id           = auth()->guard('company-admin')->user()->id;
                            $newRecord->sent_at             = Carbon::now()->format('Y-m-d H:i:s');
                        }
                        $newRecord->note                    = $request->pen_req_note;
                        $newRecord->source                  = 1;
                        $newRecord->reply_from              = auth()->guard('company-admin')->user()->email;
                        $newRecord->reply_at                = Carbon::now()->format('Y-m-d H:i:s');
                        $newRecord->ip_address              = $request->ip();
                        $newRecord->review_user_type        = 'Company Admin';
                        $newRecord->review_by               = auth()->guard('company-admin')->user()->id;
                        $newRecord->review_status           = $request->review_status;
                        $newRecord->review_at               = Carbon::now()->format('Y-m-d H:i:s');
                        $newRecord->created_at              = Carbon::now()->format('Y-m-d H:i:s');
                        $newRecord->updated_at              = Carbon::now()->format('Y-m-d H:i:s');
                        if($newRecord->save()){
                            if($newRecord->review_status == '0'){
                                appointmentRequestSend($item);
                            }
                            $response['appointment']        = $item;
                            $response['success']            = true;
                            $response['message']            = "Appointment review request submitted successfully.";
                        }else{
                            $response['success']            = false;
                            $response['message']            = "Oops! Something went wrong..";
                        }
                    }else{
                        $response['success']                = false;
                        $response['message']                = "Appointment review request submitted unsuccessfully.";
                    }
                }else{
                    $response['success']                    = false;
                    $response['message']                    = "Appointment record not found.";
                }
            }
        }
        return response()->json($response);
    }

    public function appointmentDelete(Request $request){
        $response['success']                                = false;
        $response['message']                                = "Oops! Something went wrong..";
        if($request->ajax()){
            $items                                          = LoadAppointment::whereIn('id', $request->appointment_ids)->get();
            if(!is_null($items)){
                foreach ($items as $key => $item) {
                    $oldData                                = $item->toArray();
                    if($item->delete()){
                        $this->setLoadAudit($request->load_id, 'delete', 'Load appointment deleted', $item->toArray(), $oldData);
                    }
                }
                $response['success']                        = true;
                $response['message']                        = "Appointments delete successfully.";
            }
        }
        return response()->json($response);
    }

    public function additionalStopDetails(Request $request){
        $response['success']                                            = false;
        $response['message']                                            = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                if(in_array($request->type, ['additional_details', 'required_documents'])){
                    if($request->is_stop == 1){
                        $item                                           = LoadStop::whereId($request->load_stop_id)->first();
                    }else{
                        $item                                           = LoadDetail::whereId($request->load_detail_id)->first();
                    }
                    if(isset($item)){
                        $formData                                       = $request->all();

                        $param                                          = [];
                        if($request->type == 'additional_details'){
                            $param['getTimeZone']                       = $this->timeZone;
                            $param['getTimeZoneId']                     = $this->timeZoneId;
                        }else{
                            $param['broker_shipper_files']              = [];
                            $param['broker_consignee_files']            = [];
                            if($request->is_stop == 1){
                                if(isset($item->loads->load_detail->broker->shipper_files) && !empty($item->loads->load_detail->broker->shipper_files)){
                                    $broker_shipper_files               = unserialize($item->loads->load_detail->broker->shipper_files);
                                    $broker_shipper_files               = array_filter($broker_shipper_files, function($var) {
                                        return isset($var['name_id']) && $var['name_id'] !== null;
                                    });
                                    $param['broker_shipper_files']      = $broker_shipper_files;
                                }
                                if(isset($item->loads->load_detail->broker->consignee_files) && !empty($item->loads->load_detail->broker->consignee_files)){
                                    $broker_consignee_files             = unserialize($item->loads->load_detail->broker->consignee_files);
                                    $broker_consignee_files             = array_filter($broker_consignee_files, function($var) {
                                        return isset($var['name_id']) && $var['name_id'] !== null;
                                    });
                                    $param['broker_consignee_files']    = $broker_consignee_files;
                                }
                            }else{
                                if(isset($item->broker->shipper_files) && !empty($item->broker->shipper_files)){
                                    $broker_shipper_files               = unserialize($item->broker->shipper_files);
                                    $broker_shipper_files               = array_filter($broker_shipper_files, function($var) {
                                        return isset($var['name_id']) && $var['name_id'] !== null;
                                    });
                                    $param['broker_shipper_files']      = $broker_shipper_files;
                                }
                                if(isset($item->broker->consignee_files) && !empty($item->broker->consignee_files)){
                                    $broker_consignee_files             = unserialize($item->broker->consignee_files);
                                    $broker_consignee_files             = array_filter($broker_consignee_files, function($var) {
                                        return isset($var['name_id']) && $var['name_id'] !== null;
                                    });
                                    $param['broker_consignee_files']    = $broker_consignee_files;
                                }
                            }
                        }

                        $response['html']                               = view('companyAdmin.load.ajax.view.additionalStopDetails', compact('formData','param','item'))->render();
                        $response['success']                            = true;
                        $response['message']                            = "Detail retrieved successfully.";
                    }
                }
            }catch (\Exception $e) {
                $response['success']                                    = false;
                $response['message']                                    = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function assetLocationHistory(Request $request){
        $response['success']                                            = false;
        $response['message']                                            = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                if(in_array($request->time, [15,10,5])){
                    $getTimeZone                                        = $this->timeZone;
                    $getTimeZoneId                                      = $this->timeZoneId;

                    $perPage                                            = 15; // Number of records per page
                    $page                                               = $request->has('page') && $request->page!='' ? $request->page : 1; // The page number you want to retrieve

                    if($request->time == 15){
                        DB::statement(DB::raw('set @rownum=0'));
                        $results                                        = DB::table(function ($query) use ($request){
                            $query->select('*')
                                ->from(function ($subquery) use ($request){
                                    $subquery->select(['*',DB::raw('@rownum  := @rownum  + 1 AS rownum')])
                                        ->from('vehicle_historical_stats')
                                        ->where('truck_id', $request->truck_id)
                                        ->latest();
                                })
                                ->whereRaw('rownum % 3 = 1');
                            })
                            ->offset(($page - 1) * $perPage) // Calculate the offset based on the page number
                            ->limit($perPage) // Limit the number of records per page
                            ->get();
                    }elseif($request->time == 10){
                        DB::statement(DB::raw('set @rownum=0'));
                        $results                                        = DB::table(function ($query) use ($request){
                            $query->select('*')
                                ->from(function ($subquery) use ($request){
                                    $subquery->select(['*',DB::raw('@rownum  := @rownum  + 1 AS rownum')])
                                        ->from('vehicle_historical_stats')
                                        ->where('truck_id', $request->truck_id)
                                        ->latest();
                                })
                                ->whereRaw('rownum % 2 = 0');
                            })
                            ->offset(($page - 1) * $perPage) // Calculate the offset based on the page number
                            ->limit($perPage) // Limit the number of records per page
                            ->get();
                    }else{
                        $results                                        = DB::table('vehicle_historical_stats')
                            ->where('truck_id', $request->truck_id)
                            ->latest()
                            ->offset(($page - 1) * $perPage) // Calculate the offset based on the page number
                            ->limit($perPage) // Limit the number of records per page
                            ->get();
                    }
                    $response['html']                                   = view('companyAdmin.load.ajax.view.assetLocationHistory', compact('getTimeZone','getTimeZoneId','results'))->render();
                    $response['hasMoreItems']                           = $results->count() > 0 ? true : false;
                    $response['success']                                = true;
                    $response['message']                                = "Asset location history retrieved successfully.";
                }
            }catch (\Exception $e) {
                $response['success']                                    = false;
                $response['message']                                    = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function reeferTemperatureHistory(Request $request){
        $response['success']                                            = false;
        $response['message']                                            = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $response['html']                                       = '
                    <tr>
                        <td class="text-center" colspan="9">No data available in table</td>
                    </tr>
                ';
                $response['success']                                    = true;
                $response['message']                                    = "Reefer temperature history retrieved successfully.";
            }catch (\Exception $e) {
                $response['success']                                    = false;
                $response['message']                                    = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function documentRequest(Request $request){
        $response['success']                   = false;
        $response['message']                   = "Oops! Something went wrong..";
        if($request->ajax()){
            try {
                $data                          = [];
                $formData                      = $request->all();
                if (array_key_exists('load_drivers_array', $formData)) {
                    unset($formData['load_drivers_array']);
                }
                if (array_key_exists('load_documents', $formData)) {
                    unset($formData['load_documents']);
                }
                $data['formData']              = $formData;
                $data['load_document_request'] = LoadDocumentRequest::query()
                    ->where('load_id', $request->load_id)
                    ->where('load_detail_id', $request->load_detail_id)
                    ->where('broker_id', $request->broker_id)
                    ->first();
                $data['load_drivers_array']    = ($request->has('load_drivers_array') && !empty($request->load_drivers_array))? $request->load_drivers_array : [];
                $data['load_stops_array']      = ($request->has('load_stops_array') && !empty($request->load_stops_array))? $request->load_stops_array : [];
                $data['load_documents']        = ($request->has('load_documents') && !empty($request->load_documents))? $request->load_documents : [];
                $response['html']              = view('companyAdmin.load.ajax.documentRequest', $data)->render();
                $response['success']           = true;
                $response['message']           = "Document request view retrieved successfully.";
            }catch (\Exception $e) {
                $response['success']           = false;
                $response['message']           = $e->getMessage();
            }
        }
        return response()->json($response);
    }

    public function documentSave(Request $request){
        $response['success']                                                        = false;
        $response['message']                                                        = "Oops! Something went wrong..";
        if($request->ajax()){
            $formData                                                               = $request->all();

            $params                                                                 = json_decode($formData['params'], true);
            $request_via                                                            = [];
            if(isset($formData['doc_req_email']) && $formData['doc_req_email'] == 'on'){
                $request_via[]                                                      = 1;
            }
            if(isset($formData['doc_req_sms']) && $formData['doc_req_sms'] == 'on'){
                $request_via[]                                                      = 2;
            }
            $request_send_contacts                                                  = !empty($request->request_send_contacts) ? serialize(array_values($request->request_send_contacts)) : null;

            if(isset($request->id) && $request->id!=''){
                $load_document_request                                              = LoadDocumentRequest::whereId($request->id)->first();
                if(!is_null($load_document_request)){
                    $oldData                                                        = $load_document_request->toArray();

                    $load_document_request->instructions                            = $formData['instructions'] ?? null;
                    $load_document_request->request_via                             = !empty($request_via) ? implode(',', $request_via) : null;
                    $load_document_request->request_send_contacts                   = $request_send_contacts;
                    $load_document_request->updated_at                              = Carbon::now()->format('Y-m-d H:i:s');
                    $load_document_request->updated_by                              = auth()->guard('company-admin')->user()->id;
                    $load_document_request->updated_by_type                         = auth()->guard('company-admin')->user()->type;
                    if($load_document_request->save()){
                        $this->setLoadAudit($load_document_request->load_id, 'update', 'Load document request updated', $load_document_request->getChanges(), $oldData);

                        $doc_req                                                    = isset($formData['doc_req'])?$formData['doc_req']:[];

                        $doc_req_old_id                                             = array_column($doc_req, 'item_id'); // old id
                        $doc_req_remove_query                                       = LoadDocumentRequestItem::where('load_document_request_id', $load_document_request->id);
                        if(!empty($doc_req_old_id)){
                            $doc_req_remove_query->whereNotIn('id', $doc_req_old_id);
                        }
                        $doc_req_remove_query_result                                = $doc_req_remove_query->get();

                        if(!empty($doc_req)){
                            foreach ($doc_req as $key => $value) {
                                $item_id                                            = $value['item_id'] ?? null;

                                $load_stops_array                                   = $params['load_stops_array'];
                                $searchkey                                          = array_search($value['stop_no'], array_column($params['load_stops_array'], 'stop_no'));

                                $filearry                                           = [];
                                $filearry['name_id']                                = $value['name_id'];
                                $filearry['name']                                   = isset($value['name']) ? $value['name'] : '';
                                $filearry['is_required']                            = 'on';
                                $filearry['type']                                   = $value['type'];
                                $filearry['fixed']                                  = 'no';
                                $filearry['include_w_billing']                      = isset($value['include_w_billing']) && $value['include_w_billing']=='yes' ? 'yes' : 'no';
                                $filearry['custom']                                 = 'no';
                                $filearry['is_received']                            = 'off';
                                $filearry['hide_from_driver']                       = 'no';
                                $filearry['file_not_provided']                      = 'off';
                                $filearry['file']                                   = null;

                                if(!is_null($item_id)){
                                    $item                                           = LoadDocumentRequestItem::where('id', $item_id)->first();
                                    if(!is_null($item)){
                                        $oldData                                    = $item->toArray();

                                        //
                                        if(isset($item->files) && is_serialized($item->files) && !empty(unserialize($item->files))){
                                            $getfilearry                            = unserialize($item->files);
                                            if(!empty($getfilearry)){
                                                $filearry['is_received']            = $getfilearry['is_received'] ?? 'off';
                                                $filearry['hide_from_driver']       = $getfilearry['hide_from_driver'] ?? 'no';
                                                $filearry['file_not_provided']      = $getfilearry['file_not_provided'] ?? 'off';
                                                if(isset($getfilearry['file']) && !empty($getfilearry['file'])){
                                                    $filearry['is_received']        = 'on';
                                                    $filearry['file']               = $getfilearry['file'];
                                                    $filearry['upload_user_type']   = $getfilearry['upload_user_type'];
                                                    $filearry['upload_by']          = $getfilearry['upload_by'];
                                                    $filearry['uploaded_at']        = $getfilearry['uploaded_at'];
                                                }
                                                if($filearry['type'] == 2){
                                                    if(isset($getfilearry['is_received']) && $getfilearry['is_received'] == 'on'){
                                                        $filearry['is_received']    = 'on';
                                                        if(isset($getfilearry['upload_user_type'])){
                                                            $filearry['upload_user_type']= $getfilearry['upload_user_type'];
                                                        }
                                                        if(isset($getfilearry['upload_by'])){
                                                            $filearry['upload_by']  = $getfilearry['upload_by'];
                                                        }
                                                        if(isset($getfilearry['uploaded_at'])){
                                                            $filearry['uploaded_at']= $getfilearry['uploaded_at'];
                                                        }
                                                    }
                                                }
                                            }
                                        }

                                        // edit doc
                                        $item->driver_id                            = $value['driver_id'];
                                        $item->load_stop_id                         = $load_stops_array[$searchkey]['load_stop_id'];
                                        $item->type                                 = $load_stops_array[$searchkey]['type'];
                                        $item->is_stop                              = $load_stops_array[$searchkey]['is_stop'];
                                        $item->files                                = serialize($filearry);
                                        $item->updated_at                           = Carbon::now()->format('Y-m-d H:i:s');
                                        $item->updated_by                           = auth()->guard('company-admin')->user()->id;
                                        $item->updated_by_type                      = auth()->guard('company-admin')->user()->type;
                                        if($item->save()){
                                            $this->setLoadAudit($item->load_id, 'update', 'Load document request item updated', $item->getChanges(), $oldData);
                                        }
                                    }else{
                                        // item not found
                                    }
                                }else{
                                    // new doc
                                    $item                                           = new LoadDocumentRequestItem();
                                    $item->load_document_request_id                 = $load_document_request->id;
                                    $item->load_id                                  = $load_document_request->load_id;
                                    $item->load_detail_id                           = $load_document_request->load_detail_id;
                                    $item->driver_id                                = $value['driver_id'];
                                    $item->load_stop_id                             = $load_stops_array[$searchkey]['load_stop_id'];
                                    $item->type                                     = $load_stops_array[$searchkey]['type'];
                                    $item->is_stop                                  = $load_stops_array[$searchkey]['is_stop'];
                                    $item->files                                    = serialize($filearry);
                                    $item->created_at                               = Carbon::now()->format('Y-m-d H:i:s');
                                    $item->created_by                               = auth()->guard('company-admin')->user()->id;
                                    $item->created_by_type                          = auth()->guard('company-admin')->user()->type;
                                    $item->save();
                                }
                            }
                        }

                        if($doc_req_remove_query_result->count() > 0){
                            foreach ($doc_req_remove_query_result as $remove) {
                                $oldData                                            = $remove->toArray();

                                $remove->deleted_by                                 = auth()->guard('company-admin')->user()->id;
                                $remove->deleted_by_type                            = auth()->guard('company-admin')->user()->type;
                                if($remove->save()){
                                    if($remove->delete()){
                                        $this->setLoadAudit($oldData['load_id'], 'delete', 'Load document request item deleted', $remove->toArray(), $oldData);
                                    }
                                }
                            }
                        }

                        $response['success']                                        = true;
                        $response['message']                                        = "Document request submitted successfully.";
                    }else{
                        $response['success']                                        = false;
                        $response['message']                                        = "Oops! Something went wrong..";
                    }
                }else{
                    $response['success']                                            = false;
                    $response['message']                                            = "Oops! Something went wrong..";
                }
            }else{
                $load_document_request                                              = new LoadDocumentRequest();
                $load_document_request->load_id                                     = $params['load_id'];
                $load_document_request->load_detail_id                              = $params['load_detail_id'] ?? null;
                $load_document_request->broker_id                                   = $params['broker_id'] ?? null;
                $load_document_request->instructions                                = $formData['instructions'] ?? null;
                $load_document_request->request_via                                 = !empty($request_via) ? implode(',', $request_via) : null;
                $load_document_request->request_send_contacts                       = $request_send_contacts;
                $load_document_request->created_at                                  = Carbon::now()->format('Y-m-d H:i:s');
                $load_document_request->created_by                                  = auth()->guard('company-admin')->user()->id;
                $load_document_request->created_by_type                             = auth()->guard('company-admin')->user()->type;
                if($load_document_request->save()){
                    $doc_req                                                        = isset($formData['doc_req'])?$formData['doc_req']:[];
                    if(!empty($doc_req)){
                        foreach ($doc_req as $key => $value) {
                            $load_stops_array                                       = $params['load_stops_array'];
                            $searchkey                                              = array_search($value['stop_no'], array_column($params['load_stops_array'], 'stop_no'));

                            $filearry                                               = [];
                            $filearry['name_id']                                    = $value['name_id'];
                            $filearry['name']                                       = isset($value['name']) ? $value['name'] : '';
                            $filearry['is_required']                                = 'on';
                            $filearry['type']                                       = $value['type'];
                            $filearry['fixed']                                      = 'no';
                            $filearry['include_w_billing']                          = isset($value['include_w_billing']) && $value['include_w_billing']=='yes' ? 'yes' : 'no';
                            $filearry['custom']                                     = 'no';
                            $filearry['is_received']                                = 'off';
                            $filearry['hide_from_driver']                           = 'no';
                            $filearry['file_not_provided']                          = 'off';
                            $filearry['file']                                       = null;

                            $item                                                   = new LoadDocumentRequestItem();
                            $item->load_document_request_id                         = $load_document_request->id;
                            $item->load_id                                          = $load_document_request->load_id;
                            $item->load_detail_id                                   = $load_document_request->load_detail_id;
                            $item->driver_id                                        = $value['driver_id'];
                            $item->load_stop_id                                     = $load_stops_array[$searchkey]['load_stop_id'];
                            $item->type                                             = $load_stops_array[$searchkey]['type'];
                            $item->is_stop                                          = $load_stops_array[$searchkey]['is_stop'];
                            $item->files                                            = serialize($filearry);
                            $item->created_at                                       = Carbon::now()->format('Y-m-d H:i:s');
                            $item->created_by                                       = auth()->guard('company-admin')->user()->id;
                            $item->created_by_type                                  = auth()->guard('company-admin')->user()->type;
                            $item->save();
                        }
                    }
                    $response['success']                                            = true;
                    $response['message']                                            = "Document request submitted successfully.";
                }else{
                    $response['success']                                            = false;
                    $response['message']                                            = "Oops! Something went wrong..";
                }
            }

            // send sms & email
            if(
                (isset($load_document_request->request_send_contacts) && is_serialized($load_document_request->request_send_contacts) && !empty(unserialize($load_document_request->request_send_contacts))) &&
                (isset($load_document_request->items) && $load_document_request->items->isNotEmpty())
            ){
                $contacts                                                           = unserialize($load_document_request->request_send_contacts);
                if(!empty($contacts)){
                    foreach ($contacts as $key => $contact) {
                        $driverRecords                                              = $load_document_request->items->where('driver_id', $contact['driver_id']);
                        if(isset($driverRecords) && $driverRecords->isNotEmpty()){
                            $load_detail                                            = $load_document_request->load_detail ?? null;
                            if(!is_null($load_detail)){
                                $driverFullName                                     = '';
                                $getDriver                                          = $driverRecords->first();
                                if(!is_null($getDriver)){
                                    $driverFullName                                 = isset($getDriver->driver) ? $getDriver->driver->full_name : '';
                                }

                                $details                                            = [];
                                $details['company_id']                              = auth()->guard('company-admin')->user()->company_id;
                                $details['full_name']                               = $driverFullName;
                                $details['load_id']                                 = $load_detail->load_id;
                                $details['load_detail_id']                          = $load_detail->id;
                                $details['load_number']                             = $load_detail->load_type == 0 || $load_detail->load_type == 6 ? $load_detail->load_number : getLoadTypeList()[$load_detail->load_type];

                                $documents                                          = [];
                                foreach ($driverRecords as $key => $item) {
                                    $estop_no                                       = '';
                                    $searchResults                                  = array_filter($params['load_stops_array'], function($var) use ($item){
                                        return (
                                            $var['type'] == $item->type &&
                                            $var['is_stop'] == $item->is_stop &&
                                            $var['load_stop_id'] == $item->load_stop_id
                                        );
                                    });
                                    if(!empty($searchResults)){
                                        $firstMatchingItem                          = reset($searchResults); // Get the first element of the filtered array
                                        $estop_no                                   = $firstMatchingItem['stop_no'] ?? '';
                                    }

                                    $files                                          = [];
                                    if(isset($item->files) && is_serialized($item->files) && !empty(unserialize($item->files))){
                                        $files                                      = unserialize($item->files);
                                    }

                                    $stop_name                                      = 'Stop '.$estop_no;
                                    if(isset($files['name_id']) && $files['name_id']!=''){
                                        if($files['name_id'] == 0){
                                            if(isset($files['name']) && $files['name']!=''){
                                                $stop_name                          .= ' - '.$files['name']. ' ( Other )';
                                            }else{
                                                $stop_name                          .= 'Other';
                                            }
                                        }else{
                                            $stop_name                              .= $files['name'] ? ' - '.$files['name']: '';
                                        }
                                    }
                                    $documents[]                                    = $stop_name;
                                }

                                $details['documents']                               = $documents;

                                // send Mail
                                if(isset($contact['email']) && $contact['email']!=''){
                                    /*
                                    try {
                                        //Mail::to($contact['email'])->queue(new \App\Mail\LoadDocumentRequestDriver($details));
                                        Mail::to($contact['email'])->send(new \App\Mail\LoadDocumentRequestDriver($details));
                                    } catch (\Swift_TransportException $e) {
                                        // Log the error message
                                        Log::error('Email sending failed: ' . $e->getMessage());
                                    } catch (\Exception $e) {
                                        // Log the error message
                                        Log::error('An error occurred while sending the email: ' . $e->getMessage());
                                    }
                                    */

                                    sendEmail($contact['email'], new \App\Mail\LoadDocumentRequestDriver($details));
                                }

                                // send Sms
                                if(isset($contact['phone']) && $contact['phone']!=''){
                                    // Twilio's credentials are fetched from company table
                                    $getCompanyTwilioData                           = getCompanyTwilioData();
                                    if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
                                        sendSMS($contact['phone'], 'A document request has been added to load number: '.$details['load_number'].'. Documents requested are: '.implode(', ', $details['documents']).'. Please upload these documents to the load. '.route('driver.admin.loads.show', base64Encode($details['load_detail_id'])), $getCompanyTwilioData);
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
        return response()->json($response);
    }

    public function getTrimbleData(Request $request){
        /** get request */
        $this->request          = $request;

        /** get Miles data */
        $getMilesData           = $this->getMilesData();

        /** get TurnBy direction data */
        $geTurnByData           = $this->geTurnByData();

        /** Render html for mileage and turn by directions */
        $data['mileage_html']   = view('companyAdmin.load.ajax.millage_load',$getMilesData)->render();
        $data['turn_by_html']   = view('companyAdmin.load.ajax.turn_by_load',$geTurnByData)->render();

        /** return json response */
        return response()->json($data);
    }

    public function updateLoadTrip(Request $request){
        $loadDetails                    = LoadDetail::where('load_id', $request->load_id)->latest()->first();
        if(!is_null($loadDetails)){
            $oldData                    = $loadDetails->toArray();
            $loadDetails->load_trip_id  = $request->load_trip_id;
            $loadDetails->save();
            $this->setLoadAudit($loadDetails->load_id, 'update', 'Load detail updated', $loadDetails->getChanges(), $oldData);
        }
        return response()->json(['status' => 'updated']);
    }

    public function AuditLoad(Request $request){
        $getField               = '';
        $getCompanyAdmin        = auth()->guard('company-admin')->user();
        $isCheck                = Bookmark::where('company_id',getUserCompnayId())
            ->where('user_id',$getCompanyAdmin->id)
            ->where('user_type',$getCompanyAdmin->type)
            ->where('table_id','table_audit_load')->first();

        if(!empty($isCheck->id)){
            //$getField           = unserialize($isCheck->config);
            $getField           = adjustTableColumnsSorting(unserialize($isCheck->config), config('settings.table_audit_load_first'));
        }else{
            $getField           = config('settings.table_audit_load_first');
        }

        if ($request->ajax()) {
            $data               = LoadAudit::select(
                    "load_audits.*",
                    DB::raw("CONCAT(company_admins.first_name,' ',company_admins.last_name) as company_admin_name"),
                    DB::raw("CONCAT(drivers.first_name,' ',drivers.last_name) as driver_name"),
                    "brokers.name as broker_name"
                )
                ->leftJoin('company_admins', function($join) {
                    $join->on('load_audits.user_id', '=', 'company_admins.id')
                        ->where('load_audits.user_type', '=', 'Company Admin');
                })
                ->leftJoin('drivers', function($join) {
                    $join->on('load_audits.user_id', '=', 'drivers.id')
                        ->where('load_audits.user_type', '=', 'Driver');
                })
                ->leftJoin('brokers', function($join) {
                    $join->on('load_audits.user_id', '=', 'brokers.id')
                        ->where('load_audits.user_type', '=', 'Broker');
                })
                ->where('load_audits.load_id', $request->load_id)
                ->get();
            return Datatables::of($data)
                ->addIndexColumn()
                ->editColumn('created_at', function($row){
                    if(auth()->guard('company-admin')->user()->time_format=='12'){
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.12_hour','m/d/Y h:i A'))." ".$this->timeZoneId : '';
                    }else{
                        return !is_null($row->created_at) ? Carbon::parse($row->created_at)->format(config('settings.date_time_format.24_hour','m/d/Y H:i'))." ".$this->timeZoneId : '';
                    }
                })
                ->editColumn('first_name', function($row){
                    $name       = '';
                    if($row->user_type=='Company Admin'){
                        $name   = $row->company_admin_name;
                    }elseif($row->user_type=='Driver'){
                        $name   = $row->driver_name;
                    }elseif($row->user_type=='Broker'){
                        $name   = $row->broker_name;
                    }
                    return $name;
                })
                ->editColumn('before_change', function($row){
                    // return '';
                    if(!empty($row->before_change)){
                        $decode                 = unserialize($row->before_change);
                        $html                   = "";
                        if(!empty($decode) && count($decode) > 0){
                            foreach($decode as $key=> $d){
                                if($key!="updated_at"){
                                    if(is_serialized($d)){
                                        $data2  = '';
                                        $data2  = unserialize($d);
                                        $data2  = print_r($data2,true);
                                        $html  .= "<div class='befcode'>".$key.' :- ';
                                        $html  .= '<button type="button" data-toggle="collapse" class="btn btn-success ml-2 mr-2" data-target="#demo'.$row->id.'"><i class="fa fa-eye"></i></button>';
                                        $html  .= '<div id="demo'.$row->id.'" class="collapse"><pre>'.$data2."</pre></div></div>";
                                    }else{
                                        $data2  = $d;
                                        $html  .= "<div>".$key.' :- '.$d."</div>";
                                    }
                                }
                            }
                        }
                        return $html;
                    }else{
                        return "";
                    }
                })
                ->editColumn('after_change', function($row){
                    // return '';
                    if(!empty($row->after_change)){
                        $decode                 = unserialize($row->after_change);
                        $html                   = '';
                        if(!empty($decode) && count($decode) > 0){
                            foreach($decode as $key=> $d){
                                if($key!="updated_at"){
                                    if(is_serialized($d)){
                                        $data2  = '';
                                        $data2  = unserialize($d);
                                        $data2  = print_r($data2,true);
                                    // $html   .= "<div class='aftcode'>".$key.' :- <pre>'.$data2."</pre></div>";
                                        $html  .= "<div class='aftcode'>".$key.' :- ';
                                        $html  .= '<button type="button" data-toggle="collapse" class="btn btn-success ml-2 mr-2" data-target="#demo'.$row->id.'"><i class="fa fa-eye"></i></button>';
                                        $html  .= '<div id="demo'.$row->id.'" class="collapse"><pre>'.$data2."</pre></div></div>";
                                    }else{
                                        $data2  = $d;
                                        $html  .= "<div>".$key.' :- '.$d."</div>";
                                    }
                                }
                            }
                        }
                        return $html;
                    }else{
                        return "";
                    }
                })
                ->escapeColumns([])
                ->rawColumns(['before_change','after_change'])
                ->make(true);
        }
    }
}
