<?php

namespace App\Http\Controllers\DriverAdmin;

use App\Http\Controllers\DriverAdmin\DriverAdminController;

use Illuminate\Support\Facades\Storage;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

use App\Models\Load;
use App\Models\LoadStop;
use App\Models\LoadFile;
use App\Models\LoadDetail;
use App\Models\LoadReject;
use App\Models\LoadDetention;
use App\Models\LoadStopReview;
use App\Models\LoadAccessorial;
use App\Models\LoadDocumentRequestItem;

use App\Models\Truck;
use App\Models\Broker;

use App\Models\Gallery;
use App\Models\FileUpload;
use App\Models\IntegrationSetting;
use App\Models\CompanyLoadDocument;

use App\Mail\DetentionRequestBroker;
use App\Mail\CompanyAdmin\UnreadNotificationMailToUser;

use App\Helpers\Common;
use App\Traits\AuditLoagTrait;

use DB;
use Mail;
use File;
use DataTables;
use Carbon\Carbon;

use Imagick;
use Intervention\Image\Facades\Image;

class MyTripController extends DriverAdminController{

	use AuditLoagTrait;

	public $timeZone;
	public $timeZoneId;
	public $offset;

	// if change file upload logic than must check getLoadDocuments & historicDispatchDetail & historicFileSave & historicFileRemove & carousel_content & currentFileSave & currentFileRemove & additionalFileSave & departDetail - means file related all file check

	public function __construct(){
	    parent::__construct();

	    $this->middleware(function ($request, $next) {
	        $this->timeZone     	= getTimeZone();
	        $this->timeZoneId   	= getTimeZoneId();
	        $this->offset       	= getTimeZoneOffset();

	        $this->getGeoTimeZone  	= getGeoTimeZone();

	        return $next($request);
	    });
	}

	public function index(Request $request){
		// return view('driverAdmin.mytrips.demo.index');

		// Current Dispatch retrieved
		$current_dispatch 			= LoadDetail::query();
		$current_dispatch->where('load_details.driver_id', auth()->guard('driver-admin')->user()->id);
		$current_dispatch->where( function($query) {
		    $query->whereIn('load_details.load_status', [4]) // 4 = In Transit
		    	->where('load_details.load_type', 0) // 0 = OCCUPIED
		    	->where('load_details.dispatched', 1) // 1 = Dispatched
		    	->whereNotNull('load_details.dispatched_date_time') // Dispatched date time
		    	->where('load_details.is_disable', 0)
		    	->where(function($q) {
		    	    $q->whereNull('load_details.is_on_hold')->orWhereIn('load_details.is_on_hold', [0, 1]);
		    	});
		});
		$current_dispatch->orderBy('load_details.load_status')->orderBy('load_details.actual_shipper_date');
		$current_dispatch_exists 	= $current_dispatch->exists() ? 1 : 0;

		$getCompanyLoadDocument 	= CompanyLoadDocument::where('company_id', auth()->guard('driver-admin')->user()->company_id)->get();
		// return view('driverAdmin.mytrips.index', compact('current_dispatch_exists', 'getCompanyLoadDocument'));
		return view('driverAdmin.mytrips.index-new', compact('current_dispatch_exists', 'getCompanyLoadDocument'));
	}

	public function upcomingDispatch(Request $request){
		if ($request->ajax()) {
			$query 					= LoadDetail::query();
			$query->where('load_details.driver_id', auth()->guard('driver-admin')->user()->id);
			$query->where( function($q) {
			    $q->whereIn('load_details.load_status', [11, 3]) // 11 = Send To Driver, 3 = Confirmed
			    	->where('load_details.load_type', 0) // 0 = OCCUPIED
			    	->where('load_details.is_disable', 0)
			    	->where('load_details.send_notification', 1)
			    	->where(function($q) {
			    	    $q->whereNull('load_details.is_on_hold')->orWhereIn('load_details.is_on_hold', [0, 1]);
			    	});
			});
			$query->orderBy('load_details.load_status')->orderBy('load_details.actual_shipper_date');
			return Datatables::eloquent($query)
			    ->addIndexColumn()
			    ->addColumn('action', function($row){
			        return '<a href="javascript:void(0);" data-driver_read_at="'.$row->driver_read_at.'"><i class="fa fa-angle-right" aria-hidden="true"></i></a>';
			    })
			    ->addColumn('dispatch_now', function($row){
		    		if($row->load_status == 11){
		    			return '<a href="javascript:void(0);" class="btn btn-grey">View Details</a>';
		    		}else{
		    			return '<a href="javascript:void(0);" class="btn btn-grey">Dispatch Now</a>';
		    		}
			    })
			    ->editColumn('load_status', function($row){
			    	if($row->is_on_hold == 1){
	    				return '<div class="d-inline-block text-dark-grey align-items-center">
	    		    		<img src="'.asset('theme/images/red-circle-icon.svg').'" alt="Comment" class="mr-1 status-img"> On Hold
	    		    	</div>';
			    	}else{
				    	if($row->load_status == 11){
			    			return '<div class="d-inline-block text-dark-grey align-items-center">
	    			    		<img src="'.asset('theme/images/yellow-circle-icon.svg').'" alt="Comment" class="mr-1 status-img"> Send To Driver
	    			    	</div>';
				    	}else{
				    		return '<div class="d-inline-block text-dark-grey align-items-center">
				        		<img src="'.asset('theme/images/green-circle-icon.svg').'" alt="Comment" class="mr-1 status-img"> Confirmed
				        	</div>';
				    	}
			    	}
			    })
			    ->editColumn('load_number', function($row){
			    	return '<a href="javascript:void(0);" class="text-dark-blue">'.$row->load_number.'</a>';
			    })
			    ->editColumn('agreed_upon_rate', function($row){
			        return getPrice($row->agreed_upon_rate);
			    })
			    ->addColumn('cpm', function($row){
			    	$cpm 			= 0.00;
			    	if($row->agreed_upon_rate > 0 && $row->total_miles > 0){
			    		$cpm 		= round($row->agreed_upon_rate / $row->total_miles, 2);
			    	}
			    	return getPrice($cpm);
			    })
			    ->editColumn('actual_shipper_date', function($row){
			        return !is_null($row->actual_shipper_date) ? $row->actual_shipper_date.' '.$row->shipper_timezone_abbr : '';
			    })
			    ->editColumn('actual_delivery_date', function($row){
			        return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date.' '.$row->delivery_timezone_abbr : '';
			    })
			    ->editColumn('shipper_location', function($row){
			        $html 			= [];
			        if($row->shipper_address_one){
			            $html[0]    = $row->shipper_address_one;
			        }
			        if($row->shipper_address_two){
			            $html[1]    = $row->shipper_address_two;
			        }
			        if($row->shipper_city){
			            $html[2]    = $row->shipper_city;
			        }
			        if($row->shipper_state){
			            $html[3]    = $row->shipper_state;
			        }
			        if($row->shipper_zip){
			            $html[4]    = $row->shipper_zip;
			        }
			        if(count($html) == 0){
			            return $row->shipper_location;
			        }else{
			            return implode(', ', $html);
			        }
			    })
			    ->editColumn('delivery_location', function($row){
			        $html           = [];
			        if($row->delivery_address_one){
			            $html[0]    = $row->delivery_address_one;
			        }
			        if($row->delivery_address_two){
			            $html[1]    = $row->delivery_address_two;
			        }
			        if($row->delivery_city){
			            $html[2]    = $row->delivery_city;
			        }
			        if($row->delivery_state){
			            $html[3]    = $row->delivery_state;
			        }
			        if($row->delivery_zip){
			            $html[4]    = $row->delivery_zip;
			        }
			        if(count($html) == 0){
			            return $row->delivery_location;
			        }else{
			            return implode(', ', $html);
			        }
			    })
			    ->editColumn('trailer_number', function($row){
			    	if(isset($row->loads->load_trailers) && $row->loads->load_trailers->isNotEmpty()){
			    		$trailers 	= [];
			    		$trailers[] = $row->trailer_number;

			    		$extra 		= $row->loads->load_trailers->pluck('trailer_number')->toArray();
			    		$trailers 	= array_merge($trailers, $extra);
			    		if(count($trailers) > 1){
			    			$html 	= '<ul>';
			    			foreach ($trailers as $key => $value) {
			    				$html .= '<li>'.$value.'</li>';
			    			}
			    			$html 	.= '</ul>';
			    			return '<a href="javascript:void(0);" class="text-dark multiple-trailers">'.count($trailers).' Trailers</a>
			    				<div class="trailer-tooltip d-none">'.$html.'</div>
			    			';
			    		}else{
			    			return $trailers[0];
			    		}
			    	}else{
			    		return $row->trailer_number;
			    	}
			    })
			    ->rawColumns(['action','dispatch_now','load_status','load_number','trailer_number'])
			    ->make(true);
		}
	}

	public function upcomingDispatchRead(Request $request){
		$response['success']             	= false;
		$response['message']             	= "Oops! Something went wrong..";
		if ($request->ajax()) {
		    try {
		    	$query 						= LoadDetail::query();
		    	$query->where('load_details.driver_id', auth()->guard('driver-admin')->user()->id);
		    	$query->where( function($q) {
		    	    $q->whereIn('load_details.load_status', [11, 3]) // 11 = Send To Driver, 3 = Confirmed
		    	    	->where('load_details.load_type', 0) // 0 = OCCUPIED
		    	    	->where('load_details.is_disable', 0)
		    	    	->where('load_details.send_notification', 1)
		    	    	->whereNull('load_details.driver_read_at') // Driver Not read
		    	    	->where(function($q) {
		    	    	    $q->whereNull('load_details.is_on_hold')->orWhereIn('load_details.is_on_hold', [0, 1]);
		    	    	});
		    	});
		    	$query->orderBy('load_details.load_status')->orderBy('load_details.actual_shipper_date');
		    	$records 					= $query->get();
		    	if($records->isNotEmpty()){
		    		foreach ($records as $key => $item) {
		    			$oldData 			= $item->toArray();
		    			$item->driver_read_at = date('Y-m-d H:i:s');
		    			$item->updated_at   = date('Y-m-d H:i:s');
		    			if($item->save()){
		    				$this->setLoadAudit($item->load_id, 'update', 'Load detail updated', $item->getChanges(), $oldData);
		    			}
		    		}
		    	}
		    	$response['success']     	= true;
		    	$response['message']     	= "Upcoming load detail read successfully.";
		    } catch (\Exception $e) {
		        $response['success']      	= false;
		        $response['message']   		= $e->getMessage();
		    }
		}
		return response()->json($response);
	}

	public function upcomingDispatchDetail(Request $request){
		$response['success']             	= false;
		$response['message']             	= "Oops! Something went wrong..";
		if($request->ajax()){
			try {
				$formdata                   = $request->all();
				$load_detail 				= LoadDetail::whereId($formdata['id'])->first();
				if(!is_null($load_detail)){
					// $response['html']   	= view('driverAdmin.mytrips.ajax.upcoming_dispatch.detail', compact('formdata','load_detail'))->render();
					$response['html']   	= view('driverAdmin.mytrips.ajax.upcoming_dispatch.detail-new', compact('formdata','load_detail'))->render();
					$response['success']  	= true;
					$response['message']  	= "Detail retrieved successfully.";
				}
			} catch (\Exception $e) {
			    $response['success']     	= false;
			    $response['message']     	= $e->getMessage();
			}
		}
		return response()->json($response);
	}

	public function dispatchNowDetail(Request $request){
		$response['success']             	= false;
		$response['message']             	= "Oops! Something went wrong..";
		if($request->ajax()){
			try {
				$formdata                   = $request->all();
				$load_detail 				= LoadDetail::whereId($formdata['id'])->first();
				if(!is_null($load_detail)){
					$response['html']   	= view('driverAdmin.mytrips.ajax.upcoming_dispatch.dispatch_now.detail', compact('formdata','load_detail'))->render();
					$response['success']  	= true;
					$response['message']  	= "Detail retrieved successfully.";
				}
			} catch (\Exception $e) {
			    $response['success']     	= false;
			    $response['message']     	= $e->getMessage();
			}
		}
		return response()->json($response);
	}

	public function dispatchRequirementsDetail(Request $request){
		$response['success']             	= false;
		$response['message']             	= "Oops! Something went wrong..";
		if($request->ajax()){
			try {
				$formdata                   = $request->all();
				$load_detail 				= LoadDetail::whereId($formdata['id'])->first();
				if(!is_null($load_detail)){
					$response['html']   	= view('driverAdmin.mytrips.ajax.upcoming_dispatch.dispatch_now.load_requirements', compact('formdata','load_detail'))->render();
					$response['success']  	= true;
					$response['message']  	= "Detail retrieved successfully.";
				}
			} catch (\Exception $e) {
			    $response['success']     	= false;
			    $response['message']     	= $e->getMessage();
			}
		}
		return response()->json($response);
	}

	public function changeStatus(Request $request){
		$response['success']             									= false;
		$response['message']             									= "Oops! Something went wrong..";
		if ($request->ajax()) {
		    try {
		    	$item                                    					= LoadDetail::where('id', $request->id)->first();
		    	if(!is_null($item)){
		    		$oldData                                        		= $item->toArray();

		    		// Change status not load stop only load detail for functionality
		    		// 1 = Preplaned Driver Acknowledgement, 2 = Confirmed Driver Acknowledgement, 3 = Intransit Driver Acknowledgement, 4 = Delivered Driver Acknowledgement
		    		// 0 = Pending', 1 = Accepted, 2 = Preplaned, 11 = Send To Driver, 3 = Confirmed, 4 = In Transit, 5 = Delivered, 7 = Ready to Bill, 10 = Invoiced, 8 = Paid
		    		// 1 = On Hold, 2 = Cancelled, 3 = Drooped
		    	    $item->load_status                   					= $request->status;
		    	    $item->load_status_order                				= Common::getLoadStatusOrderById( $request->status );
		    	    if($request->type==2){
		    	    	// Type = 2 Reject case
		    	    	if($request->acknowledgement == 1){
		    	    		// 1 = Preplaned Driver Acknowledgement
		    	    		$item->preplaned_driver_acknowledgement 		= 2; // 2 = Rejected
		    	    	}else if ($request->acknowledgement == 2) {
		    	    		// 2 = Confirmed Driver Acknowledgement
		    	    		$item->confirmed_driver_acknowledgement 		= 2; // 2 = Rejected
		    	    	}else if ($request->acknowledgement == 3) {
		    	    		// 3 = Intransit Driver Acknowledgement
		    	    		$item->intransit_driver_acknowledgement 		= 2; // 2 = Rejected
		    	    	}
		    	        $item->is_on_hold               					= 1;
		    	        $item->notification_reason      					= 5; // 0 = Lumper, 1 = BOL, 2 = Detention, 3 = Claim : OSD, 4 = Credit, 5 = Driver Rejected
		    	        $item->reason_on_hold           					= $request->reason;
		    	        LoadReject::create([
		    	            'load_id'   => $item->load_id,
		    	            'driver_id' => auth()->guard('driver-admin')->user()->id,
		    	            'reason'    => $request->reason,
		    	            'date_time' => date('Y-m-d H:i:s')
		    	        ]);
		    	    }elseif($request->type==1){
		    	    	// Type = 1 Confirm case
		    	    	if($request->acknowledgement == 1){
		    	    		// 1 = Preplaned Driver Acknowledgement
		    	    		$item->preplaned_driver_acknowledgement 		= 1; // 1 = Accepted
		    	    	}else if ($request->acknowledgement == 2) {
		    	    		// 2 = Confirmed Driver Acknowledgement
		    	    		$item->confirmed_driver_acknowledgement 		= 1; // 1 = Picked Up
		    	    	}else if ($request->acknowledgement == 3) {
		    	    		// 3 = Intransit Driver Acknowledgement
		    	    		$item->intransit_driver_acknowledgement 		= 1; // 1 = Delivered
		    	    	}
		    	    	if($request->status == 3){
		    	    		$item->loaded                   				= 1; // Confirmed
		    	    	}else if($request->status == 4){
		    	    		$item->dispatched                   			= 1; // Dispatch Now
		    	    		$item->dispatched_date_time                   	= date('Y-m-d H:i:s');
		    	    	}
		    	    }
		    	    $item->updated_at                						= date('Y-m-d H:i:s');
		    	    if($item->save()){
		    	    	$this->setLoadAudit($item->load_id, 'update', 'Load detail updated', $item->getChanges(), $oldData);
		    	        createLoadLog($item->getChanges(), $item, 'edit');

		    	        $response['success']              					= true;
		    	        $response['message']              					= "Status has been changed successfully.";
		    	    }else{
		    	        $response['success']              					= false;
		    	        $response['message']              					= "Status has been changed unsuccessfully.";
		    	    }
		    	}else{
		    	    $response['success']                  					= false;
		    	    $response['message']                  					= "Oops! Something went wrong..";
		    	}
		    } catch (\Exception $e) {
		        $response['success']                   						= false;
		        $response['message']                						= $e->getMessage();
		    }
		}
		return response()->json($response);
	}

	public function currentDispatchDetail(Request $request){
		$response['success']             									= false;
		$response['message']             									= "Oops! Something went wrong..";
		if($request->ajax()){
			try {
				// Current Dispatch retrieved
				$current_dispatch 											= LoadDetail::query();
				$current_dispatch->where('load_details.driver_id', auth()->guard('driver-admin')->user()->id);
				$current_dispatch->where( function($query) {
				    $query->whereIn('load_details.load_status', [4]) // 4 = In Transit
				    	->where('load_details.load_type', 0) // 0 = OCCUPIED
				    	->where('load_details.dispatched', 1) // 1 = Dispatched
				    	->whereNotNull('load_details.dispatched_date_time') // Dispatched date time
				    	->where('load_details.is_disable', 0)
				    	->where(function($q) {
				    	    $q->whereNull('load_details.is_on_hold')->orWhereIn('load_details.is_on_hold', [0, 1]);
				    	});
				});
				$current_dispatch->orderBy('load_details.load_status')->orderBy('load_details.actual_shipper_date');
				$load_detail 												= $current_dispatch->first();
				if(!is_null($load_detail)){
					$stopStatusArry 										= $this->getStopStatusArry($load_detail);
					$truckStopArry 											= $this->getTruckStopArry($stopStatusArry);

					$getTimeZone                                            = $this->timeZone;
					$getTimeZoneId                                          = $this->timeZoneId;

					$getGeoTimeZone             							= $this->getGeoTimeZone;

					$typeUserId 											= '3_'.auth()->guard('driver-admin')->user()->id;

					$response['data'] 										= [
						'truckStopArry' 									=> $truckStopArry
					];
					$response['html']   									= view('driverAdmin.mytrips.ajax.current_dispatch.detail', compact('load_detail','stopStatusArry','truckStopArry','getTimeZone','getTimeZoneId','getGeoTimeZone','typeUserId'))->render();
					$response['success']  									= true;
					$response['message']  									= "Detail retrieved successfully.";
				}else{
					$response['html']   									= '<div class="padd-custome">
                        <p class="nodata-txt">No dispatch listed. Review upcoming dispatch tab.</p>
                    </div>';
					$response['success']  									= true;
					$response['message']  									= "No dispatch listed. Review upcoming dispatch tab.";
				}
			} catch (\Exception $e) {
			    $response['success']     									= false;
			    $response['message']     									= $e->getMessage();
			}
		}
		return response()->json($response);
	}

	public function currentDispatchCompletedMiles(Request $request){
		$response['success']             									= false;
		$response['message']             									= "Oops! Something went wrong..";
		if($request->ajax()){
			try {
				$load_detail 												= LoadDetail::whereId($request->id)->first();
				if(!is_null($load_detail)){
					$itemize                   								= $load_detail->itemize ?? 0;

					$truck                      							= $load_detail->truck ?? null;
					$truck_length               							= $truck->length ?? null;
					$truck_width                							= $truck->width ?? null;
					$truck_height               							= $truck->height ?? null;
					$truck_weight                  							= 0;
					if($itemize == 1){
					    $truck_weight           							+= $load_detail->shipper_stop_weight ?? 0;
					    if(isset($load_detail->loads->load_stops)){
					    	$truck_weight         							+= $load_detail->loads->load_stops()->where('customer_type', 1)->sum('stop_weight');
					    }
					}else{
					    $truck_weight           							= $load_detail->weight ?? 0;
					}

					$trimbleMapParams                                      	= [];
					$trimbleMapParams['map_toll_roads']                    	= $load_detail->map_toll_roads;
					$trimbleMapParams['map_max_elevation']                 	= $load_detail->map_max_elevation;
					$trimbleMapParams['map_close_borders']                 	= $load_detail->map_close_borders;
					$trimbleMapParams['hazardous_load']                    	= $load_detail->hazardous_load;
					$trimbleMapParams['hazardous_options']                 	= $load_detail->hazardous_options;
					$trimbleMapParams['truck_length']                      	= $truck_length;
					$trimbleMapParams['truck_width']                       	= $truck_width;
					$trimbleMapParams['truck_height']                      	= $truck_height;
					$trimbleMapParams['truck_weight']                      	= $truck_weight > 0 ? $truck_weight : null;

					$mileageCoords        									= [];
					$currentLocation      									= [];
					if(isset($truck)){
						$currentLocation          							= truckCurrentLocation($truck);
					}
					$deadheadLocation                                   	= [];
					if(isset($load_detail->deadhead_mileage_options)){
					    $deadheadLocation                               	= json_decode($load_detail->deadhead_mileage_options, true);
					}elseif((isset($load_detail->shipper_latitude) && $load_detail->shipper_latitude!='') && (isset($load_detail->shipper_longitude) && $load_detail->shipper_longitude!='')){
					    $deadheadLocation['latitude']                   	= $load_detail->shipper_latitude;
					    $deadheadLocation['longitude']                  	= $load_detail->shipper_longitude;
					    $deadheadLocation['city']                       	= $load_detail->shipper_city;
					    $deadheadLocation['state']                      	= $load_detail->shipper_state;
					    $deadheadLocation['zip']                        	= $load_detail->shipper_zip;
					}
					if(!empty($deadheadLocation)){
					    $mileageCoords['deadheadLocation']              	= $deadheadLocation;
					    $mileageCoords['currentLocation']               	= $currentLocation;
					}

					$response['data'] 										= [
						'trimbleMapParams' 									=> $trimbleMapParams,
						'mileageCoords' 									=> $mileageCoords
					];
					$response['success']  									= true;
					$response['message']  									= "Detail retrieved successfully.";
				}
			} catch (\Exception $e) {
			    $response['success']     									= false;
			    $response['message']     									= $e->getMessage();
			}
		}
		return response()->json($response);
	}

	public function carouselContent(Request $request){
		$response['success']             									= false;
		$response['message']             									= "Oops! Something went wrong..";
		if($request->ajax()){
			try {
				$load_detail 												= LoadDetail::whereId($request->id)->first();
				if(!is_null($load_detail)){
					$stopStatusArry 										= $this->getStopStatusArry($load_detail);
					$truckStopArry 											= $this->getTruckStopArry($stopStatusArry);

					$getTimeZone                                            = $this->timeZone;
					$getTimeZoneId                                          = $this->timeZoneId;

					$getGeoTimeZone             							= $this->getGeoTimeZone;

					$typeUserId 											= '3_'.auth()->guard('driver-admin')->user()->id;

					$response['data'] 										= [
						'truckStopArry' 									=> $truckStopArry
					];
					$response['html']   									= view('driverAdmin.mytrips.ajax.current_dispatch.carousel_content', compact('load_detail','stopStatusArry','truckStopArry','getTimeZone','getTimeZoneId','getGeoTimeZone','typeUserId'))->render();
					$response['success']  									= true;
					$response['message']  									= "Detail retrieved successfully.";
				}
			} catch (\Exception $e) {
			    $response['success']     									= false;
			    $response['message']     									= $e->getMessage();
			}
		}
		return response()->json($response);
	}

	public function getStopStatusArry($load_detail){
		$index                                  	= 0;
		$stop_no                                	= 1;

		$array                                  	= [];

		$status                                 	= 'Pending';
		if((isset($load_detail->shipper_is_arrived) && $load_detail->shipper_is_arrived == 1) && (isset($load_detail->shipper_arrived_at) && $load_detail->shipper_arrived_at != '')){
		    if((isset($load_detail->shipper_is_leaves) && $load_detail->shipper_is_leaves == 1) && (isset($load_detail->shipper_leaves_at) && $load_detail->shipper_leaves_at != '')){
		        // Click on leave button
		        $status                     		= 'Picked Up';
		    }else{
		        // Click on arrive button
		        $status                    			= 'On Location';
		    }
		}
		$array[$index]['index']             		= $index;
		$array[$index]['stop_no']           		= $stop_no;
		$array[$index]['type']              		= 1;
		$array[$index]['is_stop']           		= 0;
		$array[$index]['stop_id']           		= 0;
		$array[$index]['is_arrived']        		= $load_detail->shipper_is_arrived ?? 0;
		$array[$index]['arrived_at']        		= $load_detail->shipper_arrived_at ?? null;
		$array[$index]['is_leaves']         		= $load_detail->shipper_is_leaves ?? 0;
		$array[$index]['leaves_at']        			= $load_detail->shipper_leaves_at ?? null;
		$array[$index]['status']                   	= $status;
		++$index;

		if(isset($load_detail->loads->load_stops) && $load_detail->loads->load_stops->isNotEmpty()){
		    foreach ($load_detail->loads->load_stops as $key => $stop) {
		        ++$stop_no;

		        $status                         	= 'Pending';
		        if((isset($stop->is_arrived) && $stop->is_arrived == 1) && (isset($stop->arrived_at) && $stop->arrived_at != '')){
		            if((isset($stop->is_leaves) && $stop->is_leaves == 1) && (isset($stop->leaves_at) && $stop->leaves_at != '')){
		                // Click on leave button
		                $status                  	= $stop->customer_type == 1 ? 'Picked Up': 'Delivered';
		            }else{
		                // Click on arrive button
		                $status                    	= 'On Location';
		            }
		        }
		        $array[$index]['index']           	= $index;
		        $array[$index]['stop_no']         	= $stop_no;
		        $array[$index]['type']            	= $stop->customer_type;
		        $array[$index]['is_stop']         	= 1;
		        $array[$index]['stop_id']         	= $stop->id;
		        $array[$index]['is_arrived']      	= $stop->is_arrived ?? 0;
		        $array[$index]['arrived_at']    	= $stop->arrived_at ?? null;
		        $array[$index]['is_leaves']       	= $stop->is_leaves ?? 0;
		        $array[$index]['leaves_at']    		= $stop->leaves_at ?? null;
		        $array[$index]['status']            = $status;
		        ++$index;
		    }
		}

		$status                                 	= 'Pending';
		if((isset($load_detail->delivery_is_arrived) && $load_detail->delivery_is_arrived == 1) && (isset($load_detail->delivery_arrived_at) && $load_detail->delivery_arrived_at != '')){
		    if((isset($load_detail->delivery_is_leaves) && $load_detail->delivery_is_leaves == 1) && (isset($load_detail->delivery_leaves_at) && $load_detail->delivery_leaves_at != '')){
		        // Click on leave button
		        $status                     		= 'Delivered';
		    }else{
		        // Click on arrive button
		        $status                    			= 'On Location';
		    }
		}
		$array[$index]['index']                   	= $index;
		$array[$index]['stop_no']                 	= 99;
		$array[$index]['type']                    	= 2;
		$array[$index]['is_stop']                 	= 0;
		$array[$index]['stop_id']                 	= 0;
		$array[$index]['is_arrived']              	= $load_detail->delivery_is_arrived ?? 0;
		$array[$index]['arrived_at']              	= $load_detail->delivery_arrived_at ?? null;
		$array[$index]['is_leaves']               	= $load_detail->delivery_is_leaves ?? 0;
		$array[$index]['leaves_at']              	= $load_detail->delivery_leaves_at ?? null;
		$array[$index]['status']            		= $status;
		return $array;
	}

	public function getTruckStopArry($stopStatusArry){
		$array 										= [];
		foreach ($stopStatusArry as $key => $value) {
			if($value['is_arrived'] == 0 && $value['is_leaves'] == 0){
			    $array['index']           			= $value['index'];
			    $array['status']          			= 'In Transit (Stop '.$value['stop_no'].')';
			    break;
			}elseif($value['is_arrived'] == 1 && $value['is_leaves'] == 0){
			    $array['index']           			= $value['index'];
			    $array['status']          			= 'Arrived (Stop '.$value['stop_no'].')';
			    break;
			}else{
				$array['index']           			= $value['index'];
				$array['status']          			= 'Departed (Stop '.$value['stop_no'].')';
			}
		}
		return $array;
	}

	public function arriveDepartRequest(Request $request){
		$response['success']                                				= false;
		$response['message']                                				= "Oops! Something went wrong..";
		if ($request->ajax()) {
		    try {
		    	// 1 = Stop, 0 = No Stop
		    	// Type = ( 1 = Arrive, 2 = Depart )
		    	// Customer Type ( 1 = Pickup, 2 = Delivery )

		    	if ($request->has('is_stop') && $request->is_stop == 1) {
		    	    $item                                                   = LoadStop::where('id', $request->id)->first();
		    	    if(!is_null($item)){
		    	    	$oldData                                        	= $item->toArray();

		    	    	if($request->type == 1){
		    	    		// Arrive
		    	    		$item->is_arrived   							= 1;
		    	    		$item->arrived_at   							= date('Y-m-d H:i:s');
		    	    	}else{
		    	    		// Depart
		    	    		$item->is_leaves                                = 1;
		    	    		$item->leaves_at                                = date('Y-m-d H:i:s');

		    	    		$item->status                                   = 1; // 0=Pending, 1=Complete, 2=Reject
		    	    		$item->status_at                                = date('Y-m-d H:i:s');
		    	    	}
		    	    	$item->updated_at               					= date('Y-m-d H:i:s');
		    	    	if($item->save()){
		    	    	    $this->setLoadAudit($item->load_id, 'update', 'Load stop updated', $item->getChanges(), $oldData);

		    	    	    // Truck location update
		    	    	    $truck_number 									= $item->loads->load_detail->truck_number ?? null;
		    	    	    if(!is_null($truck_number)){
		    	    	    	$truck                                      = Truck::where('unit', $truck_number)->first();
		    	    	    	if(!is_null($truck)){
		    	    	    	    $truck->last_location_name              = $item->location;
		    	    	    	    $truck->last_location_address           = $item->address_one;
		    	    	    	    $truck->last_location_address_2         = $item->address_two;
		    	    	    	    $truck->last_location_city              = $item->city;
		    	    	    	    $truck->last_location_state             = $item->state;
		    	    	    	    $truck->last_location_zip               = $item->zip;

		    	    	    	    $truck->last_location_latitude          = $item->latitude;
		    	    	    	    $truck->last_location_longitude         = $item->longitude;

		    	    	    	    $truck->last_location_timezone          = $item->timezone;
		    	    	    	    $truck->last_location_timezone_offset   = $item->timezone_offset;
		    	    	    	    $truck->last_location_timezone_abbr     = $item->timezone_abbr;
		    	    	    	    $truck->last_location_address_verified  = $item->address_verified;

		    	    	    	    $truck->last_location_notes             = $item->stop_note;

		    	    	    	    $truck->last_location_load_status       = '0';
		    	    	    	    $truck->updated_at                      = date('Y-m-d H:i:s');
		    	    	    	    $truck->save();
		    	    	    	}
		    	    	    }

		    	    	    $response['success']              				= true;
		    	    	    $response['message']              				= ($request->type == 1 ? "Arrived " : "Departed ")."successfully.";
		    	    	}else{
		    	    		$response['success']              				= false;
		    	    		$response['message']              				= ($request->type == 1 ? "Arrived " : "Departed ")."unsuccessfully.";
		    	    	}
		    	    }else{
		    	        $response['success']                                = false;
		    	        $response['message']                                = "Oops! Something went wrong..";
		    	    }
		    	}else{
		    	    $item                                                   = LoadDetail::where('id', $request->id)->first();
		    	    if(!is_null($item)){
		    	    	$oldData                                        	= $item->toArray();

		    	    	if($request->type == 1){
		    	    		// Arrive
		    	    		if($request->customer_type == 1){
		    	    			// Pickup
		    	    		    $item->shipper_is_arrived   				= 1;
		    	    		    $item->shipper_arrived_at   				= date('Y-m-d H:i:s');
		    	    		}else{
		    	    			// Delivery
		    	    		    $item->delivery_is_arrived  				= 1;
		    	    		    $item->delivery_arrived_at  				= date('Y-m-d H:i:s');
		    	    		}
		    	    	}else{
		    	    		// Depart
		    	    		if($request->customer_type == 1){
		    	    			// Pickup
		    	    		    $item->shipper_is_leaves   					= 1;
		    	    		    $item->shipper_leaves_at   					= date('Y-m-d H:i:s');
		    	    		}else{
		    	    			// Delivery
		    	    			$item->delivery_is_leaves  					= 1;
		    	    			$item->delivery_leaves_at  					= date('Y-m-d H:i:s');

		    	    			$item->load_status                   		= 5; // 5 = Delivered
		    	    			$item->load_status_order                	= Common::getLoadStatusOrderById(5);
    		    	    		$item->intransit_driver_acknowledgement 	= 1; // 1 = Delivered
		    	    		    $item->delivered 							= 1; // 1 = Delivered
		    	    		}
		    	    	}
		    	    	$item->updated_at               					= date('Y-m-d H:i:s');
		    	    	if($item->save()){
		    	    		$this->setLoadAudit($item->load_id, 'update', 'Load detail updated', $item->getChanges(), $oldData);
		    	    		if($request->type == 2 && $request->customer_type == 2){
		    	    			createLoadLog($item->getChanges(), $item, 'edit');
		    	    		}

		    	    		// Truck location update
		    	    		$truck                                          = Truck::where('unit', $item->truck_number)->first();
		    	    		if(!is_null($truck)){
		    	    		    if($request->customer_type == 1){
		    	    		    	// Pickup
		    	    		        $truck->last_location_name              = $item->shipper_location;
		    	    		        $truck->last_location_address           = $item->shipper_address_one;
		    	    		        $truck->last_location_address_2         = $item->shipper_address_two;
		    	    		        $truck->last_location_city              = $item->shipper_city;
		    	    		        $truck->last_location_state             = $item->shipper_state;
		    	    		        $truck->last_location_zip               = $item->shipper_zip;

		    	    		        $truck->last_location_latitude          = $item->shipper_latitude;
		    	    		        $truck->last_location_longitude         = $item->shipper_longitude;

		    	    		        $truck->last_location_timezone          = $item->shipper_timezone;
		    	    		        $truck->last_location_timezone_offset   = $item->shipper_timezone_offset;
		    	    		        $truck->last_location_timezone_abbr     = $item->shipper_timezone_abbr;
		    	    		        $truck->last_location_address_verified  = $item->shipper_address_verified;

		    	    		        $truck->last_location_notes             = $item->shipper_note;

		    	    		        $truck->last_location_load_status       = '0';
		    	    		    }else{
		    	    		    	// Delivery
		    	    		        $truck->last_location_name              = $item->delivery_location;
		    	    		        $truck->last_location_address           = $item->delivery_address_one;
		    	    		        $truck->last_location_address_2         = $item->delivery_address_two;
		    	    		        $truck->last_location_city              = $item->delivery_city;
		    	    		        $truck->last_location_state             = $item->delivery_state;
		    	    		        $truck->last_location_zip               = $item->delivery_zip;

		    	    		        $truck->last_location_latitude          = $item->delivery_latitude;
		    	    		        $truck->last_location_longitude         = $item->delivery_longitude;

		    	    		        $truck->last_location_timezone          = $item->delivery_timezone;
		    	    		        $truck->last_location_timezone_offset   = $item->delivery_timezone_offset;
		    	    		        $truck->last_location_timezone_abbr     = $item->delivery_timezone_abbr;
		    	    		        $truck->last_location_address_verified  = $item->delivery_address_verified;

		    	    		        $truck->last_location_notes             = $item->delivery_note;

		    	    		        $truck->last_location_load_status       = '0';
		    	    		    }
		    	    		    $truck->updated_at                          = date('Y-m-d H:i:s');
		    	    		    $truck->save();
		    	    		}

		    	    		// Please check change status functionality for dispatch
		    	    		// Same functionality dispatch now
		    	    		// Load Next Dispatch
		    	    		if($request->has('next_id') && $request->next_id !=''){
		    	    			$next                               		= LoadDetail::where('id', $request->next_id)->first();
		    	    			if(!is_null($next)){
		    	    				$oldData                            	= $next->toArray();

		    	    				// 1 = Preplaned Driver Acknowledgement, 2 = Confirmed Driver Acknowledgement, 3 = Intransit Driver Acknowledgement, 4 = Delivered Driver Acknowledgement
		    	    				// 0 = Pending', 1 = Accepted, 2 = Preplaned, 11 = Send To Driver, 3 = Confirmed, 4 = In Transit, 5 = Delivered, 7 = Ready to Bill, 10 = Invoiced, 8 = Paid
		    	    				// 1 = On Hold, 2 = Cancelled, 3 = Drooped
		    	    				$next->load_status                   	= 4;
		    	    				$next->load_status_order                = Common::getLoadStatusOrderById( 4 );
		    	    				// 2 = Confirmed Driver Acknowledgement
		    	    				$next->confirmed_driver_acknowledgement = 1; // 1 = Picked Up
		    	    				$next->dispatched                   	= 1; // Dispatch Now
		    	    				$next->dispatched_date_time          	= date('Y-m-d H:i:s');
		    	    				$next->updated_at                		= date('Y-m-d H:i:s');
		    	    				if($next->save()){
		    	    					$this->setLoadAudit($next->load_id, 'update', 'Load detail updated', $next->getChanges(), $oldData);
		    	    				    createLoadLog($next->getChanges(), $next, 'edit');
		    	    				}
		    	    			}
		    	    		}

		    	    	    $response['success']              				= true;
		    	    	    $response['message']              				= ($request->type == 1 ? "Arrived " : "Departed ")."successfully.";
		    	    	}else{
		    	    	    $response['success']              				= false;
		    	    	    $response['message']              				= ($request->type == 1 ? "Arrived " : "Departed ")."unsuccessfully.";
		    	    	}
		    	    }else{
		    	        $response['success']                                = false;
		    	        $response['message']                                = "Oops! Something went wrong..";
		    	    }
		    	}
		    } catch (\Exception $e) {
		        $response['success']                        				= false;
		        $response['message']                        				= $e->getMessage();
		    }
		}
		return response()->json($response);
	}

	public function reviewSave(Request $request){
		$response['success']                        						= false;
		$response['message']                        						= "Oops! Something went wrong..";
		if ($request->ajax()) {
			try {
				// 1 = Stop, 0 = No Stop
				// Customer Type ( 1 = Pickup, 2 = Delivery )

				if ($request->has('is_stop') && $request->is_stop == 1) {
					$item                                                   = LoadStop::where('id', $request->id)->first();
					if(!is_null($item)){
						$array 												= [
							'customer_id' 									=> $request->customer_id,
							'load_detail_id' 								=> $item->loads->load_detail_id,
							'load_stop_id' 									=> $request->id,
							'type' 											=> $request->customer_type,
							'is_stop' 										=> 1,
							'rating' 										=> $request->rating,
							'review' 										=> $request->review
						];
						// Check record exists or not
						$whereArray 										= [
							'customer_id' 									=> $request->customer_id,
							'load_stop_id' 									=> $request->id,
							// 'type' 										=> $request->customer_type,
							'is_stop' 										=> 1
						];
						$query 												= LoadStopReview::query();
						foreach ($whereArray as $key => $value) {
							$query->where($key, $value);
						}
						$review 											= $query->first();
						if(!is_null($review)){
							$oldData                                		= $review->toArray();

							$array['updated_at'] 							= date('Y-m-d H:i:s');
							$array['updated_by'] 							= auth()->guard('driver-admin')->user()->id;
							$array['updated_by_type'] 						= 3;

							foreach ($array as $key => $value) {
								$review->$key 								= $value;
							}
							if($review->save()){
								$this->setLoadAudit($review->load_detail->load_id, 'update', 'Load stop review updated', $review->getChanges(), $oldData);

								$response['review']          				= $review;
								$response['success']          				= true;
								$response['message']           				= "Post successfully.";
							}
						}else{
							$array['created_at'] 							= date('Y-m-d H:i:s');
							$array['created_by'] 							= auth()->guard('driver-admin')->user()->id;
							$array['created_by_type'] 						= 3;

							$review 										= LoadStopReview::create($array);
							if($review){
								$response['review']          				= $review;
								$response['success']          				= true;
								$response['message']           				= "Post successfully.";
							}
						}
					}else{
		    	        $response['success']                                = false;
		    	        $response['message']                                = "Oops! Something went wrong..";
		    	    }
				}else{
					$item                                                   = LoadDetail::where('id', $request->id)->first();
					if(!is_null($item)){
						$array 												= [
							'customer_id' 									=> $request->customer_id,
							'load_detail_id' 								=> $request->id,
							'type' 											=> $request->customer_type,
							'rating' 										=> $request->rating,
							'review' 										=> $request->review
						];
						// Check record exists or not
						$whereArray 										= [
							'customer_id' 									=> $request->customer_id,
							'load_detail_id' 								=> $request->id,
							'type' 											=> $request->customer_type,
							'is_stop' 										=> 0
						];
						$query 												= LoadStopReview::query();
						foreach ($whereArray as $key => $value) {
							$query->where($key, $value);
						}
						$review 											= $query->first();
						if(!is_null($review)){
							$oldData                                		= $review->toArray();

							$array['updated_at'] 							= date('Y-m-d H:i:s');
							$array['updated_by'] 							= auth()->guard('driver-admin')->user()->id;
							$array['updated_by_type'] 						= 3;

							foreach ($array as $key => $value) {
								$review->$key 								= $value;
							}
							if($review->save()){
								$this->setLoadAudit($review->load_detail->load_id, 'update', 'Load stop review updated', $review->getChanges(), $oldData);

								$response['review']          				= $review;
								$response['success']          				= true;
								$response['message']           				= "Post successfully.";
							}
						}else{
							$array['created_at'] 							= date('Y-m-d H:i:s');
							$array['created_by'] 							= auth()->guard('driver-admin')->user()->id;
							$array['created_by_type'] 						= 3;

							$review 										= LoadStopReview::create($array);
							if($review){
								$response['review']          				= $review;
								$response['success']          				= true;
								$response['message']           				= "Post successfully.";
							}
						}
					}else{
		    	        $response['success']                                = false;
		    	        $response['message']                                = "Oops! Something went wrong..";
		    	    }
				}
			} catch (\Exception $e) {
				$response['success']                						= false;
				$response['message']                						= $e->getMessage();
			}
		}
		return response()->json($response);
	}

	public function detentionRequest(Request $request){
	    $response['success']                                              			= false;
	    $response['message']                                          				= "Oops! Something went wrong..";
	    if($request->ajax()){
	        try {
	        	// 1 = Stop, 0 = No Stop
	        	// Customer Type ( 1 = Pickup, 2 = Delivery )

	        	$formData                           								= $request->all();

	            if ($request->has('is_stop') && $request->is_stop == 1) {
	                $item                                             				= LoadStop::where('id', $request->id)->first();
	                if(!is_null($item)){
	                	// Item means Load Stop
	                    $whereArray                                     			= [];
	                    if($request->has('detention_id') && $request->detention_id!=''){
	                        $whereArray['id']                           			= $request->detention_id;
	                    }else{
	                        // $whereArray['driver_id']                  			= $item->loads->load_detail->driver_id;
	                        // $whereArray['broker_id']                  			= $item->loads->load_detail->brokerage_firm;
	                        $whereArray['load_stop_id']                 			= $item->id;
	                        $whereArray['type']                         			= $item->customer_type;
	                        $whereArray['is_stop']                      			= 1;
	                    }

	                    $detentionquery                                  			= LoadDetention::query();
	                    foreach($whereArray as $field => $value) {
	                        $detentionquery->where($field, $value);
	                    }
	                    $detention                                    				= $detentionquery->first();

	                    $gpsLocation                                   				= '';
	                    if(!is_null($detention)){
	                        $driver                                      			= $detention->driver ?? null;
	                        $broker                                      			= $detention->broker ?? null;

	                        $gpsLocation   											= $detention->gps_location;
	                    }else{
	                        $driver                                      			= $item->loads->load_detail->driver ?? null;
	                        $broker                                      			= $item->loads->load_detail->broker ?? null;

	                        if(!is_null($driver)){
	                            $samsara_id                            				= (isset($driver->samsara_id) && $driver->samsara_id!='') ? $driver->samsara_id : ''; // 4644765
	                            if($samsara_id!=''){
	                                $carrierId 										= (isset($driver->driver_information->carrier_id)) ? $driver->driver_information->carrier_id : null;
	                                $getAPIKey                             			= IntegrationSetting::where('company_id', $driver->company_id)->where('carrier_id', $carrierId)->where('app_center_id', config('settings.app_id.samsara'))->where('sync_drivers', '1')->first();
	                                if(isset($getAPIKey->api_key) && !empty($getAPIKey->api_key)){
	                                    $client                            			= new \GuzzleHttp\Client();
	                                    $api_url                           			= 'https://api.samsara.com/fleet/hos/clocks?driverIds='.$samsara_id;
	                                    $api_response                      			= $client->request('GET', $api_url, [
	                                        'headers'                      			=> [
	                                            'Accept'                   			=> 'application/json',
	                                            'Authorization'            			=> 'Bearer '.$getAPIKey->api_key,
	                                        ],
	                                    ]);
	                                    $api_data                          			= @json_decode($api_response->getBody());
	                                    if(!empty($api_data)){
	                                        $appData                       			= $api_data->data[0];
	                                        if(!empty($appData)){
	                                            $vehicleIds                			= (isset($appData->currentVehicle->id) && $appData->currentVehicle->id!='')?$appData->currentVehicle->id:'';
	                                            if($vehicleIds!=''){
	                                                $api_url               			= 'https://api.samsara.com/fleet/vehicles/locations?vehicleIds='.$vehicleIds;
	                                                $api_response          			= $client->request('GET', $api_url, [
	                                                    'headers'          			=> [
	                                                        'Accept'       			=> 'application/json',
	                                                        'Authorization'			=> 'Bearer '.$getAPIKey->api_key,
	                                                    ],
	                                                ]);
	                                                $api_data              			= @json_decode($api_response->getBody());
	                                                if(!empty($api_data)){
	                                                    $appData           			= $api_data->data[0];
	                                                    if(!empty($appData) && (isset($appData->location->reverseGeo->formattedLocation) && $appData->location->reverseGeo->formattedLocation!='')){
	                                                        $gpsLocation   			= $appData->location->reverseGeo->formattedLocation;
	                                                    }
	                                                }
	                                            }
	                                        }
	                                    }
	                                }
	                            }
	                        }
	                    }

	                    $getGeoTimeZone             								= $this->getGeoTimeZone;

	                    $response['html']                                 			= view('driverAdmin.mytrips.ajax.current_dispatch.detention_request', compact('formData','item','detention','driver','broker','gpsLocation','getGeoTimeZone'))->render();
	                    $response['success']                              			= true;
	                    $response['message']                              			= "Detention request retrieved successfully.";
	                }
	            }elseif(
	            	($request->has('is_stop') && $request->is_stop == 0) &&
	            	($request->has('customer_type') && in_array($request->customer_type, [1, 2]))
	            ){
	                $query                                                			= LoadDetail::where('id', $request->id);
	                if($request->customer_type == 1)
	                    $query->where('shipper_is_arrived', 1);
	                else
	                    $query->where('delivery_is_arrived', 1);
	                $item                                                 			= $query->first();
	                if(!is_null($item)){
	                	// Item means Load Detail
	                    $whereArray                                   				= [];
	                    if($request->has('detention_id') && $request->detention_id!=''){
	                        $whereArray['id']                             			= $request->detention_id;
	                    }else{
	                        // $whereArray['driver_id']                   			= $item->driver_id;
	                        // $whereArray['broker_id']                   			= $item->brokerage_firm;
	                        $whereArray['load_detail_id']             				= $item->id;
	                        if($request->customer_type == 1){
	                            $whereArray['type']                     			= 1;
	                        }elseif($request->customer_type == 2){
	                            $whereArray['type']                       			= 2;
	                        }
	                        $whereArray['is_stop']                     				= 0;
	                    }

	                    $detentionquery                                				= LoadDetention::query();
	                    foreach($whereArray as $field => $value) {
	                        $detentionquery->where($field, $value);
	                    }
	                    $detention                                      			= $detentionquery->first();

	                    $gpsLocation                                   				= '';
	                    if(!is_null($detention)){
	                        $driver                                         		= $detention->driver ?? null;
	                        $broker                                         		= $detention->broker ?? null;

	                        $gpsLocation   											= $detention->gps_location;
	                    }else{
	                        $driver                                         		= $item->driver ?? null;
	                        $broker                                         		= $item->broker ?? null;

	                        if(!is_null($driver)){
	                            $samsara_id                            				= (isset($driver->samsara_id) && $driver->samsara_id!='') ? $driver->samsara_id : ''; // 4644765
	                            if($samsara_id!=''){
	                                $carrierId 										= (isset($driver->driver_information->carrier_id)) ? $driver->driver_information->carrier_id : null;
	                                $getAPIKey                           			= IntegrationSetting::where('company_id', $driver->company_id)->where('carrier_id', $carrierId)->where('app_center_id', config('settings.app_id.samsara'))->where('sync_drivers', '1')->first();
	                                if(isset($getAPIKey->api_key) && !empty($getAPIKey->api_key)){
	                                    $client                            			= new \GuzzleHttp\Client();
	                                    $api_url                           			= 'https://api.samsara.com/fleet/hos/clocks?driverIds='.$samsara_id;
	                                    $api_response                      			= $client->request('GET', $api_url, [
	                                        'headers'                      			=> [
	                                            'Accept'                   			=> 'application/json',
	                                            'Authorization'            			=> 'Bearer '.$getAPIKey->api_key,
	                                        ],
	                                    ]);
	                                    $api_data                          			= @json_decode($api_response->getBody());
	                                    if(!empty($api_data)){
	                                        $appData                       			= $api_data->data[0];
	                                        if(!empty($appData)){
	                                            $vehicleIds                			= (isset($appData->currentVehicle->id) && $appData->currentVehicle->id!='')?$appData->currentVehicle->id:'';
	                                            if($vehicleIds!=''){
	                                                $api_url               			= 'https://api.samsara.com/fleet/vehicles/locations?vehicleIds='.$vehicleIds;
	                                                $api_response          			= $client->request('GET', $api_url, [
	                                                    'headers'          			=> [
	                                                        'Accept'       			=> 'application/json',
	                                                        'Authorization'			=> 'Bearer '.$getAPIKey->api_key,
	                                                    ],
	                                                ]);
	                                                $api_data              			= @json_decode($api_response->getBody());
	                                                if(!empty($api_data)){
	                                                    $appData           			= $api_data->data[0];
	                                                    if(!empty($appData) && (isset($appData->location->reverseGeo->formattedLocation) && $appData->location->reverseGeo->formattedLocation!='')){
	                                                        $gpsLocation   			= $appData->location->reverseGeo->formattedLocation;
	                                                    }
	                                                }
	                                            }
	                                        }
	                                    }
	                                }
	                            }
	                        }
	                    }

	                    $getGeoTimeZone             								= $this->getGeoTimeZone;

	                    $response['html']                               			= view('driverAdmin.mytrips.ajax.current_dispatch.detention_request', compact('formData','item','detention','driver','broker','gpsLocation','getGeoTimeZone'))->render();
	                    $response['success']                            			= true;
	                    $response['message']                            			= "Detention request retrieved successfully.";
	                }
	            }
	        }catch (\Exception $e) {
	            $response['success']                                    			= false;
	            $response['message']                                    			= $e->getMessage();
	        }
	    }
	    return response()->json($response);
	}

	public function detentionSave(Request $request){
	    $response['success']                                              			= false;
	    $response['message']                                              			= "Oops! Something went wrong..";
	    if ($request->ajax()) {
	    	try {
	    		// 1 = Stop, 0 = No Stop
	    		// Customer Type ( 1 = Pickup, 2 = Delivery )

	    		$formData                           								= $request->all();

	    		if ($request->has('is_stop') && $request->is_stop == 1) {
	    			$item                                                 			= LoadStop::where('id', $request->id)->first();
	    			if(!is_null($item)){
	    				// Item means Load Stop
	    			    if($request->detention_status == 0){
	    			        $whereArray                                  			= [];
	    			        if($request->has('detention_id') && $request->detention_id!=''){
	    			            $whereArray['id']                         			= $request->detention_id;
	    			        }else{
	    			            $whereArray['driver_id']                  			= $request->driver_id;
	    			            $whereArray['broker_id']                  			= $request->broker_id;
	    			            $whereArray['load_stop_id']               			= $item->id;
	    			            $whereArray['type']                       			= $item->customer_type;
	    			            $whereArray['is_stop']                    			= 1;
	    			        }

	    			        $detentionquery                              			= LoadDetention::query();
	    			        foreach($whereArray as $field => $value) {
	    			            $detentionquery->where($field, $value);
	    			        }
	    			        $detention                                      		= $detentionquery->first();
	    			        if(!is_null($detention)){
	    			        	$oldData                                    		= [];
	    			        	$oldData                                    		= $detention->toArray();

	    			        	$load_id 											= $detention->load_detail()->first()->load_id;

	    			        	if($detention->delete()){
	    			        	    $this->setLoadAudit($load_id, 'delete', 'Load detention deleted',  $detention->toArray(), $oldData);

	    			        	    $response['success']                			= true;
	    			        	    $response['message']                			= "Detention cancel successfully.";
	    			        	}else{
	    			        	    $response['success']                			= false;
	    			        	    $response['message']                			= "Detention cancel unsuccessfully.";
	    			        	}
	    			        }
	    			    }elseif (in_array($request->detention_status, [1, 2, 3])) {
	    			    	// ===
	    			    	$oldDetention 											= null;
	    			    	if($request->has('detention_id') && $request->detention_id!=''){
	    			    	    $oldDetention                       				= LoadDetention::whereId($request->detention_id)->first();
	    			    	}
	    			    	// ===

	    			        $array                                       			= [];

	    			        $array['driver_id']                             		= $request->driver_id;
	    			        $array['broker_id']                             		= $request->broker_id;

	    			        $array['load_detail_id']                   				= $item->loads->load_detail->id;
	    			        $array['load_stop_id']                          		= $item->id;
	    			        $array['type']                                  		= $item->customer_type;
	    			        $array['is_stop']                               		= 1;

	    			        $array['detention_status']                				= $request->detention_status;

	    			        $array['detention_arrival_time']                		= ($request->detention_arrival_time) ? convertTimeToUTCzone([
	    			        	'str' 												=> $request->detention_arrival_time,
	    			        	'toFormat' 											=> 'Y-m-d H:i:s',
	    			        	'fromFormat' 										=> getTimeLayout(),
	    			        	'abbr' 												=> $request->timezone_abbr
	    			        ]) : null;
	    			        $array['detention_start_time']                  		= ($request->detention_start_time) ? convertTimeToUTCzone([
	    			        	'str' 												=> $request->detention_start_time,
	    			        	'toFormat' 											=> 'Y-m-d H:i:s',
	    			        	'fromFormat' 										=> getTimeLayout(),
	    			        	'abbr' 												=> $request->timezone_abbr
	    			        ]) : null;
	    			        if(in_array($request->detention_status, [2, 3])){
	    			            if($request->detention_status == 2){
	    			                $array['detention_end_time']        			= date('Y-m-d H:i:s');
	    			            }else{
	    			                $array['detention_end_time']        			= ($request->detention_end_time) ? convertTimeToUTCzone([
	    			                	'str' 										=> $request->detention_end_time,
	    			                	'toFormat' 									=> 'Y-m-d H:i:s',
	    			                	'fromFormat' 								=> getTimeLayout(),
	    			                	'abbr' 										=> $request->timezone_abbr
	    			                ]) : date('Y-m-d H:i:s');
	    			            }
	    			        }

	    			        $array['driver_comment']                				= $request->driver_comment;

	    			        if($request->detention_status == 3){
	    			        	if(!is_null($oldDetention)){
	    			        		if(is_null($oldDetention->submitted_at)){
	    			        			$array['submitted_user_type']            	= 'Driver';
	    			        			$array['submitted_at']                   	= Carbon::now();
	    			        			$array['submitted_by']                   	= auth()->guard('driver-admin')->user()->id;
	    			        		}
	    			        	}
	    			        }elseif ($request->detention_status == 2) {
	    			            $array['stopped_user_type']                 		= 'Driver';
	    			            $array['stopped_at']                        		= date('Y-m-d H:i:s');
	    			            $array['stopped_by']                        		= auth()->guard('driver-admin')->user()->id;

	    			            $broker_emails                          			= [];
	    			            if(isset($formData['broker_email']) && !empty($formData['broker_email'])){
	    			            	$broker_emails                         			= array_filter($formData['broker_email'], function ($var) {
	    			            	    return $var !== null && $var !== '';
	    			            	});
	    			            }
	    			            if(!empty($broker_emails)){
	    			            	$array['is_send_to_broker']   					= 1;
	    			            	$array['is_send_to_broker_at'] 					= date('Y-m-d H:i:s');
	    			            	// $array['broker_emails']                  	= serialize($broker_emails);

	    			            	$array['sent_to_broker']   						= 1;
	    			            	$array['sent_to_broker_at'] 					= date('Y-m-d H:i:s');
	    			            	$array['sent_to']                				= serialize($broker_emails);

	    			            	$array['review_user_type']                  	= 'Driver';
	    			            	$array['review_status']                     	= 'In Progress - Sent to broker';
	    			            	$array['review_at']                         	= date('Y-m-d H:i:s');
	    			            	$array['review_by']                         	= auth()->guard('driver-admin')->user()->id;
	    			            }else{
	    			            	$array['review_user_type']                  	= 'Driver';
	    			            	$array['review_status']                     	= 'Detention Stopped - Pending Approval';
	    			            	$array['review_at']                         	= date('Y-m-d H:i:s');
	    			            	$array['review_by']                         	= auth()->guard('driver-admin')->user()->id;
	    			            }
	    			        }elseif ($request->detention_status == 1) {
	    			        	$array['driver_comment_show_to_broker']   			= 1;

	    			        	$array['gps_location']                   			= $request->gpsLocation;

	    			        	if(isset($request->broker_id) && !empty($request->broker_id)){
	    			        	    $getBrokerdata                        			= Broker::whereId($request->broker_id)->first();
	    			        	    if(!is_null($getBrokerdata)){
	    			        	    	$array['free_time']                 		= $getBrokerdata->detention_time;
	    			        	    	$array['rate']                      		= $getBrokerdata->detention_price;
	    			        	    }
	    			        	}

	    			        	$broker_emails                          			= [];
	    			        	if(isset($formData['broker_email']) && !empty($formData['broker_email'])){
	    			        		$broker_emails                         			= array_filter($formData['broker_email'], function ($var) {
	    			        		    return $var !== null && $var !== '';
	    			        		});
	    			        	}
	    			        	if(!empty($broker_emails)){
	    			        		$array['is_send_to_broker']   					= 1;
	    			        		$array['is_send_to_broker_at'] 					= date('Y-m-d H:i:s');
	    			        		$array['broker_emails']                      	= serialize($broker_emails);

	    			        		$array['sent_acknowledgement_to_broker']   		= 1;
	    			        		$array['sent_acknowledgement_to_broker_at'] 	= date('Y-m-d H:i:s');
	    			        		$array['acknowledgement_emails']                = serialize($broker_emails);

	    			        		$array['acknowledged_user_type'] 				= 'Driver';
	    			        		$array['acknowledged_at'] 						= date('Y-m-d H:i:s');
	    			        		$array['acknowledged_by'] 						= auth()->guard('driver-admin')->user()->id;

	    			        		$array['review_user_type']                  	= 'Driver';
	    			        		$array['review_status']                     	= 'In Progress - Acknowledged - Sent to broker';
	    			        		$array['review_at']                         	= date('Y-m-d H:i:s');
	    			        		$array['review_by']                         	= auth()->guard('driver-admin')->user()->id;
	    			        	}else{
	    			        		$array['review_user_type']                  	= 'Driver';
	    			        		$array['review_status']                     	= 'In Progress';
	    			        		$array['review_at']                         	= date('Y-m-d H:i:s');
	    			        		$array['review_by']                         	= auth()->guard('driver-admin')->user()->id;
	    			        	}
	    			        }

	    			        // ===
	    			        $whereArray                                  			= [];
	    			        if($request->has('detention_id') && $request->detention_id!=''){
	    			            $whereArray['id']                        			= $request->detention_id;
	    			        }else{
	    			            $whereArray['driver_id']                 			= $request->driver_id;
	    			            $whereArray['broker_id']                 			= $request->broker_id;
	    			            $whereArray['load_stop_id']              			= $item->id;
	    			            $whereArray['type']                      			= $item->customer_type;
	    			            $whereArray['is_stop']                   			= 1;
	    			        }
	    			        // ===
	    			        $detention                                   			= LoadDetention::updateOrCreate($whereArray, $array);
	    			        if($detention){
	    			            if($detention->wasChanged() && isset($oldDetention)){
	    			                $this->setLoadAudit($detention->load_detail->load_id, 'update', 'Load detention updated', $detention->getChanges(), $oldDetention->toArray());
	    			            }

	    			            if(in_array($detention->detention_status, [1, 2]) && isset($detention->driver)){
	    			                $driver                                     	= $detention->driver;
	    			                if(isset($driver->dispatcher)){
	    			                    $dispatcher                             	= $driver->dispatcher;
	    			                    $name                                   	= 'Load: '.$item->loads->load_detail->load_number.' - Stop '; // Item means Load Stop
	    			                    if($item->loads->load_stops->isNotEmpty()){
	    			                        $stpno                              	= '';
	    			                        $stopIds                            	= ($item->loads->load_stops->pluck('id')->toArray());
	    			                        foreach ($stopIds as $stkey => $stopId) {
	    			                            ++$stkey;
	    			                            if($item->id==$stopId){
	    			                                $stpno                      	= $stkey;
	    			                            }
	    			                        }
	    			                        if($stpno!=''){
	    			                        	$stpno 								= $stpno+1;
	    			                            $name                           	.= $stpno.' ';
	    			                        }
	    			                    }
	    			                    if($detention->type == 1){
	    			                        $name                              		.= 'Pickup';
	    			                    }else{
	    			                        $name                              		.= 'Delivery';
	    			                    }
	    			                    $description                            	= '';
	    			                    if($detention->detention_status == 1){
	    			                        $description                        	= $driver->full_name.' has started a detention for '.$item->loads->load_detail->load_number.': '.$item->loads->load_detail->load_number.' at '.date("Y-m-d H:i:s", strtotime($detention->created_at)).' please review';
	    			                    }else{
	    			                        $description                        	= $driver->full_name.' has stopped a detention for '.$item->loads->load_detail->load_number.': '.$item->loads->load_detail->load_number.' at '.date("Y-m-d H:i:s", strtotime($detention->stopped_at)).' please review';
	    			                    }

	    			                    createNotification(
	    			                        ($detention->detention_status==1)?17:18, // source
	    			                        $name, // name
	    			                        $dispatcher->id, // user_id
	    			                        $dispatcher->type, // user_type
	    			                        2, // type
	    			                        $detention->id, // action_id
	    			                        $description, // description
	    			                        'Notification', // module
	    			                        [], // properties
	    			                        $dispatcher->company_id // company_id
	    			                    );
	    			                }
	    			            }

	            			    if(in_array($detention->review_status, ['In Progress - Acknowledged - Sent to broker','In Progress - Sent to broker','Pending Broker Review'])){
	            			    	if(isset($detention->broker_emails) && is_serialized($detention->broker_emails) && !empty(unserialize($detention->broker_emails))){
	            			    		$to_emails                          		= array_filter(unserialize($detention->broker_emails), function ($var) {
            			    			    return $var !== null && $var !== '';
            			    			});
            			    			if(!empty($to_emails)){
            			    				foreach ($to_emails as $key => $broker_email) {
            			    				    $details                       		= [];
            			    				    $details['company_id']         		= auth()->guard('driver-admin')->user()->company_id;
            			    				    $details['detention']          		= $detention;
            			    				    $details['name']               		= isset($detention->broker->name) ? $detention->broker->name : '';

            			    				    try {
            			    				        // Mail::to($broker_email)->send(new DetentionRequestBroker($details));
            			    				    } catch (\Swift_TransportException $e) {
            			    				        // Handle transport exception (e.g., connection failure)

            			    				        // Log the error message
            			    				        Log::error('Email sending failed: ' . $e->getMessage());

            			    				        // Optionally, you can re-throw the exception if desired
            			    				        // throw $e;
            			    				    } catch (\Exception $e) {
            			    				        // Handle any other exception

            			    				        // Log the error message
            			    				        Log::error('An error occurred while sending the email: ' . $e->getMessage());

            			    				        // Optionally, you can re-throw the exception if desired
            			    				        // throw $e;
            			    				    }
            			    				}
            			    			}
	            			    	}
	            			    }

	    			            $response['data']                               	= $detention;
	    			            $response['success']                            	= true;
	    			            $response['message']                            	= "Detention saved successfully.";
	    			        }else{
	    			            $response['success']                            	= false;
	    			            $response['message']                            	= "Detention saved unsuccessfully.";
	    			        }
	    			    }
	    			}
	    		}elseif(
	            	($request->has('is_stop') && $request->is_stop == 0) &&
	            	($request->has('customer_type') && in_array($request->customer_type, [1, 2]))
	            ){
	            	$query                                                			= LoadDetail::where('id', $request->id);
	            	if($request->customer_type == 1)
	            	    $query->where('shipper_is_arrived', 1);
	            	else
	            	    $query->where('delivery_is_arrived', 1);
	            	$item                                                 			= $query->first();
	            	if(!is_null($item)){
	            		// Item means Load Detail
	            		if($request->detention_status == 0){
	            			$whereArray                                 			= [];
	            			if($request->has('detention_id') && $request->detention_id!=''){
	            			    $whereArray['id']                        			= $request->detention_id;
	            			}else{
	            			    $whereArray['driver_id']                    		= $request->driver_id;
	            			    $whereArray['broker_id']                    		= $request->broker_id;
	            			    $whereArray['load_detail_id']               		= $item->id;
	            			    if($request->customer_type == 1){
	            			        $whereArray['type']                   			= 1;
	            			    }elseif($request->customer_type == 2){
	            			        $whereArray['type']                  			= 2;
	            			    }
	            			    $whereArray['is_stop']                      		= 0;
	            			}

	            			$detentionquery                              			= LoadDetention::query();
	            			foreach($whereArray as $field => $value) {
	            			    $detentionquery->where($field, $value);
	            			}
	            			$detention                                      		= $detentionquery->first();
	            			if(!is_null($detention)){
	            				$oldData                                    		= [];
	            				$oldData                                    		= $detention->toArray();

	            				$load_id 											= $detention->load_detail()->first()->load_id;

	            				if($detention->delete()){
	            				    $this->setLoadAudit($load_id, 'delete', 'Load detention deleted',  $detention->toArray(), $oldData);

	            				    $response['success']                			= true;
	            				    $response['message']                			= "Detention cancel successfully.";
	            				}else{
	            				    $response['success']                			= false;
	            				    $response['message']                			= "Detention cancel unsuccessfully.";
	            				}
	            			}
	            		}elseif (in_array($request->detention_status, [1, 2, 3])) {
	            			// ===
	            			$oldDetention 											= null;
	            			if($request->has('detention_id') && $request->detention_id!=''){
	            			    $oldDetention                  						= LoadDetention::whereId($request->detention_id)->first();
	            			}
	            			// ===

	            			$array                                    				= [];

	            			$array['driver_id']                       				= $request->driver_id;
	            			$array['broker_id']                          			= $request->broker_id;

	            			$array['load_detail_id']                   				= $item->id;
	            			if($request->customer_type == 1){
	            			    $array['type']                   					= 1;
	            			}elseif($request->customer_type == 2){
	            			    $array['type']                  					= 2;
	            			}

	            			$array['detention_status']                				= $request->detention_status;

	            			$array['detention_arrival_time']                		= ($request->detention_arrival_time) ? convertTimeToUTCzone([
	            				'str' 												=> $request->detention_arrival_time,
	            				'toFormat' 											=> 'Y-m-d H:i:s',
	            				'fromFormat' 										=> getTimeLayout(),
	            				'abbr' 												=> $request->timezone_abbr
	            			]) : null;
	            			$array['detention_start_time']                  		= ($request->detention_start_time) ? convertTimeToUTCzone([
	            				'str' 												=> $request->detention_start_time,
	            				'toFormat' 											=> 'Y-m-d H:i:s',
	            				'fromFormat' 										=> getTimeLayout(),
	            				'abbr' 												=> $request->timezone_abbr
	            			]) : null;
	            			if(in_array($request->detention_status, [2, 3])){
	            			    if($request->detention_status == 2){
	            			        $array['detention_end_time']        			= date('Y-m-d H:i:s');
	            			    }else{
	            			        $array['detention_end_time']        			= ($request->detention_end_time) ? convertTimeToUTCzone([
	            			        	'str' 										=> $request->detention_end_time,
	            			        	'toFormat' 									=> 'Y-m-d H:i:s',
	            			        	'fromFormat' 								=> getTimeLayout(),
	            			        	'abbr' 										=> $request->timezone_abbr
	            			        ]) : date('Y-m-d H:i:s');
	            			    }
	            			}

	            			$array['driver_comment']                				= $request->driver_comment;

	            			if($request->detention_status == 3){
	            				if(!is_null($oldDetention)){
	            					if(is_null($oldDetention->submitted_at)){
	            						$array['submitted_user_type']            	= 'Driver';
	            						$array['submitted_at']                   	= Carbon::now();
	            						$array['submitted_by']                   	= auth()->guard('driver-admin')->user()->id;
	            					}
	            				}
	            			}elseif ($request->detention_status == 2) {
	            			    $array['stopped_user_type']                 		= 'Driver';
	            			    $array['stopped_at']                        		= date('Y-m-d H:i:s');
	            			    $array['stopped_by']                        		= auth()->guard('driver-admin')->user()->id;

	            			    $broker_emails                          			= [];
	            			    if(isset($formData['broker_email']) && !empty($formData['broker_email'])){
	            			    	$broker_emails                         			= array_filter($formData['broker_email'], function ($var) {
	            			    	    return $var !== null && $var !== '';
	            			    	});
	            			    }
	            			    if(!empty($broker_emails)){
	            			    	$array['is_send_to_broker']   					= 1;
	            			    	$array['is_send_to_broker_at'] 					= date('Y-m-d H:i:s');
	            			    	// $array['broker_emails']                  	= serialize($broker_emails);

	            			    	$array['sent_to_broker']   						= 1;
	            			    	$array['sent_to_broker_at'] 					= date('Y-m-d H:i:s');
	            			    	$array['sent_to']                				= serialize($broker_emails);

	            			    	$array['review_user_type']                  	= 'Driver';
	            			    	$array['review_status']                     	= 'In Progress - Sent to broker';
	            			    	$array['review_at']                         	= date('Y-m-d H:i:s');
	            			    	$array['review_by']                         	= auth()->guard('driver-admin')->user()->id;
	            			    }else{
	            			    	$array['review_user_type']                  	= 'Driver';
	            			    	$array['review_status']                     	= 'Detention Stopped - Pending Approval';
	            			    	$array['review_at']                         	= date('Y-m-d H:i:s');
	            			    	$array['review_by']                         	= auth()->guard('driver-admin')->user()->id;
	            			    }
	            			}elseif ($request->detention_status == 1) {
	            				$array['driver_comment_show_to_broker']   			= 1;

	            				$array['gps_location']                   			= $request->gpsLocation;

	            				if(isset($request->broker_id) && !empty($request->broker_id)){
	            				    $getBrokerdata                        			= Broker::whereId($request->broker_id)->first();
	            				    if(!is_null($getBrokerdata)){
	            				    	$array['free_time']                 		= $getBrokerdata->detention_time;
	            				    	$array['rate']                      		= $getBrokerdata->detention_price;
	            				    }
	            				}

	            				$broker_emails                          			= [];
	            				if(isset($formData['broker_email']) && !empty($formData['broker_email'])){
	            					$broker_emails                         			= array_filter($formData['broker_email'], function ($var) {
	            					    return $var !== null && $var !== '';
	            					});
	            				}
	            				if(!empty($broker_emails)){
	            					$array['is_send_to_broker']   					= 1;
	            					$array['is_send_to_broker_at'] 					= date('Y-m-d H:i:s');
	            					$array['broker_emails']                      	= serialize($broker_emails);

	            					$array['sent_acknowledgement_to_broker']   		= 1;
	            					$array['sent_acknowledgement_to_broker_at'] 	= date('Y-m-d H:i:s');
	            					$array['acknowledgement_emails']                = serialize($broker_emails);

	            					$array['acknowledged_user_type'] 				= 'Driver';
	            					$array['acknowledged_at'] 						= date('Y-m-d H:i:s');
	            					$array['acknowledged_by'] 						= auth()->guard('driver-admin')->user()->id;

	            					$array['review_user_type']                  	= 'Driver';
	            					$array['review_status']                     	= 'In Progress - Acknowledged - Sent to broker';
	            					$array['review_at']                         	= date('Y-m-d H:i:s');
	            					$array['review_by']                         	= auth()->guard('driver-admin')->user()->id;
	            				}else{
	            					$array['review_user_type']                  	= 'Driver';
	            					$array['review_status']                     	= 'In Progress';
	            					$array['review_at']                         	= date('Y-m-d H:i:s');
	            					$array['review_by']                         	= auth()->guard('driver-admin')->user()->id;
	            				}
	            			}

	            			// ===
	            			$whereArray                                 			= [];
	            			if($request->has('detention_id') && $request->detention_id!=''){
	            			    $whereArray['id']                        			= $request->detention_id;
	            			}else{
	            			    $whereArray['driver_id']                    		= $request->driver_id;
	            			    $whereArray['broker_id']                    		= $request->broker_id;
	            			    $whereArray['load_detail_id']               		= $item->id;
	            			    if($request->customer_type == 1){
	            			        $whereArray['type']                   			= 1;
	            			    }elseif($request->customer_type == 2){
	            			        $whereArray['type']                  			= 2;
	            			    }
	            			    $whereArray['is_stop']                      		= 0;
	            			}
	            			// ===
	            			$detention                                  			= LoadDetention::updateOrCreate($whereArray, $array);
	            			if($detention){
	            			    if($detention->wasChanged() && isset($oldDetention)){
	            			        $this->setLoadAudit($detention->load_detail->load_id, 'update', 'Load detention updated', $detention->getChanges(), $oldDetention->toArray());
	            			    }

	            			    if(in_array($detention->detention_status, [1, 2]) && isset($detention->driver)){
	            			        $driver                              			= $detention->driver;
	            			        if(isset($driver->dispatcher)){
	            			            $dispatcher                   				= $driver->dispatcher;
	            			            $name                        				= 'Load: '.$item->load_number.' - '; // Item means Load Detail
	            			            if($detention->type == 1){
	            			                $name                       			.= 'Pickup';
	            			            }else{
	            			                $name                        			.= 'Delivery';
	            			            }
	            			            $description                   				= '';
	            			            if($detention->detention_status == 1){
	            			                $description                  			= $driver->full_name.' has started a detention for '.$item->load_number.': '.$item->load_number.' at '.date("Y-m-d H:i:s", strtotime($detention->created_at)).' please review';
	            			            }else{
	            			                $description                			= $driver->full_name.' has stopped a detention for '.$item->load_number.': '.$item->load_number.' at '.date("Y-m-d H:i:s", strtotime($detention->stopped_at)).' please review';
	            			            }
	            			            createNotification(
	            			                ($detention->detention_status == 1)?17:18, // source
	            			                $name, // name
	            			                $dispatcher->id, // user_id
	            			                $dispatcher->type, // user_type
	            			                2, // type
	            			                $detention->id, // action_id
	            			                $description, // description
	            			                'Notification', // module
	            			                [], // properties
	            			                $dispatcher->company_id // company_id
	            			            );
	            			        }
	            			    }

	            			    if(in_array($detention->review_status, ['In Progress - Acknowledged - Sent to broker','In Progress - Sent to broker','Pending Broker Review'])){
	            			    	if(isset($detention->broker_emails) && is_serialized($detention->broker_emails) && !empty(unserialize($detention->broker_emails))){
	            			    		$to_emails                          		= array_filter(unserialize($detention->broker_emails), function ($var) {
            			    			    return $var !== null && $var !== '';
            			    			});
            			    			if(!empty($to_emails)){
            			    				foreach ($to_emails as $key => $broker_email) {
            			    				    $details                       		= [];
            			    				    $details['company_id']         		= auth()->guard('driver-admin')->user()->company_id;
            			    				    $details['detention']          		= $detention;
            			    				    $details['name']               		= isset($detention->broker->name) ? $detention->broker->name : '';

            			    				    try {
            			    				        // Mail::to($broker_email)->send(new DetentionRequestBroker($details));
            			    				    } catch (\Swift_TransportException $e) {
            			    				        // Handle transport exception (e.g., connection failure)

            			    				        // Log the error message
            			    				        Log::error('Email sending failed: ' . $e->getMessage());

            			    				        // Optionally, you can re-throw the exception if desired
            			    				        // throw $e;
            			    				    } catch (\Exception $e) {
            			    				        // Handle any other exception

            			    				        // Log the error message
            			    				        Log::error('An error occurred while sending the email: ' . $e->getMessage());

            			    				        // Optionally, you can re-throw the exception if desired
            			    				        // throw $e;
            			    				    }
            			    				}
            			    			}
	            			    	}
	            			    }

	            			    $response['data']                       			= $detention;
	            			    $response['success']                    			= true;
	            			    $response['message']                    			= "Detention saved successfully.";
	            			}else{
	            			    $response['success']                    			= false;
	            			    $response['message']                    			= "Detention saved unsuccessfully.";
	            			}
	            		}
	            	}
	    		}
	    	}catch (\Exception $e) {
	    	    $response['success']                                    			= false;
	    	    $response['message']                                    			= $e->getMessage();
	    	}
	    }
	    return response()->json($response);
	}

	public function departDetail(Request $request){
		$response['success']                                								= false;
		$response['message']                                								= "Oops! Something went wrong..";
		if ($request->ajax()) {
			try {
				// 1 = Stop, 0 = No Stop
				// Type = ( 1 = Arrive, 2 = Depart )
				// Customer Type ( 1 = Pickup, 2 = Delivery )
				// Required Documents upload code same carousel_content
				// load_document_request_items & accessorials get item change row - ohk
				// For Missing document driverAdmin.mytrips.ajax.current_dispatch.carousel_content -> document code must check bcz code dependent

				$formData                           										= $request->all();

				if ($request->has('is_stop') && $request->is_stop == 1) {
					$item                                                   				= LoadStop::where('id', $request->id)->first();
					if(!is_null($item)){
						if($request->has('dispatch')){
							// Dispatch Update
							$response['html']   											= view('driverAdmin.mytrips.ajax.current_dispatch.dispatch_update', compact('item','formData'))->render();
							$response['success']                                			= true;
							$response['message']                                			= "Dispatch update view retrieved successfully.";
						}else{
							$getStopDocuments 												= $this->getStopdDocuments($item);

							// Required Documents
							$required_documents  											= $getStopDocuments['required_documents'];
							$required_documents          									= array_filter($required_documents, function ($var) {
						        return (
						        	(isset($var['status']) && $var['status'] == 'Pending') &&
						   			(isset($var['file_not_provided']) && $var['file_not_provided'] == 'off')
						   		);
						    });

							// Requested Documents
							$requested_documents                              				= $getStopDocuments['requested_documents'];
							$requested_documents          									= array_filter($requested_documents, function ($var) {
							    return (
							     	(isset($var['status']) && $var['status'] == 'Pending') &&
									(isset($var['file_not_provided']) && $var['file_not_provided'] == 'off')
								);
							});

							// Accessorial Documents
							$accessorial_documents                            				= $getStopDocuments['accessorial_documents'];
							$accessorial_documents          								= array_filter($accessorial_documents, function ($var) {
							    return (
							     	(isset($var['status']) && $var['status'] == 'Pending') &&
									(isset($var['file_not_provided']) && $var['file_not_provided'] == 'off')
								);
							});

							// Merged Documents
							$merged_documents  												= $getStopDocuments['merged_documents'];
							$merged_documents          										= array_filter($merged_documents, function ($var) {
							    return (
							     	(isset($var['status']) && $var['status'] == 'Pending') &&
									(isset($var['file_not_provided']) && $var['file_not_provided'] == 'off')
								);
							});

							if(!empty($merged_documents)){
								$response['html']   										= view('driverAdmin.mytrips.ajax.current_dispatch.missing_documents', compact('formData','required_documents','requested_documents','accessorial_documents'))->render();
								$response['missing']                                		= 1;
								$response['success']                                		= true;
								$response['message']                                		= "Missing documents retrieved successfully.";
							}else{
								// Dispatch Update
								$response['html']   										= view('driverAdmin.mytrips.ajax.current_dispatch.dispatch_update', compact('item','formData'))->render();
								$response['success']                                		= true;
								$response['message']                                		= "Dispatch update view retrieved successfully.";
							}
						}
					}
				}else{
					$item                                                   				= LoadDetail::where('id', $request->id)->first();
					if(!is_null($item)){
						if($request->customer_type == 1){
							// Pickup
							if($request->has('dispatch')){
								// Dispatch Update
								$response['html']   										= view('driverAdmin.mytrips.ajax.current_dispatch.dispatch_update', compact('item','formData'))->render();
								$response['success']                                		= true;
								$response['message']                                		= "Dispatch update view retrieved successfully.";
							}else{
								$getStopDocuments 											= $this->getStopdDocuments($item, $request->customer_type);

								// Required Documents
								$required_documents  										= $getStopDocuments['required_documents'];
								$required_documents          								= array_filter($required_documents, function ($var) {
							        return (
							        	(isset($var['status']) && $var['status'] == 'Pending') &&
							   			(isset($var['file_not_provided']) && $var['file_not_provided'] == 'off')
							   		);
							    });

								// Requested Documents
								$requested_documents                              			= $getStopDocuments['requested_documents'];
								$requested_documents          								= array_filter($requested_documents, function ($var) {
								    return (
								     	(isset($var['status']) && $var['status'] == 'Pending') &&
										(isset($var['file_not_provided']) && $var['file_not_provided'] == 'off')
									);
								});

								// Accessorial Documents
								$accessorial_documents                            			= $getStopDocuments['accessorial_documents'];
								$accessorial_documents          							= array_filter($accessorial_documents, function ($var) {
								    return (
								     	(isset($var['status']) && $var['status'] == 'Pending') &&
										(isset($var['file_not_provided']) && $var['file_not_provided'] == 'off')
									);
								});

								// Merged Documents
								$merged_documents  											= $getStopDocuments['merged_documents'];
								$merged_documents          									= array_filter($merged_documents, function ($var) {
								    return (
								     	(isset($var['status']) && $var['status'] == 'Pending') &&
										(isset($var['file_not_provided']) && $var['file_not_provided'] == 'off')
									);
								});

								if(!empty($merged_documents)){
									$response['html']   									= view('driverAdmin.mytrips.ajax.current_dispatch.missing_documents', compact('formData','required_documents','requested_documents','accessorial_documents'))->render();
									$response['missing']                                	= 1;
									$response['success']                                	= true;
									$response['message']                                	= "Missing documents retrieved successfully.";
								}else{
									// Dispatch Update
									$response['html']   									= view('driverAdmin.mytrips.ajax.current_dispatch.dispatch_update', compact('item','formData'))->render();
									$response['success']                                	= true;
									$response['message']                                	= "Dispatch update view retrieved successfully.";
								}
							}
						}else{
							// Delivery
							if($request->has('dispatch')){
								$query 														= LoadDetail::query();
								$query->where('load_details.driver_id', auth()->guard('driver-admin')->user()->id);
								$query->where( function($q) {
								    $q->where('load_details.load_status', 3) // 3 = Confirmed
								    	->where('load_details.load_type', 0) // 0 = OCCUPIED
								    	->where('load_details.is_disable', 0)
								    	->where('load_details.send_notification', 1)
								    	->where(function($q) {
								    	    $q->whereNull('load_details.is_on_hold')->orWhere('load_details.is_on_hold', 0);
								    	});
								});
								$query->orderBy('load_details.actual_shipper_date');
								$next 														= $query->first();

								$pendingDocuments 											= [];
								$getAllStopDocuments 										= $this->getAllStopdDocuments($item); // item = Load Detail, All Stop document
								if(!empty($getAllStopDocuments)){
									foreach ($getAllStopDocuments as $load_stop_no => $document) {
										// Required Documents
										$required_documents 								= $document['required_documents'] ?? [];
										$required_documents        							= array_filter($required_documents, function ($var) {
										    return isset($var['status']) && $var['status'] == 'Pending';
										});
										foreach ($required_documents as $key => $node) {
											$name 											= '';
											if(isset($node['filename_id']) && $node['filename_id']=='0'){
											    $name  										= 'Other - '.$node['filename'];
											}else{
												$name  										= $node['filename'];
											}
											if($node['type'] == '2'){
												$name  										.= ' - Original';
											}
											$name  											.= ' (Stop '.$load_stop_no.')';
											$pendingDocuments[] 							= $name;
										}
										// Requested Documents
										$requested_documents 								= $document['requested_documents'] ?? [];
										$requested_documents        						= array_filter($requested_documents, function ($var) {
										    return isset($var['status']) && $var['status'] == 'Pending';
										});
										foreach ($requested_documents as $key => $node) {
											$name 											= '';
											if(isset($node['filename_id']) && $node['filename_id']=='0'){
											    $name  										= 'Other - '.$node['filename'];
											}else{
												$name  										= $node['filename'];
											}
											if($node['type'] == '2'){
												$name  										.= ' - Original';
											}
											$name  											.= ' (Stop '.$load_stop_no.')';
											$pendingDocuments[] 							= $name;
										}
										// Accessorial Documents
										$accessorial_documents 								= $document['accessorial_documents'] ?? [];
										$accessorial_documents        						= array_filter($accessorial_documents, function ($var) {
										    return isset($var['status']) && $var['status'] == 'Pending';
										});
										foreach ($accessorial_documents as $key => $node) {
											$name 											= $node['filename'].' (Stop '.$load_stop_no.')';
											$pendingDocuments[] 							= $name;
										}
									}
								}

								// Dispatch Update
								$response['html']   										= view('driverAdmin.mytrips.ajax.current_dispatch.dispatch_update', compact('item','formData','next','pendingDocuments'))->render();
								$response['success']                                		= true;
								$response['message']                                		= "Dispatch update view retrieved successfully.";
							}else{
								$getStopDocuments 											= $this->getStopdDocuments($item, $request->customer_type);

								// Required Documents
								$required_documents  										= $getStopDocuments['required_documents'];
								$required_documents          								= array_filter($required_documents, function ($var) {
							        return (
							        	(isset($var['status']) && $var['status'] == 'Pending') &&
							   			(isset($var['file_not_provided']) && $var['file_not_provided'] == 'off')
							   		);
							    });

								// Requested Documents
								$requested_documents                              			= $getStopDocuments['requested_documents'];
								$requested_documents          								= array_filter($requested_documents, function ($var) {
								    return (
								     	(isset($var['status']) && $var['status'] == 'Pending') &&
										(isset($var['file_not_provided']) && $var['file_not_provided'] == 'off')
									);
								});

								// Accessorial Documents
								$accessorial_documents                            			= $getStopDocuments['accessorial_documents'];
								$accessorial_documents          							= array_filter($accessorial_documents, function ($var) {
								    return (
								     	(isset($var['status']) && $var['status'] == 'Pending') &&
										(isset($var['file_not_provided']) && $var['file_not_provided'] == 'off')
									);
								});

								// Merged Documents
								$merged_documents  											= $getStopDocuments['merged_documents'];
								$merged_documents          									= array_filter($merged_documents, function ($var) {
								    return (
								     	(isset($var['status']) && $var['status'] == 'Pending') &&
										(isset($var['file_not_provided']) && $var['file_not_provided'] == 'off')
									);
								});

								if(!empty($merged_documents)){
									$response['html']   									= view('driverAdmin.mytrips.ajax.current_dispatch.missing_documents', compact('formData','required_documents','requested_documents','accessorial_documents'))->render();
									$response['missing']                                	= 1;
									$response['success']                                	= true;
									$response['message']                                	= "Missing documents retrieved successfully.";
								}else{
									$query 													= LoadDetail::query();
									$query->where('load_details.driver_id', auth()->guard('driver-admin')->user()->id);
									$query->where( function($q) {
									    $q->where('load_details.load_status', 3) // 3 = Confirmed
									    	->where('load_details.load_type', 0) // 0 = OCCUPIED
									    	->where('load_details.is_disable', 0)
									    	->where('load_details.send_notification', 1)
									    	->where(function($q) {
									    	    $q->whereNull('load_details.is_on_hold')->orWhere('load_details.is_on_hold', 0);
									    	});
									});
									$query->orderBy('load_details.actual_shipper_date');
									$next 													= $query->first();

									$pendingDocuments 										= [];
									$getAllStopDocuments 									= $this->getAllStopdDocuments($item); // item = Load Detail, All Stop document
									if(!empty($getAllStopDocuments)){
										foreach ($getAllStopDocuments as $load_stop_no => $document) {
											// Required Documents
											$required_documents 							= $document['required_documents'] ?? [];
											$required_documents        						= array_filter($required_documents, function ($var) {
											    return isset($var['status']) && $var['status'] == 'Pending';
											});
											foreach ($required_documents as $key => $node) {
												$name 										= '';
												if(isset($node['filename_id']) && $node['filename_id']=='0'){
												    $name  									= 'Other - '.$node['filename'];
												}else{
													$name  									= $node['filename'];
												}
												if($node['type'] == '2'){
													$name  									.= ' - Original';
												}
												$name  										.= ' (Stop '.$load_stop_no.')';
												$pendingDocuments[] 						= $name;
											}
											// Requested Documents
											$requested_documents 							= $document['requested_documents'] ?? [];
											$requested_documents        					= array_filter($requested_documents, function ($var) {
											    return isset($var['status']) && $var['status'] == 'Pending';
											});
											foreach ($requested_documents as $key => $node) {
												$name 										= '';
												if(isset($node['filename_id']) && $node['filename_id']=='0'){
												    $name  									= 'Other - '.$node['filename'];
												}else{
													$name  									= $node['filename'];
												}
												if($node['type'] == '2'){
													$name  									.= ' - Original';
												}
												$name  										.= ' (Stop '.$load_stop_no.')';
												$pendingDocuments[] 						= $name;
											}
											// Accessorial Documents
											$accessorial_documents 							= $document['accessorial_documents'] ?? [];
											$accessorial_documents        					= array_filter($accessorial_documents, function ($var) {
											    return isset($var['status']) && $var['status'] == 'Pending';
											});
											foreach ($accessorial_documents as $key => $node) {
												$name 										= $node['filename'].' (Stop '.$load_stop_no.')';
												$pendingDocuments[] 						= $name;
											}
										}
									}

									// Dispatch Update
									$response['html']   									= view('driverAdmin.mytrips.ajax.current_dispatch.dispatch_update', compact('item','formData','next','pendingDocuments'))->render();
									$response['success']                                	= true;
									$response['message']                                	= "Dispatch update view retrieved successfully.";
								}
							}
						}
					}
				}
			} catch (\Exception $e) {
				$response['success']                        								= false;
				$response['message']                        								= $e->getMessage();
			}
		}
		return response()->json($response);
	}

	public function dropHookSave(Request $request){
		$response['success']                   												= false;
		$response['message']                   												= "Oops! Something went wrong..";
		if ($request->ajax()) {
		    try {
		    	// 1 = Stop, 0 = No Stop
		    	// Type = ( 1 = Drop, 2 = Hook )
		    	// Customer Type ( 1 = Pickup, 2 = Delivery )
		    	// Schedule Type ( 0 = Live, 1 = Drop Trailer, 2 = Drop & Hook )
		    	// Drop & Hook Trailer , Drop Trailer

		    	// Reminder Status ( 1 = On, 0 = Off )
		    	// Reminder On ( 1 = Email, 2 = SMS )
		    	// Confirm & Match ( 1 = Yes, 0 = No )

		    	$formData                           										= $request->all();
		    	if(isset($formData['jsonData']) && $formData['jsonData']!==''){
		    		$jsonData                           									= json_decode($formData['jsonData'], true);
		    		if(!empty($jsonData)){
		    			$id 																= isset($jsonData['id']) && $jsonData['id']!='' ? $jsonData['id'] : null;
		    			$schedule 															= isset($jsonData['schedule']) && $jsonData['schedule']!='' ? $jsonData['schedule'] : 0;
		    			if(!is_null($id) && in_array($schedule, [1, 2])){
		    				// Drop code
		    				$verified_trailer_id 											= null;
		    				$trailer_numbers_match 											= null;
		    				if(isset($jsonData['trailer_numbers_match']) && $jsonData['trailer_numbers_match'] == 0){
		    					$verified_trailer_id 										= $jsonData['verified_trailer_id'] ?? null;
		    					$trailer_numbers_match 										= 0;
		    				} elseif (isset($jsonData['trailer_numbers_match']) && $jsonData['trailer_numbers_match'] == 1) {
		    					$verified_trailer_id 										= $jsonData['trailer_id'] ?? null;
		    					$trailer_numbers_match 										= 1;
		    				}

		    				$trailer_reminder_on 											= null;
		    				$trailer_reminder_date_time 									= null;
		    				$trailer_reminder_status 										= 0;
		    				if(isset($jsonData['trailer_reminder_status']) && $jsonData['trailer_reminder_status'] == 1){
		    					$trailer_reminder_on                     					= $jsonData['trailer_reminder_on[]'] ?? null;
		    					if (is_array($trailer_reminder_on)) {
		    					    $trailer_reminder_on                					= !empty($trailer_reminder_on) ? implode(',', $trailer_reminder_on) : null;
		    					}
		    					$trailer_reminder_date_time 								= isset($jsonData['trailer_reminder_date_time']) ? convertTimeToUTCzone(['str' => $jsonData['trailer_reminder_date_time'], 'toFormat'=> 'Y-m-d H:i:s', 'fromFormat' => getTimeLayout(), 'userTimezone' => timezone_name_from_abbr($jsonData['abbr'] ?? getTimeZoneId(1))]) : null;
		    					$trailer_reminder_status 									= 1;
		    				}

    						$trailer_files 													= [];
    						if($request->has('uploads')){
    							$uploads 													= $request->uploads;
    							if(!empty($uploads)){
    								foreach ($uploads as $key => $upload) {
    									$arry 												= [];
    									$arry['name'] 										= $upload['name'] ?? '';
    									if(isset($upload['file']) && !empty($upload['file'])){
    										$file 											= $upload['file'];
    										// Generate a unique filename
    									   	$filename 										= Str::uuid() . '.' . $file->extension(); // time().'-'.$file->getClientOriginalName();
    									   	if($filename!=''){
    									   		// Ensure the destination directory exists with 0777 permissions
    				    						Storage::disk('public')->makeDirectory('companyAdmin/drop_hook', 0777, true, true);
    				    						// Open the original image
    				    						$image 										= Image::make($file);

    				    						// Check if the image width is greater than or equal to 1800 pixels
    				    						if ($image->width() >= 1800) {
    					    						// Resize the image to a width of 1800 pixels while maintaining the aspect ratio
    					    						$image->resize(1800, null, function ($constraint) {
    					    						    $constraint->aspectRatio();
    					    						});

    					    						// Set the DPI using Imagick
    											    if (extension_loaded('imagick')) {
    											    	$imagick 							= $image->getCore();
    									    	        $imagick->setImageResolution(72, 72);
    									    	        $imagick->setResolution(72, 72);
    									    	        $imagick->setImageUnits(imagick::RESOLUTION_PIXELSPERINCH);
    									    	        // $imagick->setImageFormat('jpeg');
    									    	        $image->setCore($imagick);
    											    }

    					    						// Set the DPI to 70
    					    						// $image->dpi(70, 70);

    					    						// Save the image in the storage disk without resizing
    					    						$image->save(storage_path('app/public/companyAdmin/drop_hook/' . $filename), 80);
    				    						} else {
    				    							$image->save(storage_path('app/public/companyAdmin/drop_hook/' . $filename));
    				    						}
    				    						// Storage::disk('public')->put('companyAdmin/drop_hook/'.$filename, $image->stream());

    				    						$arry['file']     							= $filename;
    				    						$arry['upload_user_type']    				= 3;
    				    						$arry['upload_by']           				= auth()->guard('driver-admin')->user()->id;
    				    						$arry['uploaded_at']         				= date('Y-m-d H:i:s');
    									   	}
    									}
    									$trailer_files[]       								= $arry;
    								}
    							}
    						}
    						$trailer_files 													= !empty($trailer_files) ? serialize($trailer_files) : null;
		    				// Drop code

		    				if(isset($jsonData['is_stop']) && $jsonData['is_stop'] == 1){
		    					$item                                                   	= LoadStop::where('id', $id)->first();
		    					if(!is_null($item)){
		    						$oldData                                        		= $item->toArray();

		    						if(isset($jsonData['type']) && $jsonData['type'] == 1){
		    							// Drop
		    							$item->verified_drop_trailer_id   					= $verified_trailer_id;
		    							$item->drop_trailer_match   						= $trailer_numbers_match;

		    							$item->drop_trailer_reminder_on   					= $trailer_reminder_on;
		    							$item->drop_trailer_reminder_date_time  			= $trailer_reminder_date_time;
		    							$item->drop_trailer_reminder_status   				= $trailer_reminder_status;

		    							$item->drop_trailer_files   						= $trailer_files;

		    							$item->drop_trailer_confirm   						= 1;
		    							$item->drop_trailer_confirm_at   					= date('Y-m-d H:i:s');
		    						}elseif (isset($jsonData['type']) && $jsonData['type'] == 2) {
		    							// Hook
		    							$item->verified_pickup_trailer_id   				= $verified_trailer_id;
		    							$item->pickup_trailer_match   						= $trailer_numbers_match;

		    							$item->pickup_trailer_files   						= $trailer_files;

		    							$item->pickup_trailer_confirm   					= 1;
		    							$item->pickup_trailer_confirm_at   					= date('Y-m-d H:i:s');
		    						}
		    						$item->updated_at               						= date('Y-m-d H:i:s');
		    						if($item->save()){
		    						    $this->setLoadAudit($item->load_id, 'update', 'Load stop updated', $item->getChanges(), $oldData);

		    							if(isset($jsonData['type']) && $jsonData['type'] == 1){
		    								// Drop
		    								if((isset($item->drop_trailer_match) && $item->drop_trailer_match == 0) && (isset($item->verified_drop_trailer_id) && $item->verified_drop_trailer_id != '')){
		    									$load_detail 								= $item->loads->load_detail ?? null;
		    									if(!is_null($load_detail)){
		    										$driver                         		= $load_detail->driver ?? null;
		    										if(!is_null($driver)){
	    											    $dispatcher                 		= $load_detail->dispatcher ?? null;
		    											if(!is_null($dispatcher)){
		    											    $load_number                	= $load_detail->load_type == 0 || $load_detail->load_type == 6 ? $load_detail->load_number : getLoadTypeList()[$load_detail->load_type];
		    											    $addresses                  	= [];
		    											    if(isset($item->address_one) && $item->address_one!==''){
		    											        $addresses[]            	= $item->address_one;
		    											    }
		    											    if(isset($item->address_two) && $item->address_two!==''){
		    											        $addresses[]            	= $item->address_two;
		    											    }
		    											    if(isset($item->city) && $item->city!==''){
		    											        $addresses[]            	= $item->city;
		    											    }
		    											    if(isset($item->state) && $item->state!==''){
		    											        $addresses[]            	= $item->state;
		    											    }
		    											    if(isset($item->zip) && $item->zip!==''){
		    											        $addresses[]            	= $item->zip;
		    											    }
		    											    $addresses                  	= implode(', ', $addresses);
		    											    $details                    	= [
		    											        'load_number'           	=> $load_number,
		    											        'self_dispatch'         	=> $load_detail->self_dispatch,
		    											        'driver_name'           	=> $driver->full_name,
		    											        'dispatcher_name'       	=> $load_detail->self_dispatch == 1 ? $driver->full_name : $dispatcher->full_name,
		    											        'stop_name'             	=> 'Stop '.($item->stop_no + 1),
		    											        'customer_type'         	=> $item->customer_type == 1 ? 'Pickup' : 'Delivery',
		    											        'addresses'             	=> $addresses,
		    											        'schedule'              	=> 'Drop Trailer',
		    											        'trailer_id'            	=> $item->drop_trailer_id,
		    											        'verified_trailer_id'   	=> $item->verified_drop_trailer_id,
		    											    ];

		    											    $description                	= 'Driver: '.$driver->full_name.' on load number: '.$load_number.' was set to drop trailer: '.$item->drop_trailer_id.' but dropped trailer '.$item->verified_drop_trailer_id.', please confirm this and reassign the trailers accordingly. ';
		    											    \Log::info($details['stop_name'].' '.$details['customer_type'].' ( '.$details['schedule'].' ) => '.$description);

		    											    createNotification(
		    											        22, // source
		    											        'Attention!', // name
		    											        $dispatcher->id, // user_id
		    											        $dispatcher->type, // user_type
		    											        2, // type
		    											        $item->load_id, // action_id
		    											        $description, // description
		    											        'Alert', // module
		    											        [], // properties
		    											        $dispatcher->company_id // company_id
		    											    );

		    											    $checkNotify                	= isUnreadDelay($dispatcher->id, $dispatcher->type, 22);
		    											    if(isset($checkNotify)){
		    											    	if ($checkNotify->email == 1 && isset($dispatcher->email) && $dispatcher->email != '') {
		    											    	    $mailData           	= [];
		    											    	    $mailData['email']  	= $dispatcher->email;
		    											    	    $mailData['name']   	= $dispatcher->full_name;
		    											    	    $mailData['phone']  	= $dispatcher->cell_phone;
		    											    	    $mailData['msg']    	= $description;
		    											    	    $mailData['url']    	= route('company.admin.notifications.index');

		    											    	    try {
		    											    	        Mail::to($dispatcher->email)->send(new UnreadNotificationMailToUser($mailData));
		    											    	    } catch (\Swift_TransportException $e) {
		    											    	        // Handle transport exception (e.g., connection failure)

		    											    	        // Log the error message
		    											    	        Log::error('Email sending failed: ' . $e->getMessage());

		    											    	        // Optionally, you can re-throw the exception if desired
		    											    	        // throw $e;
		    											    	    } catch (\Exception $e) {
		    											    	        // Handle any other exception

		    											    	        // Log the error message
		    											    	        Log::error('An error occurred while sending the email: ' . $e->getMessage());

		    											    	        // Optionally, you can re-throw the exception if desired
		    											    	        // throw $e;
		    											    	    }
		    											    	}
		    											    	if ($checkNotify->sms == 1 && isset($dispatcher->cell_phone) && $dispatcher->cell_phone != '') {
		    											    	    // Twilio's credentials are fetched from company table
		    											    	    $getCompanyTwilioData   = getCompanyTwilioData();
		    											    	    if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
		    											    	    	$messageBody        = $description."\n".route('company.admin.notifications.index');
		    											    	    	sendSMS($dispatcher->cell_phone, $messageBody, $getCompanyTwilioData);
		    											    	    }
		    											    	}
		    											    }
		    											}
		    										}
		    									}
		    								}
		    							}elseif (isset($jsonData['type']) && $jsonData['type'] == 2) {
		    								// Hook
		    								if((isset($item->pickup_trailer_match) && $item->pickup_trailer_match == 0) && (isset($item->verified_pickup_trailer_id) && $item->verified_pickup_trailer_id != '')){
		    									$load_detail 								= $item->loads->load_detail ?? null;
		    									if(!is_null($load_detail)){
		    										$driver                         		= $load_detail->driver ?? null;
		    										if(!is_null($driver)){
	    											    $dispatcher                 		= $load_detail->dispatcher ?? null;
		    											if(!is_null($dispatcher)){
		    											    $load_number                	= $load_detail->load_type == 0 || $load_detail->load_type == 6 ? $load_detail->load_number : getLoadTypeList()[$load_detail->load_type];
		    											    $addresses                  	= [];
		    											    if(isset($item->address_one) && $item->address_one!==''){
		    											        $addresses[]            	= $item->address_one;
		    											    }
		    											    if(isset($item->address_two) && $item->address_two!==''){
		    											        $addresses[]            	= $item->address_two;
		    											    }
		    											    if(isset($item->city) && $item->city!==''){
		    											        $addresses[]            	= $item->city;
		    											    }
		    											    if(isset($item->state) && $item->state!==''){
		    											        $addresses[]            	= $item->state;
		    											    }
		    											    if(isset($item->zip) && $item->zip!==''){
		    											        $addresses[]            	= $item->zip;
		    											    }
		    											    $addresses                  	= implode(', ', $addresses);
		    											    $details                    	= [
		    											        'load_number'           	=> $load_number,
		    											        'self_dispatch'         	=> $load_detail->self_dispatch,
		    											        'driver_name'           	=> $driver->full_name,
		    											        'dispatcher_name'       	=> $load_detail->self_dispatch == 1 ? $driver->full_name : $dispatcher->full_name,
		    											        'stop_name'             	=> 'Stop '.($item->stop_no + 1),
		    											        'customer_type'         	=> $item->customer_type == 1 ? 'Pickup' : 'Delivery',
		    											        'addresses'             	=> $addresses,
		    											        'schedule'              	=> 'Hook Trailer',
		    											        'trailer_id'            	=> $item->pickup_trailer_id,
		    											        'verified_trailer_id'   	=> $item->verified_pickup_trailer_id,
		    											    ];

		    											    $description                	= 'Driver: '.$driver->full_name.' on load number: '.$load_number.' was set to pickup trailer: '.$item->pickup_trailer_id.' but hooked trailer '.$item->verified_pickup_trailer_id.', please confirm this and reassign the trailers accordingly. ';
		    											    \Log::info($details['stop_name'].' '.$details['customer_type'].' ( '.$details['schedule'].' ) => '.$description);

		    											    createNotification(
		    											        22, // source
		    											        'Attention!', // name
		    											        $dispatcher->id, // user_id
		    											        $dispatcher->type, // user_type
		    											        2, // type
		    											        $item->load_id, // action_id
		    											        $description, // description
		    											        'Alert', // module
		    											        [], // properties
		    											        $dispatcher->company_id // company_id
		    											    );

		    											    $checkNotify                	= isUnreadDelay($dispatcher->id, $dispatcher->type, 22);
		    											    if(isset($checkNotify)){
		    											    	if ($checkNotify->email == 1 && isset($dispatcher->email) && $dispatcher->email != '') {
		    											    	    $mailData           	= [];
		    											    	    $mailData['email']  	= $dispatcher->email;
		    											    	    $mailData['name']   	= $dispatcher->full_name;
		    											    	    $mailData['phone']  	= $dispatcher->cell_phone;
		    											    	    $mailData['msg']    	= $description;
		    											    	    $mailData['url']    	= route('company.admin.notifications.index');

		    											    	    try {
		    											    	        Mail::to($dispatcher->email)->send(new UnreadNotificationMailToUser($mailData));
		    											    	    } catch (\Swift_TransportException $e) {
		    											    	        // Handle transport exception (e.g., connection failure)

		    											    	        // Log the error message
		    											    	        Log::error('Email sending failed: ' . $e->getMessage());

		    											    	        // Optionally, you can re-throw the exception if desired
		    											    	        // throw $e;
		    											    	    } catch (\Exception $e) {
		    											    	        // Handle any other exception

		    											    	        // Log the error message
		    											    	        Log::error('An error occurred while sending the email: ' . $e->getMessage());

		    											    	        // Optionally, you can re-throw the exception if desired
		    											    	        // throw $e;
		    											    	    }
		    											    	}
		    											    	if ($checkNotify->sms == 1 && isset($dispatcher->cell_phone) && $dispatcher->cell_phone != '') {
		    											    	    // Twilio's credentials are fetched from company table
		    											    	    $getCompanyTwilioData   = getCompanyTwilioData();
		    											    	    if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
		    											    	    	$messageBody        = $description."\n".route('company.admin.notifications.index');
		    											    	    	sendSMS($dispatcher->cell_phone, $messageBody, $getCompanyTwilioData);
		    											    	    }
		    											    	}
		    											    }
		    											}
		    										}
		    									}
		    								}
		    							}

		    						    $response['success']              					= true;
		    						    $response['message']              					= "Confirm successfully.";
		    						}else{
		    							$response['success']              					= false;
		    							$response['message']              					= "Confirm unsuccessfully.";
		    						}
		    					}
		    				}else{
					    	    $item                             							= LoadDetail::where('id', $id)->first();
					    	    if(!is_null($item)){
					    	    	$oldData                             					= $item->toArray();

					    	    	if(isset($jsonData['type']) && $jsonData['type'] == 1){
					    	    		// Drop
					    	    		if(isset($jsonData['customer_type']) && $jsonData['customer_type'] == 1){
					    	    			// Pickup
					    	    			$item->shipper_verified_drop_trailer_id   		= $verified_trailer_id;
					    	    			$item->shipper_drop_trailer_match   			= $trailer_numbers_match;

					    	    			$item->shipper_drop_trailer_reminder_on   		= $trailer_reminder_on;
					    	    			$item->shipper_drop_trailer_reminder_date_time  = $trailer_reminder_date_time;
					    	    			$item->shipper_drop_trailer_reminder_status   	= $trailer_reminder_status;

					    	    			$item->shipper_drop_trailer_files   			= $trailer_files;

					    	    			$item->shipper_drop_trailer_confirm   			= 1;
					    	    			$item->shipper_drop_trailer_confirm_at   		= date('Y-m-d H:i:s');
					    	    		}elseif (isset($jsonData['customer_type']) && $jsonData['customer_type'] == 2) {
					    	    			// Delivery
					    	    			$item->delivery_verified_drop_trailer_id   		= $verified_trailer_id;
					    	    			$item->delivery_drop_trailer_match   			= $trailer_numbers_match;

					    	    			$item->delivery_drop_trailer_reminder_on   		= $trailer_reminder_on;
					    	    			$item->delivery_drop_trailer_reminder_date_time = $trailer_reminder_date_time;
					    	    			$item->delivery_drop_trailer_reminder_status   	= $trailer_reminder_status;

					    	    			$item->delivery_drop_trailer_files   			= $trailer_files;

					    	    			$item->delivery_drop_trailer_confirm   			= 1;
					    	    			$item->delivery_drop_trailer_confirm_at   		= date('Y-m-d H:i:s');
					    	    		}
					    	    	}elseif (isset($jsonData['type']) && $jsonData['type'] == 2) {
					    	    		// Hook
					    	    		if(isset($jsonData['customer_type']) && $jsonData['customer_type'] == 1){
					    	    			// Pickup
					    	    			$item->shipper_verified_pickup_trailer_id   	= $verified_trailer_id;
					    	    			$item->shipper_pickup_trailer_match   			= $trailer_numbers_match;

					    	    			$item->shipper_pickup_trailer_files   			= $trailer_files;

					    	    			$item->shipper_pickup_trailer_confirm   		= 1;
					    	    			$item->shipper_pickup_trailer_confirm_at   		= date('Y-m-d H:i:s');
					    	    		}elseif (isset($jsonData['customer_type']) && $jsonData['customer_type'] == 2) {
					    	    			// Delivery
					    	    			$item->delivery_verified_pickup_trailer_id   	= $verified_trailer_id;
					    	    			$item->delivery_pickup_trailer_match   			= $trailer_numbers_match;

					    	    			$item->delivery_pickup_trailer_files   			= $trailer_files;

					    	    			$item->delivery_pickup_trailer_confirm   		= 1;
					    	    			$item->delivery_pickup_trailer_confirm_at   	= date('Y-m-d H:i:s');
					    	    		}
					    	    	}
					    	    	$item->updated_at               						= date('Y-m-d H:i:s');
					    	    	if($item->save()){
					    	    		$this->setLoadAudit($item->load_id, 'update', 'Load detail updated', $item->getChanges(), $oldData);

					    	    		if(isset($jsonData['type']) && $jsonData['type'] == 1){
					    	    			// Drop
					    	    			if(isset($jsonData['customer_type']) && $jsonData['customer_type'] == 1){
					    	    				// Pickup
					    	    				if((isset($item->shipper_drop_trailer_match) && $item->shipper_drop_trailer_match == 0) && (isset($item->shipper_verified_drop_trailer_id) && $item->shipper_verified_drop_trailer_id != '')){
					    	    				    $driver                         		= $item->driver ?? null;
					    	    				    if(!is_null($driver)){
				    	    				    	    $dispatcher                 		= $item->dispatcher ?? null;
					    	    				    	if(!is_null($dispatcher)){
					    	    				    	    $load_number                	= $item->load_type == 0 || $item->load_type == 6 ? $item->load_number : getLoadTypeList()[$item->load_type];
					    	    				    	    $addresses                  	= [];
					    	    				    	    if(isset($item->shipper_address_one) && $item->shipper_address_one!==''){
					    	    				    	        $addresses[]            	= $item->shipper_address_one;
					    	    				    	    }
					    	    				    	    if(isset($item->shipper_address_two) && $item->shipper_address_two!==''){
					    	    				    	        $addresses[]            	= $item->shipper_address_two;
					    	    				    	    }
					    	    				    	    if(isset($item->shipper_city) && $item->shipper_city!==''){
					    	    				    	        $addresses[]            	= $item->shipper_city;
					    	    				    	    }
					    	    				    	    if(isset($item->shipper_state) && $item->shipper_state!==''){
					    	    				    	        $addresses[]            	= $item->shipper_state;
					    	    				    	    }
					    	    				    	    if(isset($item->shipper_zip) && $item->shipper_zip!==''){
					    	    				    	        $addresses[]            	= $item->shipper_zip;
					    	    				    	    }
					    	    				    	    $addresses                  	= implode(', ', $addresses);
					    	    				    	    $details                    	= [
					    	    				    	        'load_number'           	=> $load_number,
					    	    				    	        'self_dispatch'         	=> $item->self_dispatch,
					    	    				    	        'driver_name'           	=> $driver->full_name,
					    	    				    	        'dispatcher_name'       	=> $item->self_dispatch == 1 ? $driver->full_name : $dispatcher->full_name,
					    	    				    	        'stop_name'             	=> 'Stop 1',
					    	    				    	        'customer_type'         	=> 'Pickup',
					    	    				    	        'addresses'             	=> $addresses,
					    	    				    	        'schedule'              	=> 'Drop Trailer',
					    	    				    	        'trailer_id'            	=> $item->shipper_drop_trailer_id,
					    	    				    	        'verified_trailer_id'   	=> $item->shipper_verified_drop_trailer_id,
					    	    				    	    ];

					    	    				    	    $description                	= 'Driver: '.$driver->full_name.' on load number: '.$load_number.' was set to drop trailer: '.$item->shipper_drop_trailer_id.' but dropped trailer '.$item->shipper_verified_drop_trailer_id.', please confirm this and reassign the trailers accordingly. ';
					    	    				    	    \Log::info($details['stop_name'].' '.$details['customer_type'].' ( '.$details['schedule'].' ) => '.$description);

					    	    				    	    createNotification(
					    	    				    	        22, // source
					    	    				    	        'Attention!', // name
					    	    				    	        $dispatcher->id, // user_id
					    	    				    	        $dispatcher->type, // user_type
					    	    				    	        2, // type
					    	    				    	        $item->load_id, // action_id
					    	    				    	        $description, // description
					    	    				    	        'Alert', // module
					    	    				    	        [], // properties
					    	    				    	        $dispatcher->company_id // company_id
					    	    				    	    );

					    	    				    	    $checkNotify                	= isUnreadDelay($dispatcher->id, $dispatcher->type, 22);
					    	    				    	    if(isset($checkNotify)){
					    	    				    	    	if ($checkNotify->email == 1 && isset($dispatcher->email) && $dispatcher->email != '') {
					    	    				    	    	    $mailData           	= [];
					    	    				    	    	    $mailData['email']  	= $dispatcher->email;
					    	    				    	    	    $mailData['name']   	= $dispatcher->full_name;
					    	    				    	    	    $mailData['phone']  	= $dispatcher->cell_phone;
					    	    				    	    	    $mailData['msg']    	= $description;
					    	    				    	    	    $mailData['url']    	= route('company.admin.notifications.index');

					    	    				    	    	    try {
					    	    				    	    	        Mail::to($dispatcher->email)->send(new UnreadNotificationMailToUser($mailData));
					    	    				    	    	    } catch (\Swift_TransportException $e) {
					    	    				    	    	        // Handle transport exception (e.g., connection failure)

					    	    				    	    	        // Log the error message
					    	    				    	    	        Log::error('Email sending failed: ' . $e->getMessage());

					    	    				    	    	        // Optionally, you can re-throw the exception if desired
					    	    				    	    	        // throw $e;
					    	    				    	    	    } catch (\Exception $e) {
					    	    				    	    	        // Handle any other exception

					    	    				    	    	        // Log the error message
					    	    				    	    	        Log::error('An error occurred while sending the email: ' . $e->getMessage());

					    	    				    	    	        // Optionally, you can re-throw the exception if desired
					    	    				    	    	        // throw $e;
					    	    				    	    	    }
					    	    				    	    	}
					    	    				    	    	if ($checkNotify->sms == 1 && isset($dispatcher->cell_phone) && $dispatcher->cell_phone != '') {
					    	    				    	    	    // Twilio's credentials are fetched from company table
					    	    				    	    	    $getCompanyTwilioData   = getCompanyTwilioData();
					    	    				    	    	    if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
					    	    				    	    	    	$messageBody        = $description."\n".route('company.admin.notifications.index');
					    	    				    	    	    	sendSMS($dispatcher->cell_phone, $messageBody, $getCompanyTwilioData);
					    	    				    	    	    }
					    	    				    	    	}
					    	    				    	    }
					    	    				    	}
					    	    				    }
					    	    				}
					    	    			}elseif (isset($jsonData['customer_type']) && $jsonData['customer_type'] == 2) {
					    	    				// Delivery
					    	    				if((isset($item->delivery_drop_trailer_match) && $item->delivery_drop_trailer_match == 0) && (isset($item->delivery_verified_drop_trailer_id) && $item->delivery_verified_drop_trailer_id != '')){
					    	    				    $driver                         		= $item->driver ?? null;
					    	    				    if(!is_null($driver)){
				    	    				    	    $dispatcher                 		= $item->dispatcher ?? null;
					    	    				    	if(!is_null($dispatcher)){
					    	    				    	    $load_number                	= $item->load_type == 0 || $item->load_type == 6 ? $item->load_number : getLoadTypeList()[$item->load_type];
					    	    				    	    $addresses                  	= [];
					    	    				    	    if(isset($item->delivery_address_one) && $item->delivery_address_one!==''){
					    	    				    	        $addresses[]            	= $item->delivery_address_one;
					    	    				    	    }
					    	    				    	    if(isset($item->delivery_address_two) && $item->delivery_address_two!==''){
					    	    				    	        $addresses[]            	= $item->delivery_address_two;
					    	    				    	    }
					    	    				    	    if(isset($item->delivery_city) && $item->delivery_city!==''){
					    	    				    	        $addresses[]            	= $item->delivery_city;
					    	    				    	    }
					    	    				    	    if(isset($item->delivery_state) && $item->delivery_state!==''){
					    	    				    	        $addresses[]            	= $item->delivery_state;
					    	    				    	    }
					    	    				    	    if(isset($item->delivery_zip) && $item->delivery_zip!==''){
					    	    				    	        $addresses[]            	= $item->delivery_zip;
					    	    				    	    }
					    	    				    	    $addresses                  	= implode(', ', $addresses);
					    	    				    	    $details                    	= [
					    	    				    	        'load_number'           	=> $load_number,
					    	    				    	        'self_dispatch'         	=> $item->self_dispatch,
					    	    				    	        'driver_name'           	=> $driver->full_name,
					    	    				    	        'dispatcher_name'       	=> $item->self_dispatch == 1 ? $driver->full_name : $dispatcher->full_name,
					    	    				    	        'stop_name'             	=> 'Stop 99',
					    	    				    	        'customer_type'         	=> 'Delivery',
					    	    				    	        'addresses'             	=> $addresses,
					    	    				    	        'schedule'              	=> 'Drop Trailer',
					    	    				    	        'trailer_id'            	=> $item->delivery_drop_trailer_id,
					    	    				    	        'verified_trailer_id'   	=> $item->delivery_verified_drop_trailer_id,
					    	    				    	    ];

					    	    				    	    $description                	= 'Driver: '.$driver->full_name.' on load number: '.$load_number.' was set to drop trailer: '.$item->delivery_drop_trailer_id.' but dropped trailer '.$item->delivery_verified_drop_trailer_id.', please confirm this and reassign the trailers accordingly. ';
					    	    				    	    \Log::info($details['stop_name'].' '.$details['customer_type'].' ( '.$details['schedule'].' ) => '.$description);

					    	    				    	    createNotification(
					    	    				    	        22, // source
					    	    				    	        'Attention!', // name
					    	    				    	        $dispatcher->id, // user_id
					    	    				    	        $dispatcher->type, // user_type
					    	    				    	        2, // type
					    	    				    	        $item->load_id, // action_id
					    	    				    	        $description, // description
					    	    				    	        'Alert', // module
					    	    				    	        [], // properties
					    	    				    	        $dispatcher->company_id // company_id
					    	    				    	    );

					    	    				    	    $checkNotify                	= isUnreadDelay($dispatcher->id, $dispatcher->type, 22);
					    	    				    	    if(isset($checkNotify)){
					    	    				    	    	if ($checkNotify->email == 1 && isset($dispatcher->email) && $dispatcher->email != '') {
					    	    				    	    	    $mailData           	= [];
					    	    				    	    	    $mailData['email']  	= $dispatcher->email;
					    	    				    	    	    $mailData['name']   	= $dispatcher->full_name;
					    	    				    	    	    $mailData['phone']  	= $dispatcher->cell_phone;
					    	    				    	    	    $mailData['msg']    	= $description;
					    	    				    	    	    $mailData['url']    	= route('company.admin.notifications.index');

					    	    				    	    	    try {
					    	    				    	    	        Mail::to($dispatcher->email)->send(new UnreadNotificationMailToUser($mailData));
					    	    				    	    	    } catch (\Swift_TransportException $e) {
					    	    				    	    	        // Handle transport exception (e.g., connection failure)

					    	    				    	    	        // Log the error message
					    	    				    	    	        Log::error('Email sending failed: ' . $e->getMessage());

					    	    				    	    	        // Optionally, you can re-throw the exception if desired
					    	    				    	    	        // throw $e;
					    	    				    	    	    } catch (\Exception $e) {
					    	    				    	    	        // Handle any other exception

					    	    				    	    	        // Log the error message
					    	    				    	    	        Log::error('An error occurred while sending the email: ' . $e->getMessage());

					    	    				    	    	        // Optionally, you can re-throw the exception if desired
					    	    				    	    	        // throw $e;
					    	    				    	    	    }
					    	    				    	    	}
					    	    				    	    	if ($checkNotify->sms == 1 && isset($dispatcher->cell_phone) && $dispatcher->cell_phone != '') {
					    	    				    	    	    // Twilio's credentials are fetched from company table
					    	    				    	    	    $getCompanyTwilioData   = getCompanyTwilioData();
					    	    				    	    	    if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
					    	    				    	    	    	$messageBody        = $description."\n".route('company.admin.notifications.index');
					    	    				    	    	    	sendSMS($dispatcher->cell_phone, $messageBody, $getCompanyTwilioData);
					    	    				    	    	    }
					    	    				    	    	}
					    	    				    	    }
					    	    				    	}
					    	    				    }
					    	    				}
					    	    			}
					    	    		}elseif (isset($jsonData['type']) && $jsonData['type'] == 2) {
					    	    			// Hook
					    	    			if(isset($jsonData['customer_type']) && $jsonData['customer_type'] == 1){
					    	    				// Pickup
					    	    				if((isset($item->shipper_pickup_trailer_match) && $item->shipper_pickup_trailer_match == 0) && (isset($item->shipper_verified_pickup_trailer_id) && $item->shipper_verified_pickup_trailer_id != '')){
					    	    				    $driver                         		= $item->driver ?? null;
					    	    				    if(!is_null($driver)){
			    	    				    	    	$dispatcher                 		= $item->dispatcher ?? null;
					    	    				    	if(!is_null($dispatcher)){
					    	    				    	    $load_number                	= $item->load_type == 0 || $item->load_type == 6 ? $item->load_number : getLoadTypeList()[$item->load_type];
					    	    				    	    $addresses                  	= [];
					    	    				    	    if(isset($item->shipper_address_one) && $item->shipper_address_one!==''){
					    	    				    	        $addresses[]            	= $item->shipper_address_one;
					    	    				    	    }
					    	    				    	    if(isset($item->shipper_address_two) && $item->shipper_address_two!==''){
					    	    				    	        $addresses[]            	= $item->shipper_address_two;
					    	    				    	    }
					    	    				    	    if(isset($item->shipper_city) && $item->shipper_city!==''){
					    	    				    	        $addresses[]            	= $item->shipper_city;
					    	    				    	    }
					    	    				    	    if(isset($item->shipper_state) && $item->shipper_state!==''){
					    	    				    	        $addresses[]            	= $item->shipper_state;
					    	    				    	    }
					    	    				    	    if(isset($item->shipper_zip) && $item->shipper_zip!==''){
					    	    				    	        $addresses[]            	= $item->shipper_zip;
					    	    				    	    }
					    	    				    	    $addresses                  	= implode(', ', $addresses);
					    	    				    	    $details                    	= [
					    	    				    	        'load_number'           	=> $load_number,
					    	    				    	        'self_dispatch'         	=> $item->self_dispatch,
					    	    				    	        'driver_name'           	=> $driver->full_name,
					    	    				    	        'dispatcher_name'       	=> $item->self_dispatch == 1 ? $driver->full_name : $dispatcher->full_name,
					    	    				    	        'stop_name'             	=> 'Stop 1',
					    	    				    	        'customer_type'         	=> 'Pickup',
					    	    				    	        'addresses'             	=> $addresses,
					    	    				    	        'schedule'              	=> 'Hook Trailer',
					    	    				    	        'trailer_id'            	=> $item->shipper_pickup_trailer_id,
					    	    				    	        'verified_trailer_id'   	=> $item->shipper_verified_pickup_trailer_id,
					    	    				    	    ];

					    	    				    	    $description                	= 'Driver: '.$driver->full_name.' on load number: '.$load_number.' was set to pickup trailer: '.$item->shipper_pickup_trailer_id.' but hooked trailer '.$item->shipper_verified_pickup_trailer_id.', please confirm this and reassign the trailers accordingly. ';
					    	    				    	    \Log::info($details['stop_name'].' '.$details['customer_type'].' ( '.$details['schedule'].' ) => '.$description);

					    	    				    	    createNotification(
					    	    				    	        22, // source
					    	    				    	        'Attention!', // name
					    	    				    	        $dispatcher->id, // user_id
					    	    				    	        $dispatcher->type, // user_type
					    	    				    	        2, // type
					    	    				    	        $item->load_id, // action_id
					    	    				    	        $description, // description
					    	    				    	        'Alert', // module
					    	    				    	        [], // properties
					    	    				    	        $dispatcher->company_id // company_id
					    	    				    	    );

					    	    				    	    $checkNotify                	= isUnreadDelay($dispatcher->id, $dispatcher->type, 22);
					    	    				    	    if(isset($checkNotify)){
					    	    				    	    	if ($checkNotify->email == 1 && isset($dispatcher->email) && $dispatcher->email != '') {
					    	    				    	    	    $mailData           	= [];
					    	    				    	    	    $mailData['email']  	= $dispatcher->email;
					    	    				    	    	    $mailData['name']   	= $dispatcher->full_name;
					    	    				    	    	    $mailData['phone']  	= $dispatcher->cell_phone;
					    	    				    	    	    $mailData['msg']    	= $description;
					    	    				    	    	    $mailData['url']    	= route('company.admin.notifications.index');

					    	    				    	    	    try {
					    	    				    	    	        Mail::to($dispatcher->email)->send(new UnreadNotificationMailToUser($mailData));
					    	    				    	    	    } catch (\Swift_TransportException $e) {
					    	    				    	    	        // Handle transport exception (e.g., connection failure)

					    	    				    	    	        // Log the error message
					    	    				    	    	        Log::error('Email sending failed: ' . $e->getMessage());

					    	    				    	    	        // Optionally, you can re-throw the exception if desired
					    	    				    	    	        // throw $e;
					    	    				    	    	    } catch (\Exception $e) {
					    	    				    	    	        // Handle any other exception

					    	    				    	    	        // Log the error message
					    	    				    	    	        Log::error('An error occurred while sending the email: ' . $e->getMessage());

					    	    				    	    	        // Optionally, you can re-throw the exception if desired
					    	    				    	    	        // throw $e;
					    	    				    	    	    }
					    	    				    	    	}
					    	    				    	    	if ($checkNotify->sms == 1 && isset($dispatcher->cell_phone) && $dispatcher->cell_phone != '') {
					    	    				    	    	    // Twilio's credentials are fetched from company table
					    	    				    	    	    $getCompanyTwilioData   = getCompanyTwilioData();
					    	    				    	    	    if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
					    	    				    	    	    	$messageBody        = $description."\n".route('company.admin.notifications.index');
					    	    				    	    	    	sendSMS($dispatcher->cell_phone, $messageBody, $getCompanyTwilioData);
					    	    				    	    	    }
					    	    				    	    	}
					    	    				    	    }
					    	    				    	}
					    	    				    }
					    	    				}
					    	    			}elseif (isset($jsonData['customer_type']) && $jsonData['customer_type'] == 2) {
					    	    				// Delivery
					    	    				if((isset($item->delivery_pickup_trailer_match) && $item->delivery_pickup_trailer_match == 0) && (isset($item->delivery_verified_pickup_trailer_id) && $item->delivery_verified_pickup_trailer_id != '')){
					    	    				    $driver                         		= $item->driver ?? null;
					    	    				    if(!is_null($driver)){
				    	    				    	    $dispatcher                 		= $item->dispatcher ?? null;
					    	    				    	if(!is_null($dispatcher)){
					    	    				    	    $load_number                	= $item->load_type == 0 || $item->load_type == 6 ? $item->load_number : getLoadTypeList()[$item->load_type];
					    	    				    	    $addresses                  	= [];
					    	    				    	    if(isset($item->delivery_address_one) && $item->delivery_address_one!==''){
					    	    				    	        $addresses[]            	= $item->delivery_address_one;
					    	    				    	    }
					    	    				    	    if(isset($item->delivery_address_two) && $item->delivery_address_two!==''){
					    	    				    	        $addresses[]            	= $item->delivery_address_two;
					    	    				    	    }
					    	    				    	    if(isset($item->delivery_city) && $item->delivery_city!==''){
					    	    				    	        $addresses[]            	= $item->delivery_city;
					    	    				    	    }
					    	    				    	    if(isset($item->delivery_state) && $item->delivery_state!==''){
					    	    				    	        $addresses[]            	= $item->delivery_state;
					    	    				    	    }
					    	    				    	    if(isset($item->delivery_zip) && $item->delivery_zip!==''){
					    	    				    	        $addresses[]            	= $item->delivery_zip;
					    	    				    	    }
					    	    				    	    $addresses                  	= implode(', ', $addresses);
					    	    				    	    $details                    	= [
					    	    				    	        'load_number'           	=> $load_number,
					    	    				    	        'self_dispatch'         	=> $item->self_dispatch,
					    	    				    	        'driver_name'           	=> $driver->full_name,
					    	    				    	        'dispatcher_name'       	=> $item->self_dispatch == 1 ? $driver->full_name : $dispatcher->full_name,
					    	    				    	        'stop_name'             	=> 'Stop 99',
					    	    				    	        'customer_type'         	=> 'Delivery',
					    	    				    	        'addresses'             	=> $addresses,
					    	    				    	        'schedule'              	=> 'Hook Trailer',
					    	    				    	        'trailer_id'            	=> $item->delivery_pickup_trailer_id,
					    	    				    	        'verified_trailer_id'   	=> $item->delivery_verified_pickup_trailer_id,
					    	    				    	    ];

					    	    				    	    $description                	= 'Driver: '.$driver->full_name.' on load number: '.$load_number.' was set to pickup trailer: '.$item->delivery_pickup_trailer_id.' but hooked trailer '.$item->delivery_verified_pickup_trailer_id.', please confirm this and reassign the trailers accordingly. ';
					    	    				    	    \Log::info($details['stop_name'].' '.$details['customer_type'].' ( '.$details['schedule'].' ) => '.$description);

					    	    				    	    createNotification(
					    	    				    	        22, // source
					    	    				    	        'Attention!', // name
					    	    				    	        $dispatcher->id, // user_id
					    	    				    	        $dispatcher->type, // user_type
					    	    				    	        2, // type
					    	    				    	        $item->load_id, // action_id
					    	    				    	        $description, // description
					    	    				    	        'Alert', // module
					    	    				    	        [], // properties
					    	    				    	        $dispatcher->company_id // company_id
					    	    				    	    );

					    	    				    	    $checkNotify                	= isUnreadDelay($dispatcher->id, $dispatcher->type, 22);
					    	    				    	    if(isset($checkNotify)){
					    	    				    	    	if ($checkNotify->email == 1 && isset($dispatcher->email) && $dispatcher->email != '') {
					    	    				    	    	    $mailData           	= [];
					    	    				    	    	    $mailData['email']  	= $dispatcher->email;
					    	    				    	    	    $mailData['name']   	= $dispatcher->full_name;
					    	    				    	    	    $mailData['phone']  	= $dispatcher->cell_phone;
					    	    				    	    	    $mailData['msg']    	= $description;
					    	    				    	    	    $mailData['url']    	= route('company.admin.notifications.index');

					    	    				    	    	    try {
					    	    				    	    	        Mail::to($dispatcher->email)->send(new UnreadNotificationMailToUser($mailData));
					    	    				    	    	    } catch (\Swift_TransportException $e) {
					    	    				    	    	        // Handle transport exception (e.g., connection failure)

					    	    				    	    	        // Log the error message
					    	    				    	    	        Log::error('Email sending failed: ' . $e->getMessage());

					    	    				    	    	        // Optionally, you can re-throw the exception if desired
					    	    				    	    	        // throw $e;
					    	    				    	    	    } catch (\Exception $e) {
					    	    				    	    	        // Handle any other exception

					    	    				    	    	        // Log the error message
					    	    				    	    	        Log::error('An error occurred while sending the email: ' . $e->getMessage());

					    	    				    	    	        // Optionally, you can re-throw the exception if desired
					    	    				    	    	        // throw $e;
					    	    				    	    	    }
					    	    				    	    	}
					    	    				    	    	if ($checkNotify->sms == 1 && isset($dispatcher->cell_phone) && $dispatcher->cell_phone != '') {
					    	    				    	    	    // Twilio's credentials are fetched from company table
					    	    				    	    	    $getCompanyTwilioData   = getCompanyTwilioData();
					    	    				    	    	    if(isset($getCompanyTwilioData['active']) && $getCompanyTwilioData['active'] == 'yes'){
					    	    				    	    	    	$messageBody        = $description."\n".route('company.admin.notifications.index');
					    	    				    	    	    	sendSMS($dispatcher->cell_phone, $messageBody, $getCompanyTwilioData);
					    	    				    	    	    }
					    	    				    	    	}
					    	    				    	    }
					    	    				    	}
					    	    				    }
					    	    				}
					    	    			}
					    	    		}

					    	    	    $response['success']              					= true;
					    	    	    $response['message']              					= "Confirm successfully.";
					    	    	}else{
					    	    	    $response['success']              					= false;
					    	    	    $response['message']              					= "Confirm successfully.";
					    	    	}
					    	    }
		    				}
		    			}
		    		}
		    	}
		    } catch (\Exception $e) {
		        $response['success']                        								= false;
		        $response['message']                        								= $e->getMessage();
		    }
		}
		return response()->json($response);
	}

	public function currentFileSave(Request $request){
		$response['success']                   										= false;
		$response['message']                   										= "Oops! Something went wrong..";
		if ($request->ajax()) {
		    try {
		    	$formData                           								= $request->all();

		    	if(isset($formData['jsonData']) && $formData['jsonData']!==''){
		    		$jsonData                           							= json_decode($formData['jsonData'], true);
		    		$oldJsonData                           							= $jsonData;

		    		if(isset($jsonData['source'])){
		    			if(in_array($jsonData['source'], ['load_details', 'load_stops'])){
		    				$getArray                                        		= [];
		    				if($jsonData['source'] == 'load_details'){
		    				    $item                                 				= LoadDetail::whereId($jsonData['id'])->first();
		    				    if(!is_null($item)){
		    				    	if ($jsonData['field_name'] == 'shipper_files_upload') {
		    				    	    $getArray                              		= isset($item->shipper_files_upload) && is_serialized($item->shipper_files_upload) && !empty(unserialize($item->shipper_files_upload)) ? unserialize($item->shipper_files_upload) : [];
		    				    	} else if ($jsonData['field_name'] == 'consignee_files_upload') {
		    				    	    $getArray                                       = isset($item->consignee_files_upload) && is_serialized($item->consignee_files_upload) && !empty(unserialize($item->consignee_files_upload)) ? unserialize($item->consignee_files_upload) : [];
		    				    	}
		    				    }
		    				}else{
		    				    $item                                           	= LoadStop::whereId($jsonData['id'])->first();
		    				    if(!is_null($item)){
		    				    	if($jsonData['field_name'] == 'stop_shipper_files_upload'){
		    				    	    $getArray                                	= isset($item->stop_shipper_files_upload) && is_serialized($item->stop_shipper_files_upload) && !empty(unserialize($item->stop_shipper_files_upload)) ? unserialize($item->stop_shipper_files_upload) : [];
		    				    	} else if ($jsonData['field_name'] == 'stop_consignee_files_upload') {
		    				    	    $getArray                                	= isset($item->stop_consignee_files_upload) && is_serialized($item->stop_consignee_files_upload) && !empty(unserialize($item->stop_consignee_files_upload)) ? unserialize($item->stop_consignee_files_upload) : [];
		    				    	}
		    				    }
		    				}

		    				if(!empty($getArray)){
		    					$saveArray                                      	= [];
		    					foreach($getArray as $data){
		    					    if(
		    					    	(isset($data['name_id']) && $data['name_id'] == $jsonData['filename_id']) &&
		    					    	(isset($data['name']) && $data['name'] == $jsonData['filename']) &&
		    					    	(isset($data['type']) && $data['type'] == $jsonData['type'])
		    					    ){
		    					    	if(isset($formData['files']) && !empty($formData['files'])){
		    					    		$files                                  = isset($data['file']) && !empty($data['file']) ? $data['file'] : null;
		    					    		if(isset($files) && !empty($files)){
		    					    		    foreach ($files as $key => $file) {
		    					    		        $path                       	= 'storage/companyAdmin/load_detail_document/'.$file;
		    					    		        if (File::exists($path)) {
		    					    		            File::delete($path);
		    					    		        }
		    					    		    }
		    					    		}
		    					    		$data['is_received']          			= 'on';
		    					    		$data['file_not_provided']          	= 'off';
		    					    		$data['file']                 			= UploadImagePdf($formData['files'], 'companyAdmin/load_detail_document');
		    					    		$data['upload_user_type']     			= 3; // For Driver User Type
		    					    		$data['upload_by']            			= auth()->guard('driver-admin')->user()->id;
		    					    		$data['uploaded_at']          			= Carbon::now();

		    					    		// Update jsonData
		    					    		$jsonData['is_received'] 				= $data['is_received'];
		    					    		$jsonData['file_not_provided'] 			= $data['file_not_provided'];
		    					    		$jsonData['file'] 						= $data['file'];
		    					    		$jsonData['upload_user_type'] 			= $data['upload_user_type'];
		    					    		$jsonData['upload_by'] 					= $data['upload_by'];
		    					    		$jsonData['status'] 					= 'Complete';
		    					    	}else{
		    					    		$is_received 							= isset($formData['is_received']) && $formData['is_received'] == 'on' ? 'on' : 'off';
		    					    		$file_not_provided 						= isset($formData['file_not_provided']) && $formData['file_not_provided'] == 'on' ? 'on' : 'off';
		    					    		// Type 1 = Copy, 2 = Original
		    					    		if($data['type'] == 1){
		    					    			if($file_not_provided == 'on'){
		    					    				$files                       	= isset($data['file']) && !empty($data['file']) ? $data['file'] : null;
		    					    				if(isset($files) && !empty($files)){
		    					    				    foreach ($files as $key => $file) {
		    					    				        $path               	= 'storage/companyAdmin/load_detail_document/'.$file;
		    					    				        if (File::exists($path)) {
		    					    				            File::delete($path);
		    					    				        }
		    					    				    }
		    					    				}

		    					    				$data['is_received']          	= 'off';
		    					    				$data['file_not_provided']   	= 'on';
		    					    				$data['file']                 	= null;
		    					    				if(isset($data['upload_user_type'])){
		    					    					unset($data['upload_user_type']);
		    					    				}
		    					    				if(isset($data['upload_by'])){
		    					    					unset($data['upload_by']);
		    					    				}
		    					    				if(isset($data['uploaded_at'])){
		    					    					unset($data['uploaded_at']);
		    					    				}

		    					    				// Update jsonData
		    					    				$jsonData['is_received'] 		= $data['is_received'];
		    					    				$jsonData['file_not_provided'] 	= $data['file_not_provided'];
		    					    				$jsonData['file'] 				= $data['file'];
		    					    				if(isset($jsonData['upload_user_type'])){
		    					    					unset($jsonData['upload_user_type']);
		    					    				}
		    					    				if(isset($jsonData['upload_by'])){
		    					    					unset($jsonData['upload_by']);
		    					    				}
		    					    				$jsonData['status'] 			= 'Pending';
		    					    			}else{
		    					    				$data['file_not_provided']   	= 'off';

		    					    				// Update jsonData
		    					    				$jsonData['file_not_provided'] 	= $data['file_not_provided'];
		    					    			}
		    					    		}else{
		    					    			if($is_received == 'on'){
		    					    				$data['is_received']            = 'on';
		    					    				$data['file_not_provided']    	= 'off';
		    					    				$data['upload_user_type']     	= 3; // For Driver User Type
		    					    				$data['upload_by']            	= auth()->guard('driver-admin')->user()->id;
		    					    				$data['uploaded_at']          	= Carbon::now();

		    					    				// Update jsonData
		    					    				$jsonData['is_received'] 		= $data['is_received'];
		    					    				$jsonData['file_not_provided'] 	= $data['file_not_provided'];
		    					    				$jsonData['upload_user_type'] 	= $data['upload_user_type'];
		    					    				$jsonData['upload_by'] 			= $data['upload_by'];
		    					    				$jsonData['status'] 			= 'Complete';
		    					    			}else{
		    					    				$data['is_received']         	= 'off';
		    					    				$data['file_not_provided']    	= 'on';
		    					    				if(isset($data['upload_user_type'])){
		    					    					unset($data['upload_user_type']);
		    					    				}
		    					    				if(isset($data['upload_by'])){
		    					    					unset($data['upload_by']);
		    					    				}
		    					    				if(isset($data['uploaded_at'])){
		    					    					unset($data['uploaded_at']);
		    					    				}

		    					    				// Update jsonData
		    					    				$jsonData['is_received'] 		= $data['is_received'];
		    					    				$jsonData['file_not_provided'] 	= $data['file_not_provided'];
		    					    				if(isset($jsonData['upload_user_type'])){
		    					    					unset($jsonData['upload_user_type']);
		    					    				}
		    					    				if(isset($jsonData['upload_by'])){
		    					    					unset($jsonData['upload_by']);
		    					    				}
		    					    				$jsonData['status'] 			= 'Pending';
		    					    			}
		    					    		}
		    					    	}
		    					    }
		    					    $saveArray[]                            		= $data;
		    					}

		    					if(isset($item)){
		    						if($jsonData['field_name'] == 'shipper_files_upload'){
		    						    $oldData                                    = $item->toArray();
		    						    $item->update(['shipper_files_upload' => serialize($saveArray)]);
		    						    $this->setLoadAudit($item->load_id, 'update', 'Load detail updated', $item->getChanges(), $oldData);
		    						}
		    						if($jsonData['field_name'] == 'consignee_files_upload'){
		    						    $oldData                                    = $item->toArray();
		    						    $item->update(['consignee_files_upload' => serialize($saveArray)]);
		    						    $this->setLoadAudit($item->load_id, 'update', 'Load detail updated', $item->getChanges(), $oldData);
		    						}
		    						if($jsonData['field_name'] == 'stop_shipper_files_upload'){
		    						    $oldData                                    = $item->toArray();
		    						    $item->update(['stop_shipper_files_upload' => serialize($saveArray)]);
		    						    $this->setLoadAudit($item->load_id, 'update', 'Load stop updated', $item->getChanges(), $oldData);
		    						}
		    						if($jsonData['field_name'] == 'stop_consignee_files_upload'){
		    						    $oldData                                    = $item->toArray();
		    						    $item->update(['stop_consignee_files_upload' => serialize($saveArray)]);
		    						    $this->setLoadAudit($item->load_id, 'update', 'Load stop updated', $item->getChanges(), $oldData);
		    						}
		    					}
		    				}
		    			}elseif($jsonData['source'] == 'load_document_request_items'){
		    				$load_document_request_item                             = LoadDocumentRequestItem::where('id', $jsonData['id'])->first();
		    				if(!is_null($load_document_request_item)){
		    					$oldData                                            = $load_document_request_item->toArray();

		    					$data                                         		= [];
		    					if(isset($load_document_request_item->files) && is_serialized($load_document_request_item->files) && !empty(unserialize($load_document_request_item->files))){
		    					    $data                                    	 	= unserialize($load_document_request_item->files);
		    					}

		    					if(!empty($data)){
		    						if(isset($formData['files']) && !empty($formData['files'])){
		    							$files                                 		= isset($data['file']) && !empty($data['file']) ? $data['file'] : null;
		    							if(isset($files) && !empty($files)){
		    							    foreach ($files as $key => $file) {
		    							        $path                       		= 'storage/companyAdmin/load_detail_document/'.$file;
		    							        if (File::exists($path)) {
		    							            File::delete($path);
		    							        }
		    							    }
		    							}
		    							$data['is_received']          				= 'on';
		    							$data['file_not_provided']          		= 'off';
		    							$data['file']                 				= UploadImagePdf($formData['files'], 'companyAdmin/load_detail_document');
		    							$data['upload_user_type']     				= 3; // For Driver User Type
		    							$data['upload_by']            				= auth()->guard('driver-admin')->user()->id;
		    							$data['uploaded_at']          				= Carbon::now();

		    							// Update jsonData
		    							$jsonData['is_received'] 					= $data['is_received'];
		    							$jsonData['file_not_provided'] 				= $data['file_not_provided'];
		    							$jsonData['file'] 							= $data['file'];
		    							$jsonData['upload_user_type'] 				= $data['upload_user_type'];
		    							$jsonData['upload_by'] 						= $data['upload_by'];
		    							$jsonData['status'] 						= 'Complete';
		    						}else{
		    							$is_received 								= isset($formData['is_received']) && $formData['is_received'] == 'on' ? 'on' : 'off';
		    							$file_not_provided 							= isset($formData['file_not_provided']) && $formData['file_not_provided'] == 'on' ? 'on' : 'off';
		    							// Type 1 = Copy, 2 = Original
		    							if($data['type'] == 1){
		    								if($file_not_provided == 'on'){
		    									$files                       		= isset($data['file']) && !empty($data['file']) ? $data['file'] : null;
		    									if(isset($files) && !empty($files)){
		    									    foreach ($files as $key => $file) {
		    									        $path               		= 'storage/companyAdmin/load_detail_document/'.$file;
		    									        if (File::exists($path)) {
		    									            File::delete($path);
		    									        }
		    									    }
		    									}

		    									$data['is_received']          		= 'off';
		    									$data['file_not_provided']   		= 'on';
		    									$data['file']                 		= null;
		    									if(isset($data['upload_user_type'])){
		    										unset($data['upload_user_type']);
		    									}
		    									if(isset($data['upload_by'])){
		    										unset($data['upload_by']);
		    									}
		    									if(isset($data['uploaded_at'])){
		    										unset($data['uploaded_at']);
		    									}

		    									// Update jsonData
		    									$jsonData['is_received'] 			= $data['is_received'];
		    									$jsonData['file_not_provided'] 		= $data['file_not_provided'];
		    									$jsonData['file'] 					= $data['file'];
		    									if(isset($jsonData['upload_user_type'])){
		    										unset($jsonData['upload_user_type']);
		    									}
		    									if(isset($jsonData['upload_by'])){
		    										unset($jsonData['upload_by']);
		    									}
		    									$jsonData['status'] 				= 'Pending';
		    								}else{
		    									$data['file_not_provided']   		= 'off';

		    									// Update jsonData
		    									$jsonData['file_not_provided'] 		= $data['file_not_provided'];
		    								}
		    							}else{
		    								if($is_received == 'on'){
		    									$data['is_received']            	= 'on';
		    									$data['file_not_provided']    		= 'off';
		    									$data['upload_user_type']     		= 3; // For Driver User Type
		    									$data['upload_by']            		= auth()->guard('driver-admin')->user()->id;
		    									$data['uploaded_at']          		= Carbon::now();

		    									// Update jsonData
		    									$jsonData['is_received'] 			= $data['is_received'];
		    									$jsonData['file_not_provided'] 		= $data['file_not_provided'];
		    									$jsonData['upload_user_type'] 		= $data['upload_user_type'];
		    									$jsonData['upload_by'] 				= $data['upload_by'];
		    									$jsonData['status'] 				= 'Complete';
		    								}else{
		    									$data['is_received']         		= 'off';
		    									$data['file_not_provided']    		= 'on';
		    									if(isset($data['upload_user_type'])){
		    										unset($data['upload_user_type']);
		    									}
		    									if(isset($data['upload_by'])){
		    										unset($data['upload_by']);
		    									}
		    									if(isset($data['uploaded_at'])){
		    										unset($data['uploaded_at']);
		    									}

		    									// Update jsonData
		    									$jsonData['is_received'] 			= $data['is_received'];
		    									$jsonData['file_not_provided'] 		= $data['file_not_provided'];
		    									if(isset($jsonData['upload_user_type'])){
		    										unset($jsonData['upload_user_type']);
		    									}
		    									if(isset($jsonData['upload_by'])){
		    										unset($jsonData['upload_by']);
		    									}
		    									$jsonData['status'] 				= 'Pending';
		    								}
		    							}
		    						}
		    					}

		    					$load_document_request_item->files                  = !empty($data) ? serialize($data) : null;
		    					$load_document_request_item->updated_at             = date('Y-m-d H:i:s');
		    					$load_document_request_item->updated_by             = auth()->guard('driver-admin')->user()->id;
		    					$load_document_request_item->updated_by_type        = 3;
		    					if($load_document_request_item->save()){
		    					    $this->setLoadAudit($load_document_request_item->load_id, 'update', 'Load document request item updated', $load_document_request_item->getChanges(), $oldData);
		    					}
		    				}
		    			}elseif($jsonData['source'] == 'load_accessorials'){
		    				$load_accessorial                                       = LoadAccessorial::where('id', $jsonData['id'])->first();
		    				if(!is_null($load_accessorial)){
		    					$oldData                                        	= $load_accessorial->toArray();

		    					$gallery                                            = Gallery::where('company_id', auth()->guard('driver-admin')->user()->company_id)
		    					    ->where('action_id', $load_accessorial->id)
		    					    ->where('source', 'load_accessorials')
		    					    ->where('field_name', 'accessorial_files')
		    					    ->first();
		    					if(isset($formData['files']) && !empty($formData['files'])){
		    						$is_upload                                      = 0;

	    							$imageName 										= null;
	    							// Invalid file type! Please select only jpg, jpeg, png, gif, or pdf files. - only Accessorial
	    							$fileArray                  					= UploadImagePdf($formData['files'], 'companyAdmin/gallery');
	    							// Get the first element
	    							$firstElement 									= reset($fileArray);
	    							// Check if $firstElement exists
	    							if (isset($firstElement)) {
	    								// Extract filename and extension
    								    $filenameWithExtension 						= pathinfo($firstElement, PATHINFO_EXTENSION);
    								    if($filenameWithExtension == 'pdf'){
    								    	$imageName 								= $firstElement;
    								    }
	    							}
	    							if(isset($imageName) && $imageName != ''){
	    								if(!is_null($gallery)){
	    									$path                               	= 'storage/companyAdmin/gallery/'.$gallery->image;
	    									if (File::exists($path)) {
	    									    File::delete($path);
	    									}

	    									$gallery->image                       	= $imageName;
	    									$gallery->created_by                    = auth()->guard('driver-admin')->user()->id;
	    									$gallery->created_by_type               = 3;
	    									$gallery->uploaded_date                 = Carbon::now()->format('m/d/Y H:i');
	    									if($gallery->save()){
	    										$is_upload                         	= 1;
	    									}
	    								}else{
	    									$input                                	= [];
	    									$input['company_id']                  	= auth()->guard('driver-admin')->user()->company_id;
	    									$input['action_id']                   	= $load_accessorial->id;
	    									$input['source']                      	= 'load_accessorials';
	    									$input['field_name']                  	= 'accessorial_files';
	    									$input['file_name']                   	= null;
	    									$input['file_type']                   	= getRequestDocumentsList('load_accessorials','source')['file_type'];
	    									$input['image']                       	= $imageName;
	    									$input['include_w_billing']           	= 'no';
	    									$input['hide_from_driver']            	= 'no';
	    									$input['status']                      	= 'approved';
	    									$input['created_by']                  	= auth()->guard('driver-admin')->user()->id;
	    									$input['created_by_type']             	= 3;
	    									$input['uploaded_date']               	= Carbon::now()->format('m/d/Y H:i');
	    									$gallery 								= Gallery::create($input);

	    									$is_upload                            	= 1;
	    								}
	    							}

	    							if($is_upload==1){
	    								// Update jsonData
	    								$jsonData['is_received']             		= 'on';
	    								$jsonData['file_not_provided']        		= 'off';
	    								$jsonData['file'] 							= $gallery->image;
	    								$jsonData['upload_user_type']      			= isset($gallery->created_by_type) ? $gallery->created_by_type : null;
	    								$jsonData['upload_by']                  	= isset($gallery->created_by) ? $gallery->created_by : null;
	    								$jsonData['status']                   		= 'Complete';

    									// Load accessorial
    								    $load_accessorial->is_received              = 1;
    								    $load_accessorial->file_not_provided        = 'off';

    								    //status
    								    $arry                                       = [];
    								    $paid_type                                  = $load_accessorial->paid_type;
    								    $reference                                  = $load_accessorial->reference;
    								    $total                                      = $load_accessorial->total;

    								    $owner_liable                               = $load_accessorial->owner_liable;
    								    $owner_total                                = $load_accessorial->owner_total;

    								    $driver_liable                              = $load_accessorial->driver_liable;
    								    $driver_total                               = $load_accessorial->driver_total;

    								    $doc_required                               = $load_accessorial->doc_required;

    								    array_push($arry, $paid_type!=''?1:0);
    								    array_push($arry, $reference!=''?1:0);
    								    array_push($arry, $total!=''?1:0);
    								    if($owner_liable=='1'){
    								        array_push($arry, $owner_total!=''?1:0);
    								    }
    								    if($driver_liable=='1'){
    								        array_push($arry, $driver_total!=''?1:0);
    								    }

    								    if(in_array(0, $arry)){
    								        $load_accessorial->status               = 0; // Pending
    								    }else{
    								        if($doc_required=='1'){
    								            if($load_accessorial->is_received==1){
    								                $load_accessorial->status       = 1; // Completed
    								            }else{
    								                $load_accessorial->status       = 0; // Pending
    								            }
    								        }else{
    								            $load_accessorial->status           = 1; // Completed
    								        }
    								    }
    								    if ($driver_liable=='1' && $load_accessorial->status!=1 && isset($load_accessorial->file_not_provided) && $load_accessorial->file_not_provided=='on') {
    								        $load_accessorial->status               = 2; // Driver Bypass
    								    }
    								    //status

    								    if($load_accessorial->save()){
    								    	$this->setLoadAudit($load_accessorial->load_id, 'update', 'Load accessorial updated', $load_accessorial->getChanges(), $oldData);
    								    }
	    							}
		    					}else{
		    						$file_not_provided 								= isset($formData['file_not_provided']) && $formData['file_not_provided'] == 'on' ? 'on' : 'off';
		    						if($file_not_provided == 'on'){
		    							if(!is_null($gallery)){
		    								$path                               	= 'storage/companyAdmin/gallery/'.$gallery->image;
		    								if (File::exists($path)) {
		    								    File::delete($path);
		    								}
		    								$gallery->image                       	= null;
		    								$gallery->created_by                    = auth()->guard('driver-admin')->user()->id;
		    								$gallery->created_by_type             	= 3;
		    								$gallery->uploaded_date                	= Carbon::now()->format('m/d/Y H:i');
		    								$gallery->save();
		    							}

    									// Update jsonData
    									$jsonData['is_received'] 					= 'off';
    									$jsonData['file_not_provided']   			= 'on';
    									$jsonData['file'] 							= $gallery->image ?? null;
    									if(isset($jsonData['upload_user_type'])){
    										unset($jsonData['upload_user_type']);
    									}
    									if(isset($jsonData['upload_by'])){
    										unset($jsonData['upload_by']);
    									}
    									$jsonData['status'] 						= 'Pending';

										// Load accessorial
									    $load_accessorial->is_received      		= 0;
									    $load_accessorial->file_not_provided		= 'on';

									    //status
									    $arry                              			= [];
									    $paid_type                         			= $load_accessorial->paid_type;
									    $reference                         			= $load_accessorial->reference;
									    $total                             			= $load_accessorial->total;

									    $owner_liable                      			= $load_accessorial->owner_liable;
									    $owner_total                       			= $load_accessorial->owner_total;

									    $driver_liable                     			= $load_accessorial->driver_liable;
									    $driver_total                      			= $load_accessorial->driver_total;

									    $doc_required                      			= $load_accessorial->doc_required;

									    array_push($arry, $paid_type!=''?1:0);
									    array_push($arry, $reference!=''?1:0);
									    array_push($arry, $total!=''?1:0);
									    if($owner_liable=='1'){
									        array_push($arry, $owner_total!=''?1:0);
									    }
									    if($driver_liable=='1'){
									        array_push($arry, $driver_total!=''?1:0);
									    }

									    if(in_array(0, $arry)){
									        $load_accessorial->status        		= 0; // Pending
									    }else{
									        if($doc_required=='1'){
									            if($load_accessorial->is_received==1){
									                $load_accessorial->status 		= 1; // Completed
									            }else{
									                $load_accessorial->status 		= 0; // Pending
									            }
									        }else{
									            $load_accessorial->status    		= 1; // Completed
									        }
									    }
									    if ($driver_liable=='1' && $load_accessorial->status!=1 && isset($load_accessorial->file_not_provided) && $load_accessorial->file_not_provided=='on') {
									        $load_accessorial->status        		= 2; // Driver Bypass
									    }
									    //status

									    if($load_accessorial->save()){
									    	$this->setLoadAudit($load_accessorial->load_id, 'update', 'Load accessorial updated', $load_accessorial->getChanges(), $oldData);
									    }
		    						}else{
		    							// Update jsonData
		    							$jsonData['file_not_provided'] 				= 'off';

	    								// Load accessorial
	    							    $load_accessorial->is_received      		= 0;
	    							    $load_accessorial->file_not_provided		= 'off';

	    							    //status
	    							    $arry                              			= [];
	    							    $paid_type                         			= $load_accessorial->paid_type;
	    							    $reference                         			= $load_accessorial->reference;
	    							    $total                             			= $load_accessorial->total;

	    							    $owner_liable                      			= $load_accessorial->owner_liable;
	    							    $owner_total                       			= $load_accessorial->owner_total;

	    							    $driver_liable                     			= $load_accessorial->driver_liable;
	    							    $driver_total                      			= $load_accessorial->driver_total;

	    							    $doc_required                      			= $load_accessorial->doc_required;

	    							    array_push($arry, $paid_type!=''?1:0);
	    							    array_push($arry, $reference!=''?1:0);
	    							    array_push($arry, $total!=''?1:0);
	    							    if($owner_liable=='1'){
	    							        array_push($arry, $owner_total!=''?1:0);
	    							    }
	    							    if($driver_liable=='1'){
	    							        array_push($arry, $driver_total!=''?1:0);
	    							    }

	    							    if(in_array(0, $arry)){
	    							        $load_accessorial->status        		= 0; // Pending
	    							    }else{
	    							        if($doc_required=='1'){
	    							            if($load_accessorial->is_received==1){
	    							                $load_accessorial->status 		= 1; // Completed
	    							            }else{
	    							                $load_accessorial->status 		= 0; // Pending
	    							            }
	    							        }else{
	    							            $load_accessorial->status    		= 1; // Completed
	    							        }
	    							    }
	    							    if ($driver_liable=='1' && $load_accessorial->status!=1 && isset($load_accessorial->file_not_provided) && $load_accessorial->file_not_provided=='on') {
	    							        $load_accessorial->status        		= 2; // Driver Bypass
	    							    }
	    							    //status

	    							    if($load_accessorial->save()){
	    							    	$this->setLoadAudit($load_accessorial->load_id, 'update', 'Load accessorial updated', $load_accessorial->getChanges(), $oldData);
	    							    }
		    						}
		    					}
		    				}
		    			}
		    		}
		    	}

	    		$typeUserId 														= '3_'.auth()->guard('driver-admin')->user()->id;

	    		$response['html']   												= view('driverAdmin.mytrips.ajax.current_dispatch.document_detail', compact('formData','jsonData','typeUserId'))->render();
		    	$response['success']                        						= true;
		    	$response['message']                        						= "Save successfully.";
		    } catch (\Exception $e) {
		        $response['success']                        						= false;
		        $response['message']                        						= $e->getMessage();
		    }
		}
		return response()->json($response);
	}

	public function currentFileRemove(Request $request){
		$response['success']                   										= false;
		$response['message']                   										= "Oops! Something went wrong..";
		if ($request->ajax()) {
		    try {
		    	$formData                           								= $request->all();

		    	if(isset($formData['jsonData']) && $formData['jsonData']!==''){
		    		$jsonData                           							= json_decode($formData['jsonData'], true);
		    		$oldJsonData                           							= $jsonData;

		    		if(isset($jsonData['source'])){
		    			if(in_array($jsonData['source'], ['load_details', 'load_stops'])){
		    				$getArray                                        		= [];
		    				if($jsonData['source'] == 'load_details'){
		    				    $item                                 				= LoadDetail::whereId($jsonData['id'])->first();
		    				    if(!is_null($item)){
		    				    	if ($jsonData['field_name'] == 'shipper_files_upload') {
		    				    	    $getArray                              		= isset($item->shipper_files_upload) && is_serialized($item->shipper_files_upload) && !empty(unserialize($item->shipper_files_upload)) ? unserialize($item->shipper_files_upload) : [];
		    				    	} else if ($jsonData['field_name'] == 'consignee_files_upload') {
		    				    	    $getArray                                       = isset($item->consignee_files_upload) && is_serialized($item->consignee_files_upload) && !empty(unserialize($item->consignee_files_upload)) ? unserialize($item->consignee_files_upload) : [];
		    				    	}
		    				    }
		    				}else{
		    				    $item                                           	= LoadStop::whereId($jsonData['id'])->first();
		    				    if(!is_null($item)){
		    				    	if($jsonData['field_name'] == 'stop_shipper_files_upload'){
		    				    	    $getArray                                	= isset($item->stop_shipper_files_upload) && is_serialized($item->stop_shipper_files_upload) && !empty(unserialize($item->stop_shipper_files_upload)) ? unserialize($item->stop_shipper_files_upload) : [];
		    				    	} else if ($jsonData['field_name'] == 'stop_consignee_files_upload') {
		    				    	    $getArray                                	= isset($item->stop_consignee_files_upload) && is_serialized($item->stop_consignee_files_upload) && !empty(unserialize($item->stop_consignee_files_upload)) ? unserialize($item->stop_consignee_files_upload) : [];
		    				    	}
		    				    }
		    				}

		    				if(!empty($getArray)){
		    					$saveArray                                      	= [];
		    					foreach($getArray as $data){
		    					    if(
		    					    	(isset($data['name_id']) && $data['name_id'] == $jsonData['filename_id']) &&
		    					    	(isset($data['name']) && $data['name'] == $jsonData['filename']) &&
		    					    	(isset($data['type']) && $data['type'] == $jsonData['type'])
		    					    ){
		    					    	if($jsonData['type'] == 1){
		    					    		// Copy
		    					    		$files                                  = isset($data['file']) && !empty($data['file']) ? $data['file'] : null;
		    					    		if(isset($files) && !empty($files)){
		    					    		    foreach ($files as $key => $file) {
		    					    		        $path                       	= 'storage/companyAdmin/load_detail_document/'.$file;
		    					    		        if (File::exists($path)) {
		    					    		            File::delete($path);
		    					    		        }
		    					    		    }
		    					    		}
		    					    		$data['is_received']          			= 'off';
		    					    		$data['file_not_provided']          	= 'on';
		    					    		$data['file']                 			= null;
		    					    		if(isset($data['upload_user_type'])){
		    					    			unset($data['upload_user_type']);
		    					    		}
		    					    		if(isset($data['upload_by'])){
		    					    			unset($data['upload_by']);
		    					    		}
		    					    		if(isset($data['uploaded_at'])){
		    					    			unset($data['uploaded_at']);
		    					    		}

		    					    		// Update jsonData
		    					    		$jsonData['is_received'] 				= $data['is_received'];
		    					    		$jsonData['file_not_provided'] 			= $data['file_not_provided'];
		    					    		$jsonData['file'] 						= $data['file'];
		    					    		if(isset($jsonData['upload_user_type'])){
		    					    			unset($jsonData['upload_user_type']);
		    					    		}
		    					    		if(isset($jsonData['upload_by'])){
		    					    			unset($jsonData['upload_by']);
		    					    		}
		    					    		$jsonData['status'] 					= 'Pending';
		    					    	}
		    					    }
		    					    $saveArray[]                            		= $data;
		    					}

		    					if(isset($item)){
		    						if($jsonData['field_name'] == 'shipper_files_upload'){
		    						    $oldData                                    = $item->toArray();
		    						    $item->update(['shipper_files_upload' => serialize($saveArray)]);
		    						    $this->setLoadAudit($item->load_id, 'update', 'Load detail updated', $item->getChanges(), $oldData);
		    						}
		    						if($jsonData['field_name'] == 'consignee_files_upload'){
		    						    $oldData                                    = $item->toArray();
		    						    $item->update(['consignee_files_upload' => serialize($saveArray)]);
		    						    $this->setLoadAudit($item->load_id, 'update', 'Load detail updated', $item->getChanges(), $oldData);
		    						}
		    						if($jsonData['field_name'] == 'stop_shipper_files_upload'){
		    						    $oldData                                    = $item->toArray();
		    						    $item->update(['stop_shipper_files_upload' => serialize($saveArray)]);
		    						    $this->setLoadAudit($item->load_id, 'update', 'Load stop updated', $item->getChanges(), $oldData);
		    						}
		    						if($jsonData['field_name'] == 'stop_consignee_files_upload'){
		    						    $oldData                                    = $item->toArray();
		    						    $item->update(['stop_consignee_files_upload' => serialize($saveArray)]);
		    						    $this->setLoadAudit($item->load_id, 'update', 'Load stop updated', $item->getChanges(), $oldData);
		    						}
		    					}
		    				}
		    			}elseif($jsonData['source'] == 'load_document_request_items'){
		    				$load_document_request_item                             = LoadDocumentRequestItem::where('id', $jsonData['id'])->whereNotNull('files')->first();
		    				if(!is_null($load_document_request_item)){
		    					$oldData                                            = $load_document_request_item->toArray();

		    					$data                                         		= [];
		    					if(isset($load_document_request_item->files) && is_serialized($load_document_request_item->files) && !empty(unserialize($load_document_request_item->files))){
		    					    $data                                    	 	= unserialize($load_document_request_item->files);
		    					}

		    					if(!empty($data)){
		    						if($jsonData['type'] == 1){
		    							// Copy
		    							$files                                  	= isset($data['file']) && !empty($data['file']) ? $data['file'] : null;
		    							if(isset($files) && !empty($files)){
		    							    foreach ($files as $key => $file) {
		    							        $path                       		= 'storage/companyAdmin/load_detail_document/'.$file;
		    							        if (File::exists($path)) {
		    							            File::delete($path);
		    							        }
		    							    }
		    							}
		    							$data['is_received']          				= 'off';
		    							$data['file_not_provided']          		= 'on';
		    							$data['file']                 				= null;
		    							if(isset($data['upload_user_type'])){
		    								unset($data['upload_user_type']);
		    							}
		    							if(isset($data['upload_by'])){
		    								unset($data['upload_by']);
		    							}
		    							if(isset($data['uploaded_at'])){
		    								unset($data['uploaded_at']);
		    							}

		    							// Update jsonData
		    							$jsonData['is_received'] 					= $data['is_received'];
		    							$jsonData['file_not_provided'] 				= $data['file_not_provided'];
		    							$jsonData['file'] 							= $data['file'];
		    							if(isset($jsonData['upload_user_type'])){
		    								unset($jsonData['upload_user_type']);
		    							}
		    							if(isset($jsonData['upload_by'])){
		    								unset($jsonData['upload_by']);
		    							}
		    							$jsonData['status'] 						= 'Pending';
		    						}
		    					}

		    					$load_document_request_item->files                  = !empty($data) ? serialize($data) : null;
		    					$load_document_request_item->updated_at             = date('Y-m-d H:i:s');
		    					$load_document_request_item->updated_by             = auth()->guard('driver-admin')->user()->id;
		    					$load_document_request_item->updated_by_type        = 3;
		    					if($load_document_request_item->save()){
		    					    $this->setLoadAudit($load_document_request_item->load_id, 'update', 'Load document request item updated', $load_document_request_item->getChanges(), $oldData);
		    					}
		    				}
		    			}elseif($jsonData['source'] == 'load_accessorials'){
		    				$load_accessorial                                       = LoadAccessorial::where('id', $jsonData['id'])->where('is_received', 1)->first();
		    				if(!is_null($load_accessorial)){
		    					$oldData                                        	= $load_accessorial->toArray();

		    					$gallery                                            = Gallery::where('company_id', auth()->guard('driver-admin')->user()->company_id)
		    					    ->where('action_id', $load_accessorial->id)
		    					    ->where('source', 'load_accessorials')
		    					    ->where('field_name', 'accessorial_files')
		    					    ->whereNotNull('image')
		    					    ->first();
		    					if(!is_null($gallery)){
		    						$path                                       	= 'storage/companyAdmin/gallery/'.$gallery->image;
		    						if (File::exists($path)) {
		    						    File::delete($path);
		    						}
		    						$gallery->image                             	= null;
		    						$gallery->created_by                            = auth()->guard('driver-admin')->user()->id;
		    						$gallery->created_by_type                       = 3;
		    						$gallery->uploaded_date                         = Carbon::now()->format('m/d/Y H:i');
		    						if($gallery->save()){
		    							// Update jsonData
		    							$jsonData['is_received'] 					= 'off';
		    							$jsonData['file_not_provided'] 				= 'on';
		    							$jsonData['file'] 							= $gallery->image;
		    							if(isset($jsonData['upload_user_type'])){
		    								unset($jsonData['upload_user_type']);
		    							}
		    							if(isset($jsonData['upload_by'])){
		    								unset($jsonData['upload_by']);
		    							}
		    							$jsonData['status'] 						= 'Pending';

	    								// Load accessorial
	    							    $load_accessorial->is_received              = 0;
	    							    $load_accessorial->file_not_provided        = 'on';

	    							    //status
	    							    $arry                                       = [];
	    							    $paid_type                                  = $load_accessorial->paid_type;
	    							    $reference                                  = $load_accessorial->reference;
	    							    $total                                      = $load_accessorial->total;

	    							    $owner_liable                               = $load_accessorial->owner_liable;
	    							    $owner_total                                = $load_accessorial->owner_total;

	    							    $driver_liable                              = $load_accessorial->driver_liable;
	    							    $driver_total                               = $load_accessorial->driver_total;

	    							    $doc_required                               = $load_accessorial->doc_required;

	    							    array_push($arry, $paid_type!=''?1:0);
	    							    array_push($arry, $reference!=''?1:0);
	    							    array_push($arry, $total!=''?1:0);
	    							    if($owner_liable=='1'){
	    							        array_push($arry, $owner_total!=''?1:0);
	    							    }
	    							    if($driver_liable=='1'){
	    							        array_push($arry, $driver_total!=''?1:0);
	    							    }

	    							    if(in_array(0, $arry)){
	    							        $load_accessorial->status               = 0; // Pending
	    							    }else{
	    							        if($doc_required=='1'){
	    							            if($load_accessorial->is_received==1){
	    							                $load_accessorial->status       = 1; // Completed
	    							            }else{
	    							                $load_accessorial->status       = 0; // Pending
	    							            }
	    							        }else{
	    							            $load_accessorial->status           = 1; // Completed
	    							        }
	    							    }
	    							    if ($driver_liable=='1' && $load_accessorial->status!=1 && isset($load_accessorial->file_not_provided) && $load_accessorial->file_not_provided=='on') {
	    							        $load_accessorial->status               = 2; // Driver Bypass
	    							    }
	    							    //status

	    							    if($load_accessorial->save()){
	    							    	$this->setLoadAudit($load_accessorial->load_id, 'update', 'Load accessorial updated', $load_accessorial->getChanges(), $oldData);
	    							    }
		    						}
		    					}
		    				}
		    			}
		    		}
		    	}

		    	$typeUserId 														= '3_'.auth()->guard('driver-admin')->user()->id;

		    	$response['html']   												= view('driverAdmin.mytrips.ajax.current_dispatch.document_detail', compact('formData','jsonData','typeUserId'))->render();
		    	$response['success']                        						= true;
		    	$response['message']                        						= "Remove successfully.";
		    } catch (\Exception $e) {
		        $response['success']                        						= false;
		        $response['message']                        						= $e->getMessage();
		    }
		}
		return response()->json($response);
	}

	public function additionalFileSave(Request $request){
		$response['success']                   					= false;
		$response['message']                   					= "Oops! Something went wrong..";
		if ($request->ajax()) {
		    try {
		    	$formData                          				= $request->all();

		    	$added 											= 0;
		    	$additional_file 								= [
		    		'name_id' 									=> $formData['additional_filename_id'],
		    	    'name' 										=> $formData['additional_filename'],
		    	    'is_required' 								=> 'on',
		    	    'type' 										=>  '1',
		    	    'fixed' 									=> 'no',
		    	    'include_w_billing' 						=> $formData['additional_file_include_w_billing'] == 'yes' ? 'yes' : 'no',
		    	    'custom' 									=> 'yes'
		    	];
		    	$additional_upload 								= [
		    		'name_id' 									=> $additional_file['name_id'],
		    		'name' 										=> $additional_file['name'],
		    		'is_required' 								=> $additional_file['is_required'],
		    		'type' 										=> $additional_file['type'],
		    		'fixed' 									=> $additional_file['fixed'],
		    		'include_w_billing' 						=> $additional_file['include_w_billing'],
		    		'custom' 									=> $additional_file['custom'],
		    		'is_received' 								=> 'off',
		    		'hide_from_driver' 							=> 'no',
		    		'file_not_provided' 						=> 'off',
		    		'file' 										=> null
		    	];
		    	$additional_document 							= [
		    		'id' 										=> $formData['additional_file_id'],
		    		'source' 									=> $formData['additional_file_source'],
		    		'field_name' 								=> $formData['additional_file_field_name'],
		    		'filename' 									=> $additional_upload['name'],
		    		'filename_id' 								=> $additional_upload['name_id'],
		    		'type' 										=> $additional_upload['type'],
		    		'is_received' 								=> $additional_upload['is_received'],
		    		'file_not_provided' 						=> 'off',
		    		'file' 										=> null,
		    		'status' 									=> 'Pending'
		    	];

				if($formData['additional_file_source'] == 'load_details'){
					$item                                 		= LoadDetail::whereId($formData['additional_file_id'])->first();
					if(!is_null($item)){
						$oldData                        		= $item->toArray();

						if ($formData['additional_file_field_name'] == 'shipper_files_upload') {
							$files                       		= isset($item->shipper_files) && is_serialized($item->shipper_files) && !empty(unserialize($item->shipper_files)) ? unserialize($item->shipper_files) : [];
							if(!empty($files)){
								$filteredArray 					= array_filter($files, function($var) use ($additional_file) {
									return isset($var['name_id']) && $var['name_id'] == $additional_file['name_id'] &&
							               isset($var['name']) && $var['name'] == $additional_file['name'] &&
							               isset($var['type']) && $var['type'] == $additional_file['type'];
							    });
							    if(count($filteredArray) > 0){
							    	$response['success']  		= false;
							    	$response['message']  		= "Document exists!";
							    	return response()->json($response);
							    }
							}
							$files[] 							= $additional_file;
							$uploads                    		= isset($item->shipper_files_upload) && is_serialized($item->shipper_files_upload) && !empty(unserialize($item->shipper_files_upload)) ? unserialize($item->shipper_files_upload) : [];
							$uploads[] 							= $additional_upload;

							$item->update([
								'shipper_files' 				=> serialize($files),
								'shipper_files_upload' 			=> serialize($uploads)
							]);
							if ($item->wasChanged()) {
								$added 							= 1;
								$this->setLoadAudit($item->load_id, 'update', 'Load detail updated', $item->getChanges(), $oldData);
							}
						} else if ($formData['additional_file_field_name'] == 'consignee_files_upload') {
							$files                      		= isset($item->consignee_files) && is_serialized($item->consignee_files) && !empty(unserialize($item->consignee_files)) ? unserialize($item->consignee_files) : [];
							if(!empty($files)){
								$filteredArray 					= array_filter($files, function($var) use ($additional_file) {
									return isset($var['name_id']) && $var['name_id'] == $additional_file['name_id'] &&
							               isset($var['name']) && $var['name'] == $additional_file['name'] &&
							               isset($var['type']) && $var['type'] == $additional_file['type'];
							    });
							    if(count($filteredArray) > 0){
							    	$response['success']  		= false;
							    	$response['message']  		= "Document exists!";
							    	return response()->json($response);
							    }
							}
							$files[] 							= $additional_file;
							$uploads                    		= isset($item->consignee_files_upload) && is_serialized($item->consignee_files_upload) && !empty(unserialize($item->consignee_files_upload)) ? unserialize($item->consignee_files_upload) : [];
							$uploads[] 							= $additional_upload;

							$item->update([
								'consignee_files' 				=> serialize($files),
								'consignee_files_upload' 		=> serialize($uploads)
							]);
							if ($item->wasChanged()) {
								$added 							= 1;
								$this->setLoadAudit($item->load_id, 'update', 'Load detail updated', $item->getChanges(), $oldData);
							}
						}
					}
				}else{
					$item                               		= LoadStop::whereId($formData['additional_file_id'])->first();
					if(!is_null($item)){
						$oldData                        		= $item->toArray();

						if ($formData['additional_file_field_name'] == 'stop_shipper_files_upload') {
							$files                   			= isset($item->stop_shipper_files) && is_serialized($item->stop_shipper_files) && !empty(unserialize($item->stop_shipper_files)) ? unserialize($item->stop_shipper_files) : [];
							if(!empty($files)){
								$filteredArray 					= array_filter($files, function($var) use ($additional_file) {
									return isset($var['name_id']) && $var['name_id'] == $additional_file['name_id'] &&
							               isset($var['name']) && $var['name'] == $additional_file['name'] &&
							               isset($var['type']) && $var['type'] == $additional_file['type'];
							    });
							    if(count($filteredArray) > 0){
							    	$response['success']  		= false;
							    	$response['message']  		= "Document exists!";
							    	return response()->json($response);
							    }
							}
							$files[] 							= $additional_file;
							$uploads                     		= isset($item->stop_shipper_files_upload) && is_serialized($item->stop_shipper_files_upload) && !empty(unserialize($item->stop_shipper_files_upload)) ? unserialize($item->stop_shipper_files_upload) : [];
							$uploads[] 							= $additional_upload;

							$item->update([
								'stop_shipper_files' 			=> serialize($files),
								'stop_shipper_files_upload' 	=> serialize($uploads)
							]);
							if ($item->wasChanged()) {
								$added 							= 1;
								$this->setLoadAudit($item->load_id, 'update', 'Load stop updated', $item->getChanges(), $oldData);
							}
						} else if ($formData['additional_file_field_name'] == 'stop_consignee_files_upload') {
							$files                    			= isset($item->stop_consignee_files) && is_serialized($item->stop_consignee_files) && !empty(unserialize($item->stop_consignee_files)) ? unserialize($item->stop_consignee_files) : [];
							if(!empty($files)){
								$filteredArray 					= array_filter($files, function($var) use ($additional_file) {
									return isset($var['name_id']) && $var['name_id'] == $additional_file['name_id'] &&
							               isset($var['name']) && $var['name'] == $additional_file['name'] &&
							               isset($var['type']) && $var['type'] == $additional_file['type'];
							    });
							    if(count($filteredArray) > 0){
							    	$response['success']  		= false;
							    	$response['message']  		= "Document exists!";
							    	return response()->json($response);
							    }
							}
							$files[] 							= $additional_file;
							$uploads                        	= isset($item->stop_consignee_files_upload) && is_serialized($item->stop_consignee_files_upload) && !empty(unserialize($item->stop_consignee_files_upload)) ? unserialize($item->stop_consignee_files_upload) : [];
							$uploads[] 							= $additional_upload;

							$item->update([
								'stop_consignee_files' 			=> serialize($files),
								'stop_consignee_files_upload' 	=> serialize($uploads)
							]);
							if ($item->wasChanged()) {
								$added 							= 1;
								$this->setLoadAudit($item->load_id, 'update', 'Load stop updated', $item->getChanges(), $oldData);
							}
						}
					}
				}

				if(!empty($added)){
					$response['html']   						= view('driverAdmin.mytrips.ajax.current_dispatch.additional_document_detail', compact('formData','additional_document'))->render();
					$response['success']                        = true;
					$response['message']                        = "Save successfully.";
				}
		    } catch (\Exception $e) {
		        $response['success']                        	= false;
		        $response['message']                        	= $e->getMessage();
		    }
		}
		return response()->json($response);
	}

	public function historicDispatch(Request $request){
		if ($request->ajax()) {
			$search     			= $request->search['value'] ?? '';
			$query 					= LoadDetail::query();
			$query->where('load_details.driver_id', auth()->guard('driver-admin')->user()->id);
			$query->where( function($q) {
			    $q->whereIn('load_details.load_status', [5, 6, 10, 8]) // 5 = Delivered, 6 = Ready to Bill, 10 = Invoiced, 8 = Paid
			    	->where('load_details.load_type', 0) // 0 = OCCUPIED
			    	->where('load_details.is_disable', 0)
			    	->where('load_details.send_notification', 1)
			    	->where(function($q) {
			    	    $q->whereNull('load_details.is_on_hold')->orWhereIn('load_details.is_on_hold', [0, 1]);
			    	});
			});
			return Datatables::eloquent($query)
			    ->addIndexColumn()
			    ->addColumn('action', function($row){
			        return '<a href="javascript:void(0);"><i class="fa fa-angle-right" aria-hidden="true"></i></a>';
			    })
    		    ->addColumn('icon', function($row){
    	    		return '';
    		    })
	    	    ->addColumn('status', function($row){
	        		return '';
	    	    })
			    ->editColumn('load_number', function($row){
			    	return '<a href="javascript:void(0);" class="text-dark-blue">'.$row->load_number.'</a>';
			    })
			    ->editColumn('agreed_upon_rate', function($row){
			        return getPrice($row->agreed_upon_rate);
			    })
			    ->filterColumn('agreed_upon_rate', function ($query, $keyword) use ($search) {
			    	// Remove non-numeric characters from the keyword
			    	$numericKeyword = preg_replace("/[^0-9.]/", "", $search);
			    	if($numericKeyword!=''){
			    		// Apply the filter based on the cleaned numeric keyword
			    		$query->where('agreed_upon_rate', 'LIKE', "%{$numericKeyword}%");
			    	}
			    })
			    ->addColumn('cpm', function($row){
			    	$cpm 			= 0.00;
			    	if($row->agreed_upon_rate > 0 && $row->total_miles > 0){
			    		$cpm 		= round($row->agreed_upon_rate / $row->total_miles, 2);
			    	}
			    	return getPrice($cpm);
			    })
			    ->filterColumn('cpm', function ($query, $keyword) use ($search) {
			    	// Remove non-numeric characters from the keyword
			    	$numericKeyword = preg_replace("/[^0-9.]/", "", $search);
			    	if($numericKeyword!=''){
				    	// Apply the filter based on the cleaned numeric keyword
	    	            $query->whereRaw('ROUND(agreed_upon_rate / total_miles, 2) like ?', ["%{$numericKeyword}%"]);
			    	}
			    })
			    ->editColumn('actual_shipper_date', function($row){
			        return !is_null($row->actual_shipper_date) ? $row->actual_shipper_date.' '.$row->shipper_timezone_abbr : '';
			    })
			    ->filterColumn('actual_shipper_date', function ($query, $keyword) use ($search) {
			        if(auth()->guard('driver-admin')->user()->time_format=='12'){
			            $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_shipper_date,'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ', IFNULL(load_details.shipper_timezone_abbr, '')) like ?", ["%$search%"]);
			        }else{
			            $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_shipper_date,'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ', IFNULL(load_details.shipper_timezone_abbr, '')) like ?", ["%$search%"]);
			        }
			    })
			    ->editColumn('actual_delivery_date', function($row){
			        return !is_null($row->actual_delivery_date) ? $row->actual_delivery_date.' '.$row->delivery_timezone_abbr : '';
			    })
			    ->filterColumn('actual_delivery_date', function ($query, $keyword) use ($search) {
			        if(auth()->guard('driver-admin')->user()->time_format=='12'){
			            $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.12_hour','%m/%d/%Y %h:%i %A')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
			        }else{
			            $query->whereRaw("CONCAT(DATE_FORMAT(load_details.actual_delivery_date,'".config('settings.database_date_time_format.24_hour','%m/%d/%Y %H:%i')."'),' ', IFNULL(load_details.delivery_timezone_abbr, '')) like ?", ["%$search%"]);
			        }
			    })
			    ->editColumn('shipper_location', function($row){
			        $html 			= [];
			        if($row->shipper_address_one){
			            $html[0]    = $row->shipper_address_one;
			        }
			        if($row->shipper_address_two){
			            $html[1]    = $row->shipper_address_two;
			        }
			        if($row->shipper_city){
			            $html[2]    = $row->shipper_city;
			        }
			        if($row->shipper_state){
			            $html[3]    = $row->shipper_state;
			        }
			        if($row->shipper_zip){
			            $html[4]    = $row->shipper_zip;
			        }
			        if(count($html) == 0){
			            return $row->shipper_location;
			        }else{
			            return implode(', ', $html);
			        }
			    })
			    ->filterColumn('shipper_location', function ($query, $keyword) use ($search) {
			    	$query->whereRaw("CONCAT_WS(', ', NULLIF(load_details.shipper_address_one, ''), NULLIF(load_details.shipper_address_two, ''), NULLIF(load_details.shipper_city, ''), NULLIF(load_details.shipper_state, ''), NULLIF(load_details.shipper_zip, '')) LIKE ?", ['%' . $search . '%']);
			    })
			    ->editColumn('delivery_location', function($row){
			        $html           = [];
			        if($row->delivery_address_one){
			            $html[0]    = $row->delivery_address_one;
			        }
			        if($row->delivery_address_two){
			            $html[1]    = $row->delivery_address_two;
			        }
			        if($row->delivery_city){
			            $html[2]    = $row->delivery_city;
			        }
			        if($row->delivery_state){
			            $html[3]    = $row->delivery_state;
			        }
			        if($row->delivery_zip){
			            $html[4]    = $row->delivery_zip;
			        }
			        if(count($html) == 0){
			            return $row->delivery_location;
			        }else{
			            return implode(', ', $html);
			        }
			    })
			    ->filterColumn('delivery_location', function ($query, $keyword) use ($search) {
			    	$query->whereRaw("CONCAT_WS(', ', NULLIF(load_details.delivery_address_one, ''), NULLIF(load_details.delivery_address_two, ''), NULLIF(load_details.delivery_city, ''), NULLIF(load_details.delivery_state, ''), NULLIF(load_details.delivery_zip, '')) LIKE ?", ['%' . $search . '%']);
			    })
			    ->editColumn('trailer_number', function($row){
			    	if(isset($row->loads->load_trailers) && $row->loads->load_trailers->isNotEmpty()){
			    		$trailers 	= [];
			    		$trailers[] = $row->trailer_number;

			    		$extra 		= $row->loads->load_trailers->pluck('trailer_number')->toArray();
			    		$trailers 	= array_merge($trailers, $extra);
			    		if(count($trailers) > 1){
			    			$html 	= '<ul>';
			    			foreach ($trailers as $key => $value) {
			    				$html .= '<li>'.$value.'</li>';
			    			}
			    			$html 	.= '</ul>';
			    			return '<a href="javascript:void(0);" class="text-dark multiple-trailers">'.count($trailers).' Trailers</a>
			    				<div class="trailer-tooltip d-none">'.$html.'</div>
			    			';
			    		}else{
			    			return $trailers[0];
			    		}
			    	}else{
			    		return $row->trailer_number;
			    	}
			    })
			    ->filterColumn('trailer_number', function ($query, $keyword) use ($search) {
			    	$query->where('load_details.trailer_number', 'like', ['%' . $search . '%'])
			    		->orWhereHas('loads.load_trailers', function ($query) use ($search) {
				    	    $query->where('load_trailers.trailer_number', 'like', ['%' . $search . '%']);
				    	});
			    })
			    ->rawColumns(['action','icon','status','load_number','trailer_number'])
			    ->make(true);
		}
	}

	public function historicDispatchStatus(Request $request){
		$response['success']             								= false;
		$response['message']             								= "Oops! Something went wrong..";
		if($request->ajax()){
			try {
				$formdata                   							= $request->all();
				$load_detail 											= LoadDetail::whereId($formdata['id'])->first();
				if(!is_null($load_detail)){
					$getLoadDocuments 									= $this->getLoadDocuments($load_detail);

					// Merge Documents
					$merged_documents                            		= $getLoadDocuments['merged_documents'];

					$statusValues 										= array_column($merged_documents, 'status');

					$response['status']   								= in_array('Pending', $statusValues) ? 0 : 1; // 0 = Missing Paperwork, 1 = Complete
					$response['success']  								= true;
					$response['message']  								= "Status retrieved successfully.";
				}
			} catch (\Exception $e) {
			    $response['success']     								= false;
			    $response['message']     								= $e->getMessage();
			}
		}
		return response()->json($response);
	}

	public function historicDispatchDetail(Request $request){
		$response['success']             								= false;
		$response['message']             								= "Oops! Something went wrong..";
		if($request->ajax()){
			try {
				$formdata                   							= $request->all();
				$load_detail 											= LoadDetail::whereId($formdata['id'])->first();
				if(!is_null($load_detail)){
					$getLoadDocuments 									= $this->getLoadDocuments($load_detail);

					// Static Documents
					$static_documents                            		= $getLoadDocuments['static_documents'];
					// Required Documents
					$required_documents  								= $getLoadDocuments['required_documents'];
					// Requested Documents
					$requested_documents                              	= $getLoadDocuments['requested_documents'];
					// Accessorial Documents
					$accessorial_documents                            	= $getLoadDocuments['accessorial_documents'];
					// Other Documents
					$other_documents                                  	= $getLoadDocuments['other_documents'];
					// COD Documents
					$cod_documents                                    	= $getLoadDocuments['cod_documents'];

					if($request->has('status')){
						// 0 = Missing Paperwork, 1 = All Paperwork
						if($request->status == 0){
							$static_documents          					= array_filter($static_documents, function ($var) {
							    return isset($var['status']) && $var['status'] == 'Pending';
							});
							$required_documents          				= array_filter($required_documents, function ($var) {
							    return isset($var['status']) && $var['status'] == 'Pending';
							});
							$requested_documents          				= array_filter($requested_documents, function ($var) {
							    return isset($var['status']) && $var['status'] == 'Pending';
							});
							$accessorial_documents          			= array_filter($accessorial_documents, function ($var) {
							    return isset($var['status']) && $var['status'] == 'Pending';
							});
							$cod_documents          					= array_filter($cod_documents, function ($var) {
							    return isset($var['status']) && $var['status'] == 'Pending';
							});
							$other_documents          					= array_filter($other_documents, function ($var) {
							    return isset($var['status']) && $var['status'] == 'Pending';
							});
						}
					}

					$typeUserId 										= '3_'.auth()->guard('driver-admin')->user()->id;

					// $response['html']   								= view('driverAdmin.mytrips.ajax.historic_dispatch.detail', compact('formdata','load_detail','typeUserId','static_documents','required_documents','requested_documents','accessorial_documents','other_documents','cod_documents'))->render();
					$response['html']   								= view('driverAdmin.mytrips.ajax.historic_dispatch.detail-new', compact('formdata','load_detail','typeUserId','static_documents','required_documents','requested_documents','accessorial_documents','other_documents','cod_documents'))->render();
					$response['success']  								= true;
					$response['message']  								= "Detail retrieved successfully.";
				}
			} catch (\Exception $e) {
			    $response['success']     								= false;
			    $response['message']     								= $e->getMessage();
			}
		}
		return response()->json($response);
	}

	public function historicFileSave(Request $request){
		$response['success']                   										= false;
		$response['message']                   										= "Oops! Something went wrong..";
		if ($request->ajax()) {
		    try {
		    	$formData                           								= $request->all();
		    	if(isset($formData['jsonData']) && $formData['jsonData']!==''){
		    		$jsonData                           							= json_decode($formData['jsonData'], true);
		    		$oldJsonData                           							= $jsonData;

		    		if(isset($jsonData['source'])){
		    			if(in_array($jsonData['source'], ['load_details', 'load_stops'])){
		    				$getArray                                        		= [];
		    				if($jsonData['source'] == 'load_details'){
		    				    $item                                 				= LoadDetail::whereId($jsonData['id'])->first();
		    				    if(!is_null($item)){
		    				    	if ($jsonData['field_name'] == 'shipper_files_upload') {
		    				    	    $getArray                              		= isset($item->shipper_files_upload) && is_serialized($item->shipper_files_upload) && !empty(unserialize($item->shipper_files_upload)) ? unserialize($item->shipper_files_upload) : [];
		    				    	} else if ($jsonData['field_name'] == 'consignee_files_upload') {
		    				    	    $getArray                                       = isset($item->consignee_files_upload) && is_serialized($item->consignee_files_upload) && !empty(unserialize($item->consignee_files_upload)) ? unserialize($item->consignee_files_upload) : [];
		    				    	}
		    				    }
		    				}else{
		    				    $item                                           	= LoadStop::whereId($jsonData['id'])->first();
		    				    if(!is_null($item)){
		    				    	if($jsonData['field_name'] == 'stop_shipper_files_upload'){
		    				    	    $getArray                                	= isset($item->stop_shipper_files_upload) && is_serialized($item->stop_shipper_files_upload) && !empty(unserialize($item->stop_shipper_files_upload)) ? unserialize($item->stop_shipper_files_upload) : [];
		    				    	} else if ($jsonData['field_name'] == 'stop_consignee_files_upload') {
		    				    	    $getArray                                	= isset($item->stop_consignee_files_upload) && is_serialized($item->stop_consignee_files_upload) && !empty(unserialize($item->stop_consignee_files_upload)) ? unserialize($item->stop_consignee_files_upload) : [];
		    				    	}
		    				    }
		    				}

		    				if(!empty($getArray)){
		    					$saveArray                                      	= [];
		    					foreach($getArray as $data){
		    					    if(
		    					    	(isset($data['name_id']) && $data['name_id'] == $jsonData['filename_id']) &&
		    					    	(isset($data['name']) && $data['name'] == $jsonData['filename']) &&
		    					    	(isset($data['type']) && $data['type'] == $jsonData['type'])
		    					    ){
		    					    	if(isset($formData['is_received'])){
		    					    		$data['is_received']              		= 'on';
		    					    		$data['file_not_provided']          	= 'off';
		    					    		$data['upload_user_type']     			= 3; // For Driver User Type
		    					    		$data['upload_by']            			= auth()->guard('driver-admin')->user()->id;
		    					    		$data['uploaded_at']          			= Carbon::now();

		    					    		// Update jsonData
		    					    		$jsonData['is_received'] 				= $data['is_received'];
		    					    		$jsonData['upload_user_type'] 			= $data['upload_user_type'];
		    					    		$jsonData['upload_by'] 					= $data['upload_by'];
		    					    		$jsonData['uploaded_by'] 				= isset($data['upload_by']) ? getUserByType($data['upload_by'], $data['upload_user_type']) : null;
		    					    		$jsonData['uploaded_at'] 				= Carbon::createFromFormat('Y-m-d H:i:s', $data['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId;
		    					    		$jsonData['status'] 					= 'Complete';
		    					    	} else if(isset($formData['files']) && !empty($formData['files'])){
		    					    		$files                                  = isset($data['file']) && !empty($data['file']) ? $data['file'] : null;
		    					    		if(isset($files) && !empty($files)){
		    					    		    foreach ($files as $key => $file) {
		    					    		        $path                       	= 'storage/companyAdmin/load_detail_document/'.$file;
		    					    		        if (File::exists($path)) {
		    					    		            File::delete($path);
		    					    		        }
		    					    		    }
		    					    		}
		    					    		$data['is_received']          			= 'on';
		    					    		$data['file_not_provided']          	= 'off';
		    					    		$data['file']                 			= UploadImagePdf($formData['files'], 'companyAdmin/load_detail_document');
		    					    		$data['upload_user_type']     			= 3; // For Driver User Type
		    					    		$data['upload_by']            			= auth()->guard('driver-admin')->user()->id;
		    					    		$data['uploaded_at']          			= Carbon::now();

		    					    		// Update jsonData
		    					    		$jsonData['is_received'] 				= $data['is_received'];
		    					    		$jsonData['file'] 						= $data['file'];
		    					    		$jsonData['upload_user_type'] 			= $data['upload_user_type'];
		    					    		$jsonData['upload_by'] 					= $data['upload_by'];
		    					    		$jsonData['uploaded_by'] 				= isset($data['upload_by']) ? getUserByType($data['upload_by'], $data['upload_user_type']) : null;
		    					    		$jsonData['uploaded_at'] 				= Carbon::createFromFormat('Y-m-d H:i:s', $data['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId;
		    					    		$jsonData['status'] 					= 'Complete';
		    					    	}
		    					    }
		    					    $saveArray[]                            		= $data;
		    					}

		    					if(isset($item)){
		    						if($jsonData['field_name'] == 'shipper_files_upload'){
		    						    $oldData                                    = $item->toArray();
		    						    $item->update(['shipper_files_upload' => serialize($saveArray)]);
		    						    $this->setLoadAudit($item->load_id, 'update', 'Load detail updated', $item->getChanges(), $oldData);
		    						}
		    						if($jsonData['field_name'] == 'consignee_files_upload'){
		    						    $oldData                                    = $item->toArray();
		    						    $item->update(['consignee_files_upload' => serialize($saveArray)]);
		    						    $this->setLoadAudit($item->load_id, 'update', 'Load detail updated', $item->getChanges(), $oldData);
		    						}
		    						if($jsonData['field_name'] == 'stop_shipper_files_upload'){
		    						    $oldData                                    = $item->toArray();
		    						    $item->update(['stop_shipper_files_upload' => serialize($saveArray)]);
		    						    $this->setLoadAudit($item->load_id, 'update', 'Load stop updated', $item->getChanges(), $oldData);
		    						}
		    						if($jsonData['field_name'] == 'stop_consignee_files_upload'){
		    						    $oldData                                    = $item->toArray();
		    						    $item->update(['stop_consignee_files_upload' => serialize($saveArray)]);
		    						    $this->setLoadAudit($item->load_id, 'update', 'Load stop updated', $item->getChanges(), $oldData);
		    						}
		    					}
		    				}
		    			}elseif($jsonData['source'] == 'load_document_request_items'){
		    				$load_document_request_item                             = LoadDocumentRequestItem::where('id', $jsonData['id'])->first();
		    				if(!is_null($load_document_request_item)){
		    					$oldData                                            = $load_document_request_item->toArray();

		    					$data                                         		= [];
		    					if(isset($load_document_request_item->files) && is_serialized($load_document_request_item->files) && !empty(unserialize($load_document_request_item->files))){
		    					    $data                                    	 	= unserialize($load_document_request_item->files);
		    					}

		    					if(!empty($data)){
		    						if(isset($formData['is_received'])){
		    							$data['is_received']              			= 'on';
		    							$data['file_not_provided']          		= 'off';
		    							$data['upload_user_type']     				= 3; // For Driver User Type
		    							$data['upload_by']            				= auth()->guard('driver-admin')->user()->id;
		    							$data['uploaded_at']          				= Carbon::now();

		    							// Update jsonData
		    							$jsonData['is_received'] 					= $data['is_received'];
		    							$jsonData['upload_user_type'] 				= $data['upload_user_type'];
		    							$jsonData['upload_by'] 						= $data['upload_by'];
		    							$jsonData['uploaded_by'] 					= isset($data['upload_by']) ? getUserByType($data['upload_by'], $data['upload_user_type']) : null;
		    							$jsonData['uploaded_at'] 					= Carbon::createFromFormat('Y-m-d H:i:s', $data['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId;
		    							$jsonData['status'] 						= 'Complete';
		    						} else if(isset($formData['files']) && !empty($formData['files'])){
		    							$files                                 		= isset($data['file']) && !empty($data['file']) ? $data['file'] : null;
		    							if(isset($files) && !empty($files)){
		    							    foreach ($files as $key => $file) {
		    							        $path                       		= 'storage/companyAdmin/load_detail_document/'.$file;
		    							        if (File::exists($path)) {
		    							            File::delete($path);
		    							        }
		    							    }
		    							}
		    							$data['is_received']          				= 'on';
		    							$data['file_not_provided']          		= 'off';
		    							$data['file']                 				= UploadImagePdf($formData['files'], 'companyAdmin/load_detail_document');
		    							$data['upload_user_type']     				= 3; // For Driver User Type
		    							$data['upload_by']            				= auth()->guard('driver-admin')->user()->id;
		    							$data['uploaded_at']          				= Carbon::now();

		    							// Update jsonData
		    							$jsonData['is_received'] 					= $data['is_received'];
		    							$jsonData['file'] 							= $data['file'];
		    							$jsonData['upload_user_type'] 				= $data['upload_user_type'];
		    							$jsonData['upload_by'] 						= $data['upload_by'];
		    							$jsonData['uploaded_by'] 					= isset($data['upload_by']) ? getUserByType($data['upload_by'], $data['upload_user_type']) : null;
		    							$jsonData['uploaded_at'] 					= Carbon::createFromFormat('Y-m-d H:i:s', $data['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId;
		    							$jsonData['status'] 						= 'Complete';
		    						}
		    					}

		    					$load_document_request_item->files                  = !empty($data) ? serialize($data) : null;
		    					$load_document_request_item->updated_at             = date('Y-m-d H:i:s');
		    					$load_document_request_item->updated_by             = auth()->guard('driver-admin')->user()->id;
		    					$load_document_request_item->updated_by_type        = 3;
		    					if($load_document_request_item->save()){
		    					    $this->setLoadAudit($load_document_request_item->load_id, 'update', 'Load document request item updated', $load_document_request_item->getChanges(), $oldData);
		    					}
		    				}
		    			}elseif($jsonData['source'] == 'load_files'){
		    				$load_file                                           	= LoadFile::where('id', $jsonData['id'])->first();
		    				if(!is_null($load_file)){
		    					$oldData                                        	= $load_file->toArray();

		    					$files                                         		= [];
		    					if(isset($load_file->document) && is_serialized($load_file->document) && !empty(unserialize($load_file->document))){
		    					    $files                                    	 	= unserialize($load_file->document);
		    					}
		    					if(isset($files) && !empty($files)){
		    					    foreach ($files as $key => $file) {
		    					        $path                       				= 'storage/companyAdmin/loadfile/'.$file;
		    					        if (File::exists($path)) {
		    					            File::delete($path);
		    					        }
		    					    }
		    					}
		    					$data['file']                 						= UploadImagePdf($formData['files'], 'companyAdmin/loadfile');
		    					$data['upload_user_type']     						= 3; // For Driver User Type
		    					$data['upload_by']            						= auth()->guard('driver-admin')->user()->id;
		    					$data['uploaded_at']          						= Carbon::now();

		    					// Update jsonData
		    					$jsonData['is_received'] 							= 'on';
		    					$jsonData['file'] 									= $data['file'];
		    					$jsonData['upload_user_type'] 						= $data['upload_user_type'];
		    					$jsonData['upload_by'] 								= $data['upload_by'];
		    					$jsonData['uploaded_by'] 							= isset($data['upload_by']) ? getUserByType($data['upload_by'], $data['upload_user_type']) : null;
		    					$jsonData['uploaded_at'] 							= Carbon::createFromFormat('Y-m-d H:i:s', $data['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId;
		    					$jsonData['status'] 								= 'Complete';

		    					$load_file->document                         		= serialize($data['file']);
		    					$load_file->upload_by                            	= $data['upload_by'];
		    					$load_file->upload_user_type                    	= 'Driver';
		    					if($load_file->save()){
		    					    $this->setLoadAudit($load_file->load_id, 'update', 'Load document summary updated', $load_file->getChanges(), $oldData);
		    					}
		    				}
		    			}elseif($jsonData['source'] == 'load_accessorials'){
		    				$load_accessorial                                       = LoadAccessorial::where('id', $jsonData['id'])->first();
		    				if(!is_null($load_accessorial)){
		    					$oldData                                        	= $load_accessorial->toArray();

		    					$gallery                                            = Gallery::where('company_id', auth()->guard('driver-admin')->user()->company_id)
		    					    ->where('action_id', $load_accessorial->id)
		    					    ->where('source', 'load_accessorials')
		    					    ->where('field_name', 'accessorial_files')
		    					    ->first();

		    					$is_upload                                          = 0;

    							$imageName 											= null;
    							// Invalid file type! Please select only jpg, jpeg, png, gif, or pdf files. - only Accessorial
    							$fileArray                  						= UploadImagePdf($formData['files'], 'companyAdmin/gallery');
    							// Get the first element
    							$firstElement 										= reset($fileArray);
    							// Check if $firstElement exists
    							if (isset($firstElement)) {
    								// Extract filename and extension
								    $filenameWithExtension 							= pathinfo($firstElement, PATHINFO_EXTENSION);
								    if($filenameWithExtension == 'pdf'){
								    	$imageName 									= $firstElement;
								    }
    							}
    							if(isset($imageName) && $imageName != ''){
    								if(!is_null($gallery)){
    									$path                               		= 'storage/companyAdmin/gallery/'.$gallery->image;
    									if (File::exists($path)) {
    									    File::delete($path);
    									}

    									$gallery->image                       		= $imageName;
    									$gallery->created_by                    	= auth()->guard('driver-admin')->user()->id;
    									$gallery->created_by_type               	= 3;
    									$gallery->uploaded_date                 	= Carbon::now()->format('m/d/Y H:i');
    									if($gallery->save()){
    										$is_upload                         		= 1;
    									}
    								}else{
    									$input                                		= [];
    									$input['company_id']                  		= auth()->guard('driver-admin')->user()->company_id;
    									$input['action_id']                   		= $load_accessorial->id;
    									$input['source']                      		= 'load_accessorials';
    									$input['field_name']                  		= 'accessorial_files';
    									$input['file_name']                   		= null;
    									$input['file_type']                   		= getRequestDocumentsList('load_accessorials','source')['file_type'];
    									$input['image']                       		= $imageName;
    									$input['include_w_billing']           		= 'no';
    									$input['hide_from_driver']            		= 'no';
    									$input['status']                      		= 'approved';
    									$input['created_by']                  		= auth()->guard('driver-admin')->user()->id;
    									$input['created_by_type']             		= 3;
    									$input['uploaded_date']               		= Carbon::now()->format('m/d/Y H:i');
    									$gallery 									= Gallery::create($input);

    									$is_upload                            		= 1;
    								}
    							}

		    					if($is_upload==1){
	    					    	// Update jsonData
	    					    	$jsonData['is_received']             			= 'on';
	    					    	$jsonData['file'] 								= $gallery->image ?? null;
	    					    	$jsonData['upload_user_type']      				= isset($gallery->created_by_type) ? $gallery->created_by_type : null;
	    					    	$jsonData['upload_by']                  		= isset($gallery->created_by) ? $gallery->created_by : null;
	    					    	if(isset($gallery->created_by_type) && isset($gallery->created_by)){
	    					    		$jsonData['uploaded_by']         			= getUserByType($gallery->created_by, $gallery->created_by_type);
	    					    	}else{
	    					    		$jsonData['uploaded_by']            		= null;
	    					    	}
	    					    	$jsonData['uploaded_at']              			= isset($gallery->created_at) ? Carbon::createFromFormat('Y-m-d H:i:s', $gallery->created_at)->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null; // $gallery->getRawOriginal('uploaded_date')
	    					    	$jsonData['status']                   			= 'Complete';

	    					    	// Load accessorial
	    					        $load_accessorial->is_received              	= 1;
	    					        $load_accessorial->file_not_provided        	= 'off';

	    					        //status
	    					        $arry                                       	= [];
	    					        $paid_type                                  	= $load_accessorial->paid_type;
	    					        $reference                                  	= $load_accessorial->reference;
	    					        $total                                      	= $load_accessorial->total;

	    					        $owner_liable                               	= $load_accessorial->owner_liable;
	    					        $owner_total                                	= $load_accessorial->owner_total;

	    					        $driver_liable                              	= $load_accessorial->driver_liable;
	    					        $driver_total                               	= $load_accessorial->driver_total;

	    					        $doc_required                               	= $load_accessorial->doc_required;

	    					        array_push($arry, $paid_type!=''?1:0);
	    					        array_push($arry, $reference!=''?1:0);
	    					        array_push($arry, $total!=''?1:0);
	    					        if($owner_liable=='1'){
	    					            array_push($arry, $owner_total!=''?1:0);
	    					        }
	    					        if($driver_liable=='1'){
	    					            array_push($arry, $driver_total!=''?1:0);
	    					        }

	    					        if(in_array(0, $arry)){
	    					            $load_accessorial->status               	= 0; // Pending
	    					        }else{
	    					            if($doc_required=='1'){
	    					                if($load_accessorial->is_received==1){
	    					                    $load_accessorial->status       	= 1; // Completed
	    					                }else{
	    					                    $load_accessorial->status       	= 0; // Pending
	    					                }
	    					            }else{
	    					                $load_accessorial->status           	= 1; // Completed
	    					            }
	    					        }
	    					        if ($driver_liable=='1' && $load_accessorial->status!=1 && isset($load_accessorial->file_not_provided) && $load_accessorial->file_not_provided=='on') {
	    					            $load_accessorial->status               	= 2; // Driver Bypass
	    					        }
	    					        //status

	    					        if($load_accessorial->save()){
	    					        	$this->setLoadAudit($load_accessorial->load_id, 'update', 'Load accessorial updated', $load_accessorial->getChanges(), $oldData);
	    					        }
		    					}
		    				}
		    			}
		    		}
		    	}

		    	$typeUserId 														= '3_'.auth()->guard('driver-admin')->user()->id;

		    	// $response['html']   												= view('driverAdmin.mytrips.ajax.historic_dispatch.document_detail', compact('typeUserId','jsonData'))->render();
		    	$response['html']   												= view('driverAdmin.mytrips.ajax.historic_dispatch.document_detail-new', compact('typeUserId','jsonData'))->render();
		    	$response['success']                        						= true;
		    	$response['message']                        						= "Save successfully.";
		    } catch (\Exception $e) {
		        $response['success']                        						= false;
		        $response['message']                        						= $e->getMessage();
		    }
		}
		return response()->json($response);
	}

	public function historicFileRemove(Request $request){
		$response['success']                   										= false;
		$response['message']                   										= "Oops! Something went wrong..";
		if ($request->ajax()) {
		    try {
		    	$formData                           								= $request->all();
		    	if(isset($formData['jsonData']) && $formData['jsonData']!==''){
		    		$jsonData                           							= json_decode($formData['jsonData'], true);
		    		$oldJsonData                           							= $jsonData;

		    		if(isset($jsonData['source'])){
		    			if(in_array($jsonData['source'], ['load_details', 'load_stops'])){
		    				$getArray                                        		= [];
		    				if($jsonData['source'] == 'load_details'){
		    				    $item                                 				= LoadDetail::whereId($jsonData['id'])->first();
		    				    if(!is_null($item)){
		    				    	if ($jsonData['field_name'] == 'shipper_files_upload') {
		    				    	    $getArray                              		= isset($item->shipper_files_upload) && is_serialized($item->shipper_files_upload) && !empty(unserialize($item->shipper_files_upload)) ? unserialize($item->shipper_files_upload) : [];
		    				    	} else if ($jsonData['field_name'] == 'consignee_files_upload') {
		    				    	    $getArray                                       = isset($item->consignee_files_upload) && is_serialized($item->consignee_files_upload) && !empty(unserialize($item->consignee_files_upload)) ? unserialize($item->consignee_files_upload) : [];
		    				    	}
		    				    }
		    				}else{
		    				    $item                                           	= LoadStop::whereId($jsonData['id'])->first();
		    				    if(!is_null($item)){
		    				    	if($jsonData['field_name'] == 'stop_shipper_files_upload'){
		    				    	    $getArray                                	= isset($item->stop_shipper_files_upload) && is_serialized($item->stop_shipper_files_upload) && !empty(unserialize($item->stop_shipper_files_upload)) ? unserialize($item->stop_shipper_files_upload) : [];
		    				    	} else if ($jsonData['field_name'] == 'stop_consignee_files_upload') {
		    				    	    $getArray                                	= isset($item->stop_consignee_files_upload) && is_serialized($item->stop_consignee_files_upload) && !empty(unserialize($item->stop_consignee_files_upload)) ? unserialize($item->stop_consignee_files_upload) : [];
		    				    	}
		    				    }
		    				}

		    				if(!empty($getArray)){
		    					$saveArray                                      	= [];
		    					foreach($getArray as $data){
		    					    if(
		    					    	(isset($data['name_id']) && $data['name_id'] == $jsonData['filename_id']) &&
		    					    	(isset($data['name']) && $data['name'] == $jsonData['filename']) &&
		    					    	(isset($data['type']) && $data['type'] == $jsonData['type'])
		    					    ){
		    					    	if($jsonData['type'] == 2){
		    					    		// Original
		    					    		$data['is_received']              		= 'off';
		    					    		$data['file_not_provided']          	= 'on';
		    					    		if(isset($data['upload_user_type'])){
		    					    			unset($data['upload_user_type']);
		    					    		}
		    					    		if(isset($data['upload_by'])){
		    					    			unset($data['upload_by']);
		    					    		}
		    					    		if(isset($data['uploaded_at'])){
		    					    			unset($data['uploaded_at']);
		    					    		}

		    					    		// Update jsonData
		    					    		$jsonData['is_received'] 				= $data['is_received'];
		    					    		if(isset($jsonData['upload_user_type'])){
		    					    			unset($jsonData['upload_user_type']);
		    					    		}
		    					    		if(isset($jsonData['upload_by'])){
		    					    			unset($jsonData['upload_by']);
		    					    		}
		    					    		if(isset($jsonData['uploaded_by'])){
		    					    			unset($jsonData['uploaded_by']);
		    					    		}
		    					    		if(isset($jsonData['uploaded_at'])){
		    					    			unset($jsonData['uploaded_at']);
		    					    		}
		    					    		$jsonData['status'] 					= 'Pending';
		    					    	}else if($jsonData['type'] == 1){
		    					    		// Copy
		    					    		$files                                  = isset($data['file']) && !empty($data['file']) ? $data['file'] : null;
		    					    		if(isset($files) && !empty($files)){
		    					    		    foreach ($files as $key => $file) {
		    					    		        $path                       	= 'storage/companyAdmin/load_detail_document/'.$file;
		    					    		        if (File::exists($path)) {
		    					    		            File::delete($path);
		    					    		        }
		    					    		    }
		    					    		}
		    					    		$data['is_received']          			= 'off';
		    					    		$data['file_not_provided']          	= 'on';
		    					    		$data['file']                 			= null;
		    					    		if(isset($data['upload_user_type'])){
		    					    			unset($data['upload_user_type']);
		    					    		}
		    					    		if(isset($data['upload_by'])){
		    					    			unset($data['upload_by']);
		    					    		}
		    					    		if(isset($data['uploaded_at'])){
		    					    			unset($data['uploaded_at']);
		    					    		}

		    					    		// Update jsonData
		    					    		$jsonData['is_received'] 				= $data['is_received'];
		    					    		$jsonData['file'] 						= $data['file'];
		    					    		if(isset($jsonData['upload_user_type'])){
		    					    			unset($jsonData['upload_user_type']);
		    					    		}
		    					    		if(isset($jsonData['upload_by'])){
		    					    			unset($jsonData['upload_by']);
		    					    		}
		    					    		if(isset($jsonData['uploaded_by'])){
		    					    			unset($jsonData['uploaded_by']);
		    					    		}
		    					    		if(isset($jsonData['uploaded_at'])){
		    					    			unset($jsonData['uploaded_at']);
		    					    		}
		    					    		$jsonData['status'] 					= 'Pending';
		    					    	}
		    					    }
		    					    $saveArray[]                            		= $data;
		    					}

		    					if(isset($item)){
		    						if($jsonData['field_name'] == 'shipper_files_upload'){
		    						    $oldData                                    = $item->toArray();
		    						    $item->update(['shipper_files_upload' => serialize($saveArray)]);
		    						    $this->setLoadAudit($item->load_id, 'update', 'Load detail updated', $item->getChanges(), $oldData);
		    						}
		    						if($jsonData['field_name'] == 'consignee_files_upload'){
		    						    $oldData                                    = $item->toArray();
		    						    $item->update(['consignee_files_upload' => serialize($saveArray)]);
		    						    $this->setLoadAudit($item->load_id, 'update', 'Load detail updated', $item->getChanges(), $oldData);
		    						}
		    						if($jsonData['field_name'] == 'stop_shipper_files_upload'){
		    						    $oldData                                    = $item->toArray();
		    						    $item->update(['stop_shipper_files_upload' => serialize($saveArray)]);
		    						    $this->setLoadAudit($item->load_id, 'update', 'Load stop updated', $item->getChanges(), $oldData);
		    						}
		    						if($jsonData['field_name'] == 'stop_consignee_files_upload'){
		    						    $oldData                                    = $item->toArray();
		    						    $item->update(['stop_consignee_files_upload' => serialize($saveArray)]);
		    						    $this->setLoadAudit($item->load_id, 'update', 'Load stop updated', $item->getChanges(), $oldData);
		    						}
		    					}
		    				}
		    			}elseif($jsonData['source'] == 'load_document_request_items'){
		    				$load_document_request_item                             = LoadDocumentRequestItem::where('id', $jsonData['id'])->whereNotNull('files')->first();
		    				if(!is_null($load_document_request_item)){
		    					$oldData                                            = $load_document_request_item->toArray();

		    					$data                                         		= [];
		    					if(isset($load_document_request_item->files) && is_serialized($load_document_request_item->files) && !empty(unserialize($load_document_request_item->files))){
		    					    $data                                    	 	= unserialize($load_document_request_item->files);
		    					}

		    					if(!empty($data)){
		    						if($jsonData['type'] == 2){
		    							// Original
		    							$data['is_received']              			= 'off';
		    							$data['file_not_provided']          		= 'on';
		    							if(isset($data['upload_user_type'])){
		    								unset($data['upload_user_type']);
		    							}
		    							if(isset($data['upload_by'])){
		    								unset($data['upload_by']);
		    							}
		    							if(isset($data['uploaded_at'])){
		    								unset($data['uploaded_at']);
		    							}

		    							// Update jsonData
		    							$jsonData['is_received'] 					= $data['is_received'];
		    							if(isset($jsonData['upload_user_type'])){
		    								unset($jsonData['upload_user_type']);
		    							}
		    							if(isset($jsonData['upload_by'])){
		    								unset($jsonData['upload_by']);
		    							}
		    							if(isset($jsonData['uploaded_by'])){
		    								unset($jsonData['uploaded_by']);
		    							}
		    							if(isset($jsonData['uploaded_at'])){
		    								unset($jsonData['uploaded_at']);
		    							}
		    							$jsonData['status'] 						= 'Pending';
		    						}else if($jsonData['type'] == 1){
		    							// Copy
		    							$files                                  	= isset($data['file']) && !empty($data['file']) ? $data['file'] : null;
		    							if(isset($files) && !empty($files)){
		    							    foreach ($files as $key => $file) {
		    							        $path                       		= 'storage/companyAdmin/load_detail_document/'.$file;
		    							        if (File::exists($path)) {
		    							            File::delete($path);
		    							        }
		    							    }
		    							}
		    							$data['is_received']          				= 'off';
		    							$data['file_not_provided']          		= 'on';
		    							$data['file']                 				= null;
		    							if(isset($data['upload_user_type'])){
		    								unset($data['upload_user_type']);
		    							}
		    							if(isset($data['upload_by'])){
		    								unset($data['upload_by']);
		    							}
		    							if(isset($data['uploaded_at'])){
		    								unset($data['uploaded_at']);
		    							}

		    							// Update jsonData
		    							$jsonData['is_received'] 					= $data['is_received'];
		    							$jsonData['file'] 							= $data['file'];
		    							if(isset($jsonData['upload_user_type'])){
		    								unset($jsonData['upload_user_type']);
		    							}
		    							if(isset($jsonData['upload_by'])){
		    								unset($jsonData['upload_by']);
		    							}
		    							if(isset($jsonData['uploaded_by'])){
		    								unset($jsonData['uploaded_by']);
		    							}
		    							if(isset($jsonData['uploaded_at'])){
		    								unset($jsonData['uploaded_at']);
		    							}
		    							$jsonData['status'] 						= 'Pending';
		    						}
		    					}

		    					$load_document_request_item->files                  = !empty($data) ? serialize($data) : null;
		    					$load_document_request_item->updated_at             = date('Y-m-d H:i:s');
		    					$load_document_request_item->updated_by             = auth()->guard('driver-admin')->user()->id;
		    					$load_document_request_item->updated_by_type        = 3;
		    					if($load_document_request_item->save()){
		    					    $this->setLoadAudit($load_document_request_item->load_id, 'update', 'Load document request item updated', $load_document_request_item->getChanges(), $oldData);
		    					}
		    				}
		    			}elseif($jsonData['source'] == 'load_files'){
		    				$load_file                                           	= LoadFile::where('id', $jsonData['id'])->whereNotNull('document')->first();
		    				if(!is_null($load_file)){
		    					$oldData                                        	= $load_file->toArray();

		    					$files                                         		= [];
		    					if(isset($load_file->document) && is_serialized($load_file->document) && !empty(unserialize($load_file->document))){
		    					    $files                                    	 	= unserialize($load_file->document);
		    					}
		    					if(isset($files) && !empty($files)){
		    					    foreach ($files as $key => $file) {
		    					        $path                       				= 'storage/companyAdmin/loadfile/'.$file;
		    					        if (File::exists($path)) {
		    					            File::delete($path);
		    					        }
		    					    }
		    					}

		    					// Update jsonData
		    					$jsonData['is_received'] 							= 'off';
		    					$jsonData['file'] 									= null;
		    					if(isset($jsonData['upload_user_type'])){
		    						unset($jsonData['upload_user_type']);
		    					}
		    					if(isset($jsonData['upload_by'])){
		    						unset($jsonData['upload_by']);
		    					}
		    					if(isset($jsonData['uploaded_by'])){
		    						unset($jsonData['uploaded_by']);
		    					}
		    					if(isset($jsonData['uploaded_at'])){
		    						unset($jsonData['uploaded_at']);
		    					}
		    					$jsonData['status'] 								= 'Pending';

		    					$load_file->document                         		= null;
		    					$load_file->upload_by                            	= auth()->guard('driver-admin')->user()->id;
		    					$load_file->upload_user_type                    	= 'Driver';
		    					if($load_file->save()){
		    					    $this->setLoadAudit($load_file->load_id, 'update', 'Load document summary updated', $load_file->getChanges(), $oldData);
		    					}
		    				}
		    			}elseif($jsonData['source'] == 'load_accessorials'){
		    				$load_accessorial                                       = LoadAccessorial::where('id', $jsonData['id'])->where('is_received', 1)->first();
		    				if(!is_null($load_accessorial)){
		    					$oldData                                        	= $load_accessorial->toArray();

		    					$gallery                                            = Gallery::where('company_id', auth()->guard('driver-admin')->user()->company_id)
		    					    ->where('action_id', $load_accessorial->id)
		    					    ->where('source', 'load_accessorials')
		    					    ->where('field_name', 'accessorial_files')
		    					    ->whereNotNull('image')
		    					    ->first();
		    					if(!is_null($gallery)){
		    						$path                                       	= 'storage/companyAdmin/gallery/'.$gallery->image;
		    						if (File::exists($path)) {
		    						    File::delete($path);
		    						}
		    						$gallery->image                             	= null;
		    						$gallery->created_by                            = auth()->guard('driver-admin')->user()->id;
		    						$gallery->created_by_type                       = 3;
		    						$gallery->uploaded_date                         = Carbon::now()->format('m/d/Y H:i');
		    						if($gallery->save()){
		    							// Update jsonData
		    							$jsonData['is_received'] 					= 'off';
		    							$jsonData['file'] 							= $gallery->image;
		    							if(isset($jsonData['upload_user_type'])){
		    								unset($jsonData['upload_user_type']);
		    							}
		    							if(isset($jsonData['upload_by'])){
		    								unset($jsonData['upload_by']);
		    							}
		    							if(isset($jsonData['uploaded_by'])){
		    								unset($jsonData['uploaded_by']);
		    							}
		    							if(isset($jsonData['uploaded_at'])){
		    								unset($jsonData['uploaded_at']);
		    							}
		    							$jsonData['status'] 						= 'Pending';

	    								// Load accessorial
	    							    $load_accessorial->is_received              = 0;
	    							    $load_accessorial->file_not_provided        = 'on';

	    							    //status
	    							    $arry                                       = [];
	    							    $paid_type                                  = $load_accessorial->paid_type;
	    							    $reference                                  = $load_accessorial->reference;
	    							    $total                                      = $load_accessorial->total;

	    							    $owner_liable                               = $load_accessorial->owner_liable;
	    							    $owner_total                                = $load_accessorial->owner_total;

	    							    $driver_liable                              = $load_accessorial->driver_liable;
	    							    $driver_total                               = $load_accessorial->driver_total;

	    							    $doc_required                               = $load_accessorial->doc_required;

	    							    array_push($arry, $paid_type!=''?1:0);
	    							    array_push($arry, $reference!=''?1:0);
	    							    array_push($arry, $total!=''?1:0);
	    							    if($owner_liable=='1'){
	    							        array_push($arry, $owner_total!=''?1:0);
	    							    }
	    							    if($driver_liable=='1'){
	    							        array_push($arry, $driver_total!=''?1:0);
	    							    }

	    							    if(in_array(0, $arry)){
	    							        $load_accessorial->status               = 0; // Pending
	    							    }else{
	    							        if($doc_required=='1'){
	    							            if($load_accessorial->is_received==1){
	    							                $load_accessorial->status       = 1; // Completed
	    							            }else{
	    							                $load_accessorial->status       = 0; // Pending
	    							            }
	    							        }else{
	    							            $load_accessorial->status           = 1; // Completed
	    							        }
	    							    }
	    							    if ($driver_liable=='1' && $load_accessorial->status!=1 && isset($load_accessorial->file_not_provided) && $load_accessorial->file_not_provided=='on') {
	    							        $load_accessorial->status               = 2; // Driver Bypass
	    							    }
	    							    //status

	    							    if($load_accessorial->save()){
	    							    	$this->setLoadAudit($load_accessorial->load_id, 'update', 'Load accessorial updated', $load_accessorial->getChanges(), $oldData);
	    							    }
		    						}
		    					}
		    				}
		    			}
		    		}
		    	}

		    	$typeUserId 														= '3_'.auth()->guard('driver-admin')->user()->id;

		    	// $response['html']   												= view('driverAdmin.mytrips.ajax.historic_dispatch.document_detail', compact('typeUserId','jsonData'))->render();
		    	$response['html']   												= view('driverAdmin.mytrips.ajax.historic_dispatch.document_detail-new', compact('typeUserId','jsonData'))->render();
		    	$response['success']                        						= true;
		    	$response['message']                        						= "Remove successfully.";
		    } catch (\Exception $e) {
		        $response['success']                        						= false;
		        $response['message']                        						= $e->getMessage();
		    }
		}
		return response()->json($response);
	}

	public function getStopdDocuments($item, $customer_type = null){
		// 1 = Stop, 0 = No Stop
		// Customer Type ( 1 = Pickup, 2 = Delivery )
		// Required Documents upload code same carousel_content
		// load_document_request_items & accessorials get item change row - ohk
		// For Missing document driverAdmin.mytrips.ajax.current_dispatch.carousel_content -> document code must check bcz code dependent

		// Required Documents
		$required_documents  											= [];
		// Requested Documents
		$requested_documents                                            = [];
		// Accessorial Documents
		$accessorial_documents                                          = [];

		// Get the table name
		$tableName 	  													= $item->getTable();
		if($tableName == 'load_details'){
			if($customer_type == 1){
				// Pickup

			    // Required Documents
				if(isset($item->shipper_files_upload) && is_serialized($item->shipper_files_upload) && !empty(unserialize($item->shipper_files_upload))){
					$i                                                 	= 1;
				    $uploads                              				= unserialize($item->shipper_files_upload);
				    $uploads                                 			= array_filter($uploads, function ($var) {
				        return (
				            (
				                isset($var['name_id']) && $var['name_id'] !== null && $var['is_required'] == 'on' && in_array($var['type'], [1, 2])
				            ) && !(
				                isset($var['hide_from_driver']) && $var['hide_from_driver'] == 'yes'
				            )
				        );
				    });
				    foreach ($uploads as $key => $value) {
			            // Type 1 = Copy, 2 = Original
			            $array                                  		= [];
			            $array['sr']                                	= $i;
			            $array['id']                            		= $item->id;
			            $array['source']                        		= 'load_details';
			            $array['field_name']                    		= 'shipper_files_upload';

			            $array['filename']                      		= $value['name'] ?? '';
			            $array['filename_id']                   		= $value['name_id'] ?? '';

			            $array['type']                          		= $value['type'];

			            $array['is_received']                   		= isset($value['is_received']) && $value['is_received'] == 'on' ? 'on' : 'off';
			            $array['file_not_provided']             		= isset($value['file_not_provided']) && $value['file_not_provided'] == 'on' ? 'on' : 'off';

			            $status                                 		= 'Pending';
			            if($array['type'] == 1){
			                $array['file']                      		= $value['file'] ?? null;
			                if(isset($value['file']) && !empty($value['file'])){
			                    $status                         		= 'Complete';
			                    $array['file_not_provided']     		= 'off';
			                    $array['upload_user_type']      		= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
			                    $array['upload_by']             		= isset($value['upload_by']) ? $value['upload_by'] : null;
			                }
			            }else{
			                if($array['is_received'] == 'on'){
			                    $status                         		= 'Complete';
			                    $array['file_not_provided']     		= 'off';
			                    $array['upload_user_type']      		= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
			                    $array['upload_by']             		= isset($value['upload_by']) ? $value['upload_by'] : null;
			                }
			            }
			            $array['status']                        		= $status;

			            $required_documents[]                   		= $array;

			            $i++;
			        }
			    }

			    // Requested Documents
			    if(isset($item->shipper_load_document_request_items)){
			    	$i                                              	= 1;
		            $shipper_load_document_request_items            	= $item->shipper_load_document_request_items->where('driver_id', auth()->guard('driver-admin')->user()->id);
		            foreach ($shipper_load_document_request_items as $key => $row) {
		                $value                                  		= [];
		                if(isset($row->files) && is_serialized($row->files) && !empty(unserialize($row->files))){
		                    $value                              		= unserialize($row->files);
		                }
			            if(!empty($value)){
			                if(
			                    (
			                        isset($value['name_id']) && $value['name_id'] !== null && $value['is_required'] == 'on' && in_array($value['type'], [1, 2])
			                    ) && !(
			                        isset($value['hide_from_driver']) && $value['hide_from_driver'] == 'yes'
			                    )
			                ){
		                        // Type 1 = Copy, 2 = Original
		                        $array                                 	= [];
		                        $array['sr']                          	= $i;
		                        $array['id']                           	= $row->id;
		                        $array['source']                       	= 'load_document_request_items';
		                        $array['field_name']                   	= 'files';

		                        $array['filename']                     	= $value['name'] ?? '';
		                        $array['filename_id']                  	= $value['name_id'] ?? '';

		                        $array['type']                         	= $value['type'];

		                        $array['is_received']                  	= isset($value['is_received']) && $value['is_received'] == 'on' ? 'on' : 'off';
		                        $array['file_not_provided']            	= isset($value['file_not_provided']) && $value['file_not_provided'] == 'on' ? 'on' : 'off';

		                        $status                                	= 'Pending';
		                        if($array['type'] == 1){
		                            $array['file']                     	= $value['file'] ?? null;
		                            if(isset($value['file']) && !empty($value['file'])){
		                                $status                        	= 'Complete';
		                                $array['file_not_provided']    	= 'off';
		                                $array['upload_user_type']     	= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
		                                $array['upload_by']            	= isset($value['upload_by']) ? $value['upload_by'] : null;
		                            }
		                        }else{
		                            if($array['is_received'] == 'on'){
		                                $status                        	= 'Complete';
		                                $array['file_not_provided']    	= 'off';
		                                $array['upload_user_type']     	= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
		                                $array['upload_by']            	= isset($value['upload_by']) ? $value['upload_by'] : null;
		                            }
		                        }
		                        $array['status']                       	= $status;

		                        $requested_documents[]                  = $array;

		                        $i++;
			                }
			            }
			        }
			    }

			    // Accessorial Documents
			    if(isset($item->shipper_accessorials)){
			    	$i                                               	= 1;
		            $shipper_accessorials                              	= $item->shipper_accessorials->where('driver_id', auth()->guard('driver-admin')->user()->id)->where('doc_required', '!=', 0);
		            foreach ($shipper_accessorials as $key => $row) {
		                $gallery                                     	= Gallery::where('company_id', auth()->guard('driver-admin')->user()->company_id)
		                    ->where('action_id', $row->id)
		                    ->where('source', 'load_accessorials')
		                    ->where('field_name', 'accessorial_files')
		                    ->first();
		                $filename                                   	= $row->company_accessorial->name;
		                $hide_from_driver                           	= 'no';
		                if(!is_null($gallery)){
		                    if(isset($gallery->hide_from_driver) && $gallery->hide_from_driver == 'yes'){
		                        $hide_from_driver                     	= 'yes';
		                    }
		                    // $filename                              	.= isset($gallery->file_name) ? ' - '.$gallery->file_name : '';
		                }
		                if($hide_from_driver == 'no'){
		                    // Type 1 = Copy, 2 = Original
		                    $array                                    	= [];
		                    $array['sr']                                = $i;
		                    $array['id']                              	= $row->id;
		                    $array['source']                          	= 'load_accessorials';
		                    $array['field_name']                      	= 'image';

		                    $array['filename']                        	= $filename;
		                    // $array['filename_id']                  	= 0;

		                    $array['type']                            	= 1;

		                    $array['is_received']                     	= 'off';
		                    $array['file_not_provided']               	= isset($row->file_not_provided) && $row->file_not_provided == 'on' ? 'on' : 'off';

		                    $status                                   	= 'Pending';
		                    $array['file']                            	= $gallery->image ?? null;
		                    if(isset($gallery->image) && !empty($gallery->image)){
		                        $status                               	= 'Complete';
		                        $array['is_received']                 	= 'on';
		                        $array['file_not_provided']           	= 'off';
		                        $array['upload_user_type']            	= isset($gallery->created_by_type) ? $gallery->created_by_type : null;
		                        $array['upload_by']                   	= isset($gallery->created_by) ? $gallery->created_by : null;
		                    }
		                    $array['status']                          	= $status;

		                    $accessorial_documents[]                    = $array;

		                    $i++;
		                }
			        }
			    }
			}else if($customer_type == 2){
				// Delivery

			    // Required Documents
				if(isset($item->consignee_files_upload) && is_serialized($item->consignee_files_upload) && !empty(unserialize($item->consignee_files_upload))){
					$i                                                 	= 1;
				    $uploads                              				= unserialize($item->consignee_files_upload);
				    $uploads                                 			= array_filter($uploads, function ($var) {
				        return (
				            (
				                isset($var['name_id']) && $var['name_id'] !== null && $var['is_required'] == 'on' && in_array($var['type'], [1, 2])
				            ) && !(
				                isset($var['hide_from_driver']) && $var['hide_from_driver'] == 'yes'
				            )
				        );
				    });
				    foreach ($uploads as $key => $value) {
			            // Type 1 = Copy, 2 = Original
			            $array                                  		= [];
			            $array['sr']                                	= $i;
			            $array['id']                            		= $item->id;
			            $array['source']                        		= 'load_details';
			            $array['field_name']                    		= 'consignee_files_upload';

			            $array['filename']                      		= $value['name'] ?? '';
			            $array['filename_id']                   		= $value['name_id'] ?? '';

			            $array['type']                          		= $value['type'];

			            $array['is_received']                   		= isset($value['is_received']) && $value['is_received'] == 'on' ? 'on' : 'off';
			            $array['file_not_provided']             		= isset($value['file_not_provided']) && $value['file_not_provided'] == 'on' ? 'on' : 'off';

			            $status                                 		= 'Pending';
			            if($array['type'] == 1){
			                $array['file']                      		= $value['file'] ?? null;
			                if(isset($value['file']) && !empty($value['file'])){
			                    $status                         		= 'Complete';
			                    $array['file_not_provided']     		= 'off';
			                    $array['upload_user_type']      		= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
			                    $array['upload_by']             		= isset($value['upload_by']) ? $value['upload_by'] : null;
			                }
			            }else{
			                if($array['is_received'] == 'on'){
			                    $status                         		= 'Complete';
			                    $array['file_not_provided']     		= 'off';
			                    $array['upload_user_type']      		= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
			                    $array['upload_by']             		= isset($value['upload_by']) ? $value['upload_by'] : null;
			                }
			            }
			            $array['status']                        		= $status;

			            $required_documents[]                   		= $array;

			            $i++;
			        }
			    }

			    // Requested Documents
			    if(isset($item->receiver_load_document_request_items)){
			    	$i                                                 	= 1;
		            $receiver_load_document_request_items            	= $item->receiver_load_document_request_items->where('driver_id', auth()->guard('driver-admin')->user()->id);
		            foreach ($receiver_load_document_request_items as $key => $row) {
		                $value                                  		= [];
		                if(isset($row->files) && is_serialized($row->files) && !empty(unserialize($row->files))){
		                    $value                              		= unserialize($row->files);
		                }
			            if(!empty($value)){
			                if(
			                    (
			                        isset($value['name_id']) && $value['name_id'] !== null && $value['is_required'] == 'on' && in_array($value['type'], [1, 2])
			                    ) && !(
			                        isset($value['hide_from_driver']) && $value['hide_from_driver'] == 'yes'
			                    )
			                ){
		                        // Type 1 = Copy, 2 = Original
		                        $array                                 	= [];
		                        $array['sr']                            = $i;
		                        $array['id']                           	= $row->id;
		                        $array['source']                       	= 'load_document_request_items';
		                        $array['field_name']                   	= 'files';

		                        $array['filename']                     	= $value['name'] ?? '';
		                        $array['filename_id']                  	= $value['name_id'] ?? '';

		                        $array['type']                         	= $value['type'];

		                        $array['is_received']                  	= isset($value['is_received']) && $value['is_received'] == 'on' ? 'on' : 'off';
		                        $array['file_not_provided']            	= isset($value['file_not_provided']) && $value['file_not_provided'] == 'on' ? 'on' : 'off';

		                        $status                                	= 'Pending';
		                        if($array['type'] == 1){
		                            $array['file']                     	= $value['file'] ?? null;
		                            if(isset($value['file']) && !empty($value['file'])){
		                                $status                        	= 'Complete';
		                                $array['file_not_provided']    	= 'off';
		                                $array['upload_user_type']     	= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
		                                $array['upload_by']            	= isset($value['upload_by']) ? $value['upload_by'] : null;
		                            }
		                        }else{
		                            if($array['is_received'] == 'on'){
		                                $status                        	= 'Complete';
		                                $array['file_not_provided']    	= 'off';
		                                $array['upload_user_type']     	= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
		                                $array['upload_by']            	= isset($value['upload_by']) ? $value['upload_by'] : null;
		                            }
		                        }
		                        $array['status']                       	= $status;

		                        $requested_documents[]                  = $array;

		                        $i++;
			                }
			            }
			        }
			    }

			    // Accessorial Documents
			    if(isset($item->receiver_accessorials)){
			    	$i                                                 	= 1;
		            $receiver_accessorials                              = $item->receiver_accessorials->where('driver_id', auth()->guard('driver-admin')->user()->id)->where('doc_required', '!=', 0);
		            foreach ($receiver_accessorials as $key => $row) {
		                $gallery                                     	= Gallery::where('company_id', auth()->guard('driver-admin')->user()->company_id)
		                    ->where('action_id', $row->id)
		                    ->where('source', 'load_accessorials')
		                    ->where('field_name', 'accessorial_files')
		                    ->first();
		                $filename                                     	= $row->company_accessorial->name;
		                $hide_from_driver                             	= 'no';
		                if(!is_null($gallery)){
		                    if(isset($gallery->hide_from_driver) && $gallery->hide_from_driver == 'yes'){
		                        $hide_from_driver                     	= 'yes';
		                    }
		                    // $filename                          		.= isset($gallery->file_name) ? ' - '.$gallery->file_name : '';
		                }
		                if($hide_from_driver == 'no'){
		                    // Type 1 = Copy, 2 = Original
		                    $array                                    	= [];
		                    $array['sr']                                = $i;
		                    $array['id']                              	= $row->id;
		                    $array['source']                          	= 'load_accessorials';
		                    $array['field_name']                      	= 'image';

		                    $array['filename']                        	= $filename;
		                    // $array['filename_id']                  	= 0;

		                    $array['type']                            	= 1;

		                    $array['is_received']                     	= 'off';
		                    $array['file_not_provided']               	= isset($row->file_not_provided) && $row->file_not_provided == 'on' ? 'on' : 'off';

		                    $status                                   	= 'Pending';
		                    $array['file']                            	= $gallery->image ?? null;
		                    if(isset($gallery->image) && !empty($gallery->image)){
		                        $status                               	= 'Complete';
		                        $array['is_received']                 	= 'on';
		                        $array['file_not_provided']           	= 'off';
		                        $array['upload_user_type']            	= isset($gallery->created_by_type) ? $gallery->created_by_type : null;
		                        $array['upload_by']                   	= isset($gallery->created_by) ? $gallery->created_by : null;
		                    }
		                    $array['status']                          	= $status;

		                    $accessorial_documents[]                  	= $array;

		                    $i++;
		                }
			        }
			    }
			}
		}else{
			$stop_required_field_name   								= $item->customer_type == '1' ? 'stop_shipper_files_upload' : 'stop_consignee_files_upload';

		    // Required Documents
			if(isset($item->$stop_required_field_name) && is_serialized($item->$stop_required_field_name) && !empty(unserialize($item->$stop_required_field_name))){
				$i                                                 		= 1;
			    $uploads                              					= unserialize($item->$stop_required_field_name);
			    $uploads                                 				= array_filter($uploads, function ($var) {
			        return (
			            (
			                isset($var['name_id']) && $var['name_id'] !== null && $var['is_required'] == 'on' && in_array($var['type'], [1, 2])
			            ) && !(
			                isset($var['hide_from_driver']) && $var['hide_from_driver'] == 'yes'
			            )
			        );
			    });
			    foreach ($uploads as $key => $value) {
		            // Type 1 = Copy, 2 = Original
		            $array                                  			= [];
		            $array['sr']                                		= $i;
		            $array['id']                            			= $item->id;
		            $array['source']                        			= 'load_stops';
		            $array['field_name']                    			= $stop_required_field_name;

		            $array['filename']                      			= $value['name'] ?? '';
		            $array['filename_id']                   			= $value['name_id'] ?? '';

		            $array['type']                          			= $value['type'];

		            $array['is_received']                   			= isset($value['is_received']) && $value['is_received'] == 'on' ? 'on' : 'off';
		            $array['file_not_provided']             			= isset($value['file_not_provided']) && $value['file_not_provided'] == 'on' ? 'on' : 'off';

		            $status                                 			= 'Pending';
		            if($array['type'] == 1){
		                $array['file']                      			= $value['file'] ?? null;
		                if(isset($value['file']) && !empty($value['file'])){
		                    $status                         			= 'Complete';
		                    $array['file_not_provided']     			= 'off';
		                    $array['upload_user_type']      			= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
		                    $array['upload_by']             			= isset($value['upload_by']) ? $value['upload_by'] : null;
		                }
		            }else{
		                if($array['is_received'] == 'on'){
		                    $status                         			= 'Complete';
		                    $array['file_not_provided']     			= 'off';
		                    $array['upload_user_type']      			= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
		                    $array['upload_by']             			= isset($value['upload_by']) ? $value['upload_by'] : null;
		                }
		            }
		            $array['status']                        			= $status;

		            $required_documents[]                   			= $array;

		            $i++;
		        }
		    }

		    // Requested Documents
		    if(isset($item->load_document_request_items)){
		    	$i                                                 		= 1;
	            $stop_load_document_request_items            			= $item->load_document_request_items->where('driver_id', auth()->guard('driver-admin')->user()->id);
	            foreach ($stop_load_document_request_items as $key => $row) {
	                $value                                  			= [];
	                if(isset($row->files) && is_serialized($row->files) && !empty(unserialize($row->files))){
	                    $value                              			= unserialize($row->files);
	                }
		            if(!empty($value)){
		                if(
		                    (
		                        isset($value['name_id']) && $value['name_id'] !== null && $value['is_required'] == 'on' && in_array($value['type'], [1, 2])
		                    ) && !(
		                        isset($value['hide_from_driver']) && $value['hide_from_driver'] == 'yes'
		                    )
		                ){
	                        // Type 1 = Copy, 2 = Original
	                        $array                                    	= [];
	                        $array['sr']                                = $i;
	                        $array['id']                              	= $row->id;
	                        $array['source']                          	= 'load_document_request_items';
	                        $array['field_name']                      	= 'files';

	                        $array['filename']                        	= $value['name'] ?? '';
	                        $array['filename_id']                     	= $value['name_id'] ?? '';

	                        $array['type']                            	= $value['type'];

	                        $array['is_received']                     	= isset($value['is_received']) && $value['is_received'] == 'on' ? 'on' : 'off';
	                        $array['file_not_provided']               	= isset($value['file_not_provided']) && $value['file_not_provided'] == 'on' ? 'on' : 'off';

	                        $status                                   	= 'Pending';
	                        if($array['type'] == 1){
	                            $array['file']                        	= $value['file'] ?? null;
	                            if(isset($value['file']) && !empty($value['file'])){
	                                $status                           	= 'Complete';
	                                $array['file_not_provided']       	= 'off';
	                                $array['upload_user_type']        	= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
	                                $array['upload_by']               	= isset($value['upload_by']) ? $value['upload_by'] : null;
	                            }
	                        }else{
	                            if($array['is_received'] == 'on'){
	                                $status                           	= 'Complete';
	                                $array['file_not_provided']       	= 'off';
	                                $array['upload_user_type']        	= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
	                                $array['upload_by']               	= isset($value['upload_by']) ? $value['upload_by'] : null;
	                            }
	                        }
	                        $array['status']                          	= $status;

	                        $requested_documents[]                  	= $array;

	                        $i++;
		                }
		            }
		        }
		    }

		    // Accessorial Documents
		    if(isset($item->accessorials)){
		    	$i                                                 		= 1;
	            $stop_accessorials                                  	= $item->accessorials->where('driver_id', auth()->guard('driver-admin')->user()->id)->where('doc_required', '!=', 0);
	            foreach ($stop_accessorials as $key => $row) {
	                $gallery                                         	= Gallery::where('company_id', auth()->guard('driver-admin')->user()->company_id)
	                    ->where('action_id', $row->id)
	                    ->where('source', 'load_accessorials')
	                    ->where('field_name', 'accessorial_files')
	                    ->first();
	                $filename                                        	= $row->company_accessorial->name;
	                $hide_from_driver                                	= 'no';
	                if(!is_null($gallery)){
	                    if(isset($gallery->hide_from_driver) && $gallery->hide_from_driver == 'yes'){
	                        $hide_from_driver                        	= 'yes';
	                    }
	                    // $filename                               		.= isset($gallery->file_name) ? ' - '.$gallery->file_name : '';
	                }
	                if($hide_from_driver == 'no'){
	                    // Type 1 = Copy, 2 = Original
	                    $array                                        	= [];
	                    $array['sr']                                	= $i;
	                    $array['id']                                  	= $row->id;
	                    $array['source']                              	= 'load_accessorials';
	                    $array['field_name']                          	= 'image';

	                    $array['filename']                            	= $filename;
	                    // $array['filename_id']                      	= 0;

	                    $array['type']                                	= 1;

	                    $array['is_received']                         	= 'off';
	                    $array['file_not_provided']                   	= isset($row->file_not_provided) && $row->file_not_provided == 'on' ? 'on' : 'off';

	                    $status                                       	= 'Pending';
	                    $array['file']                                	= $gallery->image ?? null;
	                    if(isset($gallery->image) && !empty($gallery->image)){
	                        $status                                   	= 'Complete';
	                        $array['is_received']                     	= 'on';
	                        $array['file_not_provided']               	= 'off';
	                        $array['upload_user_type']                	= isset($gallery->created_by_type) ? $gallery->created_by_type : null;
	                        $array['upload_by']                       	= isset($gallery->created_by) ? $gallery->created_by : null;
	                    }
	                    $array['status']                              	= $status;

	                    $accessorial_documents[]                    	= $array;

	                    $i++;
	                }
		        }
		    }
		}

		$merged_documents 												= [];
		// Check if $required_documents is not empty before merging
		if (!empty($required_documents)) {
		    $merged_documents 											= array_merge($merged_documents, $required_documents);
		}
		// Check if $requested_documents is not empty before merging
		if (!empty($requested_documents)) {
		    $merged_documents 											= array_merge($merged_documents, $requested_documents);
		}
		// Check if $accessorial_documents is not empty before merging
		if (!empty($accessorial_documents)) {
		    $merged_documents 											= array_merge($merged_documents, $accessorial_documents);
		}

		return [
			'merged_documents' 		=> $merged_documents,
			'required_documents' 	=> $required_documents,
			'requested_documents' 	=> $requested_documents,
			'accessorial_documents' => $accessorial_documents
		];
	}

	public function getAllStopdDocuments($load_detail){
		$array 															= [];
		$array[1] 														= $this->getStopdDocuments($load_detail, 1);
		$stop_no                                                    	= 2;
		if(isset($load_detail->loads->load_stops) && $load_detail->loads->load_stops->isNotEmpty()){
			foreach ($load_detail->loads->load_stops as $key => $stop) {
				$array[$stop_no] 										= $this->getStopdDocuments($stop);
				++$stop_no;
			}
		}
		$array[99] 														= $this->getStopdDocuments($load_detail, 2);
		return $array;
	}

	public function getLoadDocuments($load_detail){
		// Static Documents
		$static_documents                                               = [];
		// Required Documents
		$required_documents  											= [];
		// Requested Documents
		$requested_documents                                            = [];
		// Accessorial Documents
		$accessorial_documents                                          = [];
		// Other Documents
		$other_documents                                                = [];
		// COD Documents
		$cod_documents                                                  = [];

		// Static Documents
		$user 															= auth()->guard('driver-admin')->user();
		if(isset($user->allow_see_invoices) && $user->allow_see_invoices == 1){
			if(isset($load_detail->invoice_files) && is_serialized($load_detail->invoice_files) && !empty(unserialize($load_detail->invoice_files))){
				$value                                                  = unserialize($load_detail->invoice_files);
				if(!empty($value)){
					if(
						!(
							isset($value['hide_from_driver']) && $value['hide_from_driver'] == 'yes'
						)
					){
						// Type 1 = Copy, 2 = Original
						$array                                          = [];
						$array['id']                                    = $load_detail->id;
						$array['source']                                = 'load_details';
						$array['field_name']                            = 'invoice_files';

						$array['filename']                              = 'Invoice';
						// $array['filename_id']                    	= 0;

						$array['type']                               	= 1;
						$array['is_received']                         	= 'off';

						$status                                     	= 'Pending';
						$array['file']                           		= $value['file'] ?? null;
						if(isset($value['file']) && !empty($value['file'])){
						    $status                                     = 'Complete';
						    $array['is_received']                    	= 'on';
						    $array['upload_user_type']                  = isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
						    $array['upload_by']                      	= isset($value['upload_by']) ? $value['upload_by'] : null;
						    if(isset($array['upload_user_type']) && isset($array['upload_by'])){
						    	$array['uploaded_by']               	= getUserByType($value['upload_by'], $value['upload_user_type']);
						    }else{
						    	$array['uploaded_by']               	= null;
						    }
						    $array['uploaded_at']                       = isset($value['uploaded_at']) ? Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null;
						}
						$array['status']                            	= $status;

						// Extra Info
						$array['stop']                              	= [
							'name' 										=> 'Load'
						];

						$static_documents[]                          	= $array;
					}
				}
			}else{
				// Type 1 = Copy, 2 = Original
				$array                                                  = [];
				$array['id']                                            = $load_detail->id;
				$array['source']                                        = 'load_details';
				$array['field_name']                                    = 'invoice_files';

				$array['filename']                                      = 'Invoice';
				// $array['filename_id']                            	= 0;

				$array['type']                               			= 1;
				$array['is_received']                         			= 'off';

				$array['file']                                          = null;
				$array['status']                                        = 'Pending';

				// Extra Info
				$array['stop']                                      	= [
					'name' 												=> 'Load'
				];

				$static_documents[]                                 	= $array;
			}
		}

		if(isset($user->allow_see_rate_confirmations) && $user->allow_see_rate_confirmations == 1){
			if(isset($load_detail->rate_confirmation_files) && is_serialized($load_detail->rate_confirmation_files) && !empty(unserialize($load_detail->rate_confirmation_files))){
				$value                                                  = unserialize($load_detail->invoice_files);
				if(!empty($value)){
					if(
						!(
							isset($value['hide_from_driver']) && $value['hide_from_driver'] == 'yes'
						)
					){
						// Type 1 = Copy, 2 = Original
						$array                                          = [];
						$array['id']                                    = $load_detail->id;
						$array['source']                                = 'load_details';
						$array['field_name']                            = 'rate_confirmation_files';

						$array['filename']                              = 'Rate Confirmation';
						// $array['filename_id']                   		= 0;

						$array['type']                               	= 1;
						$array['is_received']                         	= 'off';

						$status                                     	= 'Pending';
						$array['file']                           		= $value['file'] ?? null;
						if(isset($value['file']) && !empty($value['file'])){
						    $status                                     = 'Complete';
						    $array['is_received']                     	= 'on';
						    $array['upload_user_type']                  = isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
						    $array['upload_by']                      	= isset($value['upload_by']) ? $value['upload_by'] : null;
						    if(isset($array['upload_user_type']) && isset($array['upload_by'])){
						    	$array['uploaded_by']                	= getUserByType($value['upload_by'], $value['upload_user_type']);
						    }else{
						    	$array['uploaded_by']                	= null;
						    }
						    $array['uploaded_at']                       = isset($value['uploaded_at']) ? Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null;
						}
						$array['status']                            	= $status;

						// Extra Info
						$array['stop']                            		= [
							'name' 										=> 'Load'
						];

						$static_documents[]                          	= $array;
					}
				}
			}else{
				// Type 1 = Copy, 2 = Original
				$array                                                  = [];
				$array['id']                                            = $load_detail->id;
				$array['source']                                        = 'load_details';
				$array['field_name']                                    = 'rate_confirmation_files';

				$array['filename']                                      = 'Rate Confirmation';
				// $array['filename_id']                            	= 0;

				$array['type']                               			= 1;
				$array['is_received']                         			= 'off';

				$array['file']                                          = null;
				$array['status']                                        = 'Pending';

				// Extra Info
				$array['stop']                                      	= [
					'name' 												=> 'Load'
				];

				$static_documents[]                                 	= $array;
			}
		}

		// Required Documents
		if(isset($load_detail->shipper_files_upload) && is_serialized($load_detail->shipper_files_upload) && !empty(unserialize($load_detail->shipper_files_upload))){
			$uploads         											= unserialize($load_detail->shipper_files_upload);
			$uploads          											= array_filter($uploads, function ($var) {
			    return (
			    	(
			    		isset($var['name_id']) && $var['name_id'] !== null && $var['is_required'] == 'on' && in_array($var['type'], [1, 2])
			    	) && !(
			    		isset($var['hide_from_driver']) && $var['hide_from_driver'] == 'yes'
			    	)
			    );
			});
			foreach ($uploads as $key => $value) {
				// Type 1 = Copy, 2 = Original
				$array                                              	= [];
				$array['id']                                        	= $load_detail->id;
				$array['source']                                    	= 'load_details';
				$array['field_name']                                	= 'shipper_files_upload';

				$array['filename']                                  	= $value['name'] ?? '';
				$array['filename_id']                               	= $value['name_id'] ?? '';

				$array['type']                               			= $value['type'];
				$array['is_received']                         			= isset($value['is_received']) && $value['is_received'] == 'on' ? 'on' : 'off';

				$status                                             	= 'Pending';
				if($array['type'] == 1){
					$array['file']                           			= $value['file'] ?? null;
					if(isset($value['file']) && !empty($value['file'])){
					    $status                                     	= 'Complete';
					    $array['upload_user_type']                  	= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
					    $array['upload_by']                      		= isset($value['upload_by']) ? $value['upload_by'] : null;
					    if(isset($array['upload_user_type']) && isset($array['upload_by'])){
					    	$array['uploaded_by']                      	= getUserByType($value['upload_by'], $value['upload_user_type']);
					    }else{
					    	$array['uploaded_by']                      	= null;
					    }
					    $array['uploaded_at']                       	= isset($value['uploaded_at']) ? Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null;
					}
				}else{
					if($array['is_received'] == 'on'){
						$status                                     	= 'Complete';
						$array['upload_user_type']                  	= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
						$array['upload_by']                      		= isset($value['upload_by']) ? $value['upload_by'] : null;
						if(isset($array['upload_user_type']) && isset($array['upload_by'])){
							$array['uploaded_by']                      	= getUserByType($value['upload_by'], $value['upload_user_type']);
						}else{
							$array['uploaded_by']                      	= null;
						}
						$array['uploaded_at']                       	= isset($value['uploaded_at']) ? Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null;
					}
				}
				$array['status']                                    	= $status;

				$addresses          									= [];
				if(isset($load_detail->shipper_address_one) && $load_detail->shipper_address_one!==''){
					$addresses[]   	 									= $load_detail->shipper_address_one;
				}
				if(isset($load_detail->shipper_address_two) && $load_detail->shipper_address_two!==''){
					$addresses[]   	 									= $load_detail->shipper_address_two;
				}
				if(isset($load_detail->shipper_city) && $load_detail->shipper_city!==''){
					$addresses[]   	 									= $load_detail->shipper_city;
				}
				if(isset($load_detail->shipper_state) && $load_detail->shipper_state!==''){
					$addresses[]   	 									= $load_detail->shipper_state;
				}
				if(isset($load_detail->shipper_zip) && $load_detail->shipper_zip!==''){
					$addresses[]   	 									= $load_detail->shipper_zip;
				}
				$addresses         	 									= implode(', ', $addresses);

				$stop_details 											= [];
				$stop_details['name'] 									= 'Stop 1';
				$stop_details['customer_name'] 							= $load_detail->shipper->name ?? '';
				$stop_details['addresses'] 								= $addresses;
				// Extra Info
				$array['stop']                                      	= $stop_details;

				$required_documents[]                             		= $array;
			}
		}
		// Requested Documents
		if(isset($load_detail->shipper_load_document_request_items)){
			$shipper_load_document_request_items 						= $load_detail->shipper_load_document_request_items->where('driver_id', auth()->guard('driver-admin')->user()->id);
		    foreach ($shipper_load_document_request_items as $key => $item) {
		        $value                                              	= [];
		        if(isset($item->files) && is_serialized($item->files) && !empty(unserialize($item->files))){
		            $value                                          	= unserialize($item->files);
		        }
		        if(!empty($value)){
		        	if(
		        		(
		        			isset($value['name_id']) && $value['name_id'] !== null && $value['is_required'] == 'on' && in_array($value['type'], [1, 2])
		        		) && !(
		        			isset($value['hide_from_driver']) && $value['hide_from_driver'] == 'yes'
		        		)
		        	){
		        		// Type 1 = Copy, 2 = Original
		        		$array                                     		= [];
		        		$array['id']                               		= $item->id;
		        		$array['source']                           		= 'load_document_request_items';
		        		$array['field_name']                       		= 'files';

		        		$array['filename']                              = $value['name'] ?? '';
		        		$array['filename_id']                           = $value['name_id'] ?? '';

		        		$array['type']                               	= $value['type'];
		        		$array['is_received']                         	= isset($value['is_received']) && $value['is_received'] == 'on' ? 'on' : 'off';

		        		$status                                         = 'Pending';
		        		if($array['type'] == 1){
		        			$array['file']                           	= $value['file'] ?? null;
		        			if(isset($value['file']) && !empty($value['file'])){
		        			    $status                            		= 'Complete';
		        			    $array['upload_user_type']              = isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
		        			    $array['upload_by']                    	= isset($value['upload_by']) ? $value['upload_by'] : null;
		        			    if(isset($array['upload_user_type']) && isset($array['upload_by'])){
		        			    	$array['uploaded_by']           	= getUserByType($value['upload_by'], $value['upload_user_type']);
		        			    }else{
		        			    	$array['uploaded_by']              	= null;
		        			    }
		        			    $array['uploaded_at']               	= isset($value['uploaded_at']) ? Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null;
		        			}
		        		}else{
		        			if($array['is_received'] == 'on'){
		        				$status                             	= 'Complete';
		        				$array['upload_user_type']              = isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
		        				$array['upload_by']                    	= isset($value['upload_by']) ? $value['upload_by'] : null;
		        				if(isset($array['upload_user_type']) && isset($array['upload_by'])){
		        					$array['uploaded_by']           	= getUserByType($value['upload_by'], $value['upload_user_type']);
		        				}else{
		        					$array['uploaded_by']              	= null;
		        				}
		        				$array['uploaded_at']               	= isset($value['uploaded_at']) ? Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null;
		        			}
		        		}
		        		$array['status']                             	= $status;

		        		$addresses          							= [];
		        		if(isset($load_detail->shipper_address_one) && $load_detail->shipper_address_one!==''){
		        			$addresses[]   	 							= $load_detail->shipper_address_one;
		        		}
		        		if(isset($load_detail->shipper_address_two) && $load_detail->shipper_address_two!==''){
		        			$addresses[]   	 							= $load_detail->shipper_address_two;
		        		}
		        		if(isset($load_detail->shipper_city) && $load_detail->shipper_city!==''){
		        			$addresses[]   	 							= $load_detail->shipper_city;
		        		}
		        		if(isset($load_detail->shipper_state) && $load_detail->shipper_state!==''){
		        			$addresses[]   	 							= $load_detail->shipper_state;
		        		}
		        		if(isset($load_detail->shipper_zip) && $load_detail->shipper_zip!==''){
		        			$addresses[]   	 							= $load_detail->shipper_zip;
		        		}
		        		$addresses         	 							= implode(', ', $addresses);

		        		$stop_details 									= [];
		        		$stop_details['name'] 							= 'Stop 1';
		        		$stop_details['customer_name'] 					= $load_detail->shipper->name ?? '';
		        		$stop_details['addresses'] 						= $addresses;
		        		// Extra Info
		        		$array['stop']                                  = $stop_details;

		        		$requested_documents[]                          = $array;
		        	}
		        }
		    }
		}
		// Accessorial Documents
		if(isset($load_detail->shipper_accessorials)){
			$shipper_accessorials 										= $load_detail->shipper_accessorials->where('driver_id', auth()->guard('driver-admin')->user()->id)->where('doc_required', '!=', 0);
			foreach ($shipper_accessorials as $key => $item) {
				$gallery                                            	= Gallery::where('company_id', auth()->guard('driver-admin')->user()->company_id)
				    ->where('action_id', $item->id)
				    ->where('source', 'load_accessorials')
				    ->where('field_name', 'accessorial_files')
				    ->first();
				$filename                                           	= $item->company_accessorial->name;
				$hide_from_driver 										= 'no';
				if(!is_null($gallery)){
					if(isset($gallery->hide_from_driver) && $gallery->hide_from_driver == 'yes'){
						$hide_from_driver 								= 'yes';
					}
				    $filename                                      		.= isset($gallery->file_name) ? ' - '.$gallery->file_name : '';
				}
				if($hide_from_driver == 'no'){
					// Type 1 = Copy, 2 = Original
					$array                                             	= [];
					$array['id']                                       	= $item->id;
					$array['source']                                   	= 'load_accessorials';
					$array['field_name']                               	= 'image';

					$array['filename']                              	= $filename;
					// $array['filename_id']                           	= 0;

					$array['type']                               		= 1;
					$array['is_received']                         		= 'off';

					$status                                             = 'Pending';
					$array['file']                           			= $gallery->image ?? null;
					if(isset($gallery->image) && !empty($gallery->image)){
					    $status                                     	= 'Complete';
					    $array['is_received']                         	= 'on';
					    $array['upload_user_type']                  	= isset($gallery->created_by_type) ? $gallery->created_by_type : null;
					    $array['upload_by']                      		= isset($gallery->created_by) ? $gallery->created_by : null;
					    if(isset($gallery->created_by_type) && isset($gallery->created_by)){
					    	$array['uploaded_by']                      	= getUserByType($gallery->created_by, $gallery->created_by_type);
					    }else{
					    	$array['uploaded_by']                      	= null;
					    }
					    $array['uploaded_at']                       	= isset($gallery->created_at) ? Carbon::createFromFormat('Y-m-d H:i:s', $gallery->created_at)->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null; // $gallery->getRawOriginal('uploaded_date')
					}
					$array['status']                                    = $status;

					$addresses          								= [];
					if(isset($load_detail->shipper_address_one) && $load_detail->shipper_address_one!==''){
						$addresses[]   	 								= $load_detail->shipper_address_one;
					}
					if(isset($load_detail->shipper_address_two) && $load_detail->shipper_address_two!==''){
						$addresses[]   	 								= $load_detail->shipper_address_two;
					}
					if(isset($load_detail->shipper_city) && $load_detail->shipper_city!==''){
						$addresses[]   	 								= $load_detail->shipper_city;
					}
					if(isset($load_detail->shipper_state) && $load_detail->shipper_state!==''){
						$addresses[]   	 								= $load_detail->shipper_state;
					}
					if(isset($load_detail->shipper_zip) && $load_detail->shipper_zip!==''){
						$addresses[]   	 								= $load_detail->shipper_zip;
					}
					$addresses         	 								= implode(', ', $addresses);

					$stop_details 										= [];
					$stop_details['name'] 								= 'Stop 1';
					$stop_details['customer_name'] 						= $load_detail->shipper->name ?? '';
					$stop_details['addresses'] 							= $addresses;
					// Extra Info
					$array['stop']                                      = $stop_details;

					$accessorial_documents[]                            = $array;
				}
			}
		}

		$stop_no                                                    	= 2;
		if(isset($load_detail->loads->load_stops) && $load_detail->loads->load_stops->isNotEmpty()){
			foreach ($load_detail->loads->load_stops as $key => $stop) {
				$customer_type                                      	= $stop->customer_type;
				$field_name                                         	= $customer_type=='1'?'stop_shipper_files_upload':'stop_consignee_files_upload';
				// Required Documents
				if(isset($stop->$field_name) && is_serialized($stop->$field_name) && !empty(unserialize($stop->$field_name))){
				    $uploads                                        	= unserialize($stop->$field_name);
				    $uploads          									= array_filter($uploads, function ($var) {
				        return (
				        	(
				        		isset($var['name_id']) && $var['name_id'] !== null && $var['is_required'] == 'on' && in_array($var['type'], [1, 2])
				        	) && !(
				        		isset($var['hide_from_driver']) && $var['hide_from_driver'] == 'yes'
				        	)
				        );
				    });
				    foreach ($uploads as $key => $value) {
				    	// Type 1 = Copy, 2 = Original
				    	$array                                  		= [];
				    	$array['id']                            		= $stop->id;
				    	$array['source']                        		= 'load_stops';
				    	$array['field_name']                    		= $field_name;

				    	$array['filename']                      		= $value['name'] ?? '';
				    	$array['filename_id']                   		= $value['name_id'] ?? '';

				    	$array['type']                           		= $value['type'];
				    	$array['is_received']                    		= isset($value['is_received']) && $value['is_received'] == 'on' ? 'on' : 'off';

				    	$status                                 		= 'Pending';
				    	if($array['type'] == 1){
				    		$array['file']                      		= $value['file'] ?? null;
				    		if(isset($value['file']) && !empty($value['file'])){
				    		    $status                           		= 'Complete';
				    		    $array['upload_user_type']        		= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
				    		    $array['upload_by']                     = isset($value['upload_by']) ? $value['upload_by'] : null;
				    		    if(isset($array['upload_user_type']) && isset($array['upload_by'])){
				    		    	$array['uploaded_by']               = getUserByType($value['upload_by'], $value['upload_user_type']);
				    		    }else{
				    		    	$array['uploaded_by']            	= null;
				    		    }
				    		    $array['uploaded_at']             		= isset($value['uploaded_at']) ? Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null;
				    		}
				    	}else{
				    		if($array['is_received'] == 'on'){
				    			$status                           		= 'Complete';
				    			$array['upload_user_type']        		= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
				    			$array['upload_by']                     = isset($value['upload_by']) ? $value['upload_by'] : null;
				    			if(isset($array['upload_user_type']) && isset($array['upload_by'])){
				    				$array['uploaded_by']               = getUserByType($value['upload_by'], $value['upload_user_type']);
				    			}else{
				    				$array['uploaded_by']            	= null;
				    			}
				    			$array['uploaded_at']             		= isset($value['uploaded_at']) ? Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null;
				    		}
				    	}
				    	$array['status']                          		= $status;

				    	$addresses          							= [];
				    	if(isset($stop->address_one) && $stop->address_one!==''){
				    		$addresses[]   	 							= $stop->address_one;
				    	}
				    	if(isset($stop->address_two) && $stop->address_two!==''){
				    		$addresses[]   	 							= $stop->address_two;
				    	}
				    	if(isset($stop->city) && $stop->city!==''){
				    		$addresses[]   	 							= $stop->city;
				    	}
				    	if(isset($stop->state) && $stop->state!==''){
				    		$addresses[]   	 							= $stop->state;
				    	}
				    	if(isset($stop->zip) && $stop->zip!==''){
				    		$addresses[]   	 							= $stop->zip;
				    	}
				    	$addresses         	 							= implode(', ', $addresses);

				    	$stop_details 									= [];
				    	$stop_details['name'] 							= 'Stop '.$stop_no;
				    	$stop_details['customer_name'] 					= $stop->customer->name ?? '';
				    	$stop_details['addresses'] 						= $addresses;
				    	// Extra Info
				    	$array['stop']                           		= $stop_details;

				    	$required_documents[]                   		= $array;
				    }
				}
				// Requested Documents
				if(isset($stop->load_document_request_items)){
					$stop_load_document_request_items 					= $stop->load_document_request_items->where('driver_id', auth()->guard('driver-admin')->user()->id);
				    foreach ($stop_load_document_request_items as $key => $item) {
				        $value                                      	= [];
				        if(isset($item->files) && is_serialized($item->files) && !empty(unserialize($item->files))){
				            $value                                  	= unserialize($item->files);
				        }
				        if(!empty($value)){
				        	if(
				        		(
				        			isset($value['name_id']) && $value['name_id'] !== null && $value['is_required'] == 'on' && in_array($value['type'], [1, 2])
				        		) && !(
				        			isset($value['hide_from_driver']) && $value['hide_from_driver'] == 'yes'
				        		)
				        	){
				        		// Type 1 = Copy, 2 = Original
				        		$array                                	= [];
				        		$array['id']                          	= $item->id;
				        		$array['source']                      	= 'load_document_request_items';
				        		$array['field_name']                  	= 'files';

				        		$array['filename']                 		= $value['name'] ?? '';
				        		$array['filename_id']               	= $value['name_id'] ?? '';

				        		$array['type']                         	= $value['type'];
				        		$array['is_received']                	= isset($value['is_received']) && $value['is_received'] == 'on' ? 'on' : 'off';

				        		$status                               	= 'Pending';
				        		if($array['type'] == 1){
				        			$array['file']                      = $value['file'] ?? null;
				        			if(isset($value['file']) && !empty($value['file'])){
				        			    $status                       	= 'Complete';
				        			    $array['upload_user_type']     	= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
				        			    $array['upload_by']            	= isset($value['upload_by']) ? $value['upload_by'] : null;
				        			    if(isset($array['upload_user_type']) && isset($array['upload_by'])){
				        			    	$array['uploaded_by']      	= getUserByType($value['upload_by'], $value['upload_user_type']);
				        			    }else{
				        			    	$array['uploaded_by']     	= null;
				        			    }
				        			    $array['uploaded_at']        	= isset($value['uploaded_at']) ? Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null;
				        			}
				        		}else{
				        			if($array['is_received'] == 'on'){
				        				$status                     	= 'Complete';
				        				$array['upload_user_type']     	= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
				        				$array['upload_by']            	= isset($value['upload_by']) ? $value['upload_by'] : null;
				        				if(isset($array['upload_user_type']) && isset($array['upload_by'])){
				        					$array['uploaded_by']      	= getUserByType($value['upload_by'], $value['upload_user_type']);
				        				}else{
				        					$array['uploaded_by']     	= null;
				        				}
				        				$array['uploaded_at']        	= isset($value['uploaded_at']) ? Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null;
				        			}
				        		}
				        		$array['status']                      	= $status;

				        		$addresses          					= [];
				        		if(isset($stop->address_one) && $stop->address_one!==''){
				        			$addresses[]   	 					= $stop->address_one;
				        		}
				        		if(isset($stop->address_two) && $stop->address_two!==''){
				        			$addresses[]   	 					= $stop->address_two;
				        		}
				        		if(isset($stop->city) && $stop->city!==''){
				        			$addresses[]   	 					= $stop->city;
				        		}
				        		if(isset($stop->state) && $stop->state!==''){
				        			$addresses[]   	 					= $stop->state;
				        		}
				        		if(isset($stop->zip) && $stop->zip!==''){
				        			$addresses[]   	 					= $stop->zip;
				        		}
				        		$addresses         	 					= implode(', ', $addresses);

				        		$stop_details 							= [];
				        		$stop_details['name'] 					= 'Stop '.$stop_no;
				        		$stop_details['customer_name'] 			= $stop->customer->name ?? '';
				        		$stop_details['addresses'] 				= $addresses;
				        		// Extra Info
				        		$array['stop']                           = $stop_details;

				        		$requested_documents[]               	= $array;
				        	}
				        }
				    }
				}
				// Accessorial Documents
				if(isset($stop->accessorials)){
					$stop_accessorials 									= $stop->accessorials->where('driver_id', auth()->guard('driver-admin')->user()->id)->where('doc_required', '!=', 0);
					foreach ($stop_accessorials as $key => $item) {
						$gallery                                    	= Gallery::where('company_id', auth()->guard('driver-admin')->user()->company_id)
						    ->where('action_id', $item->id)
						    ->where('source', 'load_accessorials')
						    ->where('field_name', 'accessorial_files')
						    ->first();
						$filename                                    	= $item->company_accessorial->name;
						$hide_from_driver 								= 'no';
						if(!is_null($gallery)){
							if(isset($gallery->hide_from_driver) && $gallery->hide_from_driver == 'yes'){
								$hide_from_driver 						= 'yes';
							}
						    $filename                               	.= isset($gallery->file_name) ? ' - '.$gallery->file_name : '';
						}
						if($hide_from_driver == 'no'){
							// Type 1 = Copy, 2 = Original
							$array                                    	= [];
							$array['id']                              	= $item->id;
							$array['source']                          	= 'load_accessorials';
							$array['field_name']                      	= 'image';

							$array['filename']                     		= $filename;
							// $array['filename_id']                  	= 0;

							$array['type']                           	= 1;
							$array['is_received']                     	= 'off';

							$status                                 	= 'Pending';
							$array['file']                        		= $gallery->image ?? null;
							if(isset($gallery->image) && !empty($gallery->image)){
							    $status                            		= 'Complete';
							    $array['is_received']                	= 'on';
							    $array['upload_user_type']         		= isset($gallery->created_by_type) ? $gallery->created_by_type : null;
							    $array['upload_by']                 	= isset($gallery->created_by) ? $gallery->created_by : null;
							    if(isset($gallery->created_by_type) && isset($gallery->created_by)){
							    	$array['uploaded_by']             	= getUserByType($gallery->created_by, $gallery->created_by_type);
							    }else{
							    	$array['uploaded_by']             	= null;
							    }
							    $array['uploaded_at']              		= isset($gallery->created_at) ? Carbon::createFromFormat('Y-m-d H:i:s', $gallery->created_at)->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null; // $gallery->getRawOriginal('uploaded_date')
							}
							$array['status']                        	= $status;

							$addresses          						= [];
							if(isset($stop->address_one) && $stop->address_one!==''){
								$addresses[]   	 						= $stop->address_one;
							}
							if(isset($stop->address_two) && $stop->address_two!==''){
								$addresses[]   	 						= $stop->address_two;
							}
							if(isset($stop->city) && $stop->city!==''){
								$addresses[]   	 						= $stop->city;
							}
							if(isset($stop->state) && $stop->state!==''){
								$addresses[]   	 						= $stop->state;
							}
							if(isset($stop->zip) && $stop->zip!==''){
								$addresses[]   	 						= $stop->zip;
							}
							$addresses         	 						= implode(', ', $addresses);

							$stop_details 								= [];
							$stop_details['name'] 						= 'Stop '.$stop_no;
							$stop_details['customer_name'] 				= $stop->customer->name ?? '';
							$stop_details['addresses'] 					= $addresses;
							// Extra Info
							$array['stop']                           	= $stop_details;

							$accessorial_documents[]                  	= $array;
						}
					}
				}
				//
				++$stop_no;
			}
		}

		// Required Documents
		if(isset($load_detail->consignee_files_upload) && is_serialized($load_detail->consignee_files_upload) && !empty(unserialize($load_detail->consignee_files_upload))){
			$uploads         											= unserialize($load_detail->consignee_files_upload);
			$uploads          											= array_filter($uploads, function ($var) {
			    return (
			    	(
			    		isset($var['name_id']) && $var['name_id'] !== null && $var['is_required'] == 'on' && in_array($var['type'], [1, 2])
			    	) && !(
			    		isset($var['hide_from_driver']) && $var['hide_from_driver'] == 'yes'
			    	)
			    );
			});
			foreach ($uploads as $key => $value) {
				// Type 1 = Copy, 2 = Original
				$array                                              	= [];
				$array['id']                                        	= $load_detail->id;
				$array['source']                                    	= 'load_details';
				$array['field_name']                                	= 'consignee_files_upload';

				$array['filename']                                  	= $value['name'] ?? '';
				$array['filename_id']                               	= $value['name_id'] ?? '';

				$array['type']                               			= $value['type'];
				$array['is_received']                         			= isset($value['is_received']) && $value['is_received'] == 'on' ? 'on' : 'off';

				$status                                             	= 'Pending';
				if($array['type'] == 1){
					$array['file']                           			= $value['file'] ?? null;
					if(isset($value['file']) && !empty($value['file'])){
					    $status                                     	= 'Complete';
					    $array['upload_user_type']                  	= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
					    $array['upload_by']                     		= isset($value['upload_by']) ? $value['upload_by'] : null;
					    if(isset($array['upload_user_type']) && isset($array['upload_by'])){
					    	$array['uploaded_by']               		= getUserByType($value['upload_by'], $value['upload_user_type']);
					    }else{
					    	$array['uploaded_by']            			= null;
					    }
					    $array['uploaded_at']                       	= isset($value['uploaded_at']) ? Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null;
					}
				}else{
					if($array['is_received'] == 'on'){
						$status                                     	= 'Complete';
						$array['upload_user_type']                  	= isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
						$array['upload_by']                     		= isset($value['upload_by']) ? $value['upload_by'] : null;
						if(isset($array['upload_user_type']) && isset($array['upload_by'])){
							$array['uploaded_by']               		= getUserByType($value['upload_by'], $value['upload_user_type']);
						}else{
							$array['uploaded_by']            			= null;
						}
						$array['uploaded_at']                       	= isset($value['uploaded_at']) ? Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null;
					}
				}
				$array['status']                                    	= $status;

				$addresses          									= [];
				if(isset($load_detail->delivery_address_one) && $load_detail->delivery_address_one!==''){
					$addresses[]   	 									= $load_detail->delivery_address_one;
				}
				if(isset($load_detail->delivery_address_two) && $load_detail->delivery_address_two!==''){
					$addresses[]   	 									= $load_detail->delivery_address_two;
				}
				if(isset($load_detail->delivery_state) && $load_detail->delivery_state!==''){
					$addresses[]   	 									= $load_detail->delivery_state;
				}
				if(isset($load_detail->delivery_city) && $load_detail->delivery_city!==''){
					$addresses[]   	 									= $load_detail->delivery_city;
				}
				if(isset($load_detail->delivery_zip) && $load_detail->delivery_zip!==''){
					$addresses[]   	 									= $load_detail->delivery_zip;
				}
				$addresses         	 									= implode(', ', $addresses);

				$stop_details 											= [];
				$stop_details['name'] 									= 'Stop 99';
				$stop_details['customer_name'] 							= $load_detail->receiver->name ?? '';
				$stop_details['addresses'] 								= $addresses;
				// Extra Info
				$array['stop']                                      	= $stop_details;

				$required_documents[]                             		= $array;
			}
		}
		// Requested Documents
		if(isset($load_detail->receiver_load_document_request_items)){
			$receiver_load_document_request_items 						= $load_detail->receiver_load_document_request_items->where('driver_id', auth()->guard('driver-admin')->user()->id);
		    foreach ($receiver_load_document_request_items as $key => $item) {
		        $value                                              	= [];
		        if(isset($item->files) && is_serialized($item->files) && !empty(unserialize($item->files))){
		            $value                                          	= unserialize($item->files);
		        }
		        if(!empty($value)){
		        	if(
		        		(
		        			isset($value['name_id']) && $value['name_id'] !== null && $value['is_required'] == 'on' && in_array($value['type'], [1, 2])
		        		) && !(
		        			isset($value['hide_from_driver']) && $value['hide_from_driver'] == 'yes'
		        		)
		        	){
		        		// Type 1 = Copy, 2 = Original
		        		$array                                     		= [];
		        		$array['id']                               		= $item->id;
		        		$array['source']                           		= 'load_document_request_items';
		        		$array['field_name']                       		= 'files';

		        		$array['filename']                              = $value['name'] ?? '';
		        		$array['filename_id']                           = $value['name_id'] ?? '';

		        		$array['type']                               	= $value['type'];
		        		$array['is_received']                         	= isset($value['is_received']) && $value['is_received'] == 'on' ? 'on' : 'off';

		        		$status                                         = 'Pending';
		        		if($array['type'] == 1){
		        			$array['file']                           	= $value['file'] ?? null;
		        			if(isset($value['file']) && !empty($value['file'])){
		        			    $status                            		= 'Complete';
		        			    $array['upload_user_type']              = isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
		        			    $array['upload_by']                    	= isset($value['upload_by']) ? $value['upload_by'] : null;
		        			    if(isset($array['upload_user_type']) && isset($array['upload_by'])){
		        			    	$array['uploaded_by']           	= getUserByType($value['upload_by'], $value['upload_user_type']);
		        			    }else{
		        			    	$array['uploaded_by']              	= null;
		        			    }
		        			    $array['uploaded_at']               	= isset($value['uploaded_at']) ? Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null;
		        			}
		        		}else{
		        			if($array['is_received'] == 'on'){
		        				$status                             	= 'Complete';
		        				$array['upload_user_type']              = isset($value['upload_user_type']) ? $value['upload_user_type'] : null;
		        				$array['upload_by']                    	= isset($value['upload_by']) ? $value['upload_by'] : null;
		        				if(isset($array['upload_user_type']) && isset($array['upload_by'])){
		        					$array['uploaded_by']           	= getUserByType($value['upload_by'], $value['upload_user_type']);
		        				}else{
		        					$array['uploaded_by']              	= null;
		        				}
		        				$array['uploaded_at']               	= isset($value['uploaded_at']) ? Carbon::createFromFormat('Y-m-d H:i:s', $value['uploaded_at'])->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null;
		        			}
		        		}
		        		$array['status']                             	= $status;

		        		$addresses          							= [];
		        		if(isset($load_detail->shipper_address_one) && $load_detail->shipper_address_one!==''){
		        			$addresses[]   	 							= $load_detail->shipper_address_one;
		        		}
		        		if(isset($load_detail->shipper_address_two) && $load_detail->shipper_address_two!==''){
		        			$addresses[]   	 							= $load_detail->shipper_address_two;
		        		}
		        		if(isset($load_detail->shipper_city) && $load_detail->shipper_city!==''){
		        			$addresses[]   	 							= $load_detail->shipper_city;
		        		}
		        		if(isset($load_detail->shipper_state) && $load_detail->shipper_state!==''){
		        			$addresses[]   	 							= $load_detail->shipper_state;
		        		}
		        		if(isset($load_detail->shipper_zip) && $load_detail->shipper_zip!==''){
		        			$addresses[]   	 							= $load_detail->shipper_zip;
		        		}
		        		$addresses         	 							= implode(', ', $addresses);

		        		$stop_details 									= [];
		        		$stop_details['name'] 							= 'Stop 1';
		        		$stop_details['customer_name'] 					= $load_detail->shipper->name ?? '';
		        		$stop_details['addresses'] 						= $addresses;
		        		// Extra Info
		        		$array['stop']                                  = $stop_details;

		        		$requested_documents[]                          = $array;
		        	}
		        }
		    }
		}
		// Accessorial Documents
		if(isset($load_detail->receiver_accessorials)){
			$receiver_accessorials 										= $load_detail->receiver_accessorials->where('driver_id', auth()->guard('driver-admin')->user()->id)->where('doc_required', '!=', 0);
			foreach ($receiver_accessorials as $key => $item) {
				$gallery                                           		= Gallery::where('company_id', auth()->guard('driver-admin')->user()->company_id)
				    ->where('action_id', $item->id)
				    ->where('source', 'load_accessorials')
				    ->where('field_name', 'accessorial_files')
				    ->first();
				$filename                                           	= $item->company_accessorial->name;
				$hide_from_driver 										= 'no';
				if(!is_null($gallery)){
					if(isset($gallery->hide_from_driver) && $gallery->hide_from_driver == 'yes'){
						$hide_from_driver 								= 'yes';
					}
				    $filename                                      		.= isset($gallery->file_name) ? ' - '.$gallery->file_name : '';
				}
				if($hide_from_driver == 'no'){
					// Type 1 = Copy, 2 = Original
					$array                                             	= [];
					$array['id']                                       	= $item->id;
					$array['source']                                   	= 'load_accessorials';
					$array['field_name']                               	= 'image';

					$array['filename']                              	= $filename;
					// $array['filename_id']                           	= 0;

					$array['type']                               		= 1;
					$array['is_received']                         		= 'off';

					$status                                             = 'Pending';
					$array['file']                           			= $gallery->image ?? null;
					if(isset($gallery->image) && !empty($gallery->image)){
					    $status                                     	= 'Complete';
					    $array['is_received']                         	= 'on';
					    $array['upload_user_type']                  	= isset($gallery->created_by_type) ? $gallery->created_by_type : null;
					    $array['upload_by']                      		= isset($gallery->created_by) ? $gallery->created_by : null;
					    if(isset($gallery->created_by_type) && isset($gallery->created_by)){
					    	$array['uploaded_by']                      	= getUserByType($gallery->created_by, $gallery->created_by_type);
					    }else{
					    	$array['uploaded_by']                      	= null;
					    }
					    $array['uploaded_at']                       	= isset($gallery->created_at) ? Carbon::createFromFormat('Y-m-d H:i:s', $gallery->created_at)->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null; // $gallery->getRawOriginal('uploaded_date')
					}
					$array['status']                                    = $status;

					$addresses          								= [];
					if(isset($load_detail->delivery_address_one) && $load_detail->delivery_address_one!==''){
						$addresses[]   	 								= $load_detail->delivery_address_one;
					}
					if(isset($load_detail->delivery_address_two) && $load_detail->delivery_address_two!==''){
						$addresses[]   	 								= $load_detail->delivery_address_two;
					}
					if(isset($load_detail->delivery_state) && $load_detail->delivery_state!==''){
						$addresses[]   	 								= $load_detail->delivery_state;
					}
					if(isset($load_detail->delivery_city) && $load_detail->delivery_city!==''){
						$addresses[]   	 								= $load_detail->delivery_city;
					}
					if(isset($load_detail->delivery_zip) && $load_detail->delivery_zip!==''){
						$addresses[]   	 								= $load_detail->delivery_zip;
					}
					$addresses         	 								= implode(', ', $addresses);

					$stop_details 										= [];
					$stop_details['name'] 								= 'Stop 99';
					$stop_details['customer_name'] 						= $load_detail->receiver->name ?? '';
					$stop_details['addresses'] 							= $addresses;
					// Extra Info
					$array['stop']                                      = $stop_details;

					$accessorial_documents[]                            = $array;
				}
			}
		}

		// Accessorial Documents
		if(isset($load_detail->billing_accessorials)){
			$billing_accessorials 										= $load_detail->billing_accessorials->where('driver_id', auth()->guard('driver-admin')->user()->id)->where('doc_required', '!=', 0);
			foreach ($billing_accessorials as $key => $item) {
				$gallery                                           		= Gallery::where('company_id', auth()->guard('driver-admin')->user()->company_id)
				    ->where('action_id', $item->id)
				    ->where('source', 'load_accessorials')
				    ->where('field_name', 'accessorial_files')
				    ->first();
				$filename                                           	= $item->company_accessorial->name;
				$hide_from_driver 										= 'no';
				if(!is_null($gallery)){
					if(isset($gallery->hide_from_driver) && $gallery->hide_from_driver == 'yes'){
						$hide_from_driver 								= 'yes';
					}
				    $filename                                      		.= isset($gallery->file_name) ? ' - '.$gallery->file_name : '';
				}
				if($hide_from_driver == 'no'){
					// Type 1 = Copy, 2 = Original
					$array                                             	= [];
					$array['id']                                       	= $item->id;
					$array['source']                                   	= 'load_accessorials';
					$array['field_name']                               	= 'image';

					$array['filename']                              	= $filename;
					// $array['filename_id']                           	= 0;

					$array['type']                               		= 1;
					$array['is_received']                         		= 'off';

					$status                                             = 'Pending';
					$array['file']                           			= $gallery->image ?? null;
					if(isset($gallery->image) && !empty($gallery->image)){
					    $status                                     	= 'Complete';
					    $array['is_received']                         	= 'on';
					    $array['upload_user_type']                  	= isset($gallery->created_by_type) ? $gallery->created_by_type : null;
					    $array['upload_by']                      		= isset($gallery->created_by) ? $gallery->created_by : null;
					    if(isset($gallery->created_by_type) && isset($gallery->created_by)){
					    	$array['uploaded_by']                      	= getUserByType($gallery->created_by, $gallery->created_by_type);
					    }else{
					    	$array['uploaded_by']                      	= null;
					    }
					    $array['uploaded_at']                       	= isset($gallery->created_at) ? Carbon::createFromFormat('Y-m-d H:i:s', $gallery->created_at)->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null; // $gallery->getRawOriginal('uploaded_date')
					}
					$array['status']                                    = $status;

					// Extra Info
					$array['stop']                                      = [
						'name' 											=> 'Load'
					];

					$accessorial_documents[]                            = $array;
				}
			}
		}

		// Other Documents
		$get_other_documents                                         	= LoadFile::where('load_id', $load_detail->load_id)
			->where('hide_from_driver', '!=', 'yes')
			->orderBy('id','desc')->get();
		if($get_other_documents->isNotEmpty()){
			foreach ($get_other_documents as $key => $other_document) {
				// Type 1 = Copy, 2 = Original
			    $array                                          		= [];
			    $array['id']                                    		= $other_document->id;
			    $array['source']                                		= 'load_files';
			    $array['field_name']                            		= 'document';

			    $array['filename']                              		= $other_document->company_load_document->name ?? $other_document->filename;
			    // $array['filename_id']                            	= 0;

			    $array['type']                               			= 1;
			    $array['is_received']                         			= 'off';

			    $status                                             	= 'Pending';
			    $array['file']                           				= isset($other_document->document) && is_serialized($other_document->document) && !empty(unserialize($other_document->document)) ? unserialize($other_document->document) : null;
			    if(isset($array['file']) && !empty($array['file'])){
			    	$upload_user_type 									= null;
			    	if(isset($other_document->upload_user_type) && $other_document->upload_user_type == 'Company Admin'){
			    		$upload_user_type 								= $other_document->company_admin->type;
			    	}elseif(isset($other_document->upload_user_type) && $other_document->upload_user_type == 'Driver'){
			    		$upload_user_type 								= 3;
			    	}

			        $status                                     		= 'Complete';
			        $array['is_received']                         		= 'on';
			        $array['upload_user_type']                  		= $upload_user_type;
			        $array['upload_by']                      			= isset($other_document->upload_by) ? $other_document->upload_by : null;
			        if(isset($upload_user_type) && isset($other_document->upload_by)){
			        	$array['uploaded_by']                      		= getUserByType($other_document->upload_by, $upload_user_type);
			        }else{
			        	$array['uploaded_by']                      		= null;
			        }
			        $array['uploaded_at']                       		= isset($other_document->updated_at) ? Carbon::createFromFormat('Y-m-d H:i:s', $other_document->updated_at)->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null;
			    }
			    $array['status']                                    	= $status;

			    // Extra Info
			    $array['stop']                                     		= [
			    	'name' 												=> 'Load'
			    ];

			    $other_documents[]                                		= $array;
			}
		}

		// COD Documents
		$get_cod_documents                                      		= Gallery::where('company_id', auth()->guard('driver-admin')->user()->company_id)
		    ->where('action_id', $load_detail->load_id)
		    ->where('source', 'load')
		    ->whereIn('field_name', ['up_front_file', 'at_pickup_file', 'at_delivery_file'])
		    ->get();
		if($get_cod_documents->isNotEmpty()){
		    foreach ($get_cod_documents as $key => $cod_document) {
		        if(isset($cod_document->image) && $cod_document->image!=''){
		        	// Type 1 = Copy, 2 = Original
		            $array                                          	= [];
		            $array['id']                                    	= $cod_document->id;
		            $array['source']                                	= 'load_cod_galleries';
		            $array['field_name']                            	= 'image';

		            $array['filename']                              	= $cod_document->file_name;
		            // $array['filename_id']                            = 0;

		            $array['type']                               		= 1;
		            $array['is_received']                         		= 'off';

		            $status                                             = 'Pending';
		            $array['file']                           			= $cod_document->image ?? null;
		            if(isset($cod_document->image) && !empty($cod_document->image)){
		                $status                                     	= 'Complete';
		                $array['is_received']                         	= 'on';
		                $array['upload_user_type']                  	= isset($cod_document->created_by_type) ? $cod_document->created_by_type : null;
		                $array['upload_by']                      		= isset($cod_document->created_by) ? $cod_document->created_by : null;
		                if(isset($cod_document->created_by_type) && isset($cod_document->created_by)){
		                	$array['uploaded_by']                      	= getUserByType($cod_document->created_by, $cod_document->created_by_type);
		                }else{
		                	$array['uploaded_by']                      	= null;
		                }
		                $array['uploaded_at']                       	= isset($cod_document->created_at) ? Carbon::createFromFormat('Y-m-d H:i:s', $cod_document->created_at)->setTimezone($this->timeZone)->format(getTimeLayout())." ".$this->timeZoneId : null; // $gallery->getRawOriginal('uploaded_date')
		            }
		            $array['status']                                    = $status;

		            // Extra Info
		            $array['stop']                                     	= [
		            	'name' 											=> 'COD'
		            ];

		            $cod_documents[]                                    = $array;
		        }
		    }
		}

		$merged_documents 												= [];
		// Check if $static_documents is not empty before merging
		if (!empty($static_documents)) {
		    $merged_documents 											= array_merge($merged_documents, $static_documents);
		}
		// Check if $required_documents is not empty before merging
		if (!empty($required_documents)) {
		    $merged_documents 											= array_merge($merged_documents, $required_documents);
		}
		// Check if $requested_documents is not empty before merging
		if (!empty($requested_documents)) {
		    $merged_documents 											= array_merge($merged_documents, $requested_documents);
		}
		// Check if $accessorial_documents is not empty before merging
		if (!empty($accessorial_documents)) {
		    $merged_documents 											= array_merge($merged_documents, $accessorial_documents);
		}
		// Check if $other_documents is not empty before merging
		if (!empty($other_documents)) {
		    $merged_documents 											= array_merge($merged_documents, $other_documents);
		}
		// Check if $cod_documents is not empty before merging
		if (!empty($cod_documents)) {
		    $merged_documents 											= array_merge($merged_documents, $cod_documents);
		}
		// If you want to reindex the merged array
		$merged_documents 												= array_values($merged_documents);

		return [
			'merged_documents' 		=> $merged_documents,
			'static_documents' 		=> $static_documents,
			'required_documents' 	=> $required_documents,
			'requested_documents' 	=> $requested_documents,
			'accessorial_documents' => $accessorial_documents,
			'other_documents' 		=> $other_documents,
			'cod_documents' 		=> $cod_documents,
		];
	}
}
